@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,7 +27,7 @@
  * ---------------
  * JFreeChart.java
  * ---------------
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   Andrzej Porebski;
@@ -36,6 +36,7 @@
  *                   Christian W. Zuckschwerdt;
  *                   Klaus Rheinwald;
  *                   Nicolas Brodu;
+ *                   Peter Kolb (patch 2603321);
  *
  * NOTE: The above list of contributors lists only the people that have
  * contributed to this source file (JFreeChart.java) - for a list of ALL
@@ -141,6 +142,10 @@
  *               TextTitle) (DG);
  * 23-Apr-2008 : Added new contributor (Diego Pierangeli) (DG);
  * 16-May-2008 : Added new contributor (Michael Siemer) (DG);
+ * 19-Sep-2008 : Check for title visibility (DG);
+ * 18-Dec-2008 : Use ResourceBundleWrapper - see patch 1607918 by
+ *               Jess Thrysoee (DG);
+ * 19-Mar-2009 : Added entity support - see patch 2603321 by Peter Kolb (DG);
  *
  */
 
@@ -183,6 +188,7 @@ import org.jfree.chart.block.LengthConstraintType;
 import org.jfree.chart.block.LineBorder;
 import org.jfree.chart.block.RectangleConstraint;
 import org.jfree.chart.entity.EntityCollection;
+import org.jfree.chart.entity.JFreeChartEntity;
 import org.jfree.chart.event.ChartChangeEvent;
 import org.jfree.chart.event.ChartChangeListener;
 import org.jfree.chart.event.ChartProgressEvent;
@@ -198,6 +204,7 @@ import org.jfree.chart.plot.XYPlot;
 import org.jfree.chart.title.LegendTitle;
 import org.jfree.chart.title.TextTitle;
 import org.jfree.chart.title.Title;
+import org.jfree.chart.util.ResourceBundleWrapper;
 import org.jfree.data.Range;
 import org.jfree.io.SerialUtilities;
 import org.jfree.ui.Align;
@@ -1140,11 +1147,17 @@ public class JFreeChart implements Drawable,
 
         notifyListeners(new ChartProgressEvent(this, this,
                 ChartProgressEvent.DRAWING_STARTED, 0));
-
+        
+        EntityCollection entities = null;
         // record the chart area, if info is requested...
         if (info != null) {
             info.clear();
             info.setChartArea(chartArea);
+            entities = info.getEntityCollection();
+        }
+        if (entities != null) {
+        	entities.add(new JFreeChartEntity((Rectangle2D) chartArea.clone(),
+                    this));
         }
 
         // ensure no drawing occurs outside chart area...
@@ -1192,10 +1205,6 @@ public class JFreeChart implements Drawable,
         nonTitleArea.setRect(chartArea);
         this.padding.trim(nonTitleArea);
 
-        EntityCollection entities = null;
-        if (info != null) {
-            entities = info.getEntityCollection();
-        }
         if (this.title != null) {
             EntityCollection e = drawTitle(this.title, g2, nonTitleArea,
                     (entities != null));
@@ -1207,10 +1216,12 @@ public class JFreeChart implements Drawable,
         Iterator iterator = this.subtitles.iterator();
         while (iterator.hasNext()) {
             Title currentTitle = (Title) iterator.next();
-            EntityCollection e = drawTitle(currentTitle, g2, nonTitleArea,
-                    (entities != null));
-            if (e != null) {
-                entities.addAll(e);
+            if (currentTitle.isVisible()) {
+                EntityCollection e = drawTitle(currentTitle, g2, nonTitleArea,
+                        (entities != null));
+                if (e != null) {
+                    entities.addAll(e);
+                }
             }
         }
 
@@ -1740,7 +1751,8 @@ class JFreeChartInfo extends ProjectInfo {
         // get a locale-specific resource bundle...
         String baseResourceClass
                 = "org.jfree.chart.resources.JFreeChartResources";
-        ResourceBundle resources = ResourceBundle.getBundle(baseResourceClass);
+        ResourceBundle resources = ResourceBundleWrapper.getBundle(
+                baseResourceClass);
 
         setName(resources.getString("project.name"));
         setVersion(resources.getString("project.version"));
@@ -1770,6 +1782,7 @@ class JFreeChartInfo extends ProjectInfo {
                 new Contributor("Pascal Collet", "-"),
                 new Contributor("Martin Cordova", "-"),
                 new Contributor("Paolo Cova", "-"),
+                new Contributor("Greg Darke", "-"),
                 new Contributor("Mike Duffy", "-"),
                 new Contributor("Don Elliott", "-"),
                 new Contributor("David Forslund", "-"),
@@ -1791,6 +1804,7 @@ class JFreeChartInfo extends ProjectInfo {
                 new Contributor("Xun Kang", "-"),
                 new Contributor("Bill Kelemen", "-"),
                 new Contributor("Norbert Kiesel", "-"),
+                new Contributor("Peter Kolb", "-"),
                 new Contributor("Gideon Krause", "-"),
                 new Contributor("Pierre-Marie Le Biot", "-"),
                 new Contributor("Arnaud Lelievre", "-"),
@@ -1806,6 +1820,7 @@ class JFreeChartInfo extends ProjectInfo {
                 new Contributor("Barak Naveh", "-"),
                 new Contributor("David M. O'Donnell", "-"),
                 new Contributor("Krzysztof Paz", "-"),
+                new Contributor("Eric Penfold", "-"),
                 new Contributor("Tomer Peretz", "-"),
                 new Contributor("Diego Pierangeli", "-"),
                 new Contributor("Xavier Poinsard", "-"),
@@ -1823,6 +1838,7 @@ class JFreeChartInfo extends ProjectInfo {
                 new Contributor("Jean-Luc SCHWAB", "-"),
                 new Contributor("Bryan Scott", "-"),
                 new Contributor("Tobias Selb", "-"),
+                new Contributor("Darshan Shah", "-"),
                 new Contributor("Mofeed Shahin", "-"),
                 new Contributor("Michael Siemer", "-"),
                 new Contributor("Pady Srinivasan", "-"),
