@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,10 +27,13 @@
  * ---------
  * Axis.java
  * ---------
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
- * Contributor(s):   Bill Kelemen; Nicolas Brodu
+ * Contributor(s):   Bill Kelemen;
+ *                   Nicolas Brodu;
+ *                   Peter Kolb (patches 1934255 and 2603321);
+ *                   Andrew Mickish (patch 1870189);
  *
  * Changes
  * -------
@@ -76,6 +79,9 @@
  * ------------- JFREECHART 1.0.x ---------------------------------------------
  * 22-Aug-2006 : API doc updates (DG);
  * 06-Jun-2008 : Added setTickLabelInsets(RectangleInsets, boolean) (DG);
+ * 25-Sep-2008 : Added minor tick support, see patch 1934255 by Peter Kolb (DG);
+ * 26-Sep-2008 : Added fireChangeEvent() method (DG);
+ * 19-Mar-2009 : Added entity support - see patch 2603321 by Peter Kolb (DG);
  *
  */
 
@@ -102,6 +108,8 @@ import java.util.List;
 
 import javax.swing.event.EventListenerList;
 
+import org.jfree.chart.entity.AxisEntity;
+import org.jfree.chart.entity.EntityCollection;
 import org.jfree.chart.event.AxisChangeEvent;
 import org.jfree.chart.event.AxisChangeListener;
 import org.jfree.chart.plot.Plot;
@@ -128,8 +136,8 @@ public abstract class Axis implements Cloneable, Serializable {
     public static final boolean DEFAULT_AXIS_VISIBLE = true;
 
     /** The default axis label font. */
-    public static final Font DEFAULT_AXIS_LABEL_FONT
-            = new Font("SansSerif", Font.PLAIN, 12);
+    public static final Font DEFAULT_AXIS_LABEL_FONT = new Font(
+            "SansSerif", Font.PLAIN, 12);
 
     /** The default axis label paint. */
     public static final Paint DEFAULT_AXIS_LABEL_PAINT = Color.black;
@@ -148,8 +156,8 @@ public abstract class Axis implements Cloneable, Serializable {
     public static final boolean DEFAULT_TICK_LABELS_VISIBLE = true;
 
     /** The default tick label font. */
-    public static final Font DEFAULT_TICK_LABEL_FONT
-            = new Font("SansSerif", Font.PLAIN, 10);
+    public static final Font DEFAULT_TICK_LABEL_FONT = new Font("SansSerif",
+            Font.PLAIN, 10);
 
     /** The default tick label paint. */
     public static final Paint DEFAULT_TICK_LABEL_PAINT = Color.black;
@@ -216,17 +224,45 @@ public abstract class Axis implements Cloneable, Serializable {
     private RectangleInsets tickLabelInsets;
 
     /**
-     * A flag that indicates whether or not tick marks are visible for the
-     * axis.
+     * A flag that indicates whether or not major tick marks are visible for
+     * the axis.
      */
     private boolean tickMarksVisible;
 
-    /** The length of the tick mark inside the data area (zero permitted). */
+    /**
+     * The length of the major tick mark inside the data area (zero
+     * permitted).
+     */
     private float tickMarkInsideLength;
 
-    /** The length of the tick mark outside the data area (zero permitted). */
+    /**
+     * The length of the major tick mark outside the data area (zero
+     * permitted).
+     */
     private float tickMarkOutsideLength;
 
+    /**
+     * A flag that indicates whether or not minor tick marks are visible for the
+     * axis.
+     *
+     * @since 1.0.12
+     */
+    private boolean minorTickMarksVisible;
+
+    /**
+     * The length of the minor tick mark inside the data area (zero permitted).
+     *
+     * @since 1.0.12
+     */
+    private float minorTickMarkInsideLength;
+
+    /**
+     * The length of the minor tick mark outside the data area (zero permitted).
+     *
+     * @since 1.0.12
+     */
+    private float minorTickMarkOutsideLength;
+
     /** The stroke used to draw tick marks. */
     private transient Stroke tickMarkStroke;
 
@@ -274,6 +310,10 @@ public abstract class Axis implements Cloneable, Serializable {
         this.tickMarkInsideLength = DEFAULT_TICK_MARK_INSIDE_LENGTH;
         this.tickMarkOutsideLength = DEFAULT_TICK_MARK_OUTSIDE_LENGTH;
 
+        this.minorTickMarksVisible = false;
+        this.minorTickMarkInsideLength = 0.0f;
+        this.minorTickMarkOutsideLength = 2.0f;
+
         this.plot = null;
 
         this.listenerList = new EventListenerList();
@@ -303,7 +343,7 @@ public abstract class Axis implements Cloneable, Serializable {
     public void setVisible(boolean flag) {
         if (flag != this.visible) {
             this.visible = flag;
-            notifyListeners(new AxisChangeEvent(this));
+            fireChangeEvent();
         }
     }
 
@@ -336,13 +376,13 @@ public abstract class Axis implements Cloneable, Serializable {
         if (existing != null) {
             if (!existing.equals(label)) {
                 this.label = label;
-                notifyListeners(new AxisChangeEvent(this));
+                fireChangeEvent();
             }
         }
         else {
             if (label != null) {
                 this.label = label;
-                notifyListeners(new AxisChangeEvent(this));
+                fireChangeEvent();
             }
         }
 
@@ -373,7 +413,7 @@ public abstract class Axis implements Cloneable, Serializable {
         }
         if (!this.labelFont.equals(font)) {
             this.labelFont = font;
-            notifyListeners(new AxisChangeEvent(this));
+            fireChangeEvent();
         }
     }
 
@@ -401,7 +441,7 @@ public abstract class Axis implements Cloneable, Serializable {
             throw new IllegalArgumentException("Null 'paint' argument.");
         }
         this.labelPaint = paint;
-        notifyListeners(new AxisChangeEvent(this));
+        fireChangeEvent();
     }
 
     /**
@@ -444,7 +484,7 @@ public abstract class Axis implements Cloneable, Serializable {
         if (!insets.equals(this.labelInsets)) {
             this.labelInsets = insets;
             if (notify) {
-                notifyListeners(new AxisChangeEvent(this));
+                fireChangeEvent();
             }
         }
     }
@@ -470,7 +510,7 @@ public abstract class Axis implements Cloneable, Serializable {
      */
     public void setLabelAngle(double angle) {
         this.labelAngle = angle;
-        notifyListeners(new AxisChangeEvent(this));
+        fireChangeEvent();
     }
 
     /**
@@ -498,7 +538,7 @@ public abstract class Axis implements Cloneable, Serializable {
      */
     public void setAxisLineVisible(boolean visible) {
         this.axisLineVisible = visible;
-        notifyListeners(new AxisChangeEvent(this));
+        fireChangeEvent();
     }
 
     /**
@@ -525,7 +565,7 @@ public abstract class Axis implements Cloneable, Serializable {
             throw new IllegalArgumentException("Null 'paint' argument.");
         }
         this.axisLinePaint = paint;
-        notifyListeners(new AxisChangeEvent(this));
+        fireChangeEvent();
     }
 
     /**
@@ -552,7 +592,7 @@ public abstract class Axis implements Cloneable, Serializable {
             throw new IllegalArgumentException("Null 'stroke' argument.");
         }
         this.axisLineStroke = stroke;
-        notifyListeners(new AxisChangeEvent(this));
+        fireChangeEvent();
     }
 
     /**
@@ -583,11 +623,43 @@ public abstract class Axis implements Cloneable, Serializable {
 
         if (flag != this.tickLabelsVisible) {
             this.tickLabelsVisible = flag;
-            notifyListeners(new AxisChangeEvent(this));
+            fireChangeEvent();
         }
 
     }
 
+    /**
+     * Returns the flag that indicates whether or not the minor tick marks are
+     * showing.
+     *
+     * @return The flag that indicates whether or not the minor tick marks are
+     *         showing.
+     *
+     * @see #setMinorTickMarksVisible(boolean)
+     *
+     * @since 1.0.12
+     */
+    public boolean isMinorTickMarksVisible() {
+        return this.minorTickMarksVisible;
+    }
+
+    /**
+     * Sets the flag that indicates whether or not the minor tick marks are showing
+     * and sends an {@link AxisChangeEvent} to all registered listeners.
+     *
+     * @param flag  the flag.
+     *
+     * @see #isMinorTickMarksVisible()
+     *
+     * @since 1.0.12
+     */
+    public void setMinorTickMarksVisible(boolean flag) {
+        if (flag != this.minorTickMarksVisible) {
+            this.minorTickMarksVisible = flag;
+            fireChangeEvent();
+        }
+    }
+
     /**
      * Returns the font used for the tick labels (if showing).
      *
@@ -615,7 +687,7 @@ public abstract class Axis implements Cloneable, Serializable {
 
         if (!this.tickLabelFont.equals(font)) {
             this.tickLabelFont = font;
-            notifyListeners(new AxisChangeEvent(this));
+            fireChangeEvent();
         }
 
     }
@@ -644,7 +716,7 @@ public abstract class Axis implements Cloneable, Serializable {
             throw new IllegalArgumentException("Null 'paint' argument.");
         }
         this.tickLabelPaint = paint;
-        notifyListeners(new AxisChangeEvent(this));
+        fireChangeEvent();
     }
 
     /**
@@ -672,7 +744,7 @@ public abstract class Axis implements Cloneable, Serializable {
         }
         if (!this.tickLabelInsets.equals(insets)) {
             this.tickLabelInsets = insets;
-            notifyListeners(new AxisChangeEvent(this));
+            fireChangeEvent();
         }
     }
 
@@ -700,7 +772,7 @@ public abstract class Axis implements Cloneable, Serializable {
     public void setTickMarksVisible(boolean flag) {
         if (flag != this.tickMarksVisible) {
             this.tickMarksVisible = flag;
-            notifyListeners(new AxisChangeEvent(this));
+            fireChangeEvent();
         }
     }
 
@@ -726,7 +798,7 @@ public abstract class Axis implements Cloneable, Serializable {
      */
     public void setTickMarkInsideLength(float length) {
         this.tickMarkInsideLength = length;
-        notifyListeners(new AxisChangeEvent(this));
+        fireChangeEvent();
     }
 
     /**
@@ -751,7 +823,7 @@ public abstract class Axis implements Cloneable, Serializable {
      */
     public void setTickMarkOutsideLength(float length) {
         this.tickMarkOutsideLength = length;
-        notifyListeners(new AxisChangeEvent(this));
+        fireChangeEvent();
     }
 
     /**
@@ -779,7 +851,7 @@ public abstract class Axis implements Cloneable, Serializable {
         }
         if (!this.tickMarkStroke.equals(stroke)) {
             this.tickMarkStroke = stroke;
-            notifyListeners(new AxisChangeEvent(this));
+            fireChangeEvent();
         }
     }
 
@@ -807,7 +879,65 @@ public abstract class Axis implements Cloneable, Serializable {
             throw new IllegalArgumentException("Null 'paint' argument.");
         }
         this.tickMarkPaint = paint;
-        notifyListeners(new AxisChangeEvent(this));
+        fireChangeEvent();
+    }
+
+    /**
+     * Returns the inside length of the minor tick marks.
+     *
+     * @return The length.
+     *
+     * @see #getMinorTickMarkOutsideLength()
+     * @see #setMinorTickMarkInsideLength(float)
+     *
+     * @since 1.0.12
+     */
+    public float getMinorTickMarkInsideLength() {
+        return this.minorTickMarkInsideLength;
+    }
+
+    /**
+     * Sets the inside length of the minor tick marks and sends
+     * an {@link AxisChangeEvent} to all registered listeners.
+     *
+     * @param length  the new length.
+     *
+     * @see #getMinorTickMarkInsideLength()
+     *
+     * @since 1.0.12
+     */
+    public void setMinorTickMarkInsideLength(float length) {
+        this.minorTickMarkInsideLength = length;
+        fireChangeEvent();
+    }
+
+    /**
+     * Returns the outside length of the minor tick marks.
+     *
+     * @return The length.
+     *
+     * @see #getMinorTickMarkInsideLength()
+     * @see #setMinorTickMarkOutsideLength(float)
+     *
+     * @since 1.0.12
+     */
+    public float getMinorTickMarkOutsideLength() {
+        return this.minorTickMarkOutsideLength;
+    }
+
+    /**
+     * Sets the outside length of the minor tick marks and sends
+     * an {@link AxisChangeEvent} to all registered listeners.
+     *
+     * @param length  the new length.
+     *
+     * @see #getMinorTickMarkInsideLength()
+     *
+     * @since 1.0.12
+     */
+    public void setMinorTickMarkOutsideLength(float length) {
+        this.minorTickMarkOutsideLength = length;
+        fireChangeEvent();
     }
 
     /**
@@ -921,10 +1051,53 @@ public abstract class Axis implements Cloneable, Serializable {
      *
      * @return The list of ticks.
      */
-    public abstract List refreshTicks(Graphics2D g2,
-                                      AxisState state,
-                                      Rectangle2D dataArea,
-                                      RectangleEdge edge);
+    public abstract List refreshTicks(Graphics2D g2, AxisState state,
+            Rectangle2D dataArea, RectangleEdge edge);
+
+    /**
+     * Created an entity for the axis.
+     *
+     * @param cursor  the initial cursor value.
+     * @param state  the axis state after completion of the drawing with a
+     *     possibly updated cursor position.
+     * @param dataArea  the data area.
+     * @param edge  the edge.
+     * @param plotState  the PlotRenderingInfo from which a reference to the
+     *     entity collection can be obtained.
+     *
+     * @since 1.0.13
+     */
+	protected void createAndAddEntity(double cursor, AxisState state,
+            Rectangle2D dataArea, RectangleEdge edge,
+            PlotRenderingInfo plotState){
+
+		if (plotState == null || plotState.getOwner() == null) {
+            return;  // no need to create entity if we can´t save it anyways...
+        }
+		Rectangle2D hotspot = null;
+		if (edge.equals(RectangleEdge.TOP)){
+			hotspot = new Rectangle2D.Double(dataArea.getX(),
+                    state.getCursor(), dataArea.getWidth(),
+                    cursor - state.getCursor());
+		}
+		else if(edge.equals(RectangleEdge.BOTTOM)) {
+			hotspot = new Rectangle2D.Double(dataArea.getX(), cursor,
+                    dataArea.getWidth(), state.getCursor() - cursor);
+		}
+		else if(edge.equals(RectangleEdge.LEFT)) {
+			hotspot = new Rectangle2D.Double(state.getCursor(),
+                    dataArea.getY(), cursor - state.getCursor(),
+                    dataArea.getHeight());
+		}
+		else if(edge.equals(RectangleEdge.RIGHT)){
+			hotspot = new Rectangle2D.Double(cursor, dataArea.getY(),
+                    state.getCursor() - cursor, dataArea.getHeight());
+		}
+		EntityCollection e = plotState.getOwner().getEntityCollection();
+		if (e != null) {
+            e.add(new AxisEntity(hotspot, this));
+        }
+	}
 
     /**
      * Registers an object for notification of changes to the axis.
@@ -969,14 +1142,21 @@ public abstract class Axis implements Cloneable, Serializable {
      * @param event  information about the change to the axis.
      */
     protected void notifyListeners(AxisChangeEvent event) {
-
         Object[] listeners = this.listenerList.getListenerList();
         for (int i = listeners.length - 2; i >= 0; i -= 2) {
             if (listeners[i] == AxisChangeListener.class) {
                 ((AxisChangeListener) listeners[i + 1]).axisChanged(event);
             }
         }
+    }
 
+    /**
+     * Sends an {@link AxisChangeEvent} to all registered listeners.
+     *
+     * @since 1.0.12
+     */
+    protected void fireChangeEvent() {
+        notifyListeners(new AxisChangeEvent(this));
     }
 
     /**
@@ -1025,12 +1205,9 @@ public abstract class Axis implements Cloneable, Serializable {
      *
      * @return Information about the axis.
      */
-    protected AxisState drawLabel(String label,
-                                  Graphics2D g2,
-                                  Rectangle2D plotArea,
-                                  Rectangle2D dataArea,
-                                  RectangleEdge edge,
-                                  AxisState state) {
+    protected AxisState drawLabel(String label, Graphics2D g2,
+            Rectangle2D plotArea, Rectangle2D dataArea, RectangleEdge edge,
+            AxisState state) {
 
         // it is unlikely that 'state' will be null, but check anyway...
         if (state == null) {
@@ -1049,7 +1226,6 @@ public abstract class Axis implements Cloneable, Serializable {
         Rectangle2D labelBounds = TextUtilities.getTextBounds(label, g2, fm);
 
         if (edge == RectangleEdge.TOP) {
-
             AffineTransform t = AffineTransform.getRotateInstance(
                     getLabelAngle(), labelBounds.getCenterX(),
                     labelBounds.getCenterY());
@@ -1063,10 +1239,8 @@ public abstract class Axis implements Cloneable, Serializable {
                     TextAnchor.CENTER);
             state.cursorUp(insets.getTop() + labelBounds.getHeight()
                     + insets.getBottom());
-
         }
         else if (edge == RectangleEdge.BOTTOM) {
-
             AffineTransform t = AffineTransform.getRotateInstance(
                     getLabelAngle(), labelBounds.getCenterX(),
                     labelBounds.getCenterY());
@@ -1080,10 +1254,8 @@ public abstract class Axis implements Cloneable, Serializable {
                     TextAnchor.CENTER);
             state.cursorDown(insets.getTop() + labelBounds.getHeight()
                     + insets.getBottom());
-
         }
         else if (edge == RectangleEdge.LEFT) {
-
             AffineTransform t = AffineTransform.getRotateInstance(
                     getLabelAngle() - Math.PI / 2.0, labelBounds.getCenterX(),
                     labelBounds.getCenterY());
@@ -1241,6 +1413,15 @@ public abstract class Axis implements Cloneable, Serializable {
         if (!ObjectUtilities.equal(this.tickMarkStroke, that.tickMarkStroke)) {
             return false;
         }
+        if (this.minorTickMarksVisible != that.minorTickMarksVisible) {
+            return false;
+        }
+        if (this.minorTickMarkInsideLength != that.minorTickMarkInsideLength) {
+            return false;
+        }
+        if (this.minorTickMarkOutsideLength != that.minorTickMarkOutsideLength) {
+            return false;
+        }
         if (this.fixedDimension != that.fixedDimension) {
             return false;
         }
