@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,10 +27,11 @@
  * -----------------
  * CategoryAxis.java
  * -----------------
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Original Author:  David Gilbert;
  * Contributor(s):   Pady Srinivasan (patch 1217634);
+ *                   Peter Kolb (patches 2497611 and 2603321);
  *
  * Changes
  * -------
@@ -86,6 +87,12 @@
  *               equalPaintMaps() method (DG);
  * 23-Apr-2008 : Fixed bug 1942059, bad use of insets in
  *               calculateTextBlockWidth() (DG);
+ * 26-Jun-2008 : Added new getCategoryMiddle() method (DG);
+ * 27-Oct-2008 : Set font on Graphics2D when creating category labels (DG);
+ * 14-Jan-2009 : Added new variant of getCategorySeriesMiddle() to make it
+ *               simpler for renderers with hidden series (PK);
+ * 19-Mar-2009 : Added entity support - see patch 2603321 by Peter Kolb (DG);
+ * 16-Apr-2009 : Added tick mark drawing (DG);
  *
  */
 
@@ -95,6 +102,7 @@ import java.awt.Font;
 import java.awt.Graphics2D;
 import java.awt.Paint;
 import java.awt.Shape;
+import java.awt.geom.Line2D;
 import java.awt.geom.Point2D;
 import java.awt.geom.Rectangle2D;
 import java.io.IOException;
@@ -203,8 +211,6 @@ public class CategoryAxis extends Axis implements Cloneable, Serializable {
         this.maximumCategoryLabelLines = 1;
         this.maximumCategoryLabelWidthRatio = 0.0f;
 
-        setTickMarksVisible(false);  // not supported by this axis type yet
-
         this.categoryLabelPositionOffset = 4;
         this.categoryLabelPositions = CategoryLabelPositions.STANDARD;
         this.tickLabelFontMap = new HashMap();
@@ -624,6 +630,10 @@ public class CategoryAxis extends Axis implements Cloneable, Serializable {
     public double getCategoryMiddle(int category, int categoryCount,
                                     Rectangle2D area, RectangleEdge edge) {
 
+        if (category < 0 || category >= categoryCount) {
+            throw new IllegalArgumentException("Invalid category index: "
+                    + category);
+        }
         return getCategoryStart(category, categoryCount, area, edge)
                + calculateCategorySize(categoryCount, area, edge) / 2;
 
@@ -650,6 +660,33 @@ public class CategoryAxis extends Axis implements Cloneable, Serializable {
 
     }
 
+    /**
+     * A convenience method that returns the axis coordinate for the centre of
+     * a category.
+     *
+     * @param category  the category key (<code>null</code> not permitted).
+     * @param categories  the categories (<code>null</code> not permitted).
+     * @param area  the data area (<code>null</code> not permitted).
+     * @param edge  the edge along which the axis lies (<code>null</code> not
+     *     permitted).
+     *
+     * @return The centre coordinate.
+     *
+     * @since 1.0.11
+     *
+     * @see #getCategorySeriesMiddle(Comparable, Comparable, CategoryDataset,
+     *     double, Rectangle2D, RectangleEdge)
+     */
+    public double getCategoryMiddle(Comparable category,
+            List categories, Rectangle2D area, RectangleEdge edge) {
+        if (categories == null) {
+            throw new IllegalArgumentException("Null 'categories' argument.");
+        }
+        int categoryIndex = categories.indexOf(category);
+        int categoryCount = categories.size();
+        return getCategoryMiddle(categoryIndex, categoryCount, area, edge);
+    }
+
     /**
      * Returns the middle coordinate (in Java2D space) for a series within a
      * category.
@@ -687,6 +724,40 @@ public class CategoryAxis extends Axis implements Cloneable, Serializable {
         }
     }
 
+    /**
+     * Returns the middle coordinate (in Java2D space) for a series within a
+     * category.
+     *
+     * @param categoryIndex  the category index.
+     * @param categoryCount  the category count.
+     * @param seriesIndex the series index.
+     * @param seriesCount the series count.
+     * @param itemMargin  the item margin (0.0 <= itemMargin < 1.0);
+     * @param area  the area (<code>null</code> not permitted).
+     * @param edge  the edge (<code>null</code> not permitted).
+     *
+     * @return The coordinate in Java2D space.
+     *
+     * @since 1.0.13
+     */
+    public double getCategorySeriesMiddle(int categoryIndex, int categoryCount,
+            int seriesIndex, int seriesCount, double itemMargin,
+            Rectangle2D area, RectangleEdge edge) {
+
+        double start = getCategoryStart(categoryIndex, categoryCount, area,
+                edge);
+        double end = getCategoryEnd(categoryIndex, categoryCount, area, edge);
+        double width = end - start;
+        if (seriesCount == 1) {
+            return start + width / 2.0;
+        }
+        else {
+            double gap = (width * itemMargin) / (seriesCount - 1);
+            double ww = (width * (1 - itemMargin)) / seriesCount;
+            return start + (seriesIndex * (ww + gap)) + ww / 2.0;
+        }
+    }
+
     /**
      * Calculates the size (width or height, depending on the location of the
      * axis) of a category.
@@ -843,12 +914,9 @@ public class CategoryAxis extends Axis implements Cloneable, Serializable {
      *
      * @return The axis state (never <code>null</code>).
      */
-    public AxisState draw(Graphics2D g2,
-                          double cursor,
-                          Rectangle2D plotArea,
-                          Rectangle2D dataArea,
-                          RectangleEdge edge,
-                          PlotRenderingInfo plotState) {
+    public AxisState draw(Graphics2D g2, double cursor, Rectangle2D plotArea,
+            Rectangle2D dataArea, RectangleEdge edge,
+            PlotRenderingInfo plotState) {
 
         // if the axis is not visible, don't draw it...
         if (!isVisible()) {
@@ -858,13 +926,16 @@ public class CategoryAxis extends Axis implements Cloneable, Serializable {
         if (isAxisLineVisible()) {
             drawAxisLine(g2, cursor, dataArea, edge);
         }
+        AxisState state = new AxisState(cursor);
+        if (isTickMarksVisible()) {
+            drawTickMarks(g2, cursor, dataArea, edge, state);
+        }
 
         // draw the category labels and axis label
-        AxisState state = new AxisState(cursor);
         state = drawCategoryLabels(g2, plotArea, dataArea, edge, state,
                 plotState);
         state = drawLabel(getLabel(), g2, plotArea, dataArea, edge, state);
-
+        createAndAddEntity(cursor, state, dataArea, edge, plotState);
         return state;
 
     }
@@ -1069,6 +1140,7 @@ public class CategoryAxis extends Axis implements Cloneable, Serializable {
             Iterator iterator = categories.iterator();
             while (iterator.hasNext()) {
                 Comparable category = (Comparable) iterator.next();
+                g2.setFont(getTickLabelFont(category));
                 TextBlock label = createLabel(category, l * r, edge, g2);
                 if (edge == RectangleEdge.TOP || edge == RectangleEdge.BOTTOM) {
                     max = Math.max(max, calculateTextBlockHeight(label,
@@ -1091,6 +1163,75 @@ public class CategoryAxis extends Axis implements Cloneable, Serializable {
 
     }
 
+    /**
+     * Draws the tick marks.
+     *
+     * @since 1.0.13
+     */
+    public void drawTickMarks(Graphics2D g2, double cursor,
+            Rectangle2D dataArea, RectangleEdge edge, AxisState state) {
+
+        Plot p = getPlot();
+        if (p == null) {
+            return;
+        }
+        CategoryPlot plot = (CategoryPlot) p;
+        double il = getTickMarkInsideLength();
+        double ol = getTickMarkOutsideLength();
+        Line2D line = new Line2D.Double();
+        List categories = plot.getCategoriesForAxis(this);
+        g2.setPaint(getTickMarkPaint());
+        g2.setStroke(getTickMarkStroke());
+        if (edge.equals(RectangleEdge.TOP)) {
+            Iterator iterator = categories.iterator();
+            while (iterator.hasNext()) {
+                Comparable key = (Comparable) iterator.next();
+                double x = getCategoryMiddle(key, categories, dataArea, edge);
+                line.setLine(x, cursor, x, cursor + il);
+                g2.draw(line);
+                line.setLine(x, cursor, x, cursor - ol);
+                g2.draw(line);
+            }
+            state.cursorUp(ol);
+        }
+        else if (edge.equals(RectangleEdge.BOTTOM)) {
+            Iterator iterator = categories.iterator();
+            while (iterator.hasNext()) {
+                Comparable key = (Comparable) iterator.next();
+                double x = getCategoryMiddle(key, categories, dataArea, edge);
+                line.setLine(x, cursor, x, cursor - il);
+                g2.draw(line);
+                line.setLine(x, cursor, x, cursor + ol);
+                g2.draw(line);
+            }
+            state.cursorDown(ol);
+        }
+        else if (edge.equals(RectangleEdge.LEFT)) {
+            Iterator iterator = categories.iterator();
+            while (iterator.hasNext()) {
+                Comparable key = (Comparable) iterator.next();
+                double y = getCategoryMiddle(key, categories, dataArea, edge);
+                line.setLine(cursor, y, cursor + il, y);
+                g2.draw(line);
+                line.setLine(cursor, y, cursor - ol, y);
+                g2.draw(line);
+            }
+            state.cursorLeft(ol);
+        }
+        else if (edge.equals(RectangleEdge.RIGHT)) {
+            Iterator iterator = categories.iterator();
+            while (iterator.hasNext()) {
+                Comparable key = (Comparable) iterator.next();
+                double y = getCategoryMiddle(key, categories, dataArea, edge);
+                line.setLine(cursor, y, cursor - il, y);
+                g2.draw(line);
+                line.setLine(cursor, y, cursor + ol, y);
+                g2.draw(line);
+            }
+            state.cursorRight(ol);
+        }
+    }
+
     /**
      * Creates a label.
      *
