@@ -2,32 +2,32 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2006, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
- * This library is free software; you can redistribute it and/or modify it 
- * under the terms of the GNU Lesser General Public License as published by 
- * the Free Software Foundation; either version 2.1 of the License, or 
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
  * License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
- * USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+ * USA.
  *
- * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
+ * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
  * in the United States and other countries.]
  *
  * -------------------
  * CategoryAxis3D.java
  * -------------------
- * (C) Copyright 2003-2006, by Klaus Rheinwald and Contributors.
+ * (C) Copyright 2003-2009, by Klaus Rheinwald and Contributors.
  *
  * Original Author:  Klaus Rheinwald;
  * Contributor(s):   Tin Luu,
@@ -37,18 +37,19 @@
  * Changes
  * -------
  * 19-Feb-2003 : File creation;
- * 21-Mar-2003 : Added to JFreeChart CVS, see bug id 685501 for code 
+ * 21-Mar-2003 : Added to JFreeChart CVS, see bug id 685501 for code
  *               contribution from KR (DG);
  * 26-Mar-2003 : Implemented Serializable (DG);
- * 13-May-2003 : Renamed HorizontalCategoryAxis3D --> CategoryAxis3D, and 
+ * 13-May-2003 : Renamed HorizontalCategoryAxis3D --> CategoryAxis3D, and
  *               modified to take into account the plot orientation (DG);
  * 14-Aug-2003 : Implemented Cloneable (DG);
  * 21-Aug-2003 : Fixed draw() method bugs (DG);
- * 22-Mar-2004 : Added workaround for bug 920959 (null pointer exception with 
+ * 22-Mar-2004 : Added workaround for bug 920959 (null pointer exception with
  *               no renderer) (DG);
  * ------------- JFREECHART 1.0.x ---------------------------------------------
  * 18-Aug-2006 : Fix for bug drawing category labels, thanks to Adriaan
  *               Joubert (1277726) (DG);
+ * 16-Apr-2009 : Draw axis line and tick marks (DG);
  *
  */
 
@@ -68,19 +69,19 @@ import org.jfree.ui.RectangleEdge;
  * An axis that displays categories and has a 3D effect.
  * Used for bar charts and line charts.
  */
-public class CategoryAxis3D extends CategoryAxis 
-                            implements Cloneable, Serializable {
+public class CategoryAxis3D extends CategoryAxis
+        implements Cloneable, Serializable {
 
     /** For serialization. */
     private static final long serialVersionUID = 4114732251353700972L;
-    
+
     /**
      * Creates a new axis.
      */
     public CategoryAxis3D() {
         this(null);
     }
-    
+
     /**
      * Creates a new axis using default attribute values.
      *
@@ -91,25 +92,25 @@ public class CategoryAxis3D extends CategoryAxis
     }
 
     /**
-     * Draws the axis on a Java 2D graphics device (such as the screen or a 
+     * Draws the axis on a Java 2D graphics device (such as the screen or a
      * printer).
      *
      * @param g2  the graphics device (<code>null</code> not permitted).
      * @param cursor  the cursor location.
-     * @param plotArea  the area within which the axis should be drawn 
+     * @param plotArea  the area within which the axis should be drawn
      *                  (<code>null</code> not permitted).
-     * @param dataArea  the area within which the plot is being drawn 
+     * @param dataArea  the area within which the plot is being drawn
      *                  (<code>null</code> not permitted).
      * @param edge  the location of the axis (<code>null</code> not permitted).
      * @param plotState  collects information about the plot (<code>null</code>
      *                   permitted).
-     * 
+     *
      * @return The axis state (never <code>null</code>).
      */
-    public AxisState draw(Graphics2D g2, 
+    public AxisState draw(Graphics2D g2,
                           double cursor,
-                          Rectangle2D plotArea, 
-                          Rectangle2D dataArea, 
+                          Rectangle2D plotArea,
+                          Rectangle2D dataArea,
                           RectangleEdge edge,
                           PlotRenderingInfo plotState) {
 
@@ -119,7 +120,7 @@ public class CategoryAxis3D extends CategoryAxis
         }
 
         // calculate the adjusted data area taking into account the 3D effect...
-        // this assumes that there is a 3D renderer, all this 3D effect is a 
+        // this assumes that there is a 3D renderer, all this 3D effect is a
         // bit of an ugly hack...
         CategoryPlot plot = (CategoryPlot) getPlot();
 
@@ -137,40 +138,46 @@ public class CategoryAxis3D extends CategoryAxis
             else if (edge == RectangleEdge.RIGHT || edge == RectangleEdge.TOP) {
                 adjustedX += e3D.getXOffset();
             }
-            adjustedDataArea.setRect(adjustedX, adjustedY, adjustedW, 
+            adjustedDataArea.setRect(adjustedX, adjustedY, adjustedW,
                     adjustedH);
         }
         else {
-            adjustedDataArea.setRect(dataArea);   
+            adjustedDataArea.setRect(dataArea);
         }
 
+        if (isAxisLineVisible()) {
+            drawAxisLine(g2, cursor, adjustedDataArea, edge);
+        }
         // draw the category labels and axis label
         AxisState state = new AxisState(cursor);
-        state = drawCategoryLabels(g2, plotArea, adjustedDataArea, edge, 
+        if (isTickMarksVisible()) {
+            drawTickMarks(g2, cursor, adjustedDataArea, edge, state);
+        }
+        state = drawCategoryLabels(g2, plotArea, adjustedDataArea, edge,
                 state, plotState);
         state = drawLabel(getLabel(), g2, plotArea, dataArea, edge, state);
 
         return state;
-        
+
     }
-    
+
     /**
      * Returns the Java 2D coordinate for a category.
-     * 
+     *
      * @param anchor  the anchor point.
      * @param category  the category index.
      * @param categoryCount  the category count.
      * @param area  the data area.
      * @param edge  the location of the axis.
-     * 
+     *
      * @return The coordinate.
      */
-    public double getCategoryJava2DCoordinate(CategoryAnchor anchor, 
-                                              int category, 
-                                              int categoryCount, 
+    public double getCategoryJava2DCoordinate(CategoryAnchor anchor,
+                                              int category,
+                                              int categoryCount,
                                               Rectangle2D area,
                                               RectangleEdge edge) {
-    
+
         double result = 0.0;
         Rectangle2D adjustedArea = area;
         CategoryPlot plot = (CategoryPlot) getPlot();
@@ -188,36 +195,36 @@ public class CategoryAxis3D extends CategoryAxis
             else if (edge == RectangleEdge.RIGHT || edge == RectangleEdge.TOP) {
                 adjustedX += e3D.getXOffset();
             }
-            adjustedArea = new Rectangle2D.Double(adjustedX, adjustedY, 
+            adjustedArea = new Rectangle2D.Double(adjustedX, adjustedY,
                     adjustedW, adjustedH);
         }
 
         if (anchor == CategoryAnchor.START) {
-            result = getCategoryStart(category, categoryCount, adjustedArea, 
+            result = getCategoryStart(category, categoryCount, adjustedArea,
                     edge);
         }
         else if (anchor == CategoryAnchor.MIDDLE) {
-            result = getCategoryMiddle(category, categoryCount, adjustedArea, 
+            result = getCategoryMiddle(category, categoryCount, adjustedArea,
                     edge);
         }
         else if (anchor == CategoryAnchor.END) {
-            result = getCategoryEnd(category, categoryCount, adjustedArea, 
+            result = getCategoryEnd(category, categoryCount, adjustedArea,
                     edge);
         }
         return result;
-                                                      
+
     }
-                                              
+
     /**
      * Returns a clone of the axis.
-     * 
+     *
      * @return A clone.
-     * 
-     * @throws CloneNotSupportedException If the axis is not cloneable for 
+     *
+     * @throws CloneNotSupportedException If the axis is not cloneable for
      *         some reason.
      */
     public Object clone() throws CloneNotSupportedException {
         return super.clone();
     }
-    
+
 }
