@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,7 +27,7 @@
  * -----------------
  * DateTickUnit.java
  * -----------------
- * (C) Copyright 2000-2008, by Object Refinery Limited.
+ * (C) Copyright 2000-2009, by Object Refinery Limited.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   Chris Boek;
@@ -48,6 +48,8 @@
  * 04-Apr-2007 : Added new methods addToDate(Date, TimeZone) and rollDate(Date,
  *               TimeZone) (CB);
  * 09-Jun-2008 : Deprecated addToDate(Date) (DG);
+ * 09-Jan-2009 : Replaced the unit and rollUnit fields with an enumerated
+ *               type (DG);
  *
  */
 
@@ -62,7 +64,7 @@ import java.util.TimeZone;
 import org.jfree.util.ObjectUtilities;
 
 /**
- * A tick unit for use by subclasses of {@link DateAxis}. Instances of this
+ * A tick unit for use by subclasses of {@link DateAxis}.  Instances of this
  * class are immutable.
  */
 public class DateTickUnit extends TickUnit implements Serializable {
@@ -70,35 +72,22 @@ public class DateTickUnit extends TickUnit implements Serializable {
     /** For serialization. */
     private static final long serialVersionUID = -7289292157229621901L;
 
-    /** A constant for years. */
-    public static final int YEAR = 0;
-
-    /** A constant for months. */
-    public static final int MONTH = 1;
-
-    /** A constant for days. */
-    public static final int DAY = 2;
-
-    /** A constant for hours. */
-    public static final int HOUR = 3;
-
-    /** A constant for minutes. */
-    public static final int MINUTE = 4;
-
-    /** A constant for seconds. */
-    public static final int SECOND = 5;
-
-    /** A constant for milliseconds. */
-    public static final int MILLISECOND = 6;
-
-    /** The unit. */
-    private int unit;
+    /**
+     * The units.
+     *
+     * @since 1.0.13
+     */
+    private DateTickUnitType unitType;
 
     /** The unit count. */
     private int count;
 
-    /** The roll unit. */
-    private int rollUnit;
+    /**
+     * The roll unit type.
+     *
+     * @since 1.0.13
+     */
+    private DateTickUnitType rollUnitType;
 
     /** The roll count. */
     private int rollCount;
@@ -107,94 +96,105 @@ public class DateTickUnit extends TickUnit implements Serializable {
     private DateFormat formatter;
 
     /**
-     * Creates a new date tick unit.  The dates will be formatted using a
-     * SHORT format for the default locale.
+     * Creates a new date tick unit.
      *
-     * @param unit  the unit.
-     * @param count  the unit count.
+     * @param unitType  the unit type (<code>null</code> not permitted).
+     * @param multiple  the multiple (of the unit type, must be > 0).
+     *
+     * @since 1.0.13
      */
-    public DateTickUnit(int unit, int count) {
-        this(unit, count, null);
+    public DateTickUnit(DateTickUnitType unitType, int multiple) {
+        this(unitType, multiple, DateFormat.getDateInstance(DateFormat.SHORT));
     }
 
     /**
-     * Creates a new date tick unit.  You can specify the units using one of
-     * the constants YEAR, MONTH, DAY, HOUR, MINUTE, SECOND or MILLISECOND.
-     * In addition, you can specify a unit count, and a date format.
+     * Creates a new date tick unit.
      *
-     * @param unit  the unit.
-     * @param count  the unit count.
-     * @param formatter  the date formatter (defaults to DateFormat.SHORT).
+     * @param unitType  the unit type (<code>null</code> not permitted).
+     * @param multiple  the multiple (of the unit type, must be > 0).
+     * @param formatter  the date formatter (<code>null</code> not permitted).
+     *
+     * @since 1.0.13
      */
-    public DateTickUnit(int unit, int count, DateFormat formatter) {
-
-        this(unit, count, unit, count, formatter);
-
+    public DateTickUnit(DateTickUnitType unitType, int multiple,
+            DateFormat formatter) {
+        this(unitType, multiple, unitType, multiple, formatter);
     }
 
     /**
      * Creates a new unit.
      *
-     * @param unit  the unit.
-     * @param count  the count.
-     * @param rollUnit  the roll unit.
-     * @param rollCount  the roll count.
-     * @param formatter  the date formatter (defaults to DateFormat.SHORT).
+     * @param unitType  the unit.
+     * @param multiple  the multiple.
+     * @param rollUnitType  the roll unit.
+     * @param rollMultiple  the roll multiple.
+     * @param formatter  the date formatter (<code>null</code> not permitted).
+     *
+     * @since 1.0.13
      */
-    public DateTickUnit(int unit, int count, int rollUnit, int rollCount,
-                        DateFormat formatter) {
-        super(DateTickUnit.getMillisecondCount(unit, count));
-        this.unit = unit;
-        this.count = count;
-        this.rollUnit = rollUnit;
-        this.rollCount = rollCount;
-        this.formatter = formatter;
+    public DateTickUnit(DateTickUnitType unitType, int multiple,
+            DateTickUnitType rollUnitType, int rollMultiple,
+            DateFormat formatter) {
+        super(DateTickUnit.getMillisecondCount(unitType, multiple));
         if (formatter == null) {
-            this.formatter = DateFormat.getDateInstance(DateFormat.SHORT);
+            throw new IllegalArgumentException("Null 'formatter' argument.");
         }
+        if (multiple <= 0) {
+            throw new IllegalArgumentException("Requires 'multiple' > 0.");
+        }
+        if (rollMultiple <= 0) {
+            throw new IllegalArgumentException("Requires 'rollMultiple' > 0.");
+        }
+        this.unitType = unitType;
+        this.count = multiple;
+        this.rollUnitType = rollUnitType;
+        this.rollCount = rollMultiple;
+        this.formatter = formatter;
+
+        // populate deprecated fields
+        this.unit = unitTypeToInt(unitType);
+        this.rollUnit = unitTypeToInt(rollUnitType);
     }
 
     /**
-     * Returns the date unit.  This will be one of the constants
-     * <code>YEAR</code>, <code>MONTH</code>, <code>DAY</code>,
-     * <code>HOUR</code>, <code>MINUTE</code>, <code>SECOND</code> or
-     * <code>MILLISECOND</code>, defined by this class.  Note that these
-     * constants do NOT correspond to those defined in Java's
-     * <code>Calendar</code> class.
+     * Returns the unit type.
      *
-     * @return The date unit.
+     * @return The unit type (never <code>null</code>).
+     *
+     * @since 1.0.13
      */
-    public int getUnit() {
-        return this.unit;
+    public DateTickUnitType getUnitType() {
+        return this.unitType;
     }
 
     /**
-     * Returns the unit count.
+     * Returns the unit multiple.
      *
-     * @return The unit count.
+     * @return The unit multiple (always > 0).
      */
-    public int getCount() {
+    public int getMultiple() {
         return this.count;
     }
 
     /**
-     * Returns the roll unit.  This is the amount by which the tick advances if
-     * it is "hidden" when displayed on a segmented date axis.  Typically the
-     * roll will be smaller than the regular tick unit (for example, a 7 day
-     * tick unit might use a 1 day roll).
+     * Returns the roll unit type.
      *
-     * @return The roll unit.
+     * @return The roll unit type (never <code>null</code>).
+     *
+     * @since 1.0.13
      */
-    public int getRollUnit() {
-        return this.rollUnit;
+    public DateTickUnitType getRollUnitType() {
+        return this.rollUnitType;
     }
 
     /**
-     * Returns the roll count.
+     * Returns the roll unit multiple.
      *
-     * @return The roll count.
+     * @return The roll unit multiple.
+     *
+     * @since 1.0.13
      */
-    public int getRollCount() {
+    public int getRollMultiple() {
         return this.rollCount;
     }
 
@@ -220,23 +220,6 @@ public class DateTickUnit extends TickUnit implements Serializable {
         return this.formatter.format(date);
     }
 
-    /**
-     * Calculates a new date by adding this unit to the base date, with
-     * calculations performed in the default timezone and locale.
-     *
-     * @param base  the base date.
-     *
-     * @return A new date one unit after the base date.
-     *
-     * @see #addToDate(Date, TimeZone)
-     *
-     * @deprecated As of JFreeChart 1.0.10, this method is deprecated - you
-     *     should use {@link #addToDate(Date, TimeZone)} instead.
-     */
-    public Date addToDate(Date base) {
-    	return addToDate(base, TimeZone.getDefault());
-    }
-
     /**
      * Calculates a new date by adding this unit to the base date.
      *
@@ -249,12 +232,12 @@ public class DateTickUnit extends TickUnit implements Serializable {
      */
     public Date addToDate(Date base, TimeZone zone) {
         // as far as I know, the Locale for the calendar only affects week
-    	// number calculations, and since DateTickUnit doesn't do week
-    	// arithmetic, the default locale (whatever it is) should be fine
-    	// here...
-    	Calendar calendar = Calendar.getInstance(zone);
+        // number calculations, and since DateTickUnit doesn't do week
+        // arithmetic, the default locale (whatever it is) should be fine
+        // here...
+        Calendar calendar = Calendar.getInstance(zone);
         calendar.setTime(base);
-        calendar.add(getCalendarField(this.unit), this.count);
+        calendar.add(this.unitType.getCalendarField(), this.count);
         return calendar.getTime();
     }
 
@@ -269,7 +252,7 @@ public class DateTickUnit extends TickUnit implements Serializable {
      * @see #rollDate(Date, TimeZone)
      */
     public Date rollDate(Date base) {
-    	return rollDate(base, TimeZone.getDefault());
+        return rollDate(base, TimeZone.getDefault());
     }
 
     /**
@@ -285,12 +268,12 @@ public class DateTickUnit extends TickUnit implements Serializable {
      */
     public Date rollDate(Date base, TimeZone zone) {
         // as far as I know, the Locale for the calendar only affects week
-    	// number calculations, and since DateTickUnit doesn't do week
-    	// arithmetic, the default locale (whatever it is) should be fine
-    	// here...
+        // number calculations, and since DateTickUnit doesn't do week
+        // arithmetic, the default locale (whatever it is) should be fine
+        // here...
         Calendar calendar = Calendar.getInstance(zone);
         calendar.setTime(base);
-        calendar.add(getCalendarField(this.rollUnit), this.rollCount);
+        calendar.add(this.rollUnitType.getCalendarField(), this.rollCount);
         return calendar.getTime();
     }
 
@@ -301,40 +284,7 @@ public class DateTickUnit extends TickUnit implements Serializable {
      * @return The field code.
      */
     public int getCalendarField() {
-        return getCalendarField(this.unit);
-    }
-
-    /**
-     * Returns a field code (that can be used with the Calendar class) for a
-     * given 'unit' code.  The 'unit' is one of:  {@link #YEAR}, {@link #MONTH},
-     * {@link #DAY}, {@link #HOUR}, {@link #MINUTE}, {@link #SECOND} and
-     * {@link #MILLISECOND}.
-     *
-     * @param tickUnit  the unit.
-     *
-     * @return The field code.
-     */
-    private int getCalendarField(int tickUnit) {
-
-        switch (tickUnit) {
-            case (YEAR):
-                return Calendar.YEAR;
-            case (MONTH):
-                return Calendar.MONTH;
-            case (DAY):
-                return Calendar.DATE;
-            case (HOUR):
-                return Calendar.HOUR_OF_DAY;
-            case (MINUTE):
-                return Calendar.MINUTE;
-            case (SECOND):
-                return Calendar.SECOND;
-            case (MILLISECOND):
-                return Calendar.MILLISECOND;
-            default:
-                return Calendar.MILLISECOND;
-        }
-
+        return this.unitType.getCalendarField();
     }
 
     /**
@@ -348,36 +298,120 @@ public class DateTickUnit extends TickUnit implements Serializable {
      * @param count  the unit count.
      *
      * @return The number of milliseconds.
+     *
+     * @since 1.0.13
      */
-    private static long getMillisecondCount(int unit, int count) {
+    private static long getMillisecondCount(DateTickUnitType unit, int count) {
 
-        switch (unit) {
-            case (YEAR):
-                return (365L * 24L * 60L * 60L * 1000L) * count;
-            case (MONTH):
-                return (31L * 24L * 60L * 60L * 1000L) * count;
-            case (DAY):
-                return (24L * 60L * 60L * 1000L) * count;
-            case (HOUR):
-                return (60L * 60L * 1000L) * count;
-            case (MINUTE):
-                return (60L * 1000L) * count;
-            case (SECOND):
-                return 1000L * count;
-            case (MILLISECOND):
-                return count;
-            default:
-                throw new IllegalArgumentException(
-                    "DateTickUnit.getMillisecondCount() : unit must "
-                    + "be one of the constants YEAR, MONTH, DAY, HOUR, MINUTE, "
-                    + "SECOND or MILLISECOND defined in the DateTickUnit "
-                    + "class. Do *not* use the constants defined in "
-                    + "java.util.Calendar."
-                );
+        if (unit.equals(DateTickUnitType.YEAR)) {
+            return (365L * 24L * 60L * 60L * 1000L) * count;
+        }
+        else if (unit.equals(DateTickUnitType.MONTH)) {
+            return (31L * 24L * 60L * 60L * 1000L) * count;
+        }
+        else if (unit.equals(DateTickUnitType.DAY)) {
+            return (24L * 60L * 60L * 1000L) * count;
+        }
+        else if (unit.equals(DateTickUnitType.HOUR)) {
+            return (60L * 60L * 1000L) * count;
+        }
+        else if (unit.equals(DateTickUnitType.MINUTE)) {
+            return (60L * 1000L) * count;
+        }
+        else if (unit.equals(DateTickUnitType.SECOND)) {
+            return 1000L * count;
+        }
+        else if (unit.equals(DateTickUnitType.MILLISECOND)) {
+            return count;
+        }
+        else {
+            throw new IllegalArgumentException("The 'unit' argument has a " +
+            		"value that is not recognised.");
         }
 
     }
 
+    /**
+     * A utility method that is used internally to convert the old unit
+     * constants into the corresponding enumerated value.
+     *
+     * @param unit  the unit specified using the deprecated integer codes.
+     *
+     * @return The unit type.
+     *
+     * @since 1.0.13
+     */
+    private static DateTickUnitType intToUnitType(int unit) {
+        switch (unit) {
+            case YEAR: return DateTickUnitType.YEAR;
+            case MONTH: return DateTickUnitType.MONTH;
+            case DAY: return DateTickUnitType.DAY;
+            case HOUR: return DateTickUnitType.HOUR;
+            case MINUTE: return DateTickUnitType.MINUTE;
+            case SECOND: return DateTickUnitType.SECOND;
+            case MILLISECOND: return DateTickUnitType.MILLISECOND;
+            default: throw new IllegalArgumentException(
+                    "Unrecognised 'unit' value " + unit + ".");
+        }
+    }
+
+    /**
+     * Converts a unit type to the corresponding deprecated integer constant.
+     *
+     * @param unitType  the unit type (<code>null</code> not permitted).
+     *
+     * @return The int code.
+     *
+     * @since 1.0.13
+     */
+    private static int unitTypeToInt(DateTickUnitType unitType) {
+        if (unitType == null) {
+            throw new IllegalArgumentException("Null 'unitType' argument.");
+        }
+        if (unitType.equals(DateTickUnitType.YEAR)) {
+            return YEAR;
+        }
+        else if (unitType.equals(DateTickUnitType.MONTH)) {
+            return MONTH;
+        }
+        else if (unitType.equals(DateTickUnitType.DAY)) {
+            return DAY;
+        }
+        else if (unitType.equals(DateTickUnitType.HOUR)) {
+            return HOUR;
+        }
+        else if (unitType.equals(DateTickUnitType.MINUTE)) {
+            return MINUTE;
+        }
+        else if (unitType.equals(DateTickUnitType.SECOND)) {
+            return SECOND;
+        }
+        else if (unitType.equals(DateTickUnitType.MILLISECOND)) {
+            return MILLISECOND;
+        }
+        else {
+            throw new IllegalArgumentException(
+                    "The 'unitType' is not recognised");
+        }
+    }
+
+    /**
+     * A utility method to put a default in place if a null formatter is
+     * supplied.
+     *
+     * @param formatter  the formatter (<code>null</code> permitted).
+     *
+     * @return The formatter if it is not null, otherwise a default.
+     */
+    private static DateFormat notNull(DateFormat formatter) {
+        if (formatter == null) {
+            return DateFormat.getDateInstance(DateFormat.SHORT);
+        }
+        else {
+            return formatter;
+        }
+    }
+
     /**
      * Tests this unit for equality with another object.
      *
@@ -396,7 +430,7 @@ public class DateTickUnit extends TickUnit implements Serializable {
             return false;
         }
         DateTickUnit that = (DateTickUnit) obj;
-        if (this.unit != that.unit) {
+        if (!(this.unitType.equals(that.unitType))) {
             return false;
         }
         if (this.count != that.count) {
@@ -415,18 +449,12 @@ public class DateTickUnit extends TickUnit implements Serializable {
      */
     public int hashCode() {
         int result = 19;
-        result = 37 * result + this.unit;
+        result = 37 * result + this.unitType.hashCode();
         result = 37 * result + this.count;
         result = 37 * result + this.formatter.hashCode();
         return result;
     }
 
-    /**
-     * Strings for use by the toString() method.
-     */
-    private static final String[] units = {"YEAR", "MONTH", "DAY", "HOUR",
-            "MINUTE", "SECOND", "MILLISECOND"};
-
     /**
      * Returns a string representation of this instance, primarily used for
      * debugging purposes.
@@ -434,8 +462,189 @@ public class DateTickUnit extends TickUnit implements Serializable {
      * @return A string representation of this instance.
      */
     public String toString() {
-        return "DateTickUnit[" + DateTickUnit.units[this.unit] + ", "
+        return "DateTickUnit[" + this.unitType.toString() + ", "
                 + this.count + "]";
     }
 
+    /**
+     * A constant for years.
+     *
+     * @deprecated As of version 1.0.13, use {@link DateTickUnitType} instead.
+     */
+    public static final int YEAR = 0;
+
+    /**
+     * A constant for months.
+     *
+     * @deprecated As of version 1.0.13, use {@link DateTickUnitType} instead.
+     */
+    public static final int MONTH = 1;
+
+    /**
+     * A constant for days.
+     *
+     * @deprecated As of version 1.0.13, use {@link DateTickUnitType} instead.
+     */
+    public static final int DAY = 2;
+
+    /**
+     * A constant for hours.
+     *
+     * @deprecated As of version 1.0.13, use {@link DateTickUnitType} instead.
+     */
+    public static final int HOUR = 3;
+
+    /**
+     * A constant for minutes.
+     *
+     * @deprecated As of version 1.0.13, use {@link DateTickUnitType} instead.
+     */
+    public static final int MINUTE = 4;
+
+    /**
+     * A constant for seconds.
+     *
+     * @deprecated As of version 1.0.13, use {@link DateTickUnitType} instead.
+     */
+    public static final int SECOND = 5;
+
+    /**
+     * A constant for milliseconds.
+     *
+     * @deprecated As of version 1.0.13, use {@link DateTickUnitType} instead.
+     */
+    public static final int MILLISECOND = 6;
+
+    /**
+     * The unit.
+     *
+     * @deprecated As of version 1.0.13, use the unitType field.
+     */
+    private int unit;
+
+    /**
+     * The roll unit.
+     *
+     * @deprecated As of version 1.0.13, use the rollUnitType field.
+     */
+    private int rollUnit;
+
+    /**
+     * Creates a new date tick unit.  You can specify the units using one of
+     * the constants YEAR, MONTH, DAY, HOUR, MINUTE, SECOND or MILLISECOND.
+     * In addition, you can specify a unit count, and a date format.
+     *
+     * @param unit  the unit.
+     * @param count  the unit count.
+     * @param formatter  the date formatter (defaults to DateFormat.SHORT).
+     *
+     * @deprecated As of version 1.0.13, use {@link #DateTickUnit(
+     *     DateTickUnitType, int, DateFormat)}.
+     */
+    public DateTickUnit(int unit, int count, DateFormat formatter) {
+        this(unit, count, unit, count, formatter);
+    }
+
+    /**
+     * Creates a new date tick unit.  The dates will be formatted using a
+     * SHORT format for the default locale.
+     *
+     * @param unit  the unit.
+     * @param count  the unit count.
+     *
+     * @deprecated As of version 1.0.13, use {@link #DateTickUnit(
+     *     DateTickUnitType, int)}.
+     */
+    public DateTickUnit(int unit, int count) {
+        this(unit, count, null);
+    }
+
+    /**
+     * Creates a new unit.
+     *
+     * @param unit  the unit.
+     * @param count  the count.
+     * @param rollUnit  the roll unit.
+     * @param rollCount  the roll count.
+     * @param formatter  the date formatter (defaults to DateFormat.SHORT).
+     *
+     * @deprecated As of version 1.0.13, use {@link #DateTickUnit(
+     *     DateTickUnitType, int, DateTickUnitType, int, DateFormat)}.
+     */
+    public DateTickUnit(int unit, int count, int rollUnit, int rollCount,
+                        DateFormat formatter) {
+        this(intToUnitType(unit), count, intToUnitType(rollUnit), rollCount,
+                notNull(formatter));
+    }
+
+    /**
+     * Returns the date unit.  This will be one of the constants
+     * <code>YEAR</code>, <code>MONTH</code>, <code>DAY</code>,
+     * <code>HOUR</code>, <code>MINUTE</code>, <code>SECOND</code> or
+     * <code>MILLISECOND</code>, defined by this class.  Note that these
+     * constants do NOT correspond to those defined in Java's
+     * <code>Calendar</code> class.
+     *
+     * @return The date unit.
+     *
+     * @deprecated As of 1.0.13, use the getUnitType() method.
+     */
+    public int getUnit() {
+        return this.unit;
+    }
+
+    /**
+     * Returns the unit count.
+     *
+     * @return The unit count.
+     *
+     * @deprecated As of version 1.0.13, use {@link #getMultiple()}.
+     */
+    public int getCount() {
+        return this.count;
+    }
+
+    /**
+     * Returns the roll unit.  This is the amount by which the tick advances if
+     * it is "hidden" when displayed on a segmented date axis.  Typically the
+     * roll will be smaller than the regular tick unit (for example, a 7 day
+     * tick unit might use a 1 day roll).
+     *
+     * @return The roll unit.
+     *
+     * @deprecated As of version 1.0.13, use {@link #getRollUnitType()}.
+     */
+    public int getRollUnit() {
+        return this.rollUnit;
+    }
+
+    /**
+     * Returns the roll count.
+     *
+     * @return The roll count.
+     *
+     * @deprecated As of version 1.0.13, use the {@link #getRollMultiple()}
+     *
+     */
+    public int getRollCount() {
+        return this.rollCount;
+    }
+
+    /**
+     * Calculates a new date by adding this unit to the base date, with
+     * calculations performed in the default timezone and locale.
+     *
+     * @param base  the base date.
+     *
+     * @return A new date one unit after the base date.
+     *
+     * @see #addToDate(Date, TimeZone)
+     *
+     * @deprecated As of JFreeChart 1.0.10, this method is deprecated - you
+     *     should use {@link #addToDate(Date, TimeZone)} instead.
+     */
+    public Date addToDate(Date base) {
+        return addToDate(base, TimeZone.getDefault());
+    }
+
 }
