@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,10 +27,11 @@
  * ---------------
  * NumberAxis.java
  * ---------------
- * (C) Copyright 2000-2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   Laurence Vanhelsuwe;
+ *                   Peter Kolb (patches 1934255 and 2603321);
  *
  * Changes
  * -------
@@ -90,7 +91,11 @@
  * 11-Dec-2006 : Fix bug in auto-tick unit selection with tick format override,
  *               see bug 1608371 (DG);
  * 22-Mar-2007 : Use new defaultAutoRange attribute (DG);
- *
+ * 25-Sep-2008 : Added minor tick support, see patch 1934255 by Peter Kolb (DG);
+ * 21-Jan-2009 : Default minor tick counts will now come from the tick unit
+ *               collection (DG);
+ * 19-Mar-2009 : Added entity support - see patch 2603321 by Peter Kolb (DG);
+ * 
  */
 
 package org.jfree.chart.axis;
@@ -643,12 +648,9 @@ public class NumberAxis extends ValueAxis implements Cloneable, Serializable {
      *
      * @return The axis state (never <code>null</code>).
      */
-    public AxisState draw(Graphics2D g2,
-                          double cursor,
-                          Rectangle2D plotArea,
-                          Rectangle2D dataArea,
-                          RectangleEdge edge,
-                          PlotRenderingInfo plotState) {
+    public AxisState draw(Graphics2D g2, double cursor, Rectangle2D plotArea,
+            Rectangle2D dataArea, RectangleEdge edge,
+            PlotRenderingInfo plotState) {
 
         AxisState state = null;
         // if the axis is not visible, don't draw it...
@@ -674,7 +676,7 @@ public class NumberAxis extends ValueAxis implements Cloneable, Serializable {
 
         // draw the axis label...
         state = drawLabel(getLabel(), g2, plotArea, dataArea, edge, state);
-
+        createAndAddEntity(cursor, state, dataArea, edge, plotState);
         return state;
 
     }
@@ -708,65 +710,65 @@ public class NumberAxis extends ValueAxis implements Cloneable, Serializable {
 
         // we can add the units in any order, the TickUnits collection will
         // sort them...
-        units.add(new NumberTickUnit(0.0000001, df1));
-        units.add(new NumberTickUnit(0.000001, df2));
-        units.add(new NumberTickUnit(0.00001, df3));
-        units.add(new NumberTickUnit(0.0001, df4));
-        units.add(new NumberTickUnit(0.001, df5));
-        units.add(new NumberTickUnit(0.01, df6));
-        units.add(new NumberTickUnit(0.1, df7));
-        units.add(new NumberTickUnit(1, df8));
-        units.add(new NumberTickUnit(10, df8));
-        units.add(new NumberTickUnit(100, df8));
-        units.add(new NumberTickUnit(1000, df8));
-        units.add(new NumberTickUnit(10000, df8));
-        units.add(new NumberTickUnit(100000, df8));
-        units.add(new NumberTickUnit(1000000, df9));
-        units.add(new NumberTickUnit(10000000, df9));
-        units.add(new NumberTickUnit(100000000, df9));
-        units.add(new NumberTickUnit(1000000000, df10));
-        units.add(new NumberTickUnit(10000000000.0, df10));
-        units.add(new NumberTickUnit(100000000000.0, df10));
+        units.add(new NumberTickUnit(0.0000001, df1, 2));
+        units.add(new NumberTickUnit(0.000001, df2, 2));
+        units.add(new NumberTickUnit(0.00001, df3, 2));
+        units.add(new NumberTickUnit(0.0001, df4, 2));
+        units.add(new NumberTickUnit(0.001, df5, 2));
+        units.add(new NumberTickUnit(0.01, df6, 2));
+        units.add(new NumberTickUnit(0.1, df7, 2));
+        units.add(new NumberTickUnit(1, df8, 2));
+        units.add(new NumberTickUnit(10, df8, 2));
+        units.add(new NumberTickUnit(100, df8, 2));
+        units.add(new NumberTickUnit(1000, df8, 2));
+        units.add(new NumberTickUnit(10000, df8, 2));
+        units.add(new NumberTickUnit(100000, df8, 2));
+        units.add(new NumberTickUnit(1000000, df9, 2));
+        units.add(new NumberTickUnit(10000000, df9, 2));
+        units.add(new NumberTickUnit(100000000, df9, 2));
+        units.add(new NumberTickUnit(1000000000, df10, 2));
+        units.add(new NumberTickUnit(10000000000.0, df10, 2));
+        units.add(new NumberTickUnit(100000000000.0, df10, 2));
 
-        units.add(new NumberTickUnit(0.00000025, df0));
-        units.add(new NumberTickUnit(0.0000025, df1));
-        units.add(new NumberTickUnit(0.000025, df2));
-        units.add(new NumberTickUnit(0.00025, df3));
-        units.add(new NumberTickUnit(0.0025, df4));
-        units.add(new NumberTickUnit(0.025, df5));
-        units.add(new NumberTickUnit(0.25, df6));
-        units.add(new NumberTickUnit(2.5, df7));
-        units.add(new NumberTickUnit(25, df8));
-        units.add(new NumberTickUnit(250, df8));
-        units.add(new NumberTickUnit(2500, df8));
-        units.add(new NumberTickUnit(25000, df8));
-        units.add(new NumberTickUnit(250000, df8));
-        units.add(new NumberTickUnit(2500000, df9));
-        units.add(new NumberTickUnit(25000000, df9));
-        units.add(new NumberTickUnit(250000000, df9));
-        units.add(new NumberTickUnit(2500000000.0, df10));
-        units.add(new NumberTickUnit(25000000000.0, df10));
-        units.add(new NumberTickUnit(250000000000.0, df10));
+        units.add(new NumberTickUnit(0.00000025, df0, 5));
+        units.add(new NumberTickUnit(0.0000025, df1, 5));
+        units.add(new NumberTickUnit(0.000025, df2, 5));
+        units.add(new NumberTickUnit(0.00025, df3, 5));
+        units.add(new NumberTickUnit(0.0025, df4, 5));
+        units.add(new NumberTickUnit(0.025, df5, 5));
+        units.add(new NumberTickUnit(0.25, df6, 5));
+        units.add(new NumberTickUnit(2.5, df7, 5));
+        units.add(new NumberTickUnit(25, df8, 5));
+        units.add(new NumberTickUnit(250, df8, 5));
+        units.add(new NumberTickUnit(2500, df8, 5));
+        units.add(new NumberTickUnit(25000, df8, 5));
+        units.add(new NumberTickUnit(250000, df8, 5));
+        units.add(new NumberTickUnit(2500000, df9, 5));
+        units.add(new NumberTickUnit(25000000, df9, 5));
+        units.add(new NumberTickUnit(250000000, df9, 5));
+        units.add(new NumberTickUnit(2500000000.0, df10, 5));
+        units.add(new NumberTickUnit(25000000000.0, df10, 5));
+        units.add(new NumberTickUnit(250000000000.0, df10, 5));
 
-        units.add(new NumberTickUnit(0.0000005, df1));
-        units.add(new NumberTickUnit(0.000005, df2));
-        units.add(new NumberTickUnit(0.00005, df3));
-        units.add(new NumberTickUnit(0.0005, df4));
-        units.add(new NumberTickUnit(0.005, df5));
-        units.add(new NumberTickUnit(0.05, df6));
-        units.add(new NumberTickUnit(0.5, df7));
-        units.add(new NumberTickUnit(5L, df8));
-        units.add(new NumberTickUnit(50L, df8));
-        units.add(new NumberTickUnit(500L, df8));
-        units.add(new NumberTickUnit(5000L, df8));
-        units.add(new NumberTickUnit(50000L, df8));
-        units.add(new NumberTickUnit(500000L, df8));
-        units.add(new NumberTickUnit(5000000L, df9));
-        units.add(new NumberTickUnit(50000000L, df9));
-        units.add(new NumberTickUnit(500000000L, df9));
-        units.add(new NumberTickUnit(5000000000L, df10));
-        units.add(new NumberTickUnit(50000000000L, df10));
-        units.add(new NumberTickUnit(500000000000L, df10));
+        units.add(new NumberTickUnit(0.0000005, df1, 5));
+        units.add(new NumberTickUnit(0.000005, df2, 5));
+        units.add(new NumberTickUnit(0.00005, df3, 5));
+        units.add(new NumberTickUnit(0.0005, df4, 5));
+        units.add(new NumberTickUnit(0.005, df5, 5));
+        units.add(new NumberTickUnit(0.05, df6, 5));
+        units.add(new NumberTickUnit(0.5, df7, 5));
+        units.add(new NumberTickUnit(5L, df8, 5));
+        units.add(new NumberTickUnit(50L, df8, 5));
+        units.add(new NumberTickUnit(500L, df8, 5));
+        units.add(new NumberTickUnit(5000L, df8, 5));
+        units.add(new NumberTickUnit(50000L, df8, 5));
+        units.add(new NumberTickUnit(500000L, df8, 5));
+        units.add(new NumberTickUnit(5000000L, df9, 5));
+        units.add(new NumberTickUnit(50000000L, df9, 5));
+        units.add(new NumberTickUnit(500000000L, df9, 5));
+        units.add(new NumberTickUnit(5000000000L, df10, 5));
+        units.add(new NumberTickUnit(50000000000L, df10, 5));
+        units.add(new NumberTickUnit(500000000000L, df10, 5));
 
         return units;
 
@@ -781,44 +783,41 @@ public class NumberAxis extends ValueAxis implements Cloneable, Serializable {
      * @see #createStandardTickUnits()
      */
     public static TickUnitSource createIntegerTickUnits() {
-
         TickUnits units = new TickUnits();
         DecimalFormat df0 = new DecimalFormat("0");
         DecimalFormat df1 = new DecimalFormat("#,##0");
-        units.add(new NumberTickUnit(1, df0));
-        units.add(new NumberTickUnit(2, df0));
-        units.add(new NumberTickUnit(5, df0));
-        units.add(new NumberTickUnit(10, df0));
-        units.add(new NumberTickUnit(20, df0));
-        units.add(new NumberTickUnit(50, df0));
-        units.add(new NumberTickUnit(100, df0));
-        units.add(new NumberTickUnit(200, df0));
-        units.add(new NumberTickUnit(500, df0));
-        units.add(new NumberTickUnit(1000, df1));
-        units.add(new NumberTickUnit(2000, df1));
-        units.add(new NumberTickUnit(5000, df1));
-        units.add(new NumberTickUnit(10000, df1));
-        units.add(new NumberTickUnit(20000, df1));
-        units.add(new NumberTickUnit(50000, df1));
-        units.add(new NumberTickUnit(100000, df1));
-        units.add(new NumberTickUnit(200000, df1));
-        units.add(new NumberTickUnit(500000, df1));
-        units.add(new NumberTickUnit(1000000, df1));
-        units.add(new NumberTickUnit(2000000, df1));
-        units.add(new NumberTickUnit(5000000, df1));
-        units.add(new NumberTickUnit(10000000, df1));
-        units.add(new NumberTickUnit(20000000, df1));
-        units.add(new NumberTickUnit(50000000, df1));
-        units.add(new NumberTickUnit(100000000, df1));
-        units.add(new NumberTickUnit(200000000, df1));
-        units.add(new NumberTickUnit(500000000, df1));
-        units.add(new NumberTickUnit(1000000000, df1));
-        units.add(new NumberTickUnit(2000000000, df1));
-        units.add(new NumberTickUnit(5000000000.0, df1));
-        units.add(new NumberTickUnit(10000000000.0, df1));
-
+        units.add(new NumberTickUnit(1, df0, 2));
+        units.add(new NumberTickUnit(2, df0, 2));
+        units.add(new NumberTickUnit(5, df0, 5));
+        units.add(new NumberTickUnit(10, df0, 2));
+        units.add(new NumberTickUnit(20, df0, 2));
+        units.add(new NumberTickUnit(50, df0, 5));
+        units.add(new NumberTickUnit(100, df0, 2));
+        units.add(new NumberTickUnit(200, df0, 2));
+        units.add(new NumberTickUnit(500, df0, 5));
+        units.add(new NumberTickUnit(1000, df1, 2));
+        units.add(new NumberTickUnit(2000, df1, 2));
+        units.add(new NumberTickUnit(5000, df1, 5));
+        units.add(new NumberTickUnit(10000, df1, 2));
+        units.add(new NumberTickUnit(20000, df1, 2));
+        units.add(new NumberTickUnit(50000, df1, 5));
+        units.add(new NumberTickUnit(100000, df1, 2));
+        units.add(new NumberTickUnit(200000, df1, 2));
+        units.add(new NumberTickUnit(500000, df1, 5));
+        units.add(new NumberTickUnit(1000000, df1, 2));
+        units.add(new NumberTickUnit(2000000, df1, 2));
+        units.add(new NumberTickUnit(5000000, df1, 5));
+        units.add(new NumberTickUnit(10000000, df1, 2));
+        units.add(new NumberTickUnit(20000000, df1, 2));
+        units.add(new NumberTickUnit(50000000, df1, 5));
+        units.add(new NumberTickUnit(100000000, df1, 2));
+        units.add(new NumberTickUnit(200000000, df1, 2));
+        units.add(new NumberTickUnit(500000000, df1, 5));
+        units.add(new NumberTickUnit(1000000000, df1, 2));
+        units.add(new NumberTickUnit(2000000000, df1, 2));
+        units.add(new NumberTickUnit(5000000000.0, df1, 5));
+        units.add(new NumberTickUnit(10000000000.0, df1, 2));
         return units;
-
     }
 
     /**
@@ -839,67 +838,65 @@ public class NumberAxis extends ValueAxis implements Cloneable, Serializable {
     public static TickUnitSource createStandardTickUnits(Locale locale) {
 
         TickUnits units = new TickUnits();
-
         NumberFormat numberFormat = NumberFormat.getNumberInstance(locale);
-
         // we can add the units in any order, the TickUnits collection will
         // sort them...
-        units.add(new NumberTickUnit(0.0000001,    numberFormat));
-        units.add(new NumberTickUnit(0.000001,     numberFormat));
-        units.add(new NumberTickUnit(0.00001,      numberFormat));
-        units.add(new NumberTickUnit(0.0001,       numberFormat));
-        units.add(new NumberTickUnit(0.001,        numberFormat));
-        units.add(new NumberTickUnit(0.01,         numberFormat));
-        units.add(new NumberTickUnit(0.1,          numberFormat));
-        units.add(new NumberTickUnit(1,            numberFormat));
-        units.add(new NumberTickUnit(10,           numberFormat));
-        units.add(new NumberTickUnit(100,          numberFormat));
-        units.add(new NumberTickUnit(1000,         numberFormat));
-        units.add(new NumberTickUnit(10000,        numberFormat));
-        units.add(new NumberTickUnit(100000,       numberFormat));
-        units.add(new NumberTickUnit(1000000,      numberFormat));
-        units.add(new NumberTickUnit(10000000,     numberFormat));
-        units.add(new NumberTickUnit(100000000,    numberFormat));
-        units.add(new NumberTickUnit(1000000000,   numberFormat));
-        units.add(new NumberTickUnit(10000000000.0,   numberFormat));
+        units.add(new NumberTickUnit(0.0000001, numberFormat, 2));
+        units.add(new NumberTickUnit(0.000001, numberFormat, 2));
+        units.add(new NumberTickUnit(0.00001, numberFormat, 2));
+        units.add(new NumberTickUnit(0.0001, numberFormat, 2));
+        units.add(new NumberTickUnit(0.001, numberFormat, 2));
+        units.add(new NumberTickUnit(0.01, numberFormat, 2));
+        units.add(new NumberTickUnit(0.1, numberFormat, 2));
+        units.add(new NumberTickUnit(1, numberFormat, 2));
+        units.add(new NumberTickUnit(10, numberFormat, 2));
+        units.add(new NumberTickUnit(100, numberFormat, 2));
+        units.add(new NumberTickUnit(1000, numberFormat, 2));
+        units.add(new NumberTickUnit(10000, numberFormat, 2));
+        units.add(new NumberTickUnit(100000, numberFormat, 2));
+        units.add(new NumberTickUnit(1000000, numberFormat, 2));
+        units.add(new NumberTickUnit(10000000, numberFormat, 2));
+        units.add(new NumberTickUnit(100000000, numberFormat, 2));
+        units.add(new NumberTickUnit(1000000000, numberFormat, 2));
+        units.add(new NumberTickUnit(10000000000.0, numberFormat, 2));
 
-        units.add(new NumberTickUnit(0.00000025,   numberFormat));
-        units.add(new NumberTickUnit(0.0000025,    numberFormat));
-        units.add(new NumberTickUnit(0.000025,     numberFormat));
-        units.add(new NumberTickUnit(0.00025,      numberFormat));
-        units.add(new NumberTickUnit(0.0025,       numberFormat));
-        units.add(new NumberTickUnit(0.025,        numberFormat));
-        units.add(new NumberTickUnit(0.25,         numberFormat));
-        units.add(new NumberTickUnit(2.5,          numberFormat));
-        units.add(new NumberTickUnit(25,           numberFormat));
-        units.add(new NumberTickUnit(250,          numberFormat));
-        units.add(new NumberTickUnit(2500,         numberFormat));
-        units.add(new NumberTickUnit(25000,        numberFormat));
-        units.add(new NumberTickUnit(250000,       numberFormat));
-        units.add(new NumberTickUnit(2500000,      numberFormat));
-        units.add(new NumberTickUnit(25000000,     numberFormat));
-        units.add(new NumberTickUnit(250000000,    numberFormat));
-        units.add(new NumberTickUnit(2500000000.0,   numberFormat));
-        units.add(new NumberTickUnit(25000000000.0,   numberFormat));
+        units.add(new NumberTickUnit(0.00000025, numberFormat, 5));
+        units.add(new NumberTickUnit(0.0000025, numberFormat, 5));
+        units.add(new NumberTickUnit(0.000025, numberFormat, 5));
+        units.add(new NumberTickUnit(0.00025, numberFormat, 5));
+        units.add(new NumberTickUnit(0.0025, numberFormat, 5));
+        units.add(new NumberTickUnit(0.025, numberFormat, 5));
+        units.add(new NumberTickUnit(0.25, numberFormat, 5));
+        units.add(new NumberTickUnit(2.5, numberFormat, 5));
+        units.add(new NumberTickUnit(25, numberFormat, 5));
+        units.add(new NumberTickUnit(250, numberFormat, 5));
+        units.add(new NumberTickUnit(2500, numberFormat, 5));
+        units.add(new NumberTickUnit(25000, numberFormat, 5));
+        units.add(new NumberTickUnit(250000, numberFormat, 5));
+        units.add(new NumberTickUnit(2500000, numberFormat, 5));
+        units.add(new NumberTickUnit(25000000, numberFormat, 5));
+        units.add(new NumberTickUnit(250000000, numberFormat, 5));
+        units.add(new NumberTickUnit(2500000000.0, numberFormat, 5));
+        units.add(new NumberTickUnit(25000000000.0, numberFormat, 5));
 
-        units.add(new NumberTickUnit(0.0000005,    numberFormat));
-        units.add(new NumberTickUnit(0.000005,     numberFormat));
-        units.add(new NumberTickUnit(0.00005,      numberFormat));
-        units.add(new NumberTickUnit(0.0005,       numberFormat));
-        units.add(new NumberTickUnit(0.005,        numberFormat));
-        units.add(new NumberTickUnit(0.05,         numberFormat));
-        units.add(new NumberTickUnit(0.5,          numberFormat));
-        units.add(new NumberTickUnit(5L,           numberFormat));
-        units.add(new NumberTickUnit(50L,          numberFormat));
-        units.add(new NumberTickUnit(500L,         numberFormat));
-        units.add(new NumberTickUnit(5000L,        numberFormat));
-        units.add(new NumberTickUnit(50000L,       numberFormat));
-        units.add(new NumberTickUnit(500000L,      numberFormat));
-        units.add(new NumberTickUnit(5000000L,     numberFormat));
-        units.add(new NumberTickUnit(50000000L,    numberFormat));
-        units.add(new NumberTickUnit(500000000L,   numberFormat));
-        units.add(new NumberTickUnit(5000000000L,  numberFormat));
-        units.add(new NumberTickUnit(50000000000L,  numberFormat));
+        units.add(new NumberTickUnit(0.0000005, numberFormat, 5));
+        units.add(new NumberTickUnit(0.000005, numberFormat, 5));
+        units.add(new NumberTickUnit(0.00005, numberFormat, 5));
+        units.add(new NumberTickUnit(0.0005, numberFormat, 5));
+        units.add(new NumberTickUnit(0.005, numberFormat, 5));
+        units.add(new NumberTickUnit(0.05, numberFormat, 5));
+        units.add(new NumberTickUnit(0.5, numberFormat, 5));
+        units.add(new NumberTickUnit(5L, numberFormat, 5));
+        units.add(new NumberTickUnit(50L, numberFormat, 5));
+        units.add(new NumberTickUnit(500L, numberFormat, 5));
+        units.add(new NumberTickUnit(5000L, numberFormat, 5));
+        units.add(new NumberTickUnit(50000L, numberFormat, 5));
+        units.add(new NumberTickUnit(500000L, numberFormat, 5));
+        units.add(new NumberTickUnit(5000000L, numberFormat, 5));
+        units.add(new NumberTickUnit(50000000L, numberFormat, 5));
+        units.add(new NumberTickUnit(500000000L, numberFormat, 5));
+        units.add(new NumberTickUnit(5000000000L, numberFormat, 5));
+        units.add(new NumberTickUnit(50000000000L, numberFormat, 5));
 
         return units;
 
@@ -916,45 +913,40 @@ public class NumberAxis extends ValueAxis implements Cloneable, Serializable {
      * @see #setStandardTickUnits(TickUnitSource)
      */
     public static TickUnitSource createIntegerTickUnits(Locale locale) {
-
         TickUnits units = new TickUnits();
-
         NumberFormat numberFormat = NumberFormat.getNumberInstance(locale);
-
-        units.add(new NumberTickUnit(1,              numberFormat));
-        units.add(new NumberTickUnit(2,              numberFormat));
-        units.add(new NumberTickUnit(5,              numberFormat));
-        units.add(new NumberTickUnit(10,             numberFormat));
-        units.add(new NumberTickUnit(20,             numberFormat));
-        units.add(new NumberTickUnit(50,             numberFormat));
-        units.add(new NumberTickUnit(100,            numberFormat));
-        units.add(new NumberTickUnit(200,            numberFormat));
-        units.add(new NumberTickUnit(500,            numberFormat));
-        units.add(new NumberTickUnit(1000,           numberFormat));
-        units.add(new NumberTickUnit(2000,           numberFormat));
-        units.add(new NumberTickUnit(5000,           numberFormat));
-        units.add(new NumberTickUnit(10000,          numberFormat));
-        units.add(new NumberTickUnit(20000,          numberFormat));
-        units.add(new NumberTickUnit(50000,          numberFormat));
-        units.add(new NumberTickUnit(100000,         numberFormat));
-        units.add(new NumberTickUnit(200000,         numberFormat));
-        units.add(new NumberTickUnit(500000,         numberFormat));
-        units.add(new NumberTickUnit(1000000,        numberFormat));
-        units.add(new NumberTickUnit(2000000,        numberFormat));
-        units.add(new NumberTickUnit(5000000,        numberFormat));
-        units.add(new NumberTickUnit(10000000,       numberFormat));
-        units.add(new NumberTickUnit(20000000,       numberFormat));
-        units.add(new NumberTickUnit(50000000,       numberFormat));
-        units.add(new NumberTickUnit(100000000,      numberFormat));
-        units.add(new NumberTickUnit(200000000,      numberFormat));
-        units.add(new NumberTickUnit(500000000,      numberFormat));
-        units.add(new NumberTickUnit(1000000000,     numberFormat));
-        units.add(new NumberTickUnit(2000000000,     numberFormat));
-        units.add(new NumberTickUnit(5000000000.0,   numberFormat));
-        units.add(new NumberTickUnit(10000000000.0,  numberFormat));
-
+        units.add(new NumberTickUnit(1, numberFormat, 2));
+        units.add(new NumberTickUnit(2, numberFormat, 2));
+        units.add(new NumberTickUnit(5, numberFormat, 5));
+        units.add(new NumberTickUnit(10, numberFormat, 2));
+        units.add(new NumberTickUnit(20, numberFormat, 2));
+        units.add(new NumberTickUnit(50, numberFormat, 5));
+        units.add(new NumberTickUnit(100, numberFormat, 2));
+        units.add(new NumberTickUnit(200, numberFormat, 2));
+        units.add(new NumberTickUnit(500, numberFormat, 5));
+        units.add(new NumberTickUnit(1000, numberFormat, 2));
+        units.add(new NumberTickUnit(2000, numberFormat, 2));
+        units.add(new NumberTickUnit(5000, numberFormat, 5));
+        units.add(new NumberTickUnit(10000, numberFormat, 2));
+        units.add(new NumberTickUnit(20000, numberFormat, 2));
+        units.add(new NumberTickUnit(50000, numberFormat, 5));
+        units.add(new NumberTickUnit(100000, numberFormat, 2));
+        units.add(new NumberTickUnit(200000, numberFormat, 2));
+        units.add(new NumberTickUnit(500000, numberFormat, 5));
+        units.add(new NumberTickUnit(1000000, numberFormat, 2));
+        units.add(new NumberTickUnit(2000000, numberFormat, 2));
+        units.add(new NumberTickUnit(5000000, numberFormat, 5));
+        units.add(new NumberTickUnit(10000000, numberFormat, 2));
+        units.add(new NumberTickUnit(20000000, numberFormat, 2));
+        units.add(new NumberTickUnit(50000000, numberFormat, 5));
+        units.add(new NumberTickUnit(100000000, numberFormat, 2));
+        units.add(new NumberTickUnit(200000000, numberFormat, 2));
+        units.add(new NumberTickUnit(500000000, numberFormat, 5));
+        units.add(new NumberTickUnit(1000000000, numberFormat, 2));
+        units.add(new NumberTickUnit(2000000000, numberFormat, 2));
+        units.add(new NumberTickUnit(5000000000.0, numberFormat, 5));
+        units.add(new NumberTickUnit(10000000000.0, numberFormat, 2));
         return units;
-
     }
 
     /**
@@ -1063,9 +1055,8 @@ public class NumberAxis extends ValueAxis implements Cloneable, Serializable {
                                                Rectangle2D dataArea,
                                                RectangleEdge edge) {
 
-        double tickLabelWidth = estimateMaximumTickLabelWidth(
-            g2, getTickUnit()
-        );
+        double tickLabelWidth = estimateMaximumTickLabelWidth(g2,
+                getTickUnit());
 
         // start with the current tick unit...
         TickUnitSource tickUnits = getStandardTickUnits();
@@ -1075,8 +1066,8 @@ public class NumberAxis extends ValueAxis implements Cloneable, Serializable {
         // then extrapolate...
         double guess = (tickLabelWidth / unit1Width) * unit1.getSize();
 
-        NumberTickUnit unit2
-            = (NumberTickUnit) tickUnits.getCeilingTickUnit(guess);
+        NumberTickUnit unit2 = (NumberTickUnit) tickUnits.getCeilingTickUnit(
+                guess);
         double unit2Width = lengthToJava2D(unit2.getSize(), dataArea, edge);
 
         tickLabelWidth = estimateMaximumTickLabelWidth(g2, unit2);
@@ -1163,8 +1154,7 @@ public class NumberAxis extends ValueAxis implements Cloneable, Serializable {
      * @return A list of ticks.
      */
     protected List refreshTicksHorizontal(Graphics2D g2,
-                                          Rectangle2D dataArea,
-                                          RectangleEdge edge) {
+            Rectangle2D dataArea, RectangleEdge edge) {
 
         List result = new java.util.ArrayList();
 
@@ -1175,11 +1165,25 @@ public class NumberAxis extends ValueAxis implements Cloneable, Serializable {
             selectAutoTickUnit(g2, dataArea, edge);
         }
 
-        double size = getTickUnit().getSize();
+        TickUnit tu = getTickUnit();
+        double size = tu.getSize();
         int count = calculateVisibleTickCount();
         double lowestTickValue = calculateLowestVisibleTickValue();
 
         if (count <= ValueAxis.MAXIMUM_TICK_COUNT) {
+            int minorTickSpaces = getMinorTickCount();
+            if (minorTickSpaces <= 0) {
+                minorTickSpaces = tu.getMinorTickCount();
+            }
+            for (int minorTick = 1; minorTick < minorTickSpaces; minorTick++) {
+                double minorTickValue = lowestTickValue 
+                        - size * minorTick / minorTickSpaces;
+                if (getRange().contains(minorTickValue)){
+                    result.add(new NumberTick(TickType.MINOR, minorTickValue,
+                            "", TextAnchor.TOP_CENTER, TextAnchor.CENTER,
+                            0.0));
+                }
+            }
             for (int i = 0; i < count; i++) {
                 double currentTickValue = lowestTickValue + (i * size);
                 String tickLabel;
@@ -1215,8 +1219,20 @@ public class NumberAxis extends ValueAxis implements Cloneable, Serializable {
                 }
 
                 Tick tick = new NumberTick(new Double(currentTickValue),
-                		tickLabel, anchor, rotationAnchor, angle);
+                        tickLabel, anchor, rotationAnchor, angle);
                 result.add(tick);
+                double nextTickValue = lowestTickValue + ((i + 1)* size);
+                for (int minorTick = 1; minorTick < minorTickSpaces;
+                        minorTick++) {
+                    double minorTickValue = currentTickValue
+                            + (nextTickValue - currentTickValue)
+                            * minorTick / minorTickSpaces;
+                    if (getRange().contains(minorTickValue)){
+                        result.add(new NumberTick(TickType.MINOR,
+                                minorTickValue, "", TextAnchor.TOP_CENTER,
+                                TextAnchor.CENTER, 0.0));
+                    }
+                }
             }
         }
         return result;
@@ -1234,8 +1250,7 @@ public class NumberAxis extends ValueAxis implements Cloneable, Serializable {
      * @return A list of ticks.
      */
     protected List refreshTicksVertical(Graphics2D g2,
-                                        Rectangle2D dataArea,
-                                        RectangleEdge edge) {
+            Rectangle2D dataArea, RectangleEdge edge) {
 
         List result = new java.util.ArrayList();
         result.clear();
@@ -1246,11 +1261,26 @@ public class NumberAxis extends ValueAxis implements Cloneable, Serializable {
             selectAutoTickUnit(g2, dataArea, edge);
         }
 
-        double size = getTickUnit().getSize();
+        TickUnit tu = getTickUnit();
+        double size = tu.getSize();
         int count = calculateVisibleTickCount();
         double lowestTickValue = calculateLowestVisibleTickValue();
 
         if (count <= ValueAxis.MAXIMUM_TICK_COUNT) {
+            int minorTickSpaces = getMinorTickCount();
+            if (minorTickSpaces <= 0) {
+                minorTickSpaces = tu.getMinorTickCount();
+            }
+            for (int minorTick = 1; minorTick < minorTickSpaces; minorTick++){
+                double minorTickValue = lowestTickValue
+                        - size * minorTick / minorTickSpaces;
+                if (getRange().contains(minorTickValue)){
+                    result.add(new NumberTick(TickType.MINOR, minorTickValue,
+                            "", TextAnchor.TOP_CENTER, TextAnchor.CENTER,
+                            0.0));
+                }
+            }
+
             for (int i = 0; i < count; i++) {
                 double currentTickValue = lowestTickValue + (i * size);
                 String tickLabel;
@@ -1289,8 +1319,21 @@ public class NumberAxis extends ValueAxis implements Cloneable, Serializable {
                 }
 
                 Tick tick = new NumberTick(new Double(currentTickValue),
-                		tickLabel, anchor, rotationAnchor, angle);
+                        tickLabel, anchor, rotationAnchor, angle);
                 result.add(tick);
+
+                double nextTickValue = lowestTickValue + ((i + 1)* size);
+                for (int minorTick = 1; minorTick < minorTickSpaces;
+                        minorTick++){
+                    double minorTickValue = currentTickValue
+                            + (nextTickValue - currentTickValue)
+                            * minorTick / minorTickSpaces;
+                    if (getRange().contains(minorTickValue)){
+                        result.add(new NumberTick(TickType.MINOR,
+                                minorTickValue, "", TextAnchor.TOP_CENTER,
+                                TextAnchor.CENTER, 0.0));
+                    }
+                }
             }
         }
         return result;
@@ -1328,9 +1371,6 @@ public class NumberAxis extends ValueAxis implements Cloneable, Serializable {
         if (!(obj instanceof NumberAxis)) {
             return false;
         }
-        if (!super.equals(obj)) {
-            return false;
-        }
         NumberAxis that = (NumberAxis) obj;
         if (this.autoRangeIncludesZero != that.autoRangeIncludesZero) {
             return false;
@@ -1348,7 +1388,7 @@ public class NumberAxis extends ValueAxis implements Cloneable, Serializable {
         if (!this.rangeType.equals(that.rangeType)) {
             return false;
         }
-        return true;
+        return super.equals(obj);
     }
 
     /**
