@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,7 +27,7 @@
  * --------------------
  * MultiplePiePlot.java
  * --------------------
- * (C) Copyright 2004-2008, by Object Refinery Limited.
+ * (C) Copyright 2004-2009, by Object Refinery Limited.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   Brian Cabana (patch 1943021);
@@ -49,6 +49,8 @@
  * 18-May-2007 : Set dataset for LegendItem (DG);
  * 18-Apr-2008 : In the constructor, register the plot as a dataset listener -
  *               see patch 1943021 from Brian Cabana (DG);
+ * 30-Dec-2008 : Added legendItemShape field, and fixed cloning bug (DG);
+ * 09-Jan-2009 : See ignoreNullValues to true for sub-chart (DG);
  *
  */
 
@@ -59,6 +61,8 @@ import java.awt.Font;
 import java.awt.Graphics2D;
 import java.awt.Paint;
 import java.awt.Rectangle;
+import java.awt.Shape;
+import java.awt.geom.Ellipse2D;
 import java.awt.geom.Point2D;
 import java.awt.geom.Rectangle2D;
 import java.io.IOException;
@@ -86,6 +90,7 @@ import org.jfree.ui.RectangleEdge;
 import org.jfree.ui.RectangleInsets;
 import org.jfree.util.ObjectUtilities;
 import org.jfree.util.PaintUtilities;
+import org.jfree.util.ShapeUtilities;
 import org.jfree.util.TableOrder;
 
 /**
@@ -111,22 +116,32 @@ public class MultiplePiePlot extends Plot implements Cloneable, Serializable {
 
     /**
      * The key for the aggregated items.
+     *
      * @since 1.0.2
      */
     private Comparable aggregatedItemsKey;
 
     /**
      * The paint for the aggregated items.
+     *
      * @since 1.0.2
      */
     private transient Paint aggregatedItemsPaint;
 
     /**
      * The colors to use for each section.
+     *
      * @since 1.0.2
      */
     private transient Map sectionPaints;
 
+    /**
+     * The legend item shape (never null).
+     *
+     * @since 1.0.12
+     */
+    private transient Shape legendItemShape;
+
     /**
      * Creates a new plot with no data.
      */
@@ -143,6 +158,7 @@ public class MultiplePiePlot extends Plot implements Cloneable, Serializable {
         super();
         setDataset(dataset);
         PiePlot piePlot = new PiePlot(null);
+        piePlot.setIgnoreNullValues(true);
         this.pieChart = new JFreeChart(piePlot);
         this.pieChart.removeLegend();
         this.dataExtractOrder = TableOrder.BY_COLUMN;
@@ -154,6 +170,7 @@ public class MultiplePiePlot extends Plot implements Cloneable, Serializable {
         this.aggregatedItemsKey = "Other";
         this.aggregatedItemsPaint = Color.lightGray;
         this.sectionPaints = new HashMap();
+        this.legendItemShape = new Ellipse2D.Double(-4.0, -4.0, 8.0, 8.0);
     }
 
     /**
@@ -191,6 +208,8 @@ public class MultiplePiePlot extends Plot implements Cloneable, Serializable {
 
     /**
      * Returns the pie chart that is used to draw the individual pie plots.
+     * Note that there are some attributes on this chart instance that will
+     * be ignored at rendering time (for example, legend item settings).
      *
      * @return The pie chart (never <code>null</code>).
      *
@@ -330,6 +349,37 @@ public class MultiplePiePlot extends Plot implements Cloneable, Serializable {
          // TODO: need to fetch this from localised resources
     }
 
+    /**
+     * Returns the shape used for legend items.
+     *
+     * @return The shape (never <code>null</code>).
+     *
+     * @see #setLegendItemShape(Shape)
+     *
+     * @since 1.0.12
+     */
+    public Shape getLegendItemShape() {
+        return this.legendItemShape;
+    }
+
+    /**
+     * Sets the shape used for legend items and sends a {@link PlotChangeEvent}
+     * to all registered listeners.
+     *
+     * @param shape  the shape (<code>null</code> not permitted).
+     *
+     * @see #getLegendItemShape()
+     *
+     * @since 1.0.12
+     */
+    public void setLegendItemShape(Shape shape) {
+        if (shape == null) {
+            throw new IllegalArgumentException("Null 'shape' argument.");
+        }
+        this.legendItemShape = shape;
+        fireChangeEvent();
+    }
+
     /**
      * Draws the plot on a Java 2D graphics device (such as the screen or a
      * printer).
@@ -508,43 +558,41 @@ public class MultiplePiePlot extends Plot implements Cloneable, Serializable {
     public LegendItemCollection getLegendItems() {
 
         LegendItemCollection result = new LegendItemCollection();
+        if (this.dataset == null) {
+            return result;
+        }
 
-        if (this.dataset != null) {
-            List keys = null;
+        List keys = null;
+        prefetchSectionPaints();
+        if (this.dataExtractOrder == TableOrder.BY_ROW) {
+            keys = this.dataset.getColumnKeys();
+        }
+        else if (this.dataExtractOrder == TableOrder.BY_COLUMN) {
+            keys = this.dataset.getRowKeys();
+        }
 
-            prefetchSectionPaints();
-            if (this.dataExtractOrder == TableOrder.BY_ROW) {
-                keys = this.dataset.getColumnKeys();
-            }
-            else if (this.dataExtractOrder == TableOrder.BY_COLUMN) {
-                keys = this.dataset.getRowKeys();
-            }
-
-            if (keys != null) {
-                int section = 0;
-                Iterator iterator = keys.iterator();
-                while (iterator.hasNext()) {
-                    Comparable key = (Comparable) iterator.next();
-                    String label = key.toString();
-                    String description = label;
-                    Paint paint = (Paint) this.sectionPaints.get(key);
-                    LegendItem item = new LegendItem(label, description,
-                            null, null, Plot.DEFAULT_LEGEND_ITEM_CIRCLE,
-                            paint, Plot.DEFAULT_OUTLINE_STROKE, paint);
-                    item.setDataset(getDataset());
-                    result.add(item);
-                    section++;
-                }
-            }
-            if (this.limit > 0.0) {
-                result.add(new LegendItem(this.aggregatedItemsKey.toString(),
-                        this.aggregatedItemsKey.toString(), null, null,
-                        Plot.DEFAULT_LEGEND_ITEM_CIRCLE,
-                        this.aggregatedItemsPaint,
-                        Plot.DEFAULT_OUTLINE_STROKE,
-                        this.aggregatedItemsPaint));
+        if (keys != null) {
+            int section = 0;
+            Iterator iterator = keys.iterator();
+            while (iterator.hasNext()) {
+                Comparable key = (Comparable) iterator.next();
+                String label = key.toString();  // TODO: use a generator here
+                String description = label;
+                Paint paint = (Paint) this.sectionPaints.get(key);
+                LegendItem item = new LegendItem(label, description, null,
+                        null, getLegendItemShape(), paint,
+                        Plot.DEFAULT_OUTLINE_STROKE, paint);
+                item.setDataset(getDataset());
+                result.add(item);
+                section++;
             }
         }
+        if (this.limit > 0.0) {
+            result.add(new LegendItem(this.aggregatedItemsKey.toString(),
+                    this.aggregatedItemsKey.toString(), null, null,
+                    getLegendItemShape(), this.aggregatedItemsPaint,
+                    Plot.DEFAULT_OUTLINE_STROKE, this.aggregatedItemsPaint));
+        }
         return result;
     }
 
@@ -581,12 +629,31 @@ public class MultiplePiePlot extends Plot implements Cloneable, Serializable {
         if (!ObjectUtilities.equal(this.pieChart, that.pieChart)) {
             return false;
         }
+        if (!ShapeUtilities.equal(this.legendItemShape, that.legendItemShape)) {
+            return false;
+        }
         if (!super.equals(obj)) {
             return false;
         }
         return true;
     }
 
+    /**
+     * Returns a clone of the plot.
+     *
+     * @return A clone.
+     *
+     * @throws CloneNotSupportedException if some component of the plot does
+     *         not support cloning.
+     */
+    public Object clone() throws CloneNotSupportedException {
+        MultiplePiePlot clone = (MultiplePiePlot) super.clone();
+        clone.pieChart = (JFreeChart) this.pieChart.clone();
+        clone.sectionPaints = new HashMap(this.sectionPaints);
+        clone.legendItemShape = ShapeUtilities.clone(this.legendItemShape);
+        return clone;
+    }
+
     /**
      * Provides serialization support.
      *
@@ -597,6 +664,7 @@ public class MultiplePiePlot extends Plot implements Cloneable, Serializable {
     private void writeObject(ObjectOutputStream stream) throws IOException {
         stream.defaultWriteObject();
         SerialUtilities.writePaint(this.aggregatedItemsPaint, stream);
+        SerialUtilities.writeShape(this.legendItemShape, stream);
     }
 
     /**
@@ -611,8 +679,8 @@ public class MultiplePiePlot extends Plot implements Cloneable, Serializable {
         throws IOException, ClassNotFoundException {
         stream.defaultReadObject();
         this.aggregatedItemsPaint = SerialUtilities.readPaint(stream);
+        this.legendItemShape = SerialUtilities.readShape(stream);
         this.sectionPaints = new HashMap();
     }
 
-
 }
