@@ -6,22 +6,22 @@
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
- * This library is free software; you can redistribute it and/or modify it 
- * under the terms of the GNU Lesser General Public License as published by 
- * the Free Software Foundation; either version 2.1 of the License, or 
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
  * License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
- * USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+ * USA.
  *
- * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
+ * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
  * in the United States and other countries.]
  *
  * --------------
@@ -40,14 +40,14 @@
  * Changes
  * -------
  * 21-Jun-2002 : Version 1;
- * 31-Jul-2002 : Modified to use startAngle and direction, drawing modified so 
+ * 31-Jul-2002 : Modified to use startAngle and direction, drawing modified so
  *               that charts render with foreground alpha < 1.0 (DG);
- * 05-Aug-2002 : Small modification to draw method to support URLs for HTML 
+ * 05-Aug-2002 : Small modification to draw method to support URLs for HTML
  *               image maps (RA);
  * 26-Sep-2002 : Fixed errors reported by Checkstyle (DG);
- * 18-Oct-2002 : Added drawing bug fix sent in by Xun Kang, and made a couple 
+ * 18-Oct-2002 : Added drawing bug fix sent in by Xun Kang, and made a couple
  *               of other related fixes (DG);
- * 30-Oct-2002 : Changed the PieDataset interface. Fixed another drawing 
+ * 30-Oct-2002 : Changed the PieDataset interface. Fixed another drawing
  *               bug (DG);
  * 12-Nov-2002 : Fixed null pointer exception for zero or negative values (DG);
  * 07-Mar-2003 : Modified to pass pieIndex on to PieSectionEntity (DG);
@@ -56,14 +56,14 @@
  * 30-Jul-2003 : Modified entity constructor (CZ);
  * 29-Aug-2003 : Small changes for API updates in PiePlot class (DG);
  * 02-Sep-2003 : Fixed bug where the 'no data' message is not displayed (DG);
- * 08-Sep-2003 : Added internationalization via use of properties 
- *               resourceBundle (RFE 690236) (AL); 
+ * 08-Sep-2003 : Added internationalization via use of properties
+ *               resourceBundle (RFE 690236) (AL);
  * 29-Oct-2003 : Added workaround for font alignment in PDF output (DG);
  * 20-Nov-2003 : Fixed bug 845289 (sides not showing) (DG);
  * 25-Nov-2003 : Added patch (845095) to fix outline paint issues (DG);
  * 10-Mar-2004 : Numerous changes to enhance labelling (DG);
  * 31-Mar-2004 : Adjusted plot area when label generator is null (DG);
- * 08-Apr-2004 : Added flag to PiePlot class to control the treatment of null 
+ * 08-Apr-2004 : Added flag to PiePlot class to control the treatment of null
  *               values (DG);
  *               Added pieIndex to PieSectionEntity (DG);
  * 15-Nov-2004 : Removed creation of default tool tip generator (DG);
@@ -72,11 +72,11 @@
  * 27-Sep-2006 : Updated draw() method for new lookup methods (DG);
  * 22-Mar-2007 : Added equals() override (DG);
  * 18-Jun-2007 : Added handling for simple label option (DG);
- * 04-Oct-2007 : Added option to darken sides of plot - thanks to Alex Moots 
+ * 04-Oct-2007 : Added option to darken sides of plot - thanks to Alex Moots
  *               (see patch 1805262) (DG);
  * 21-Nov-2007 : Changed default depth factor, fixed labelling bugs and added
  *               debug code - see debug flags in PiePlot class (DG);
- * 20-Mar-2008 : Fixed bug 1920854 - multiple redraws of the section 
+ * 20-Mar-2008 : Fixed bug 1920854 - multiple redraws of the section
  *               labels (DG);
  *
  */
@@ -122,28 +122,28 @@ public class PiePlot3D extends PiePlot implements Serializable {
 
     /** For serialization. */
     private static final long serialVersionUID = 3408984188945161432L;
-    
+
     /** The factor of the depth of the pie from the plot height */
     private double depthFactor = 0.12;
 
-    /** 
+    /**
      * A flag that controls whether or not the sides of the pie chart
      * are rendered using a darker colour.
-     * 
+     *
      *  @since 1.0.7.
      */
-    private boolean darkerSides = false;  // default preserves previous 
+    private boolean darkerSides = false;  // default preserves previous
                                           // behaviour
-    
+
     /**
      * Creates a new instance with no dataset.
      */
     public PiePlot3D() {
-        this(null);   
+        this(null);
     }
-    
+
     /**
-     * Creates a pie chart with a three dimensional effect using the specified 
+     * Creates a pie chart with a three dimensional effect using the specified
      * dataset.
      *
      * @param dataset  the dataset (<code>null</code> permitted).
@@ -157,7 +157,7 @@ public class PiePlot3D extends PiePlot implements Serializable {
      * Returns the depth factor for the chart.
      *
      * @return The depth factor.
-     * 
+     *
      * @see #setDepthFactor(double)
      */
     public double getDepthFactor() {
@@ -169,7 +169,7 @@ public class PiePlot3D extends PiePlot implements Serializable {
      * sends a {@link PlotChangeEvent} to all registered listeners.
      *
      * @param factor  the depth factor (for example, 0.20 is twenty percent).
-     * 
+     *
      * @see #getDepthFactor()
      */
     public void setDepthFactor(double factor) {
@@ -183,9 +183,9 @@ public class PiePlot3D extends PiePlot implements Serializable {
      * section colour is an instance of {@link java.awt.Color}.
      *
      * @return A boolean.
-     * 
+     *
      * @see #setDarkerSides(boolean)
-     * 
+     *
      * @since 1.0.7
      */
     public boolean getDarkerSides() {
@@ -194,15 +194,15 @@ public class PiePlot3D extends PiePlot implements Serializable {
 
     /**
      * Sets a flag that controls whether or not the sides of the pie chart
-     * are rendered using a darker colour, and sends a {@link PlotChangeEvent} 
+     * are rendered using a darker colour, and sends a {@link PlotChangeEvent}
      * to all registered listeners.  This is only applied if the
      * section colour is an instance of {@link java.awt.Color}.
      *
-     * @param darker true to darken the sides, false to use the default 
+     * @param darker true to darken the sides, false to use the default
      *         behaviour.
-     * 
+     *
      * @see #getDarkerSides()
-     * 
+     *
      * @since 1.0.7.
      */
     public void setDarkerSides(boolean darker) {
@@ -211,16 +211,16 @@ public class PiePlot3D extends PiePlot implements Serializable {
     }
 
     /**
-     * Draws the plot on a Java 2D graphics device (such as the screen or a 
-     * printer).  This method is called by the 
-     * {@link org.jfree.chart.JFreeChart} class, you don't normally need 
+     * Draws the plot on a Java 2D graphics device (such as the screen or a
+     * printer).  This method is called by the
+     * {@link org.jfree.chart.JFreeChart} class, you don't normally need
      * to call it yourself.
      *
      * @param g2  the graphics device.
      * @param plotArea  the area within which the plot should be drawn.
      * @param anchor  the anchor point.
      * @param parentState  the state from the parent plot, if there is one.
-     * @param info  collects info about the drawing 
+     * @param info  collects info about the drawing
      *              (<code>null</code> permitted).
      */
     public void draw(Graphics2D g2, Rectangle2D plotArea, Point2D anchor,
@@ -246,9 +246,9 @@ public class PiePlot3D extends PiePlot implements Serializable {
         double gapPercent = getInteriorGap();
         double labelPercent = 0.0;
         if (getLabelGenerator() != null) {
-            labelPercent = getLabelGap() + getMaximumLabelWidth();   
+            labelPercent = getLabelGap() + getMaximumLabelWidth();
         }
-        double gapHorizontal = plotArea.getWidth() * (gapPercent 
+        double gapHorizontal = plotArea.getWidth() * (gapPercent
                 + labelPercent) * 2.0;
         double gapVertical = plotArea.getHeight() * gapPercent * 2.0;
 
@@ -260,7 +260,7 @@ public class PiePlot3D extends PiePlot implements Serializable {
             double igy1 = plotArea.getY() + vGap;
             double igy2 = plotArea.getMaxY() - vGap;
             g2.setPaint(Color.lightGray);
-            g2.draw(new Rectangle2D.Double(igx1, igy1, igx2 - igx1, 
+            g2.draw(new Rectangle2D.Double(igx1, igy1, igx2 - igx1,
                     igy2 - igy1));
         }
 
@@ -268,7 +268,7 @@ public class PiePlot3D extends PiePlot implements Serializable {
         double linkY = plotArea.getY() + gapVertical / 2;
         double linkW = plotArea.getWidth() - gapHorizontal;
         double linkH = plotArea.getHeight() - gapVertical;
-        
+
         // make the link area a square if the pie chart is to be circular...
         if (isCircular()) { // is circular?
             double min = Math.min(linkW, linkH) / 2;
@@ -277,12 +277,12 @@ public class PiePlot3D extends PiePlot implements Serializable {
             linkW = 2 * min;
             linkH = 2 * min;
         }
-        
+
         PiePlotState state = initialise(g2, plotArea, this, null, info);
 
-        // the link area defines the dog leg points for the linking lines to 
+        // the link area defines the dog leg points for the linking lines to
         // the labels
-        Rectangle2D linkAreaXX = new Rectangle2D.Double(linkX, linkY, linkW, 
+        Rectangle2D linkAreaXX = new Rectangle2D.Double(linkX, linkY, linkW,
                 linkH * (1 - this.depthFactor));
         state.setLinkArea(linkAreaXX);
 
@@ -290,38 +290,38 @@ public class PiePlot3D extends PiePlot implements Serializable {
             g2.setPaint(Color.blue);
             g2.draw(linkAreaXX);
             g2.setPaint(Color.yellow);
-            g2.draw(new Ellipse2D.Double(linkAreaXX.getX(), linkAreaXX.getY(), 
+            g2.draw(new Ellipse2D.Double(linkAreaXX.getX(), linkAreaXX.getY(),
                     linkAreaXX.getWidth(), linkAreaXX.getHeight()));
         }
-        
-        // the explode area defines the max circle/ellipse for the exploded pie 
+
+        // the explode area defines the max circle/ellipse for the exploded pie
         // sections.
         // it is defined by shrinking the linkArea by the linkMargin factor.
         double hh = linkW * getLabelLinkMargin();
         double vv = linkH * getLabelLinkMargin();
-        Rectangle2D explodeArea = new Rectangle2D.Double(linkX + hh / 2.0, 
+        Rectangle2D explodeArea = new Rectangle2D.Double(linkX + hh / 2.0,
                 linkY + vv / 2.0, linkW - hh, linkH - vv);
-       
+
         state.setExplodedPieArea(explodeArea);
-        
+
         // the pie area defines the circle/ellipse for regular pie sections.
-        // it is defined by shrinking the explodeArea by the explodeMargin 
-        // factor. 
+        // it is defined by shrinking the explodeArea by the explodeMargin
+        // factor.
         double maximumExplodePercent = getMaximumExplodePercent();
         double percent = maximumExplodePercent / (1.0 + maximumExplodePercent);
-        
+
         double h1 = explodeArea.getWidth() * percent;
         double v1 = explodeArea.getHeight() * percent;
-        Rectangle2D pieArea = new Rectangle2D.Double(explodeArea.getX() 
+        Rectangle2D pieArea = new Rectangle2D.Double(explodeArea.getX()
                 + h1 / 2.0, explodeArea.getY() + v1 / 2.0,
                 explodeArea.getWidth() - h1, explodeArea.getHeight() - v1);
 
-        // the link area defines the dog-leg point for the linking lines to 
+        // the link area defines the dog-leg point for the linking lines to
         // the labels
         int depth = (int) (pieArea.getHeight() * this.depthFactor);
-        Rectangle2D linkArea = new Rectangle2D.Double(linkX, linkY, linkW, 
+        Rectangle2D linkArea = new Rectangle2D.Double(linkX, linkY, linkW,
                 linkH - depth);
-        state.setLinkArea(linkArea);   
+        state.setLinkArea(linkArea);
 
         state.setPieArea(pieArea);
         state.setPieCenterX(pieArea.getCenterX());
@@ -346,8 +346,8 @@ public class PiePlot3D extends PiePlot implements Serializable {
             FontMetrics fm = g2.getFontMetrics(sfont);
             int stringWidth = fm.stringWidth(text);
 
-            g2.drawString(text, (int) (plotArea.getX() + (plotArea.getWidth() 
-                    - stringWidth) / 2), (int) (plotArea.getY() 
+            g2.drawString(text, (int) (plotArea.getX() + (plotArea.getWidth()
+                    - stringWidth) / 2), (int) (plotArea.getY()
                     + (plotArea.getHeight() / 2)));
             return;
         }
@@ -355,9 +355,9 @@ public class PiePlot3D extends PiePlot implements Serializable {
         // coordinates of the drawing area for the arcs to arrive at this
         // effect.
         if (isCircular()) {
-            double min = Math.min(plotArea.getWidth(), 
+            double min = Math.min(plotArea.getWidth(),
                     plotArea.getHeight()) / 2;
-            plotArea = new Rectangle2D.Double(plotArea.getCenterX() - min, 
+            plotArea = new Rectangle2D.Double(plotArea.getCenterX() - min,
                     plotArea.getCenterY() - min, 2 * min, 2 * min);
         }
         // get a list of keys...
@@ -373,7 +373,7 @@ public class PiePlot3D extends PiePlot implements Serializable {
 
         //g2.clip(clipArea);
         Composite originalComposite = g2.getComposite();
-        g2.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER, 
+        g2.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER,
                 getForegroundAlpha()));
 
         double totalValue = DatasetUtilities.calculatePieDatasetTotal(dataset);
@@ -404,12 +404,12 @@ public class PiePlot3D extends PiePlot implements Serializable {
             }
             double startAngle = getStartAngle();
             double direction = getDirection().getFactor();
-            double angle1 = startAngle + (direction * (runningTotal * 360)) 
+            double angle1 = startAngle + (direction * (runningTotal * 360))
                     / totalValue;
-            double angle2 = startAngle + (direction * (runningTotal + value) 
+            double angle2 = startAngle + (direction * (runningTotal + value)
                     * 360) / totalValue;
             if (Math.abs(angle2 - angle1) > getMinimumArcAngleToDraw()) {
-                arcList.add(new Arc2D.Double(arcX, arcY + depth, 
+                arcList.add(new Arc2D.Double(arcX, arcY + depth,
                         pieArea.getWidth(), pieArea.getHeight() - depth,
                         angle1, angle2 - angle1, Arc2D.PIE));
             }
@@ -421,17 +421,17 @@ public class PiePlot3D extends PiePlot implements Serializable {
 
         Shape oldClip = g2.getClip();
 
-        Ellipse2D top = new Ellipse2D.Double(pieArea.getX(), pieArea.getY(), 
+        Ellipse2D top = new Ellipse2D.Double(pieArea.getX(), pieArea.getY(),
                 pieArea.getWidth(), pieArea.getHeight() - depth);
 
-        Ellipse2D bottom = new Ellipse2D.Double(pieArea.getX(), pieArea.getY() 
+        Ellipse2D bottom = new Ellipse2D.Double(pieArea.getX(), pieArea.getY()
                 + depth, pieArea.getWidth(), pieArea.getHeight() - depth);
 
-        Rectangle2D lower = new Rectangle2D.Double(top.getX(), 
-                top.getCenterY(), pieArea.getWidth(), bottom.getMaxY() 
+        Rectangle2D lower = new Rectangle2D.Double(top.getX(),
+                top.getCenterY(), pieArea.getWidth(), bottom.getMaxY()
                 - top.getCenterY());
 
-        Rectangle2D upper = new Rectangle2D.Double(pieArea.getX(), top.getY(), 
+        Rectangle2D upper = new Rectangle2D.Double(pieArea.getX(), top.getY(),
                 pieArea.getWidth(), bottom.getCenterY() - top.getY());
 
         Area a = new Area(top);
@@ -450,18 +450,18 @@ public class PiePlot3D extends PiePlot implements Serializable {
         // draw the bottom circle
         int[] xs;
         int[] ys;
-        arc = new Arc2D.Double(arcX, arcY + depth, pieArea.getWidth(), 
+        arc = new Arc2D.Double(arcX, arcY + depth, pieArea.getWidth(),
                 pieArea.getHeight() - depth, 0, 360, Arc2D.PIE);
 
         int categoryCount = arcList.size();
-        for (int categoryIndex = 0; categoryIndex < categoryCount; 
+        for (int categoryIndex = 0; categoryIndex < categoryCount;
                  categoryIndex++) {
             arc = (Arc2D.Double) arcList.get(categoryIndex);
             if (arc == null) {
                 continue;
             }
             Comparable key = getSectionKey(categoryIndex);
-            paint = lookupSectionPaint(key, true);
+            paint = lookupSectionPaint(key);
             outlinePaint = lookupSectionOutlinePaint(key);
             outlineStroke = lookupSectionOutlineStroke(key);
             g2.setPaint(paint);
@@ -476,7 +476,7 @@ public class PiePlot3D extends PiePlot implements Serializable {
             // draw the height
             xs = new int[] {(int) arc.getCenterX(), (int) arc.getCenterX(),
                     (int) p1.getX(), (int) p1.getX()};
-            ys = new int[] {(int) arc.getCenterY(), (int) arc.getCenterY() 
+            ys = new int[] {(int) arc.getCenterY(), (int) arc.getCenterY()
                     - depth, (int) p1.getY() - depth, (int) p1.getY()};
             Polygon polygon = new Polygon(xs, ys, 4);
             g2.setPaint(java.awt.Color.lightGray);
@@ -499,10 +499,10 @@ public class PiePlot3D extends PiePlot implements Serializable {
             Arc2D segment = (Arc2D) iterator.next();
             if (segment != null) {
                 Comparable key = getSectionKey(cat);
-                paint = lookupSectionPaint(key, true);
+                paint = lookupSectionPaint(key);
                 outlinePaint = lookupSectionOutlinePaint(key);
                 outlineStroke = lookupSectionOutlineStroke(key);
-                drawSide(g2, pieArea, segment, front, back, paint, 
+                drawSide(g2, pieArea, segment, front, back, paint,
                         outlinePaint, outlineStroke, false, true);
             }
             cat++;
@@ -518,7 +518,7 @@ public class PiePlot3D extends PiePlot implements Serializable {
                 paint = lookupSectionPaint(key);
                 outlinePaint = lookupSectionOutlinePaint(key);
                 outlineStroke = lookupSectionOutlineStroke(key);
-                drawSide(g2, pieArea, segment, front, back, paint, 
+                drawSide(g2, pieArea, segment, front, back, paint,
                         outlinePaint, outlineStroke, true, false);
             }
             cat++;
@@ -528,16 +528,16 @@ public class PiePlot3D extends PiePlot implements Serializable {
 
         // draw the sections at the top of the pie (and set up tooltips)...
         Arc2D upperArc;
-        for (int sectionIndex = 0; sectionIndex < categoryCount; 
+        for (int sectionIndex = 0; sectionIndex < categoryCount;
                  sectionIndex++) {
             arc = (Arc2D.Double) arcList.get(sectionIndex);
             if (arc == null) {
                 continue;
             }
             upperArc = new Arc2D.Double(arcX, arcY, pieArea.getWidth(),
-                    pieArea.getHeight() - depth, arc.getAngleStart(), 
+                    pieArea.getHeight() - depth, arc.getAngleStart(),
                     arc.getAngleExtent(), Arc2D.PIE);
-            
+
             Comparable currentKey = (Comparable) sectionKeys.get(sectionIndex);
             paint = lookupSectionPaint(currentKey, true);
             outlinePaint = lookupSectionOutlinePaint(currentKey);
@@ -550,13 +550,13 @@ public class PiePlot3D extends PiePlot implements Serializable {
 
            // add a tooltip for the section...
             if (info != null) {
-                EntityCollection entities 
+                EntityCollection entities
                         = info.getOwner().getEntityCollection();
                 if (entities != null) {
                     String tip = null;
                     PieToolTipGenerator tipster = getToolTipGenerator();
                     if (tipster != null) {
-                        // @mgs: using the method's return value was missing 
+                        // @mgs: using the method's return value was missing
                         tip = tipster.generateToolTip(dataset, currentKey);
                     }
                     String url = null;
@@ -565,7 +565,7 @@ public class PiePlot3D extends PiePlot implements Serializable {
                                 getPieIndex());
                     }
                     PieSectionEntity entity = new PieSectionEntity(
-                            upperArc, dataset, getPieIndex(), sectionIndex, 
+                            upperArc, dataset, getPieIndex(), sectionIndex,
                             currentKey, tip, url);
                     entities.add(entity);
                 }
@@ -574,15 +574,15 @@ public class PiePlot3D extends PiePlot implements Serializable {
 
         List keys = dataset.getKeys();
         Rectangle2D adjustedPlotArea = new Rectangle2D.Double(
-                originalPlotArea.getX(), originalPlotArea.getY(), 
-                originalPlotArea.getWidth(), originalPlotArea.getHeight() 
+                originalPlotArea.getX(), originalPlotArea.getY(),
+                originalPlotArea.getWidth(), originalPlotArea.getHeight()
                 - depth);
         if (getSimpleLabels()) {
-            drawSimpleLabels(g2, keys, totalValue, adjustedPlotArea, 
+            drawSimpleLabels(g2, keys, totalValue, adjustedPlotArea,
                     linkArea, state);
         }
         else {
-            drawLabels(g2, keys, totalValue, adjustedPlotArea, linkArea, 
+            drawLabels(g2, keys, totalValue, adjustedPlotArea, linkArea,
                     state);
         }
 
@@ -607,14 +607,14 @@ public class PiePlot3D extends PiePlot implements Serializable {
      * @param drawBack  draw the back?
      */
     protected void drawSide(Graphics2D g2,
-                            Rectangle2D plotArea, 
-                            Arc2D arc, 
-                            Area front, 
+                            Rectangle2D plotArea,
+                            Arc2D arc,
+                            Area front,
                             Area back,
-                            Paint paint, 
+                            Paint paint,
                             Paint outlinePaint,
                             Stroke outlineStroke,
-                            boolean drawFront, 
+                            boolean drawFront,
                             boolean drawBack) {
 
         if (getDarkerSides()) {
@@ -630,7 +630,7 @@ public class PiePlot3D extends PiePlot implements Serializable {
         double end = start + extent;
 
         g2.setStroke(outlineStroke);
-        
+
         // for CLOCKWISE charts, the extent will be negative...
         if (extent < 0.0) {
 
@@ -638,12 +638,12 @@ public class PiePlot3D extends PiePlot implements Serializable {
 
                 if (!isAngleAtBack(end)) {
 
-                    if (extent > -180.0) {  // the segment is entirely at the 
+                    if (extent > -180.0) {  // the segment is entirely at the
                                             // front of the chart
                         if (drawFront) {
                             Area side = new Area(new Rectangle2D.Double(
-                                    arc.getEndPoint().getX(), plotArea.getY(), 
-                                    arc.getStartPoint().getX() 
+                                    arc.getEndPoint().getX(), plotArea.getY(),
+                                    arc.getStartPoint().getX()
                                     - arc.getEndPoint().getX(),
                                     plotArea.getHeight()));
                             side.intersect(front);
@@ -653,12 +653,12 @@ public class PiePlot3D extends PiePlot implements Serializable {
                             g2.draw(side);
                         }
                     }
-                    else {  // the segment starts at the front, and wraps all 
+                    else {  // the segment starts at the front, and wraps all
                             // the way around
                             // the back and finishes at the front again
                         Area side1 = new Area(new Rectangle2D.Double(
                                 plotArea.getX(), plotArea.getY(),
-                                arc.getStartPoint().getX() - plotArea.getX(), 
+                                arc.getStartPoint().getX() - plotArea.getX(),
                                 plotArea.getHeight()));
                         side1.intersect(front);
 
@@ -690,13 +690,13 @@ public class PiePlot3D extends PiePlot implements Serializable {
 
                     }
                 }
-                else {  // starts at the front, finishes at the back (going 
+                else {  // starts at the front, finishes at the back (going
                         // around the left side)
 
                     if (drawBack) {
                         Area side2 = new Area(new Rectangle2D.Double(
                                 plotArea.getX(), plotArea.getY(),
-                                arc.getEndPoint().getX() - plotArea.getX(), 
+                                arc.getEndPoint().getX() - plotArea.getX(),
                                 plotArea.getHeight()));
                         side2.intersect(back);
                         g2.setPaint(paint);
@@ -718,7 +718,7 @@ public class PiePlot3D extends PiePlot implements Serializable {
                     }
                 }
             }
-            else {  // the segment starts at the back (still extending 
+            else {  // the segment starts at the back (still extending
                     // CLOCKWISE)
 
                 if (!isAngleAtFront(end)) {
@@ -726,7 +726,7 @@ public class PiePlot3D extends PiePlot implements Serializable {
                         if (drawBack) {
                             Area side = new Area(new Rectangle2D.Double(
                                     arc.getStartPoint().getX(), plotArea.getY(),
-                                    arc.getEndPoint().getX() 
+                                    arc.getEndPoint().getX()
                                     - arc.getStartPoint().getX(),
                                     plotArea.getHeight()));
                             side.intersect(back);
@@ -736,7 +736,7 @@ public class PiePlot3D extends PiePlot implements Serializable {
                             g2.draw(side);
                         }
                     }
-                    else {  // starts at the back, wraps around front, and 
+                    else {  // starts at the back, wraps around front, and
                             // finishes at back again
                         Area side1 = new Area(new Rectangle2D.Double(
                                 arc.getStartPoint().getX(), plotArea.getY(),
@@ -812,7 +812,7 @@ public class PiePlot3D extends PiePlot implements Serializable {
                         if (drawFront) {
                             Area side = new Area(new Rectangle2D.Double(
                                     arc.getStartPoint().getX(), plotArea.getY(),
-                                    arc.getEndPoint().getX() 
+                                    arc.getEndPoint().getX()
                                     - arc.getStartPoint().getX(),
                                     plotArea.getHeight()));
                             side.intersect(front);
@@ -890,7 +890,7 @@ public class PiePlot3D extends PiePlot implements Serializable {
                         if (drawBack) {
                             Area side = new Area(new Rectangle2D.Double(
                                     arc.getEndPoint().getX(), plotArea.getY(),
-                                    arc.getStartPoint().getX() 
+                                    arc.getStartPoint().getX()
                                     - arc.getEndPoint().getX(),
                                     plotArea.getHeight()));
                             side.intersect(back);
@@ -900,7 +900,7 @@ public class PiePlot3D extends PiePlot implements Serializable {
                             g2.draw(side);
                         }
                     }
-                    else {  // starts at back and wraps right around to the 
+                    else {  // starts at back and wraps right around to the
                             // back again
                         Area side1 = new Area(new Rectangle2D.Double(
                                 arc.getStartPoint().getX(), plotArea.getY(),
@@ -936,7 +936,7 @@ public class PiePlot3D extends PiePlot implements Serializable {
 
                     }
                 }
-                else {  // starts at the back and finishes at the front 
+                else {  // starts at the back and finishes at the front
                         // (wrapping the left side)
                     if (drawBack) {
                         Area side1 = new Area(new Rectangle2D.Double(
@@ -978,8 +978,8 @@ public class PiePlot3D extends PiePlot implements Serializable {
     }
 
     /**
-     * A utility method that returns true if the angle represents a point at 
-     * the front of the 3D pie chart.  0 - 180 degrees is the back, 180 - 360 
+     * A utility method that returns true if the angle represents a point at
+     * the front of the 3D pie chart.  0 - 180 degrees is the back, 180 - 360
      * is the front.
      *
      * @param angle  the angle.
@@ -991,8 +991,8 @@ public class PiePlot3D extends PiePlot implements Serializable {
     }
 
     /**
-     * A utility method that returns true if the angle represents a point at 
-     * the back of the 3D pie chart.  0 - 180 degrees is the back, 180 - 360 
+     * A utility method that returns true if the angle represents a point at
+     * the back of the 3D pie chart.  0 - 180 degrees is the back, 180 - 360
      * is the front.
      *
      * @param angle  the angle.
@@ -1002,12 +1002,12 @@ public class PiePlot3D extends PiePlot implements Serializable {
     private boolean isAngleAtBack(double angle) {
         return (Math.sin(Math.toRadians(angle)) > 0.0);
     }
-    
+
     /**
      * Tests this plot for equality with an arbitrary object.
-     * 
+     *
      * @param obj  the object (<code>null</code> permitted).
-     * 
+     *
      * @return A boolean.
      */
     public boolean equals(Object obj) {
