@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,7 +27,7 @@
  * ---------
  * Plot.java
  * ---------
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   Sylvain Vieujot;
@@ -37,6 +37,7 @@
  *                   Nicolas Brodu;
  *                   Michal Krause;
  *                   Richard West, Advanced Micro Devices, Inc.;
+ *                   Peter Kolb - patch 2603321;
  *
  * Changes
  * -------
@@ -121,6 +122,9 @@
  * 07-Jun-2007 : Added new fillBackground() method to handle GradientPaint
  *               taking into account orientation (DG);
  * 25-Mar-2008 : Added fireChangeEvent() method - see patch 1914411 (DG);
+ * 15-Aug-2008 : Added setDrawingSupplier() method with notify flag (DG);
+ * 13-Jan-2009 : Added notify flag (DG);
+ * 19-Mar-2009 : Added entity support - see patch 2603321 by Peter Kolb (DG);
  *
  */
 
@@ -147,9 +151,12 @@ import java.io.Serializable;
 
 import javax.swing.event.EventListenerList;
 
+import org.jfree.chart.JFreeChart;
 import org.jfree.chart.LegendItemCollection;
 import org.jfree.chart.LegendItemSource;
 import org.jfree.chart.axis.AxisLocation;
+import org.jfree.chart.entity.EntityCollection;
+import org.jfree.chart.entity.PlotEntity;
 import org.jfree.chart.event.AxisChangeEvent;
 import org.jfree.chart.event.AxisChangeListener;
 import org.jfree.chart.event.ChartChangeEventType;
@@ -173,10 +180,9 @@ import org.jfree.util.PaintUtilities;
 import org.jfree.util.PublicCloneable;
 
 /**
- * The base class for all plots in JFreeChart.  The
- * {@link org.jfree.chart.JFreeChart} class delegates the drawing of axes and
- * data to the plot.  This base class provides facilities common to most plot
- * types.
+ * The base class for all plots in JFreeChart.  The {@link JFreeChart} class
+ * delegates the drawing of axes and data to the plot.  This base class
+ * provides facilities common to most plot types.
  */
 public abstract class Plot implements AxisChangeListener,
         DatasetChangeListener, MarkerChangeListener, LegendItemSource,
@@ -276,6 +282,15 @@ public abstract class Plot implements AxisChangeListener,
     /** Storage for registered change listeners. */
     private transient EventListenerList listenerList;
 
+    /**
+     * A flag that controls whether or not the plot will notify listeners
+     * of changes (defaults to true, but sometimes it is useful to disable
+     * this).
+     *
+     * @since 1.0.13
+     */
+    private boolean notify;
+
     /**
      * Creates a new plot.
      */
@@ -297,6 +312,7 @@ public abstract class Plot implements AxisChangeListener,
 
         this.drawingSupplier = new DefaultDrawingSupplier();
 
+        this.notify = true;
         this.listenerList = new EventListenerList();
 
     }
@@ -609,10 +625,12 @@ public abstract class Plot implements AxisChangeListener,
     }
 
     /**
-     * Sets the drawing supplier for the plot.  The drawing supplier is
-     * responsible for supplying a limitless (possibly repeating) sequence of
-     * <code>Paint</code>, <code>Stroke</code> and <code>Shape</code> objects
-     * that the plot's renderer(s) can use to populate its (their) tables.
+     * Sets the drawing supplier for the plot and sends a
+     * {@link PlotChangeEvent} to all registered listeners.  The drawing
+     * supplier is responsible for supplying a limitless (possibly repeating)
+     * sequence of <code>Paint</code>, <code>Stroke</code> and
+     * <code>Shape</code> objects that the plot's renderer(s) can use to
+     * populate its (their) tables.
      *
      * @param supplier  the new supplier.
      *
@@ -623,6 +641,28 @@ public abstract class Plot implements AxisChangeListener,
         fireChangeEvent();
     }
 
+    /**
+     * Sets the drawing supplier for the plot and, if requested, sends a
+     * {@link PlotChangeEvent} to all registered listeners.  The drawing
+     * supplier is responsible for supplying a limitless (possibly repeating)
+     * sequence of <code>Paint</code>, <code>Stroke</code> and
+     * <code>Shape</code> objects that the plot's renderer(s) can use to
+     * populate its (their) tables.
+     *
+     * @param supplier  the new supplier.
+     * @param notify  notify listeners?
+     *
+     * @see #getDrawingSupplier()
+     *
+     * @since 1.0.11
+     */
+    public void setDrawingSupplier(DrawingSupplier supplier, boolean notify) {
+        this.drawingSupplier = supplier;
+        if (notify) {
+            fireChangeEvent();
+        }
+    }
+
     /**
      * Returns the background image that is used to fill the plot's background
      * area.
@@ -857,6 +897,38 @@ public abstract class Plot implements AxisChangeListener,
         return null;
     }
 
+    /**
+     * Returns a flag that controls whether or not change events are sent to
+     * registered listeners.
+     *
+     * @return A boolean.
+     *
+     * @see #setNotify(boolean)
+     *
+     * @since 1.0.13
+     */
+    public boolean isNotify() {
+        return this.notify;
+    }
+
+    /**
+     * Sets a flag that controls whether or not listeners receive
+     * {@link PlotChangeEvent} notifications.
+     *
+     * @param notify  a boolean.
+     *
+     * @see #isNotify()
+     *
+     * @since 1.0.13
+     */
+    public void setNotify(boolean notify) {
+        this.notify = notify;
+        // if the flag is being set to true, there may be queued up changes...
+        if (notify) {
+            notifyListeners(new PlotChangeEvent(this));
+        }
+    }
+
     /**
      * Registers an object for notification of changes to the plot.
      *
@@ -885,6 +957,11 @@ public abstract class Plot implements AxisChangeListener,
      * @param event  information about the change event.
      */
     public void notifyListeners(PlotChangeEvent event) {
+        // if the 'notify' flag has been switched to false, we don't notify
+        // the listeners
+        if (!this.notify) {
+            return;
+        }
         Object[] listeners = this.listenerList.getListenerList();
         for (int i = listeners.length - 2; i >= 0; i -= 2) {
             if (listeners[i] == PlotChangeListener.class) {
@@ -1067,6 +1144,30 @@ public abstract class Plot implements AxisChangeListener,
         g2.setClip(savedClip);
     }
 
+    /**
+     * Creates a plot entity that contains a reference to the plot and the
+     * data area as shape.
+     *
+     * @param dataArea  the data area used as hot spot for the entity.
+     * @param plotState  the plot rendering info containing a reference to the
+     *     EntityCollection.
+     * @param toolTip  the tool tip (defined in the respective Plot
+     *     subclass) (<code>null</code> permitted).
+     * @param urlText  the url (defined in the respective Plot subclass)
+     *     (<code>null</code> permitted).
+     *
+     *  @since 1.0.13
+     */
+ 	protected void createAndAddEntity(Rectangle2D dataArea,
+            PlotRenderingInfo plotState, String toolTip, String urlText){
+		if (plotState != null && plotState.getOwner() != null) {
+			EntityCollection e = plotState.getOwner().getEntityCollection();
+			if (e != null) {
+                e.add(new PlotEntity(dataArea, this, toolTip, urlText));
+            }
+		}
+	}
+
     /**
      * Handles a 'click' on the plot.  Since the plot does not maintain any
      * information about where it has been drawn, the plot rendering info is
@@ -1235,6 +1336,9 @@ public abstract class Plot implements AxisChangeListener,
         if (!this.drawingSupplier.equals(that.drawingSupplier)) {
             return false;
         }
+        if (this.notify != that.notify) {
+            return false;
+        }
         return true;
     }
 
