@@ -2,33 +2,33 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2005, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
- * This library is free software; you can redistribute it and/or modify it 
- * under the terms of the GNU Lesser General Public License as published by 
- * the Free Software Foundation; either version 2.1 of the License, or 
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
  * License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
- * USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+ * USA.
  *
- * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
+ * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
  * in the United States and other countries.]
  *
  * -----------------
  * WaferMapPlot.java
  * -----------------
  *
- * (C) Copyright 2003, 2004, by Robert Redburn and Contributors.
+ * (C) Copyright 2003-2008, by Robert Redburn and Contributors.
  *
  * Original Author:  Robert Redburn;
  * Contributor(s):   David Gilbert (for Object Refinery Limited);
@@ -37,12 +37,14 @@
  * -------
  * 25-Nov-2003 : Version 1 contributed by Robert Redburn (DG);
  * 05-May-2005 : Updated draw() method parameters (DG);
- * 10-Jun-2005 : Changed private --> protected for drawChipGrid(), 
+ * 10-Jun-2005 : Changed private --> protected for drawChipGrid(),
  *               drawWaferEdge() and getWafterEdge() (DG);
  * 16-Jun-2005 : Added default constructor and setDataset() method (DG);
+ * 18-Dec-2008 : Use ResourceBundleWrapper - see patch 1607918 by
+ *               Jess Thrysoee (DG);
  *
  */
- 
+
 package org.jfree.chart.plot;
 
 import java.awt.BasicStroke;
@@ -63,6 +65,7 @@ import org.jfree.chart.event.PlotChangeEvent;
 import org.jfree.chart.event.RendererChangeEvent;
 import org.jfree.chart.event.RendererChangeListener;
 import org.jfree.chart.renderer.WaferMapRenderer;
+import org.jfree.chart.util.ResourceBundleWrapper;
 import org.jfree.data.general.DatasetChangeEvent;
 import org.jfree.data.general.WaferMapDataset;
 import org.jfree.ui.RectangleInsets;
@@ -71,12 +74,11 @@ import org.jfree.ui.RectangleInsets;
  * A wafer map plot.
  */
 public class WaferMapPlot extends Plot implements RendererChangeListener,
-                                                  Cloneable,
-                                                  Serializable {
+        Cloneable, Serializable {
 
     /** For serialization. */
     private static final long serialVersionUID = 4668320403707308155L;
-    
+
     /** The default grid line stroke. */
     public static final Stroke DEFAULT_GRIDLINE_STROKE = new BasicStroke(0.5f,
         BasicStroke.CAP_BUTT,
@@ -92,17 +94,18 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
     public static final boolean DEFAULT_CROSSHAIR_VISIBLE = false;
 
     /** The default crosshair stroke. */
-    public static final Stroke DEFAULT_CROSSHAIR_STROKE 
-        = DEFAULT_GRIDLINE_STROKE;
+    public static final Stroke DEFAULT_CROSSHAIR_STROKE
+            = DEFAULT_GRIDLINE_STROKE;
 
     /** The default crosshair paint. */
     public static final Paint DEFAULT_CROSSHAIR_PAINT = Color.blue;
 
     /** The resourceBundle for the localization. */
-    protected static ResourceBundle localizationResources = 
-        ResourceBundle.getBundle("org.jfree.chart.plot.LocalizationBundle");
+    protected static ResourceBundle localizationResources
+            = ResourceBundleWrapper.getBundle(
+                    "org.jfree.chart.plot.LocalizationBundle");
 
-    /** The plot orientation. 
+    /** The plot orientation.
      *  vertical = notch down
      *  horizontal = notch right
      */
@@ -111,9 +114,9 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
     /** The dataset. */
     private WaferMapDataset dataset;
 
-    /** 
-     * Object responsible for drawing the visual representation of each point 
-     * on the plot. 
+    /**
+     * Object responsible for drawing the visual representation of each point
+     * on the plot.
      */
     private WaferMapRenderer renderer;
 
@@ -121,12 +124,12 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
      * Creates a new plot with no dataset.
      */
     public WaferMapPlot() {
-        this(null);   
+        this(null);
     }
-    
+
     /**
      * Creates a new plot.
-     * 
+     *
      * @param dataset  the dataset (<code>null</code> permitted).
      */
     public WaferMapPlot(WaferMapDataset dataset) {
@@ -144,7 +147,7 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
         super();
 
         this.orientation = PlotOrientation.VERTICAL;
-        
+
         this.dataset = dataset;
         if (dataset != null) {
             dataset.addChangeListener(this);
@@ -169,7 +172,7 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
 
     /**
      * Returns the dataset
-     * 
+     *
      * @return The dataset (possibly <code>null</code>).
      */
     public WaferMapDataset getDataset() {
@@ -179,11 +182,11 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
     /**
      * Sets the dataset used by the plot and sends a {@link PlotChangeEvent}
      * to all registered listeners.
-     * 
+     *
      * @param dataset  the dataset (<code>null</code> permitted).
      */
     public void setDataset(WaferMapDataset dataset) {
-        // if there is an existing dataset, remove the plot from the list of 
+        // if there is an existing dataset, remove the plot from the list of
         // change listeners...
         if (this.dataset != null) {
             this.dataset.removeChangeListener(this);
@@ -199,10 +202,10 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
         // send a dataset change event to self to trigger plot change event
         datasetChanged(new DatasetChangeEvent(this, dataset));
     }
-    
+
     /**
-     * Sets the item renderer, and notifies all listeners of a change to the 
-     * plot.  If the renderer is set to <code>null</code>, no chart will be 
+     * Sets the item renderer, and notifies all listeners of a change to the
+     * plot.  If the renderer is set to <code>null</code>, no chart will be
      * drawn.
      *
      * @param renderer  the new renderer (<code>null</code> permitted).
@@ -217,10 +220,10 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
         }
         fireChangeEvent();
     }
-    
+
     /**
      * Draws the wafermap view.
-     * 
+     *
      * @param g2  the graphics device.
      * @param area  the plot area.
      * @param anchor  the anchor point (<code>null</code> permitted).
@@ -228,7 +231,7 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
      * @param info  the plot rendering info.
      */
     public void draw(Graphics2D g2, Rectangle2D area, Point2D anchor,
-                     PlotState state, 
+                     PlotState state,
                      PlotRenderingInfo info) {
 
         // if the plot area is too small, just return...
@@ -247,19 +250,19 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
         RectangleInsets insets = getInsets();
         insets.trim(area);
 
-        drawChipGrid(g2, area);       
+        drawChipGrid(g2, area);
         drawWaferEdge(g2, area);
-        
+
     }
 
     /**
      * Calculates and draws the chip locations on the wafer.
-     * 
+     *
      * @param g2  the graphics device.
      * @param plotArea  the plot area.
      */
     protected void drawChipGrid(Graphics2D g2, Rectangle2D plotArea) {
-        
+
         Shape savedClip = g2.getClip();
         g2.setClip(getWaferEdge(plotArea));
         Rectangle2D chip = new Rectangle2D.Double();
@@ -281,33 +284,33 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
             if (plotArea.getWidth() > plotArea.getHeight()) {
                 major = plotArea.getWidth();
                 minor = plotArea.getHeight();
-            } 
+            }
             else {
                 major = plotArea.getHeight();
                 minor = plotArea.getWidth();
-            } 
+            }
             //set upperLeft point
             if (plotArea.getWidth() == minor) { // x is minor
                 startY += (major - minor) / 2;
-                chipWidth = (plotArea.getWidth() - (space * xchips - 1)) 
+                chipWidth = (plotArea.getWidth() - (space * xchips - 1))
                     / xchips;
-                chipHeight = (plotArea.getWidth() - (space * ychips - 1)) 
+                chipHeight = (plotArea.getWidth() - (space * ychips - 1))
                     / ychips;
             }
             else { // y is minor
                 startX += (major - minor) / 2;
-                chipWidth = (plotArea.getHeight() - (space * xchips - 1)) 
+                chipWidth = (plotArea.getHeight() - (space * xchips - 1))
                     / xchips;
-                chipHeight = (plotArea.getHeight() - (space * ychips - 1)) 
+                chipHeight = (plotArea.getHeight() - (space * ychips - 1))
                     / ychips;
             }
         }
-        
+
         for (int x = 1; x <= xchips; x++) {
-            double upperLeftX = (startX - chipWidth) + (chipWidth * x) 
+            double upperLeftX = (startX - chipWidth) + (chipWidth * x)
                 + (space * (x - 1));
             for (int y = 1; y <= ychips; y++) {
-                double upperLeftY = (startY - chipHeight) + (chipHeight * y) 
+                double upperLeftY = (startY - chipHeight) + (chipHeight * y)
                     + (space * (y - 1));
                 chip.setFrame(upperLeftX, upperLeftY, chipWidth, chipHeight);
                 g2.setColor(Color.white);
@@ -317,7 +320,7 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
                             this.dataset.getChipValue(x - 1, ychips - y - 1)
                         )
                     );
-                } 
+                }
                 g2.fill(chip);
                 g2.setColor(Color.lightGray);
                 g2.draw(chip);
@@ -328,9 +331,9 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
 
     /**
      * Calculates the location of the waferedge.
-     * 
+     *
      * @param plotArea  the plot area.
-     * 
+     *
      * @return The wafer edge.
      */
     protected Ellipse2D getWaferEdge(Rectangle2D plotArea) {
@@ -345,11 +348,11 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
             if (plotArea.getWidth() > plotArea.getHeight()) {
                 major = plotArea.getWidth();
                 minor = plotArea.getHeight();
-            } 
+            }
             else {
                 major = plotArea.getHeight();
                 minor = plotArea.getWidth();
-            } 
+            }
             //ellipse diameter is the minor dimension
             diameter = minor;
             //set upperLeft point
@@ -360,13 +363,13 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
                 upperLeftX = plotArea.getX() + (major - minor) / 2;
             }
         }
-        edge.setFrame(upperLeftX, upperLeftY, diameter, diameter); 
-        return edge;        
+        edge.setFrame(upperLeftX, upperLeftY, diameter, diameter);
+        return edge;
     }
 
     /**
      * Draws the waferedge, including the notch.
-     * 
+     *
      * @param g2  the graphics device.
      * @param plotArea  the plot area.
      */
@@ -382,9 +385,9 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
         Rectangle2D waferFrame = waferEdge.getFrame();
         double notchDiameter = waferFrame.getWidth() * 0.04;
         if (this.orientation == PlotOrientation.HORIZONTAL) {
-            Rectangle2D notchFrame = 
+            Rectangle2D notchFrame =
                 new Rectangle2D.Double(
-                    waferFrame.getX() + waferFrame.getWidth() 
+                    waferFrame.getX() + waferFrame.getWidth()
                     - (notchDiameter / 2), waferFrame.getY()
                     + (waferFrame.getHeight() / 2) - (notchDiameter / 2),
                     notchDiameter, notchDiameter
@@ -392,25 +395,25 @@ public class WaferMapPlot extends Plot implements RendererChangeListener,
             notch = new Arc2D.Double(notchFrame, 90d, 180d, Arc2D.OPEN);
         }
         else {
-            Rectangle2D notchFrame = 
+            Rectangle2D notchFrame =
                 new Rectangle2D.Double(
-                    waferFrame.getX() + (waferFrame.getWidth() / 2) 
-                    - (notchDiameter / 2), waferFrame.getY() 
+                    waferFrame.getX() + (waferFrame.getWidth() / 2)
+                    - (notchDiameter / 2), waferFrame.getY()
                     + waferFrame.getHeight() - (notchDiameter / 2),
                     notchDiameter, notchDiameter
                 );
-            notch = new Arc2D.Double(notchFrame, 0d, 180d, Arc2D.OPEN);        
+            notch = new Arc2D.Double(notchFrame, 0d, 180d, Arc2D.OPEN);
         }
         g2.setColor(Color.white);
         g2.fill(notch);
         g2.setColor(Color.black);
         g2.draw(notch);
-        
+
     }
 
     /**
      * Return the legend items from the renderer.
-     * 
+     *
      * @return The legend items.
      */
     public LegendItemCollection getLegendItems() {
