@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,10 +27,11 @@
  * ----------------
  * BarRenderer.java
  * ----------------
- * (C) Copyright 2002-2008, by Object Refinery Limited.
+ * (C) Copyright 2002-2009, by Object Refinery Limited.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   Christian W. Zuckschwerdt;
+ *                   Peter Kolb (patch 2497611);
  *
  * Changes
  * -------
@@ -82,6 +83,12 @@
  * 18-May-2007 : Set dataset and seriesKey for LegendItem (DG);
  * 07-May-2008 : If minimumBarLength is > 0.0, extend the non-base end of the
  *               bar (DG);
+ * 17-Jun-2008 : Apply legend shape, font and paint attributes (DG);
+ * 24-Jun-2008 : Added barPainter mechanism (DG);
+ * 26-Jun-2008 : Added crosshair support (DG);
+ * 13-Aug-2008 : Added shadowPaint attribute (DG);
+ * 14-Jan-2009 : Added support for seriesVisible flags (PK);
+ * 03-Feb-2009 : Added defaultShadowsVisible flag - see patch 2511330 (PK);
  *
  */
 
@@ -90,7 +97,6 @@ package org.jfree.chart.renderer.category;
 import java.awt.BasicStroke;
 import java.awt.Color;
 import java.awt.Font;
-import java.awt.GradientPaint;
 import java.awt.Graphics2D;
 import java.awt.Paint;
 import java.awt.Shape;
@@ -98,6 +104,9 @@ import java.awt.Stroke;
 import java.awt.geom.Line2D;
 import java.awt.geom.Point2D;
 import java.awt.geom.Rectangle2D;
+import java.io.IOException;
+import java.io.ObjectInputStream;
+import java.io.ObjectOutputStream;
 import java.io.Serializable;
 
 import org.jfree.chart.LegendItem;
@@ -114,18 +123,25 @@ import org.jfree.chart.plot.PlotRenderingInfo;
 import org.jfree.data.Range;
 import org.jfree.data.category.CategoryDataset;
 import org.jfree.data.general.DatasetUtilities;
+import org.jfree.io.SerialUtilities;
 import org.jfree.text.TextUtilities;
 import org.jfree.ui.GradientPaintTransformer;
 import org.jfree.ui.RectangleEdge;
 import org.jfree.ui.StandardGradientPaintTransformer;
 import org.jfree.util.ObjectUtilities;
+import org.jfree.util.PaintUtilities;
 import org.jfree.util.PublicCloneable;
 
 /**
  * A {@link CategoryItemRenderer} that draws individual data items as bars.
+ * The example shown here is generated by the <code>BarChartDemo1.java</code>
+ * program included in the JFreeChart Demo Collection:
+ * <br><br>
+ * <img src="../../../../../images/BarRendererSample.png"
+ * alt="BarRendererSample.png" />
  */
 public class BarRenderer extends AbstractCategoryItemRenderer
-                         implements Cloneable, PublicCloneable, Serializable {
+        implements Cloneable, PublicCloneable, Serializable {
 
     /** For serialization. */
     private static final long serialVersionUID = 6000649414965887481L;
@@ -139,6 +155,69 @@ public class BarRenderer extends AbstractCategoryItemRenderer
      */
     public static final double BAR_OUTLINE_WIDTH_THRESHOLD = 3.0;
 
+    /**
+     * The default bar painter assigned to each new instance of this renderer.
+     *
+     * @since 1.0.11
+     */
+    private static BarPainter defaultBarPainter = new GradientBarPainter();
+
+    /**
+     * Returns the default bar painter.
+     *
+     * @return The default bar painter.
+     *
+     * @since 1.0.11
+     */
+    public static BarPainter getDefaultBarPainter() {
+        return BarRenderer.defaultBarPainter;
+    }
+
+    /**
+     * Sets the default bar painter.
+     *
+     * @param painter  the painter (<code>null</code> not permitted).
+     *
+     * @since 1.0.11
+     */
+    public static void setDefaultBarPainter(BarPainter painter) {
+        if (painter == null) {
+            throw new IllegalArgumentException("Null 'painter' argument.");
+        }
+        BarRenderer.defaultBarPainter = painter;
+    }
+
+    /**
+     * The default value for the initialisation of the shadowsVisible flag.
+     */
+    private static boolean defaultShadowsVisible = true;
+
+    /**
+     * Returns the default value for the <code>shadowsVisible</code> flag.
+     *
+     * @return A boolean.
+     *
+     * @see #setDefaultShadowsVisible(boolean)
+     *
+     * @since 1.0.13
+     */
+    public static boolean getDefaultShadowsVisible() {
+        return BarRenderer.defaultShadowsVisible;
+    }
+
+    /**
+     * Sets the default value for the shadows visible flag.
+     *
+     * @param visible  the new value for the default.
+     *
+     * @see #getDefaultShadowsVisible()
+     *
+     * @since 1.0.13
+     */
+    public static void setDefaultShadowsVisible(boolean visible) {
+        BarRenderer.defaultShadowsVisible = visible;
+    }
+
     /** The margin between items (bars) within a category. */
     private double itemMargin;
 
@@ -186,6 +265,41 @@ public class BarRenderer extends AbstractCategoryItemRenderer
      */
     private boolean includeBaseInRange;
 
+    /**
+     * The bar painter (never <code>null</code>).
+     *
+     * @since 1.0.11
+     */
+    private BarPainter barPainter;
+
+    /**
+     * The flag that controls whether or not shadows are drawn for the bars.
+     *
+     * @since 1.0.11
+     */
+    private boolean shadowsVisible;
+
+    /**
+     * The shadow paint.
+     *
+     * @since 1.0.11
+     */
+    private transient Paint shadowPaint;
+
+    /**
+     * The x-offset for the shadow effect.
+     *
+     * @since 1.0.11
+     */
+    private double shadowXOffset;
+
+    /**
+     * The y-offset for the shadow effect.
+     *
+     * @since 1.0.11
+     */
+    private double shadowYOffset;
+
     /**
      * Creates a new bar renderer with default settings.
      */
@@ -201,6 +315,12 @@ public class BarRenderer extends AbstractCategoryItemRenderer
         this.negativeItemLabelPositionFallback = null;
         this.gradientPaintTransformer = new StandardGradientPaintTransformer();
         this.minimumBarLength = 0.0;
+        setBaseLegendShape(new Rectangle2D.Double(-4.0, -4.0, 8.0, 8.0));
+        this.barPainter = getDefaultBarPainter();
+        this.shadowsVisible = getDefaultShadowsVisible();
+        this.shadowPaint = Color.gray;
+        this.shadowXOffset = 4.0;
+        this.shadowYOffset = 4.0;
     }
 
     /**
@@ -454,6 +574,141 @@ public class BarRenderer extends AbstractCategoryItemRenderer
         }
     }
 
+    /**
+     * Returns the bar painter.
+     *
+     * @return The bar painter (never <code>null</code>).
+     *
+     * @see #setBarPainter(BarPainter)
+     *
+     * @since 1.0.11
+     */
+    public BarPainter getBarPainter() {
+        return this.barPainter;
+    }
+
+    /**
+     * Sets the bar painter for this renderer and sends a
+     * {@link RendererChangeEvent} to all registered listeners.
+     *
+     * @param painter  the painter (<code>null</code> not permitted).
+     *
+     * @see #getBarPainter()
+     *
+     * @since 1.0.11
+     */
+    public void setBarPainter(BarPainter painter) {
+        if (painter == null) {
+            throw new IllegalArgumentException("Null 'painter' argument.");
+        }
+        this.barPainter = painter;
+        fireChangeEvent();
+    }
+
+    /**
+     * Returns the flag that controls whether or not shadows are drawn for
+     * the bars.
+     *
+     * @return A boolean.
+     *
+     * @since 1.0.11
+     */
+    public boolean getShadowsVisible() {
+        return this.shadowsVisible;
+    }
+
+    /**
+     * Sets the flag that controls whether or not shadows are
+     * drawn by the renderer.
+     *
+     * @param visible  the new flag value.
+     *
+     * @since 1.0.11
+     */
+    public void setShadowVisible(boolean visible) {
+        this.shadowsVisible = visible;
+        fireChangeEvent();
+    }
+
+    /**
+     * Returns the shadow paint.
+     *
+     * @return The shadow paint.
+     *
+     * @see #setShadowPaint(Paint)
+     *
+     * @since 1.0.11
+     */
+    public Paint getShadowPaint() {
+        return this.shadowPaint;
+    }
+
+    /**
+     * Sets the shadow paint and sends a {@link RendererChangeEvent} to all
+     * registered listeners.
+     *
+     * @param paint  the paint (<code>null</code> not permitted).
+     *
+     * @see #getShadowPaint()
+     *
+     * @since 1.0.11
+     */
+    public void setShadowPaint(Paint paint) {
+        if (paint == null) {
+            throw new IllegalArgumentException("Null 'paint' argument.");
+        }
+        this.shadowPaint = paint;
+        fireChangeEvent();
+    }
+
+    /**
+     * Returns the shadow x-offset.
+     *
+     * @return The shadow x-offset.
+     *
+     * @since 1.0.11
+     */
+    public double getShadowXOffset() {
+        return this.shadowXOffset;
+    }
+
+    /**
+     * Sets the x-offset for the bar shadow and sends a
+     * {@link RendererChangeEvent} to all registered listeners.
+     *
+     * @param offset  the offset.
+     *
+     * @since 1.0.11
+     */
+    public void setShadowXOffset(double offset) {
+        this.shadowXOffset = offset;
+        fireChangeEvent();
+    }
+
+    /**
+     * Returns the shadow y-offset.
+     *
+     * @return The shadow y-offset.
+     *
+     * @since 1.0.11
+     */
+    public double getShadowYOffset() {
+        return this.shadowYOffset;
+    }
+
+    /**
+     * Sets the y-offset for the bar shadow and sends a
+     * {@link RendererChangeEvent} to all registered listeners.
+     *
+     * @param offset  the offset.
+     *
+     * @since 1.0.11
+     */
+    public void setShadowYOffset(double offset) {
+        this.shadowYOffset = offset;
+        fireChangeEvent();
+    }
+
     /**
      * Returns the lower clip value.  This value is recalculated in the
      * initialise() method.
@@ -527,7 +782,8 @@ public class BarRenderer extends AbstractCategoryItemRenderer
         CategoryDataset dataset = plot.getDataset(rendererIndex);
         if (dataset != null) {
             int columns = dataset.getColumnCount();
-            int rows = dataset.getRowCount();
+            int rows = state.getVisibleSeriesCount() >= 0
+                    ? state.getVisibleSeriesCount() : dataset.getRowCount();
             double space = 0.0;
             PlotOrientation orientation = plot.getOrientation();
             if (orientation == PlotOrientation.HORIZONTAL) {
@@ -589,7 +845,8 @@ public class BarRenderer extends AbstractCategoryItemRenderer
         }
         double barW0 = domainAxis.getCategoryStart(column, getColumnCount(),
                 dataArea, plot.getDomainAxisEdge());
-        int seriesCount = getRowCount();
+        int seriesCount = state.getVisibleSeriesCount() >= 0
+                ? state.getVisibleSeriesCount() : getRowCount();
         int categoryCount = getColumnCount();
         if (seriesCount > 1) {
             double seriesGap = space * getItemMargin()
@@ -643,6 +900,9 @@ public class BarRenderer extends AbstractCategoryItemRenderer
      *         <code>null</code> or empty).
      */
     public Range findRangeBounds(CategoryDataset dataset) {
+        if (dataset == null) {
+            return null;
+        }
         Range result = DatasetUtilities.findRangeBounds(dataset);
         if (result != null) {
             if (this.includeBaseInRange) {
@@ -686,7 +946,7 @@ public class BarRenderer extends AbstractCategoryItemRenderer
             urlText = getLegendItemURLGenerator().generateLabel(dataset,
                     series);
         }
-        Shape shape = new Rectangle2D.Double(-4.0, -4.0, 8.0, 8.0);
+        Shape shape = lookupLegendShape(series);
         Paint paint = lookupSeriesPaint(series);
         Paint outlinePaint = lookupSeriesOutlinePaint(series);
         Stroke outlineStroke = lookupSeriesOutlineStroke(series);
@@ -695,6 +955,11 @@ public class BarRenderer extends AbstractCategoryItemRenderer
                 urlText, true, shape, true, paint, isDrawBarOutline(),
                 outlinePaint, outlineStroke, false, new Line2D.Float(),
                 new BasicStroke(1.0f), Color.black);
+        result.setLabelFont(lookupLegendTextFont(series));
+        Paint labelPaint = lookupLegendTextPaint(series);
+        if (labelPaint != null) {
+            result.setLabelPaint(labelPaint);
+        }
         result.setDataset(dataset);
         result.setDatasetIndex(datasetIndex);
         result.setSeriesKey(dataset.getRowKey(series));
@@ -730,16 +995,22 @@ public class BarRenderer extends AbstractCategoryItemRenderer
                          int column,
                          int pass) {
 
+        // nothing is drawn if the row index is not included in the list with
+        // the indices of the visible rows...
+        int visibleRow = state.getVisibleSeriesIndex(row);
+        if (visibleRow < 0) {
+            return;
+        }
         // nothing is drawn for null values...
         Number dataValue = dataset.getValue(row, column);
         if (dataValue == null) {
             return;
         }
 
-        double value = dataValue.doubleValue();
+        final double value = dataValue.doubleValue();
         PlotOrientation orientation = plot.getOrientation();
         double barW0 = calculateBarW0(plot, orientation, dataArea, domainAxis,
-                state, row, column);
+                state, visibleRow, column);
         double[] barL0L1 = calculateBarL0L1(value);
         if (barL0L1 == null) {
             return;  // the bar is not visible
@@ -765,14 +1036,23 @@ public class BarRenderer extends AbstractCategoryItemRenderer
             barLengthAdj = getMinimumBarLength() - barLength;
         }
         double barL0Adj = 0.0;
+        RectangleEdge barBase;
         if (orientation == PlotOrientation.HORIZONTAL) {
             if (positive && inverted || !positive && !inverted) {
                 barL0Adj = barLengthAdj;
+                barBase = RectangleEdge.RIGHT;
+            }
+            else {
+                barBase = RectangleEdge.LEFT;
             }
         }
         else {
             if (positive && !inverted || !positive && inverted) {
                 barL0Adj = barLengthAdj;
+                barBase = RectangleEdge.BOTTOM;
+            }
+            else {
+                barBase = RectangleEdge.TOP;
             }
         }
 
@@ -786,33 +1066,25 @@ public class BarRenderer extends AbstractCategoryItemRenderer
             bar = new Rectangle2D.Double(barW0, barL0 - barL0Adj,
                     state.getBarWidth(), barLength + barLengthAdj);
         }
-        Paint itemPaint = getItemPaint(row, column);
-        GradientPaintTransformer t = getGradientPaintTransformer();
-        if (t != null && itemPaint instanceof GradientPaint) {
-            itemPaint = t.transform((GradientPaint) itemPaint, bar);
+        if (getShadowsVisible()) {
+            this.barPainter.paintBarShadow(g2, this, row, column, bar, barBase,
+                true);
         }
-        g2.setPaint(itemPaint);
-        g2.fill(bar);
+        this.barPainter.paintBar(g2, this, row, column, bar, barBase);
 
-        // draw the outline...
-        if (isDrawBarOutline()
-                && state.getBarWidth() > BAR_OUTLINE_WIDTH_THRESHOLD) {
-            Stroke stroke = getItemOutlineStroke(row, column);
-            Paint paint = getItemOutlinePaint(row, column);
-            if (stroke != null && paint != null) {
-                g2.setStroke(stroke);
-                g2.setPaint(paint);
-                g2.draw(bar);
-            }
-        }
-
-        CategoryItemLabelGenerator generator
-            = getItemLabelGenerator(row, column);
+        CategoryItemLabelGenerator generator = getItemLabelGenerator(row,
+                column);
         if (generator != null && isItemLabelVisible(row, column)) {
             drawItemLabel(g2, dataset, row, column, plot, generator, bar,
                     (value < 0.0));
         }
 
+        // submit the current data point as a crosshair candidate
+        int datasetIndex = plot.indexOf(dataset);
+        updateCrosshairValues(state.getCrosshairState(),
+                dataset.getRowKey(row), dataset.getColumnKey(column), value,
+                datasetIndex, barW0, barL0, orientation);
+
         // add an item entity, if this information is being collected
         EntityCollection entities = state.getEntityCollection();
         if (entities != null) {
@@ -1060,16 +1332,12 @@ public class BarRenderer extends AbstractCategoryItemRenderer
      * @return A boolean.
      */
     public boolean equals(Object obj) {
-
         if (obj == this) {
             return true;
         }
         if (!(obj instanceof BarRenderer)) {
             return false;
         }
-        if (!super.equals(obj)) {
-            return false;
-        }
         BarRenderer that = (BarRenderer) obj;
         if (this.base != that.base) {
             return false;
@@ -1098,8 +1366,48 @@ public class BarRenderer extends AbstractCategoryItemRenderer
             that.negativeItemLabelPositionFallback)) {
             return false;
         }
-        return true;
+        if (!this.barPainter.equals(that.barPainter)) {
+            return false;
+        }
+        if (this.shadowsVisible != that.shadowsVisible) {
+            return false;
+        }
+        if (!PaintUtilities.equal(this.shadowPaint, that.shadowPaint)) {
+            return false;
+        }
+        if (this.shadowXOffset != that.shadowXOffset) {
+            return false;
+        }
+        if (this.shadowYOffset != that.shadowYOffset) {
+            return false;
+        }
+        return super.equals(obj);
+    }
 
+    /**
+     * Provides serialization support.
+     *
+     * @param stream  the output stream.
+     *
+     * @throws IOException  if there is an I/O error.
+     */
+    private void writeObject(ObjectOutputStream stream) throws IOException {
+        stream.defaultWriteObject();
+        SerialUtilities.writePaint(this.shadowPaint, stream);
+    }
+
+    /**
+     * Provides serialization support.
+     *
+     * @param stream  the input stream.
+     *
+     * @throws IOException  if there is an I/O error.
+     * @throws ClassNotFoundException  if there is a classpath problem.
+     */
+    private void readObject(ObjectInputStream stream)
+            throws IOException, ClassNotFoundException {
+        stream.defaultReadObject();
+        this.shadowPaint = SerialUtilities.readPaint(stream);
     }
 
 }
