@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,11 +27,12 @@
  * ------------------------
  * IntervalBarRenderer.java
  * ------------------------
- * (C) Copyright 2002-2008, by Jeremy Bowman.
+ * (C) Copyright 2002-2009, by Jeremy Bowman.
  *
  * Original Author:  Jeremy Bowman;
  * Contributor(s):   David Gilbert (for Object Refinery Limited);
  *                   Christian W. Zuckschwerdt;
+ *                   Peter Kolb (patch 2497611);
  *
  * Changes
  * -------
@@ -55,16 +56,16 @@
  * 20-Apr-2005 : Renamed CategoryLabelGenerator
  *               --> CategoryItemLabelGenerator (DG);
  * 02-Feb-2007 : Removed author tags all over JFreeChart sources (DG);
+ * 24-Jun-2008 : Added new barPainter mechanism (DG);
+ * 07-Oct-2008 : Override equals() method to fix minor bug (DG);
+ * 14-Jan-2009 : Added support for seriesVisible flags (PK);
  *
  */
 
 package org.jfree.chart.renderer.category;
 
 import java.awt.Graphics2D;
-import java.awt.Paint;
-import java.awt.Stroke;
 import java.awt.geom.Rectangle2D;
-import java.io.Serializable;
 
 import org.jfree.chart.axis.CategoryAxis;
 import org.jfree.chart.axis.ValueAxis;
@@ -75,17 +76,18 @@ import org.jfree.chart.plot.PlotOrientation;
 import org.jfree.data.category.CategoryDataset;
 import org.jfree.data.category.IntervalCategoryDataset;
 import org.jfree.ui.RectangleEdge;
-import org.jfree.util.PublicCloneable;
 
 /**
  * A renderer that handles the drawing of bars for a bar plot where
- * each bar has a high and low value.
- * <p>
- * For use with the {@link CategoryPlot} class.
+ * each bar has a high and low value.  This renderer is for use with the
+ * {@link CategoryPlot} class.  The example shown here is generated by the
+ * <code>IntervalBarChartDemo1.java</code> program included in the JFreeChart
+ * Demo Collection:
+ * <br><br>
+ * <img src="../../../../../images/IntervalBarRendererSample.png"
+ * alt="IntervalBarRendererSample.png" />
  */
-public class IntervalBarRenderer extends BarRenderer
-        implements CategoryItemRenderer, Cloneable, PublicCloneable,
-                   Serializable {
+public class IntervalBarRenderer extends BarRenderer {
 
     /** For serialization. */
     private static final long serialVersionUID = -5068857361615528725L;
@@ -157,7 +159,13 @@ public class IntervalBarRenderer extends BarRenderer
                                  int row,
                                  int column) {
 
-        int seriesCount = getRowCount();
+        int visibleRow = state.getVisibleSeriesIndex(row);
+        if (visibleRow < 0) {
+            return;
+        }
+        int seriesCount = state.getVisibleSeriesCount() >= 0
+                ? state.getVisibleSeriesCount() : getRowCount();
+
         int categoryCount = getColumnCount();
 
         PlotOrientation orientation = plot.getOrientation();
@@ -174,7 +182,7 @@ public class IntervalBarRenderer extends BarRenderer
             return;
         }
         double java2dValue0 = rangeAxis.valueToJava2D(value0.doubleValue(),
-        		dataArea, rangeAxisLocation);
+                dataArea, rangeAxisLocation);
 
         // Y1
         Number value1 = dataset.getStartValue(row, column);
@@ -199,24 +207,25 @@ public class IntervalBarRenderer extends BarRenderer
         // BAR HEIGHT
         double rectHeight = Math.abs(java2dValue1 - java2dValue0);
 
+        RectangleEdge barBase = RectangleEdge.LEFT;
         if (orientation == PlotOrientation.HORIZONTAL) {
             // BAR Y
             rectY = domainAxis.getCategoryStart(column, getColumnCount(),
-            		dataArea, domainAxisLocation);
+                    dataArea, domainAxisLocation);
             if (seriesCount > 1) {
                 double seriesGap = dataArea.getHeight() * getItemMargin()
                                    / (categoryCount * (seriesCount - 1));
-                rectY = rectY + row * (state.getBarWidth() + seriesGap);
+                rectY = rectY + visibleRow * (state.getBarWidth() + seriesGap);
             }
             else {
-                rectY = rectY + row * state.getBarWidth();
+                rectY = rectY + visibleRow * state.getBarWidth();
             }
 
             rectX = java2dValue0;
 
             rectHeight = state.getBarWidth();
             rectWidth = Math.abs(java2dValue1 - java2dValue0);
-
+            barBase = RectangleEdge.LEFT;
         }
         else if (orientation == PlotOrientation.VERTICAL) {
             // BAR X
@@ -226,31 +235,22 @@ public class IntervalBarRenderer extends BarRenderer
             if (seriesCount > 1) {
                 double seriesGap = dataArea.getWidth() * getItemMargin()
                                    / (categoryCount * (seriesCount - 1));
-                rectX = rectX + row * (state.getBarWidth() + seriesGap);
+                rectX = rectX + visibleRow * (state.getBarWidth() + seriesGap);
             }
             else {
-                rectX = rectX + row * state.getBarWidth();
+                rectX = rectX + visibleRow * state.getBarWidth();
             }
 
             rectY = java2dValue0;
-
+            barBase = RectangleEdge.BOTTOM;
         }
         Rectangle2D bar = new Rectangle2D.Double(rectX, rectY, rectWidth,
                 rectHeight);
-        Paint seriesPaint = getItemPaint(row, column);
-        g2.setPaint(seriesPaint);
-        g2.fill(bar);
-
-        // draw the outline...
-        if (state.getBarWidth() > BAR_OUTLINE_WIDTH_THRESHOLD) {
-            Stroke stroke = getItemOutlineStroke(row, column);
-            Paint paint = getItemOutlinePaint(row, column);
-            if (stroke != null && paint != null) {
-                g2.setStroke(stroke);
-                g2.setPaint(paint);
-                g2.draw(bar);
-            }
+        BarPainter painter = getBarPainter();
+        if (getShadowsVisible()) {
+            painter.paintBarShadow(g2, this, row, column, bar, barBase, false);
         }
+        getBarPainter().paintBar(g2, this, row, column, bar, barBase);
 
         CategoryItemLabelGenerator generator = getItemLabelGenerator(row,
                 column);
@@ -267,4 +267,22 @@ public class IntervalBarRenderer extends BarRenderer
 
     }
 
+    /**
+     * Tests this renderer for equality with an arbitrary object.
+     *
+     * @param obj  the object (<code>null</code> permitted).
+     *
+     * @return A boolean.
+     */
+    public boolean equals(Object obj) {
+        if (obj == this) {
+            return true;
+        }
+        if (!(obj instanceof IntervalBarRenderer)) {
+            return false;
+        }
+        // there are no fields to check
+        return super.equals(obj);
+    }
+
 }
