@@ -2,32 +2,32 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
- * This library is free software; you can redistribute it and/or modify it 
- * under the terms of the GNU Lesser General Public License as published by 
- * the Free Software Foundation; either version 2.1 of the License, or 
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
  * License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
- * USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+ * USA.
  *
- * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
+ * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
  * in the United States and other countries.]
  *
  * -----------------------
  * LayeredBarRenderer.java
  * -----------------------
- * (C) Copyright 2003-2007, by Arnaud Lelievre and Contributors.
+ * (C) Copyright 2003-2008, by Arnaud Lelievre and Contributors.
  *
  * Original Author:  Arnaud Lelievre (for Garden);
  * Contributor(s):   David Gilbert (for Object Refinery Limited);
@@ -40,11 +40,11 @@
  * 07-Oct-2003 : Added renderer state (DG);
  * 21-Oct-2003 : Bar width moved to renderer state (DG);
  * 05-Nov-2004 : Modified drawItem() signature (DG);
- * 20-Apr-2005 : Renamed CategoryLabelGenerator 
+ * 20-Apr-2005 : Renamed CategoryLabelGenerator
  *               --> CategoryItemLabelGenerator (DG);
  * 17-Nov-2005 : Added support for gradient paint (DG);
  * ------------- JFREECHART 1.0.x ---------------------------------------------
- * 18-Aug-2006 : Fixed the bar width calculation to respect the maximum bar 
+ * 18-Aug-2006 : Fixed the bar width calculation to respect the maximum bar
  *               width setting (thanks to Zoheb Borbora) (DG);
  * 02-Feb-2007 : Removed author tags all over JFreeChart sources (DG);
  *
@@ -61,10 +61,8 @@ import java.io.Serializable;
 
 import org.jfree.chart.axis.CategoryAxis;
 import org.jfree.chart.axis.ValueAxis;
-import org.jfree.chart.entity.CategoryItemEntity;
 import org.jfree.chart.entity.EntityCollection;
 import org.jfree.chart.labels.CategoryItemLabelGenerator;
-import org.jfree.chart.labels.CategoryToolTipGenerator;
 import org.jfree.chart.plot.CategoryPlot;
 import org.jfree.chart.plot.PlotOrientation;
 import org.jfree.data.category.CategoryDataset;
@@ -73,12 +71,16 @@ import org.jfree.ui.RectangleEdge;
 import org.jfree.util.ObjectList;
 
 /**
- * A {@link CategoryItemRenderer} that represents data using bars which are 
- * superimposed.
+ * A {@link CategoryItemRenderer} that represents data using bars which are
+ * superimposed.  The example shown here is generated by the
+ * <code>LayeredBarChartDemo1.java</code> program included in the JFreeChart
+ * Demo Collection:
+ * <br><br>
+ * <img src="../../../../../images/LayeredBarRendererSample.png"
+ * alt="LayeredBarRendererSample.png" />
  */
-public class LayeredBarRenderer extends BarRenderer 
-                                implements Serializable {
-    
+public class LayeredBarRenderer extends BarRenderer implements Serializable {
+
     /** For serialization. */
     private static final long serialVersionUID = -8716572894780469487L;
 
@@ -114,23 +116,23 @@ public class LayeredBarRenderer extends BarRenderer
      * Sets the width of the bars of a series.
      *
      * @param series  the series index (zero based).
-     * @param width  the width of the series bar in percentage (1.0=100%, it is 
+     * @param width  the width of the series bar in percentage (1.0=100%, it is
      *               the maximum).
-     */ 
+     */
     public void setSeriesBarWidth(int series, double width) {
         this.seriesBarWidthList.set(series, new Double(width));
     }
 
     /**
      * Calculates the bar width and stores it in the renderer state.
-     * 
+     *
      * @param plot  the plot.
      * @param dataArea  the data area.
      * @param rendererIndex  the renderer index.
      * @param state  the renderer state.
      */
-    protected void calculateBarWidth(CategoryPlot plot, 
-                                     Rectangle2D dataArea, 
+    protected void calculateBarWidth(CategoryPlot plot,
+                                     Rectangle2D dataArea,
                                      int rendererIndex,
                                      CategoryItemRendererState state) {
 
@@ -156,12 +158,12 @@ public class LayeredBarRenderer extends BarRenderer
             if (columns > 1) {
                 categoryMargin = domainAxis.getCategoryMargin();
             }
-            double used = space * (1 - domainAxis.getLowerMargin() 
+            double used = space * (1 - domainAxis.getLowerMargin()
                 - domainAxis.getUpperMargin() - categoryMargin);
             if ((rows * columns) > 0) {
-                state.setBarWidth(Math.min(used / (dataset.getColumnCount()), 
+                state.setBarWidth(Math.min(used / (dataset.getColumnCount()),
                         maxWidth));
-            } 
+            }
             else {
                 state.setBarWidth(Math.min(used, maxWidth));
             }
@@ -195,11 +197,11 @@ public class LayeredBarRenderer extends BarRenderer
 
         PlotOrientation orientation = plot.getOrientation();
         if (orientation == PlotOrientation.HORIZONTAL) {
-            drawHorizontalItem(g2, state, dataArea, plot, domainAxis, 
+            drawHorizontalItem(g2, state, dataArea, plot, domainAxis,
                     rangeAxis, data, row, column);
         }
         else if (orientation == PlotOrientation.VERTICAL) {
-            drawVerticalItem(g2, state, dataArea, plot, domainAxis, rangeAxis, 
+            drawVerticalItem(g2, state, dataArea, plot, domainAxis, rangeAxis,
                     data, row, column);
         }
 
@@ -214,7 +216,7 @@ public class LayeredBarRenderer extends BarRenderer
      * @param plot  the plot.
      * @param domainAxis  the domain axis.
      * @param rangeAxis  the range axis.
-     * @param data  the data.
+     * @param dataset  the dataset.
      * @param row  the row index (zero-based).
      * @param column  the column index (zero-based).
      */
@@ -224,12 +226,12 @@ public class LayeredBarRenderer extends BarRenderer
                                       CategoryPlot plot,
                                       CategoryAxis domainAxis,
                                       ValueAxis rangeAxis,
-                                      CategoryDataset data,
+                                      CategoryDataset dataset,
                                       int row,
                                       int column) {
 
         // nothing is drawn for null values...
-        Number dataValue = data.getValue(row, column);
+        Number dataValue = dataset.getValue(row, column);
         if (dataValue == null) {
             return;
         }
@@ -275,7 +277,7 @@ public class LayeredBarRenderer extends BarRenderer
         double rectWidth = Math.abs(transX2 - transX1);
 
         // Y
-        double rectY = domainAxis.getCategoryMiddle(column, getColumnCount(), 
+        double rectY = domainAxis.getCategoryMiddle(column, getColumnCount(),
                 dataArea, plot.getDomainAxisEdge()) - state.getBarWidth() / 2.0;
 
         int seriesCount = getRowCount();
@@ -287,15 +289,15 @@ public class LayeredBarRenderer extends BarRenderer
         double seriesBarWidth = getSeriesBarWidth(row);
         if (!Double.isNaN(seriesBarWidth)) {
             widthFactor = seriesBarWidth;
-        } 
+        }
         rectHeight = widthFactor * state.getBarWidth();
         rectY = rectY + (1 - widthFactor) * state.getBarWidth() / 2.0;
         if (seriesCount > 1) {
             shift = rectHeight * 0.20 / (seriesCount - 1);
         }
 
-        Rectangle2D bar = new Rectangle2D.Double(rectX, 
-                (rectY + ((seriesCount - 1 - row) * shift)), rectWidth, 
+        Rectangle2D bar = new Rectangle2D.Double(rectX,
+                (rectY + ((seriesCount - 1 - row) * shift)), rectWidth,
                 (rectHeight - (seriesCount - 1 - row) * shift * 2));
 
         Paint itemPaint = getItemPaint(row, column);
@@ -307,7 +309,7 @@ public class LayeredBarRenderer extends BarRenderer
         g2.fill(bar);
 
         // draw the outline...
-        if (isDrawBarOutline() 
+        if (isDrawBarOutline()
                 && state.getBarWidth() > BAR_OUTLINE_WIDTH_THRESHOLD) {
             Stroke stroke = getItemOutlineStroke(row, column);
             Paint paint = getItemOutlinePaint(row, column);
@@ -318,33 +320,17 @@ public class LayeredBarRenderer extends BarRenderer
             }
         }
 
-        CategoryItemLabelGenerator generator 
+        CategoryItemLabelGenerator generator
             = getItemLabelGenerator(row, column);
         if (generator != null && isItemLabelVisible(row, column)) {
-            drawItemLabel(g2, data, row, column, plot, generator, bar, 
+            drawItemLabel(g2, dataset, row, column, plot, generator, bar,
                     (transX1 > transX2));
-        }        
+        }
 
         // collect entity and tool tip information...
-        if (state.getInfo() != null) {
-            EntityCollection entities = state.getEntityCollection();
-            if (entities != null) {
-                String tip = null;
-                CategoryToolTipGenerator tipster 
-                    = getToolTipGenerator(row, column);
-                if (tipster != null) {
-                    tip = tipster.generateToolTip(data, row, column);
-                }
-                String url = null;
-                if (getItemURLGenerator(row, column) != null) {
-                    url = getItemURLGenerator(row, column).generateURL(data, 
-                            row, column);
-                }
-                CategoryItemEntity entity = new CategoryItemEntity(bar, tip, 
-                        url, data, data.getRowKey(row), 
-                        data.getColumnKey(column));
-                entities.add(entity);
-            }
+        EntityCollection entities = state.getEntityCollection();
+        if (entities != null) {
+            addItemEntity(entities, dataset, row, column, bar);
         }
     }
 
@@ -357,7 +343,7 @@ public class LayeredBarRenderer extends BarRenderer
      * @param plot  the plot.
      * @param domainAxis  the domain axis.
      * @param rangeAxis  the range axis.
-     * @param data  the data.
+     * @param dataset  the dataset.
      * @param row  the row index (zero-based).
      * @param column  the column index (zero-based).
      */
@@ -367,18 +353,18 @@ public class LayeredBarRenderer extends BarRenderer
                                     CategoryPlot plot,
                                     CategoryAxis domainAxis,
                                     ValueAxis rangeAxis,
-                                    CategoryDataset data,
+                                    CategoryDataset dataset,
                                     int row,
                                     int column) {
 
         // nothing is drawn for null values...
-        Number dataValue = data.getValue(row, column);
+        Number dataValue = dataset.getValue(row, column);
         if (dataValue == null) {
             return;
         }
 
         // BAR X
-        double rectX = domainAxis.getCategoryMiddle(column, getColumnCount(), 
+        double rectX = domainAxis.getCategoryMiddle(column, getColumnCount(),
                 dataArea, plot.getDomainAxisEdge()) - state.getBarWidth() / 2.0;
 
         int seriesCount = getRowCount();
@@ -433,7 +419,7 @@ public class LayeredBarRenderer extends BarRenderer
         double seriesBarWidth = getSeriesBarWidth(row);
         if (!Double.isNaN(seriesBarWidth)) {
             widthFactor = seriesBarWidth;
-        } 
+        }
         rectWidth = widthFactor * state.getBarWidth();
         rectX = rectX + (1 - widthFactor) * state.getBarWidth() / 2.0;
         if (seriesCount > 1) {
@@ -453,7 +439,7 @@ public class LayeredBarRenderer extends BarRenderer
         g2.fill(bar);
 
         // draw the outline...
-        if (isDrawBarOutline() 
+        if (isDrawBarOutline()
                 && state.getBarWidth() > BAR_OUTLINE_WIDTH_THRESHOLD) {
             Stroke stroke = getItemOutlineStroke(row, column);
             Paint paint = getItemOutlinePaint(row, column);
@@ -468,33 +454,17 @@ public class LayeredBarRenderer extends BarRenderer
         double transX1 = rangeAxis.valueToJava2D(base, dataArea, edge);
         double transX2 = rangeAxis.valueToJava2D(value, dataArea, edge);
 
-        CategoryItemLabelGenerator generator 
+        CategoryItemLabelGenerator generator
             = getItemLabelGenerator(row, column);
         if (generator != null && isItemLabelVisible(row, column)) {
-            drawItemLabel(g2, data, row, column, plot, generator, bar, 
+            drawItemLabel(g2, dataset, row, column, plot, generator, bar,
                     (transX1 > transX2));
-        }        
+        }
 
         // collect entity and tool tip information...
-        if (state.getInfo() != null) {
-            EntityCollection entities = state.getEntityCollection();
-            if (entities != null) {
-                String tip = null;
-                CategoryToolTipGenerator tipster 
-                    = getToolTipGenerator(row, column);
-                if (tipster != null) {
-                    tip = tipster.generateToolTip(data, row, column);
-                }
-                String url = null;
-                if (getItemURLGenerator(row, column) != null) {
-                    url = getItemURLGenerator(row, column).generateURL(
-                        data, row, column);
-                }
-                CategoryItemEntity entity = new CategoryItemEntity(bar, tip, 
-                        url, data, data.getRowKey(row), 
-                        data.getColumnKey(column));
-                entities.add(entity);
-            }
+        EntityCollection entities = state.getEntityCollection();
+        if (entities != null) {
+            addItemEntity(entities, dataset, row, column, bar);
         }
     }
 
