@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,10 +27,10 @@
  * ------------------
  * LevelRenderer.java
  * ------------------
- * (C) Copyright 2004-2008, by Object Refinery Limited.
+ * (C) Copyright 2004-2009, by Object Refinery Limited.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
- * Contributor(s):   -;
+ * Contributor(s):   Peter Kolb (patch 2511330);
  *
  * Changes
  * -------
@@ -41,11 +41,16 @@
  * ------------- JFREECHART 1.0.x ---------------------------------------------
  * 23-Jan-2006 : Renamed getMaxItemWidth() --> getMaximumItemWidth() (DG);
  * 13-May-2008 : Code clean-up (DG);
+ * 26-Jun-2008 : Added crosshair support (DG);
+ * 23-Jan-2009 : Set more appropriate default shape in legend (DG);
+ * 23-Jan-2009 : Added support for seriesVisible flags - see patch
+ *               2511330 (PK)
  *
  */
 
 package org.jfree.chart.renderer.category;
 
+import java.awt.Color;
 import java.awt.Graphics2D;
 import java.awt.Paint;
 import java.awt.Stroke;
@@ -53,6 +58,7 @@ import java.awt.geom.Line2D;
 import java.awt.geom.Rectangle2D;
 import java.io.Serializable;
 
+import org.jfree.chart.HashUtilities;
 import org.jfree.chart.axis.CategoryAxis;
 import org.jfree.chart.axis.ValueAxis;
 import org.jfree.chart.entity.EntityCollection;
@@ -67,7 +73,13 @@ import org.jfree.util.PublicCloneable;
 
 /**
  * A {@link CategoryItemRenderer} that draws individual data items as
- * horizontal lines, spaced in the same way as bars in a bar chart.
+ * horizontal lines, spaced in the same way as bars in a bar chart.  The
+ * example shown here is generated by the
+ * <code>OverlaidBarChartDemo2.java</code> program included in the JFreeChart
+ * Demo Collection:
+ * <br><br>
+ * <img src="../../../../../images/LevelRendererSample.png"
+ * alt="LevelRendererSample.png" />
  */
 public class LevelRenderer extends AbstractCategoryItemRenderer
         implements Cloneable, PublicCloneable, Serializable {
@@ -92,6 +104,10 @@ public class LevelRenderer extends AbstractCategoryItemRenderer
         this.itemMargin = DEFAULT_ITEM_MARGIN;
         this.maxItemWidth = 1.0;  // 100 percent, so it will not apply unless
                                   // changed
+        setBaseLegendShape(new Rectangle2D.Float(-5.0f, -1.0f, 10.0f, 2.0f));
+        // set the outline paint to fully transparent, then the legend shape
+        // will just have the same colour as the lines drawn by the renderer
+        setBaseOutlinePaint(new Color(0, 0, 0, 0));
     }
 
     /**
@@ -187,7 +203,8 @@ public class LevelRenderer extends AbstractCategoryItemRenderer
         CategoryDataset dataset = plot.getDataset(rendererIndex);
         if (dataset != null) {
             int columns = dataset.getColumnCount();
-            int rows = dataset.getRowCount();
+            int rows = state.getVisibleSeriesCount() >= 0
+                    ? state.getVisibleSeriesCount() : dataset.getRowCount();
             double space = 0.0;
             PlotOrientation orientation = plot.getOrientation();
             if (orientation == PlotOrientation.HORIZONTAL) {
@@ -249,7 +266,10 @@ public class LevelRenderer extends AbstractCategoryItemRenderer
         }
         double barW0 = domainAxis.getCategoryStart(column, getColumnCount(),
                 dataArea, plot.getDomainAxisEdge());
-        int seriesCount = getRowCount();
+        int seriesCount = state.getVisibleSeriesCount();
+        if (seriesCount < 0) {
+            seriesCount = getRowCount();
+        }
         int categoryCount = getColumnCount();
         if (seriesCount > 1) {
             double seriesGap = space * getItemMargin()
@@ -286,6 +306,13 @@ public class LevelRenderer extends AbstractCategoryItemRenderer
             ValueAxis rangeAxis, CategoryDataset dataset, int row, int column,
             int pass) {
 
+        // nothing is drawn if the row index is not included in the list with
+        // the indices of the visible rows...
+        int visibleRow = state.getVisibleSeriesIndex(row);
+        if (visibleRow < 0) {
+            return;
+        }
+
         // nothing is drawn for null values...
         Number dataValue = dataset.getValue(row, column);
         if (dataValue == null) {
@@ -296,7 +323,7 @@ public class LevelRenderer extends AbstractCategoryItemRenderer
 
         PlotOrientation orientation = plot.getOrientation();
         double barW0 = calculateBarW0(plot, orientation, dataArea, domainAxis,
-                state, row, column);
+                state, visibleRow, column);
         RectangleEdge edge = plot.getRangeAxisEdge();
         double barL = rangeAxis.valueToJava2D(value, dataArea, edge);
 
@@ -329,7 +356,13 @@ public class LevelRenderer extends AbstractCategoryItemRenderer
                     (value < 0.0));
         }
 
-        // add an item entity, if this information is being collected
+        // submit the current data point as a crosshair candidate
+        int datasetIndex = plot.indexOf(dataset);
+        updateCrosshairValues(state.getCrosshairState(),
+                dataset.getRowKey(row), dataset.getColumnKey(column), value,
+                datasetIndex, barW0, barL, orientation);
+
+        // collect entity and tool tip information...
         EntityCollection entities = state.getEntityCollection();
         if (entities != null) {
             addItemEntity(entities, dataset, row, column, line.getBounds());
@@ -357,6 +390,27 @@ public class LevelRenderer extends AbstractCategoryItemRenderer
         return (space * factor) / (categories * series);
     }
 
+    /**
+     * Returns the Java2D coordinate for the middle of the specified data item.
+     *
+     * @param rowKey  the row key.
+     * @param columnKey  the column key.
+     * @param dataset  the dataset.
+     * @param axis  the axis.
+     * @param area  the drawing area.
+     * @param edge  the edge along which the axis lies.
+     *
+     * @return The Java2D coordinate.
+     *
+     * @since 1.0.11
+     */
+    public double getItemMiddle(Comparable rowKey, Comparable columnKey,
+            CategoryDataset dataset, CategoryAxis axis, Rectangle2D area,
+            RectangleEdge edge) {
+        return axis.getCategorySeriesMiddle(columnKey, rowKey, dataset,
+                this.itemMargin, area, edge);
+    }
+
     /**
      * Tests an object for equality with this instance.
      *
@@ -381,6 +435,18 @@ public class LevelRenderer extends AbstractCategoryItemRenderer
         return super.equals(obj);
     }
 
+    /**
+     * Returns a hash code for this instance.
+     *
+     * @return A hash code.
+     */
+    public int hashCode() {
+        int hash = super.hashCode();
+        hash = HashUtilities.hashCode(hash, this.itemMargin);
+        hash = HashUtilities.hashCode(hash, this.maxItemWidth);
+        return hash;
+    }
+
     /**
      * Returns the maximum width, as a percentage of the available drawing
      * space.
