@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,13 +27,14 @@
  * -------------------------
  * LineAndShapeRenderer.java
  * -------------------------
- * (C) Copyright 2001-2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2001-2009, by Object Refinery Limited and Contributors.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   Mark Watson (www.markwatson.com);
  *                   Jeremy Bowman;
  *                   Richard Atkinson;
  *                   Christian W. Zuckschwerdt;
+ *                   Peter Kolb (patch 2497611);
  *
  * Changes
  * -------
@@ -85,6 +86,9 @@
  * 18-May-2007 : Set dataset and seriesKey for LegendItem (DG);
  * 24-Sep-2007 : Deprecated redundant fields/methods (DG);
  * 27-Sep-2007 : Added option to offset series x-position within category (DG);
+ * 17-Jun-2008 : Apply legend shape, font and paint attributes (DG);
+ * 26-Jun-2008 : Added crosshair support (DG);
+ * 14-Jan-2009 : Added support for seriesVisible flags (PK);
  *
  */
 
@@ -115,6 +119,11 @@ import org.jfree.util.ShapeUtilities;
 /**
  * A renderer that draws shapes for each data item, and lines between data
  * items (for use with the {@link CategoryPlot} class).
+ * The example shown here is generated by the <code>LineChartDemo1.java</code>
+ * program included in the JFreeChart Demo Collection:
+ * <br><br>
+ * <img src="../../../../../images/LineAndShapeRendererSample.png"
+ * alt="LineAndShapeRendererSample.png" />
  */
 public class LineAndShapeRenderer extends AbstractCategoryItemRenderer
         implements Cloneable, PublicCloneable, Serializable {
@@ -834,7 +843,7 @@ public class LineAndShapeRenderer extends AbstractCategoryItemRenderer
                 urlText = getLegendItemURLGenerator().generateLabel(
                         dataset, series);
             }
-            Shape shape = lookupSeriesShape(series);
+            Shape shape = lookupLegendShape(series);
             Paint paint = lookupSeriesPaint(series);
             Paint fillPaint = (this.useFillPaint
                     ? getItemFillPaint(series, 0) : paint);
@@ -849,6 +858,11 @@ public class LineAndShapeRenderer extends AbstractCategoryItemRenderer
                     fillPaint, shapeOutlineVisible, outlinePaint, outlineStroke,
                     lineVisible, new Line2D.Double(-7.0, 0.0, 7.0, 0.0),
                     getItemStroke(series, 0), getItemPaint(series, 0));
+            result.setLabelFont(lookupLegendTextFont(series));
+            Paint labelPaint = lookupLegendTextPaint(series);
+            if (labelPaint != null) {
+                result.setLabelPaint(labelPaint);
+            }
             result.setDataset(dataset);
             result.setDatasetIndex(datasetIndex);
             result.setSeriesKey(dataset.getRowKey(series));
@@ -904,14 +918,20 @@ public class LineAndShapeRenderer extends AbstractCategoryItemRenderer
             return;
         }
 
+        int visibleRow = state.getVisibleSeriesIndex(row);
+        if (visibleRow < 0) {
+            return;
+        }
+		int visibleRowCount = state.getVisibleSeriesCount();
+
         PlotOrientation orientation = plot.getOrientation();
 
         // current data point...
         double x1;
         if (this.useSeriesOffset) {
-            x1 = domainAxis.getCategorySeriesMiddle(dataset.getColumnKey(
-                    column), dataset.getRowKey(row), dataset, this.itemMargin,
-                    dataArea, plot.getDomainAxisEdge());
+            x1 = domainAxis.getCategorySeriesMiddle(column,
+                    dataset.getColumnCount(), visibleRow, visibleRowCount,
+                    this.itemMargin, dataArea, plot.getDomainAxisEdge());
         }
         else {
             x1 = domainAxis.getCategoryMiddle(column, getColumnCount(),
@@ -930,8 +950,8 @@ public class LineAndShapeRenderer extends AbstractCategoryItemRenderer
                     double x0;
                     if (this.useSeriesOffset) {
                         x0 = domainAxis.getCategorySeriesMiddle(
-                                dataset.getColumnKey(column - 1),
-                                dataset.getRowKey(row), dataset,
+                                column - 1, dataset.getColumnCount(),
+                                visibleRow, visibleRowCount,
                                 this.itemMargin, dataArea,
                                 plot.getDomainAxisEdge());
                     }
@@ -1000,6 +1020,12 @@ public class LineAndShapeRenderer extends AbstractCategoryItemRenderer
                 }
             }
 
+            // submit the current data point as a crosshair candidate
+            int datasetIndex = plot.indexOf(dataset);
+            updateCrosshairValues(state.getCrosshairState(),
+                    dataset.getRowKey(row), dataset.getColumnKey(column),
+                    value, datasetIndex, x1, y1, orientation);
+
             // add an item entity, if this information is being collected
             EntityCollection entities = state.getEntityCollection();
             if (entities != null) {
@@ -1078,11 +1104,11 @@ public class LineAndShapeRenderer extends AbstractCategoryItemRenderer
     public Object clone() throws CloneNotSupportedException {
         LineAndShapeRenderer clone = (LineAndShapeRenderer) super.clone();
         clone.seriesLinesVisible
-            = (BooleanList) this.seriesLinesVisible.clone();
+                = (BooleanList) this.seriesLinesVisible.clone();
         clone.seriesShapesVisible
-            = (BooleanList) this.seriesShapesVisible.clone();
+                = (BooleanList) this.seriesShapesVisible.clone();
         clone.seriesShapesFilled
-            = (BooleanList) this.seriesShapesFilled.clone();
+                = (BooleanList) this.seriesShapesFilled.clone();
         return clone;
     }
 
