@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,12 +27,13 @@
  * -----------------------
  * StackedBarRenderer.java
  * -----------------------
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   Richard Atkinson;
  *                   Thierry Saura;
  *                   Christian W. Zuckschwerdt;
+ *                   Peter Kolb (patch 2511330);
  *
  * Changes
  * -------
@@ -86,14 +87,14 @@
  *               1304139 (DG);
  * ------------- JFREECHART 1.0.x ---------------------------------------------
  * 11-Oct-2006 : Source reformatting (DG);
+ * 24-Jun-2008 : Added new barPainter mechanism (DG);
+ * 04-Feb-2009 : Added support for hidden series (PK);
  *
  */
 
 package org.jfree.chart.renderer.category;
 
-import java.awt.GradientPaint;
 import java.awt.Graphics2D;
-import java.awt.Paint;
 import java.awt.geom.Rectangle2D;
 import java.io.Serializable;
 
@@ -110,14 +111,18 @@ import org.jfree.data.DataUtilities;
 import org.jfree.data.Range;
 import org.jfree.data.category.CategoryDataset;
 import org.jfree.data.general.DatasetUtilities;
-import org.jfree.ui.GradientPaintTransformer;
 import org.jfree.ui.RectangleEdge;
 import org.jfree.ui.TextAnchor;
 import org.jfree.util.PublicCloneable;
 
 /**
- * A stacked bar renderer for use with the
- * {@link org.jfree.chart.plot.CategoryPlot} class.
+ * A stacked bar renderer for use with the {@link CategoryPlot} class.
+ * The example shown here is generated by the
+ * <code>StackedBarChartDemo1.java</code> program included in the
+ * JFreeChart Demo Collection:
+ * <br><br>
+ * <img src="../../../../../images/StackedBarRendererSample.png"
+ * alt="StackedBarRendererSample.png" />
  */
 public class StackedBarRenderer extends BarRenderer
         implements Cloneable, PublicCloneable, Serializable {
@@ -187,14 +192,15 @@ public class StackedBarRenderer extends BarRenderer
     }
 
     /**
-     * Returns the number of passes (<code>2</code>) required by this renderer.
-     * The first pass is used to draw the bars, the second pass is used to
-     * draw the item labels (if visible).
+     * Returns the number of passes (<code>3</code>) required by this renderer.
+     * The first pass is used to draw the bar shadows, the second pass is used
+     * to draw the bars, and the third pass is used to draw the item labels
+     * (if visible).
      *
      * @return The number of passes required by the renderer.
      */
     public int getPassCount() {
-        return 2;
+        return 3;
     }
 
     /**
@@ -206,6 +212,9 @@ public class StackedBarRenderer extends BarRenderer
      * @return The range (or <code>null</code> if the dataset is empty).
      */
     public Range findRangeBounds(CategoryDataset dataset) {
+        if (dataset == null) {
+            return null;
+        }
         if (this.renderAsPercentages) {
             return new Range(0.0, 1.0);
         }
@@ -284,6 +293,10 @@ public class StackedBarRenderer extends BarRenderer
                          int column,
                          int pass) {
 
+        if (!isSeriesVisible(row)) {
+            return;
+        }
+
         // nothing is drawn for null values...
         Number dataValue = dataset.getValue(row, column);
         if (dataValue == null) {
@@ -293,7 +306,8 @@ public class StackedBarRenderer extends BarRenderer
         double value = dataValue.doubleValue();
         double total = 0.0;  // only needed if calculating percentages
         if (this.renderAsPercentages) {
-            total = DataUtilities.calculateColumnTotal(dataset, column);
+            total = DataUtilities.calculateColumnTotal(dataset, column,
+                    state.getVisibleSeriesArray());
             value = value / total;
         }
 
@@ -307,7 +321,7 @@ public class StackedBarRenderer extends BarRenderer
 
         for (int i = 0; i < row; i++) {
             Number v = dataset.getValue(i, column);
-            if (v != null) {
+            if (v != null && isSeriesVisible(i)) {
                 double d = v.doubleValue();
                 if (this.renderAsPercentages) {
                     d = d / total;
@@ -323,8 +337,28 @@ public class StackedBarRenderer extends BarRenderer
 
         double translatedBase;
         double translatedValue;
+        boolean positive = (value > 0.0);
+        boolean inverted = rangeAxis.isInverted();
+        RectangleEdge barBase;
+        if (orientation == PlotOrientation.HORIZONTAL) {
+            if (positive && inverted || !positive && !inverted) {
+                barBase = RectangleEdge.RIGHT;
+            }
+            else {
+                barBase = RectangleEdge.LEFT;
+            }
+        }
+        else {
+            if (positive && !inverted || !positive && inverted) {
+                barBase = RectangleEdge.BOTTOM;
+            }
+            else {
+                barBase = RectangleEdge.TOP;
+            }
+        }
+
         RectangleEdge location = plot.getRangeAxisEdge();
-        if (value >= 0.0) {
+        if (positive) {
             translatedBase = rangeAxis.valueToJava2D(positiveBase, dataArea,
                     location);
             translatedValue = rangeAxis.valueToJava2D(positiveBase + value,
@@ -350,19 +384,15 @@ public class StackedBarRenderer extends BarRenderer
                     barLength);
         }
         if (pass == 0) {
-            Paint itemPaint = getItemPaint(row, column);
-            GradientPaintTransformer t = getGradientPaintTransformer();
-            if (t != null && itemPaint instanceof GradientPaint) {
-                itemPaint = t.transform((GradientPaint) itemPaint, bar);
-            }
-            g2.setPaint(itemPaint);
-            g2.fill(bar);
-            if (isDrawBarOutline()
-                    && state.getBarWidth() > BAR_OUTLINE_WIDTH_THRESHOLD) {
-                g2.setStroke(getItemOutlineStroke(row, column));
-                g2.setPaint(getItemOutlinePaint(row, column));
-                g2.draw(bar);
+            if (getShadowsVisible()) {
+                boolean pegToBase = (positive && (positiveBase == getBase()))
+                        || (!positive && (negativeBase == getBase()));
+                getBarPainter().paintBarShadow(g2, this, row, column, bar,
+                        barBase, pegToBase);
             }
+        }
+        else if (pass == 1) {
+            getBarPainter().paintBar(g2, this, row, column, bar, barBase);
 
             // add an item entity, if this information is being collected
             EntityCollection entities = state.getEntityCollection();
@@ -370,7 +400,7 @@ public class StackedBarRenderer extends BarRenderer
                 addItemEntity(entities, dataset, row, column, bar);
             }
         }
-        else if (pass == 1) {
+        else if (pass == 2) {
             CategoryItemLabelGenerator generator = getItemLabelGenerator(row,
                     column);
             if (generator != null && isItemLabelVisible(row, column)) {
