@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,7 +27,7 @@
  * -------------------------
  * StackedBarRenderer3D.java
  * -------------------------
- * (C) Copyright 2000-2008, by Serge V. Grachov and Contributors.
+ * (C) Copyright 2000-2009, by Serge V. Grachov and Contributors.
  *
  * Original Author:  Serge V. Grachov;
  * Contributor(s):   David Gilbert (for Object Refinery Limited);
@@ -80,6 +80,10 @@
  *               see bug report 1599652 (DG);
  * 08-May-2007 : Fixed bugs 1713401 (drawBarOutlines flag) and  1713474
  *               (shading) (DG);
+ * 15-Aug-2008 : Fixed bug 2031407 - no negative zero for stack encoding (DG);
+ * 03-Feb-2009 : Fixed regression in findRangeBounds() method for null
+ *               dataset (DG);
+ * 04-Feb-2009 : Handle seriesVisible flag (DG);
  *
  */
 
@@ -111,8 +115,13 @@ import org.jfree.util.BooleanUtilities;
 import org.jfree.util.PublicCloneable;
 
 /**
- * Renders stacked bars with 3D-effect, for use with the
- * {@link org.jfree.chart.plot.CategoryPlot} class.
+ * Renders stacked bars with 3D-effect, for use with the {@link CategoryPlot}
+ * class.  The example shown here is generated by the
+ * <code>StackedBarChart3DDemo1.java</code> program included in the
+ * JFreeChart Demo Collection:
+ * <br><br>
+ * <img src="../../../../../images/StackedBarRenderer3DSample.png"
+ * alt="StackedBarRenderer3DSample.png" />
  */
 public class StackedBarRenderer3D extends BarRenderer3D
         implements Cloneable, PublicCloneable, Serializable {
@@ -210,6 +219,9 @@ public class StackedBarRenderer3D extends BarRenderer3D
      * @return The range (or <code>null</code> if the dataset is empty).
      */
     public Range findRangeBounds(CategoryDataset dataset) {
+        if (dataset == null) {
+            return null;
+        }
         if (this.renderAsPercentages) {
             return new Range(0.0, 1.0);
         }
@@ -276,9 +288,38 @@ public class StackedBarRenderer3D extends BarRenderer3D
      * @return The value list.
      *
      * @since 1.0.4
+     *
+     * @deprecated As of 1.0.13, use {@link #createStackedValueList(
+     *     CategoryDataset, Comparable, int[], double, boolean)}.
      */
     protected static List createStackedValueList(CategoryDataset dataset,
             Comparable category, double base, boolean asPercentages) {
+        int[] rows = new int[dataset.getRowCount()];
+        for (int i = 0; i < rows.length; i++) {
+            rows[i] = i;
+        }
+        return createStackedValueList(dataset, category, rows, base,
+                asPercentages);
+    }
+
+    /**
+     * Returns a list containing the stacked values for the specified series
+     * in the given dataset, plus the supplied base value.
+     *
+     * @param dataset  the dataset (<code>null</code> not permitted).
+     * @param category  the category key (<code>null</code> not permitted).
+     * @param includedRows  the included rows.
+     * @param base  the base value.
+     * @param asPercentages  a flag that controls whether the values in the
+     *     list are converted to percentages of the total.
+     *
+     * @return The value list.
+     *
+     * @since 1.0.13
+     */
+    protected static List createStackedValueList(CategoryDataset dataset,
+            Comparable category, int[] includedRows, double base,
+            boolean asPercentages) {
 
         List result = new ArrayList();
         double posBase = base;
@@ -286,13 +327,14 @@ public class StackedBarRenderer3D extends BarRenderer3D
         double total = 0.0;
         if (asPercentages) {
             total = DataUtilities.calculateColumnTotal(dataset,
-                    dataset.getColumnIndex(category));
+                    dataset.getColumnIndex(category), includedRows);
         }
 
         int baseIndex = -1;
-        int seriesCount = dataset.getRowCount();
-        for (int s = 0; s < seriesCount; s++) {
-            Number n = dataset.getValue(dataset.getRowKey(s), category);
+        int rowCount = includedRows.length;
+        for (int i = 0; i < rowCount; i++) {
+            int r = includedRows[i];
+            Number n = dataset.getValue(dataset.getRowKey(r), category);
             if (n == null) {
                 continue;
             }
@@ -306,7 +348,7 @@ public class StackedBarRenderer3D extends BarRenderer3D
                     baseIndex = 0;
                 }
                 posBase = posBase + v;
-                result.add(new Object[] {new Integer(s), new Double(posBase)});
+                result.add(new Object[] {new Integer(r), new Double(posBase)});
             }
             else if (v < 0.0) {
                 if (baseIndex < 0) {
@@ -314,7 +356,7 @@ public class StackedBarRenderer3D extends BarRenderer3D
                     baseIndex = 0;
                 }
                 negBase = negBase + v; // '+' because v is negative
-                result.add(0, new Object[] {new Integer(-s),
+                result.add(0, new Object[] {new Integer(-r - 1),
                         new Double(negBase)});
                 baseIndex++;
             }
@@ -358,8 +400,8 @@ public class StackedBarRenderer3D extends BarRenderer3D
         Comparable category = dataset.getColumnKey(column);
 
         List values = createStackedValueList(dataset,
-                dataset.getColumnKey(column), getBase(),
-                this.renderAsPercentages);
+                dataset.getColumnKey(column), state.getVisibleSeriesArray(),
+                getBase(), this.renderAsPercentages);
 
         Rectangle2D adjusted = new Rectangle2D.Double(dataArea.getX(),
                 dataArea.getY() + getYOffset(),
@@ -421,12 +463,12 @@ public class StackedBarRenderer3D extends BarRenderer3D
             Object[] curr = (Object[]) values.get(index + 1);
             int series = 0;
             if (curr[0] == null) {
-                series = -((Integer) prev[0]).intValue();
+                series = -((Integer) prev[0]).intValue() - 1;
             }
             else {
                 series = ((Integer) curr[0]).intValue();
                 if (series < 0) {
-                    series = -((Integer) prev[0]).intValue();
+                    series = -((Integer) prev[0]).intValue() - 1;
                 }
             }
             double v0 = ((Double) prev[1]).doubleValue();
@@ -617,12 +659,12 @@ public class StackedBarRenderer3D extends BarRenderer3D
             Object[] curr = (Object[]) values.get(index + 1);
             int series = 0;
             if (curr[0] == null) {
-                series = -((Integer) prev[0]).intValue();
+                series = -((Integer) prev[0]).intValue() - 1;
             }
             else {
                 series = ((Integer) curr[0]).intValue();
                 if (series < 0) {
-                    series = -((Integer) prev[0]).intValue();
+                    series = -((Integer) prev[0]).intValue() - 1;
                 }
             }
             double v0 = ((Double) prev[1]).doubleValue();
