@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,7 +27,7 @@
  * -------------------------
  * WaterfallBarRenderer.java
  * -------------------------
- * (C) Copyright 2003-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2003-2009, by Object Refinery Limited and Contributors.
  *
  * Original Author:  Darshan Shah;
  * Contributor(s):   David Gilbert (for Object Refinery Limited);
@@ -49,6 +49,10 @@
  *               --> CategoryItemLabelGenerator (DG);
  * 09-Jun-2005 : Use addItemEntity() from superclass (DG);
  * 27-Mar-2008 : Fixed error in findRangeBounds() method (DG);
+ * 26-Sep-2008 : Fixed bug with bar alignment when maximumBarWidth is
+ *               applied (DG);
+ * 04-Feb-2009 : Updated findRangeBounds to handle null dataset consistently
+ *               with other renderers (DG);
  *
  */
 
@@ -91,6 +95,12 @@ import org.jfree.util.PaintUtilities;
  *   inherited methods (for example,
  *   {@link AbstractRenderer#setSeriesPaint(int, Paint)}) are ignored;</li>
  * </ul>
+ * The example shown here is generated by the
+ * <code>WaterfallChartDemo1.java</code> program included in the JFreeChart
+ * Demo Collection:
+ * <br><br>
+ * <img src="../../../../../images/WaterfallBarRendererSample.png"
+ * alt="WaterfallBarRendererSample.png" />
  */
 public class WaterfallBarRenderer extends BarRenderer {
 
@@ -263,11 +273,9 @@ public class WaterfallBarRenderer extends BarRenderer {
      * @return The range (or <code>null</code> if the dataset is empty).
      */
     public Range findRangeBounds(CategoryDataset dataset) {
-
         if (dataset == null) {
-            throw new IllegalArgumentException("Null 'dataset' argument.");
+            return null;
         }
-
         boolean allItemsNull = true; // we'll set this to false if there is at
                                      // least one non-null data item...
         double minimum = 0.0;
@@ -338,14 +346,12 @@ public class WaterfallBarRenderer extends BarRenderer {
         }
         state.setSeriesRunningTotal(current);
 
-        int seriesCount = getRowCount();
         int categoryCount = getColumnCount();
         PlotOrientation orientation = plot.getOrientation();
 
         double rectX = 0.0;
         double rectY = 0.0;
 
-        RectangleEdge domainAxisLocation = plot.getDomainAxisEdge();
         RectangleEdge rangeAxisLocation = plot.getRangeAxisEdge();
 
         // Y0
@@ -370,39 +376,23 @@ public class WaterfallBarRenderer extends BarRenderer {
         double rectHeight = Math.max(getMinimumBarLength(),
                 Math.abs(j2dy1 - j2dy0));
 
+        Comparable seriesKey = dataset.getRowKey(row);
+        Comparable categoryKey = dataset.getColumnKey(column);
         if (orientation == PlotOrientation.HORIZONTAL) {
-            // BAR Y
-            rectY = domainAxis.getCategoryStart(column, getColumnCount(),
-                    dataArea, domainAxisLocation);
-            if (seriesCount > 1) {
-                double seriesGap = dataArea.getHeight() * getItemMargin()
-                                   / (categoryCount * (seriesCount - 1));
-                rectY = rectY + row * (state.getBarWidth() + seriesGap);
-            }
-            else {
-                rectY = rectY + row * state.getBarWidth();
-            }
+            rectY = domainAxis.getCategorySeriesMiddle(categoryKey, seriesKey,
+                    dataset, getItemMargin(), dataArea, RectangleEdge.LEFT);
 
             rectX = j2dy0;
             rectHeight = state.getBarWidth();
+            rectY = rectY - rectHeight / 2.0;
             rectWidth = Math.max(getMinimumBarLength(),
                     Math.abs(j2dy1 - j2dy0));
 
         }
         else if (orientation == PlotOrientation.VERTICAL) {
-            // BAR X
-            rectX = domainAxis.getCategoryStart(column, getColumnCount(),
-                    dataArea, domainAxisLocation);
-
-            if (seriesCount > 1) {
-                double seriesGap = dataArea.getWidth() * getItemMargin()
-                                   / (categoryCount * (seriesCount - 1));
-                rectX = rectX + row * (state.getBarWidth() + seriesGap);
-            }
-            else {
-                rectX = rectX + row * state.getBarWidth();
-            }
-
+            rectX = domainAxis.getCategorySeriesMiddle(categoryKey, seriesKey,
+                    dataset, getItemMargin(), dataArea, RectangleEdge.TOP);
+            rectX = rectX - rectWidth / 2.0;
             rectY = j2dy0;
         }
         Rectangle2D bar = new Rectangle2D.Double(rectX, rectY, rectWidth,
