@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,7 +27,7 @@
  * ---------------------------
  * AbstractXYItemRenderer.java
  * ---------------------------
- * (C) Copyright 2002-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2002-2009, by Object Refinery Limited and Contributors.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   Richard Atkinson;
@@ -104,7 +104,12 @@
  * 14-May-2008 : Updated addEntity() method to take plot orientation into
  *               account when the incoming area is null (DG);
  * 02-Jun-2008 : Added isPointInRect() method (DG);
- *
+ * 17-Jun-2008 : Apply legend shape, font and paint attributes (DG);
+ * 09-Mar-2009 : Added getAnnotations() method (DG);
+ * 27-Mar-2009 : Added new findDomainBounds() and findRangeBounds() methods to
+ *               take account of hidden series (DG);
+ * 01-Apr-2009 : Moved defaultEntityRadius up to superclass (DG);
+ * 
  */
 
 package org.jfree.chart.renderer.xy;
@@ -122,6 +127,8 @@ import java.awt.geom.Line2D;
 import java.awt.geom.Point2D;
 import java.awt.geom.Rectangle2D;
 import java.io.Serializable;
+import java.util.ArrayList;
+import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
 
@@ -174,28 +181,12 @@ public abstract class AbstractXYItemRenderer extends AbstractRenderer
     /** The plot. */
     private XYPlot plot;
 
-    /**
-     * The item label generator for ALL series.
-     *
-     * @deprecated This field is redundant, use itemLabelGeneratorList and
-     *     baseItemLabelGenerator instead.  Deprecated as of version 1.0.6.
-     */
-    private XYItemLabelGenerator itemLabelGenerator;
-
     /** A list of item label generators (one per series). */
     private ObjectList itemLabelGeneratorList;
 
     /** The base item label generator. */
     private XYItemLabelGenerator baseItemLabelGenerator;
 
-    /**
-     * The tool tip generator for ALL series.
-     *
-     * @deprecated This field is redundant, use tooltipGeneratorList and
-     *     baseToolTipGenerator instead.  Deprecated as of version 1.0.6.
-     */
-    private XYToolTipGenerator toolTipGenerator;
-
     /** A list of tool tip generators (one per series). */
     private ObjectList toolTipGeneratorList;
 
@@ -217,9 +208,6 @@ public abstract class AbstractXYItemRenderer extends AbstractRenderer
      */
     private List foregroundAnnotations;
 
-    /** The default radius for the entity 'hotspot' */
-    private int defaultEntityRadius;
-
     /** The legend item label generator. */
     private XYSeriesLabelGenerator legendItemLabelGenerator;
 
@@ -242,7 +230,6 @@ public abstract class AbstractXYItemRenderer extends AbstractRenderer
         this.urlGenerator = null;
         this.backgroundAnnotations = new java.util.ArrayList();
         this.foregroundAnnotations = new java.util.ArrayList();
-        this.defaultEntityRadius = 3;
         this.legendItemLabelGenerator = new StandardXYSeriesLabelGenerator(
                 "{0}");
     }
@@ -343,40 +330,6 @@ public abstract class AbstractXYItemRenderer extends AbstractRenderer
         return (XYItemLabelGenerator) this.itemLabelGeneratorList.get(series);
     }
 
-    /**
-     * Returns the item label generator override.
-     *
-     * @return The generator (possibly <code>null</code>).
-     *
-     * @since 1.0.5
-     *
-     * @see #setItemLabelGenerator(XYItemLabelGenerator)
-     *
-     * @deprecated As of version 1.0.6, this override setting should not be
-     *     used.  You can use the base setting instead
-     *     ({@link #getBaseItemLabelGenerator()}).
-     */
-    public XYItemLabelGenerator getItemLabelGenerator() {
-        return this.itemLabelGenerator;
-    }
-
-    /**
-     * Sets the item label generator for ALL series and sends a
-     * {@link RendererChangeEvent} to all registered listeners.
-     *
-     * @param generator  the generator (<code>null</code> permitted).
-     *
-     * @see #getItemLabelGenerator()
-     *
-     * @deprecated As of version 1.0.6, this override setting should not be
-     *     used.  You can use the base setting instead
-     *     ({@link #setBaseItemLabelGenerator(XYItemLabelGenerator)}).
-     */
-    public void setItemLabelGenerator(XYItemLabelGenerator generator) {
-        this.itemLabelGenerator = generator;
-        fireChangeEvent();
-    }
-
     /**
      * Sets the item label generator for a series and sends a
      * {@link RendererChangeEvent} to all registered listeners.
@@ -437,40 +390,6 @@ public abstract class AbstractXYItemRenderer extends AbstractRenderer
         return generator;
     }
 
-    /**
-     * Returns the override tool tip generator.
-     *
-     * @return The tool tip generator (possible <code>null</code>).
-     *
-     * @since 1.0.5
-     *
-     * @see #setToolTipGenerator(XYToolTipGenerator)
-     *
-     * @deprecated As of version 1.0.6, this override setting should not be
-     *     used.  You can use the base setting instead
-     *     ({@link #getBaseToolTipGenerator()}).
-     */
-    public XYToolTipGenerator getToolTipGenerator() {
-        return this.toolTipGenerator;
-    }
-
-    /**
-     * Sets the tool tip generator for ALL series and sends a
-     * {@link RendererChangeEvent} to all registered listeners.
-     *
-     * @param generator  the generator (<code>null</code> permitted).
-     *
-     * @see #getToolTipGenerator()
-     *
-     * @deprecated As of version 1.0.6, this override setting should not be
-     *     used.  You can use the base setting instead
-     *     ({@link #setBaseToolTipGenerator(XYToolTipGenerator)}).
-     */
-    public void setToolTipGenerator(XYToolTipGenerator generator) {
-        this.toolTipGenerator = generator;
-        fireChangeEvent();
-    }
-
     /**
      * Returns the tool tip generator for a series.
      *
@@ -605,23 +524,18 @@ public abstract class AbstractXYItemRenderer extends AbstractRenderer
     }
 
     /**
-     * Returns the radius of the circle used for the default entity area
-     * when no area is specified.
+     * Returns a collection of the annotations that are assigned to the
+     * renderer.
      *
-     * @return A radius.
+     * @return A collection of annotations (possibly empty but never
+     *     <code>null</code>).
+     * 
+     * @since 1.0.13
      */
-    public int getDefaultEntityRadius() {
-        return this.defaultEntityRadius;
-    }
-
-    /**
-     * Sets the radius of the circle used for the default entity area
-     * when no area is specified.
-     *
-     * @param radius  the radius.
-     */
-    public void setDefaultEntityRadius(int radius) {
-        this.defaultEntityRadius = radius;
+    public Collection getAnnotations() {
+        List result = new java.util.ArrayList(this.foregroundAnnotations);
+        result.addAll(this.backgroundAnnotations);
+        return result;
     }
 
     /**
@@ -708,13 +622,42 @@ public abstract class AbstractXYItemRenderer extends AbstractRenderer
      *
      * @return The range (<code>null</code> if the dataset is <code>null</code>
      *         or empty).
+     *
+     * @see #findRangeBounds(XYDataset)
      */
     public Range findDomainBounds(XYDataset dataset) {
-        if (dataset != null) {
-            return DatasetUtilities.findDomainBounds(dataset, false);
+        return findDomainBounds(dataset, false);
+    }
+
+    /**
+     * Returns the lower and upper bounds (range) of the x-values in the
+     * specified dataset.
+     *
+     * @param dataset  the dataset (<code>null</code> permitted).
+     *
+     * @return The range (<code>null</code> if the dataset is <code>null</code>
+     *         or empty).
+     *
+     * @since 1.0.13
+     */
+    protected Range findDomainBounds(XYDataset dataset,
+            boolean includeInterval) {
+        if (dataset == null) {
+            return null;
+        }
+        if (getDataBoundsIncludesVisibleSeriesOnly()) {
+            List visibleSeriesKeys = new ArrayList();
+            int seriesCount = dataset.getSeriesCount();
+            for (int s = 0; s < seriesCount; s++) {
+                if (isSeriesVisible(s)) {
+                    visibleSeriesKeys.add(dataset.getSeriesKey(s));
+                }
+            }
+            return DatasetUtilities.findDomainBounds(dataset,
+                    visibleSeriesKeys, includeInterval);
         }
         else {
-            return null;
+            return DatasetUtilities.findDomainBounds(dataset, includeInterval);
         }
     }
 
@@ -726,13 +669,60 @@ public abstract class AbstractXYItemRenderer extends AbstractRenderer
      *
      * @return The range (<code>null</code> if the dataset is <code>null</code>
      *         or empty).
+     *
+     * @see #findDomainBounds(XYDataset)
      */
     public Range findRangeBounds(XYDataset dataset) {
-        if (dataset != null) {
-            return DatasetUtilities.findRangeBounds(dataset, false);
+        return findRangeBounds(dataset, false);
+    }
+
+    /**
+     * Returns the range of values the renderer requires to display all the
+     * items from the specified dataset.
+     *
+     * @param dataset  the dataset (<code>null</code> permitted).
+     *
+     * @return The range (<code>null</code> if the dataset is <code>null</code>
+     *         or empty).
+     *
+     * @since 1.0.13
+     */
+    protected Range findRangeBounds(XYDataset dataset,
+            boolean includeInterval) {
+        if (dataset == null) {
+            return null;
+        }
+        if (getDataBoundsIncludesVisibleSeriesOnly()) {
+            List visibleSeriesKeys = new ArrayList();
+            int seriesCount = dataset.getSeriesCount();
+            for (int s = 0; s < seriesCount; s++) {
+                if (isSeriesVisible(s)) {
+                    visibleSeriesKeys.add(dataset.getSeriesKey(s));
+                }
+            }
+            // the bounds should be calculated using just the items within
+            // the current range of the x-axis...if there is one
+            Range xRange = null;
+            XYPlot p = getPlot();
+            if (p != null) {
+                ValueAxis xAxis = null;
+                int index = p.getIndexOf(this);
+                if (index >= 0) {
+                    xAxis = plot.getDomainAxisForDataset(index);
+                }
+                if (xAxis != null) {
+                    xRange = xAxis.getRange();
+                }
+            }
+            if (xRange == null) {
+                xRange = new Range(Double.NEGATIVE_INFINITY,
+                        Double.POSITIVE_INFINITY);
+            }
+            return DatasetUtilities.findRangeBounds(dataset,
+                    visibleSeriesKeys, xRange, includeInterval);
         }
         else {
-            return null;
+            return DatasetUtilities.findRangeBounds(dataset, includeInterval);
         }
     }
 
@@ -792,12 +782,17 @@ public abstract class AbstractXYItemRenderer extends AbstractRenderer
                     urlText = getLegendItemURLGenerator().generateLabel(
                             dataset, series);
                 }
-                Shape shape = lookupSeriesShape(series);
+                Shape shape = lookupLegendShape(series);
                 Paint paint = lookupSeriesPaint(series);
                 Paint outlinePaint = lookupSeriesOutlinePaint(series);
                 Stroke outlineStroke = lookupSeriesOutlineStroke(series);
                 result = new LegendItem(label, description, toolTipText,
                         urlText, shape, paint, outlineStroke, outlinePaint);
+                Paint labelPaint = lookupLegendTextPaint(series);
+                result.setLabelFont(lookupLegendTextFont(series));
+                if (labelPaint != null) {
+                    result.setLabelPaint(labelPaint);
+                }
                 result.setSeriesKey(dataset.getSeriesKey(series));
                 result.setSeriesIndex(series);
                 result.setDataset(dataset);
@@ -929,8 +924,8 @@ public abstract class AbstractXYItemRenderer extends AbstractRenderer
      * @param dataArea  the area for plotting data (not yet adjusted for any 3D
      *                  effect).
      * @param value  the value at which the grid line should be drawn.
-     * @param paint  the paint.
-     * @param stroke  the stroke.
+     * @param paint  the paint (<code>null</code> not permitted).
+     * @param stroke  the stroke (<code>null</code> not permitted).
      *
      * @since 1.0.5
      */
@@ -1519,9 +1514,6 @@ public abstract class AbstractXYItemRenderer extends AbstractRenderer
         if (!this.backgroundAnnotations.equals(that.backgroundAnnotations)) {
             return false;
         }
-        if (this.defaultEntityRadius != that.defaultEntityRadius) {
-            return false;
-        }
         if (!ObjectUtilities.equal(this.legendItemLabelGenerator,
                 that.legendItemLabelGenerator)) {
             return false;
@@ -1551,31 +1543,6 @@ public abstract class AbstractXYItemRenderer extends AbstractRenderer
         return result;
     }
 
-    /**
-     * Considers the current (x, y) coordinate and updates the crosshair point
-     * if it meets the criteria (usually means the (x, y) coordinate is the
-     * closest to the anchor point so far).
-     *
-     * @param crosshairState  the crosshair state (<code>null</code> permitted,
-     *                        but the method does nothing in that case).
-     * @param x  the x-value (in data space).
-     * @param y  the y-value (in data space).
-     * @param transX  the x-value translated to Java2D space.
-     * @param transY  the y-value translated to Java2D space.
-     * @param orientation  the plot orientation (<code>null</code> not
-     *                     permitted).
-     *
-     * @deprecated Use {@link #updateCrosshairValues(CrosshairState, double,
-     *         double, int, int, double, double, PlotOrientation)} -- see bug
-     *         report 1086307.
-     */
-    protected void updateCrosshairValues(CrosshairState crosshairState,
-            double x, double y, double transX, double transY,
-            PlotOrientation orientation) {
-        updateCrosshairValues(crosshairState, x, y, 0, 0, transX, transY,
-                orientation);
-    }
-
     /**
      * Considers the current (x, y) coordinate and updates the crosshair point
      * if it meets the criteria (usually means the (x, y) coordinate is the
@@ -1728,17 +1695,14 @@ public abstract class AbstractXYItemRenderer extends AbstractRenderer
         }
         Shape hotspot = area;
         if (hotspot == null) {
-        	double w = this.defaultEntityRadius * 2;
-        	if (getPlot().getOrientation() == PlotOrientation.VERTICAL) {
-        		hotspot = new Ellipse2D.Double(
-        				entityX - this.defaultEntityRadius,
-        				entityY - this.defaultEntityRadius, w, w);
-        	}
-        	else {
-        		hotspot = new Ellipse2D.Double(
-        				entityY - this.defaultEntityRadius,
-        	            entityX - this.defaultEntityRadius, w, w);
-        	}
+            double r = getDefaultEntityRadius();
+            double w = r * 2;
+            if (getPlot().getOrientation() == PlotOrientation.VERTICAL) {
+                hotspot = new Ellipse2D.Double(entityX - r, entityY - r, w, w);
+            }
+            else {
+                hotspot = new Ellipse2D.Double(entityY - r, entityX - r, w, w);
+            }
         }
         String tip = null;
         XYToolTipGenerator generator = getToolTipGenerator(series, item);
@@ -1768,9 +1732,121 @@ public abstract class AbstractXYItemRenderer extends AbstractRenderer
      */
     public static boolean isPointInRect(Rectangle2D rect, double x, double y) {
         // TODO: For JFreeChart 1.2.0, this method should go in the
-    	//       ShapeUtilities class
-    	return (x >= rect.getMinX() && x <= rect.getMaxX()
-        		&& y >= rect.getMinY() && y <= rect.getMaxY());
+        //       ShapeUtilities class
+        return (x >= rect.getMinX() && x <= rect.getMaxX()
+                && y >= rect.getMinY() && y <= rect.getMaxY());
     }
 
+    // === DEPRECATED CODE ===
+
+    /**
+     * The item label generator for ALL series.
+     *
+     * @deprecated This field is redundant, use itemLabelGeneratorList and
+     *     baseItemLabelGenerator instead.  Deprecated as of version 1.0.6.
+     */
+    private XYItemLabelGenerator itemLabelGenerator;
+
+    /**
+     * The tool tip generator for ALL series.
+     *
+     * @deprecated This field is redundant, use tooltipGeneratorList and
+     *     baseToolTipGenerator instead.  Deprecated as of version 1.0.6.
+     */
+    private XYToolTipGenerator toolTipGenerator;
+
+    /**
+     * Returns the item label generator override.
+     *
+     * @return The generator (possibly <code>null</code>).
+     *
+     * @since 1.0.5
+     *
+     * @see #setItemLabelGenerator(XYItemLabelGenerator)
+     *
+     * @deprecated As of version 1.0.6, this override setting should not be
+     *     used.  You can use the base setting instead
+     *     ({@link #getBaseItemLabelGenerator()}).
+     */
+    public XYItemLabelGenerator getItemLabelGenerator() {
+        return this.itemLabelGenerator;
+    }
+
+    /**
+     * Sets the item label generator for ALL series and sends a
+     * {@link RendererChangeEvent} to all registered listeners.
+     *
+     * @param generator  the generator (<code>null</code> permitted).
+     *
+     * @see #getItemLabelGenerator()
+     *
+     * @deprecated As of version 1.0.6, this override setting should not be
+     *     used.  You can use the base setting instead
+     *     ({@link #setBaseItemLabelGenerator(XYItemLabelGenerator)}).
+     */
+    public void setItemLabelGenerator(XYItemLabelGenerator generator) {
+        this.itemLabelGenerator = generator;
+        fireChangeEvent();
+    }
+
+    /**
+     * Returns the override tool tip generator.
+     *
+     * @return The tool tip generator (possible <code>null</code>).
+     *
+     * @since 1.0.5
+     *
+     * @see #setToolTipGenerator(XYToolTipGenerator)
+     *
+     * @deprecated As of version 1.0.6, this override setting should not be
+     *     used.  You can use the base setting instead
+     *     ({@link #getBaseToolTipGenerator()}).
+     */
+    public XYToolTipGenerator getToolTipGenerator() {
+        return this.toolTipGenerator;
+    }
+
+    /**
+     * Sets the tool tip generator for ALL series and sends a
+     * {@link RendererChangeEvent} to all registered listeners.
+     *
+     * @param generator  the generator (<code>null</code> permitted).
+     *
+     * @see #getToolTipGenerator()
+     *
+     * @deprecated As of version 1.0.6, this override setting should not be
+     *     used.  You can use the base setting instead
+     *     ({@link #setBaseToolTipGenerator(XYToolTipGenerator)}).
+     */
+    public void setToolTipGenerator(XYToolTipGenerator generator) {
+        this.toolTipGenerator = generator;
+        fireChangeEvent();
+    }
+
+    /**
+     * Considers the current (x, y) coordinate and updates the crosshair point
+     * if it meets the criteria (usually means the (x, y) coordinate is the
+     * closest to the anchor point so far).
+     *
+     * @param crosshairState  the crosshair state (<code>null</code> permitted,
+     *                        but the method does nothing in that case).
+     * @param x  the x-value (in data space).
+     * @param y  the y-value (in data space).
+     * @param transX  the x-value translated to Java2D space.
+     * @param transY  the y-value translated to Java2D space.
+     * @param orientation  the plot orientation (<code>null</code> not
+     *                     permitted).
+     *
+     * @deprecated Use {@link #updateCrosshairValues(CrosshairState, double,
+     *         double, int, int, double, double, PlotOrientation)} -- see bug
+     *         report 1086307.
+     */
+    protected void updateCrosshairValues(CrosshairState crosshairState,
+            double x, double y, double transX, double transY,
+            PlotOrientation orientation) {
+        updateCrosshairValues(crosshairState, x, y, 0, 0, transX, transY,
+                orientation);
+    }
+
+
 }
