@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,7 +27,7 @@
  * ------------------------
  * CandlestickRenderer.java
  * ------------------------
- * (C) Copyright 2001-2008, by Object Refinery Limited.
+ * (C) Copyright 2001-2009, by Object Refinery Limited.
  *
  * Original Authors:  David Gilbert (for Object Refinery Limited);
  *                    Sylvain Vieujot;
@@ -80,6 +80,8 @@
  * 08-Oct-2007 : Added new volumePaint field (DG);
  * 08-Apr-2008 : Added findRangeBounds() method override (DG);
  * 13-May-2008 : Fixed chart entity bugs (1962467 and 1962472) (DG);
+ * 27-Mar-2009 : Updated findRangeBounds() to call new method in
+ *               superclass (DG);
  *
  */
 
@@ -119,7 +121,12 @@ import org.jfree.util.PublicCloneable;
 
 /**
  * A renderer that draws candlesticks on an {@link XYPlot} (requires a
- * {@link OHLCDataset}).
+ * {@link OHLCDataset}).  The example shown here is generated
+ * by the <code>CandlestickChartDemo1.java</code> program included in the
+ * JFreeChart demo collection:
+ * <br><br>
+ * <img src="../../../../../images/CandlestickRendererSample.png"
+ * alt="CandlestickRendererSample.png" />
  * <P>
  * This renderer does not include code to calculate the crosshair point for the
  * plot.
@@ -563,12 +570,7 @@ public class CandlestickRenderer extends AbstractXYItemRenderer
      *         or empty).
      */
     public Range findRangeBounds(XYDataset dataset) {
-        if (dataset != null) {
-            return DatasetUtilities.findRangeBounds(dataset, true);
-        }
-        else {
-            return null;
-        }
+        return findRangeBounds(dataset, true);
     }
 
     /**
@@ -778,7 +780,7 @@ public class CandlestickRenderer extends AbstractXYItemRenderer
             g2.setPaint(getVolumePaint());
             Composite originalComposite = g2.getComposite();
             g2.setComposite(AlphaComposite.getInstance(
-            		AlphaComposite.SRC_OVER, 0.3f));
+                    AlphaComposite.SRC_OVER, 0.3f));
 
             if (horiz) {
                 g2.fill(new Rectangle2D.Double(min, xx - volumeWidth / 2,
@@ -833,13 +835,13 @@ public class CandlestickRenderer extends AbstractXYItemRenderer
             body = new Rectangle2D.Double(yyMinOpenClose, xx - stickWidth / 2,
                     yyMaxOpenClose - yyMinOpenClose, stickWidth);
             hotspot = new Rectangle2D.Double(base, xx - stickWidth / 2,
-            		length, stickWidth);
+                    length, stickWidth);
         }
         else {
             body = new Rectangle2D.Double(xx - stickWidth / 2, yyMinOpenClose,
                     stickWidth, yyMaxOpenClose - yyMinOpenClose);
             hotspot = new Rectangle2D.Double(xx - stickWidth / 2,
-            		base, stickWidth, length);
+                    base, stickWidth, length);
         }
         if (yClose > yOpen) {
             if (this.upPaint != null) {
