@@ -62,6 +62,7 @@
  * 06-Jul-2006 : Replace dataset methods getX() --> getXValue() (DG);
  * 08-Apr-2008 : Added findRangeBounds() override (DG);
  * 29-Apr-2008 : Added tickLength field (DG);
+ * 25-Sep-2008 : Check for non-null entity collection (DG);
  *
  */
 
@@ -80,9 +81,7 @@ import java.io.Serializable;
 
 import org.jfree.chart.axis.ValueAxis;
 import org.jfree.chart.entity.EntityCollection;
-import org.jfree.chart.entity.XYItemEntity;
 import org.jfree.chart.event.RendererChangeEvent;
-import org.jfree.chart.labels.XYToolTipGenerator;
 import org.jfree.chart.plot.CrosshairState;
 import org.jfree.chart.plot.PlotOrientation;
 import org.jfree.chart.plot.PlotRenderingInfo;
@@ -100,6 +99,13 @@ import org.jfree.util.PublicCloneable;
  * A renderer that draws high/low/open/close markers on an {@link XYPlot}
  * (requires a {@link OHLCDataset}).  This renderer does not include code to
  * calculate the crosshair point for the plot.
+ *
+ * The example shown here is generated by the
+ * <code>HighLowChartDemo1.java</code> program included in the JFreeChart Demo
+ * Collection:
+ * <br><br>
+ * <img src="../../../../../images/HighLowRendererSample.png"
+ * alt="HighLowRendererSample.png" />
  */
 public class HighLowRenderer extends AbstractXYItemRenderer
         implements XYItemRenderer, Cloneable, PublicCloneable, Serializable {
@@ -440,20 +446,8 @@ public class HighLowRenderer extends AbstractXYItemRenderer
             }
         }
 
-        // add an entity for the item...
         if (entities != null) {
-            String tip = null;
-            XYToolTipGenerator generator = getToolTipGenerator(series, item);
-            if (generator != null) {
-                tip = generator.generateToolTip(dataset, series, item);
-            }
-            String url = null;
-            if (getURLGenerator() != null) {
-                url = getURLGenerator().generateURL(dataset, series, item);
-            }
-            XYItemEntity entity = new XYItemEntity(entityArea, dataset,
-                    series, item, tip, url);
-            entities.add(entity);
+            addEntity(entities, entityArea, dataset, series, item, 0.0, 0.0);
         }
 
     }
