@@ -62,6 +62,8 @@
  *               items that are not displayed (DG);
  * 26-Oct-2007 : Deprecated override attributes (DG);
  * 02-Jun-2008 : Fixed tooltips at lower edges of data area (DG);
+ * 17-Jun-2008 : Apply legend shape, font and paint attributes (DG);
+ * 19-Sep-2008 : Fixed bug with drawSeriesLineAsPath - patch by Greg Darke (DG);
  *
  */
 
@@ -99,7 +101,13 @@ import org.jfree.util.ShapeUtilities;
 /**
  * A renderer that connects data points with lines and/or draws shapes at each
  * data point.  This renderer is designed for use with the {@link XYPlot}
- * class.
+ * class.  The example shown here is generated by
+ * the <code>XYLineAndShapeRendererDemo2.java</code> program included in the
+ * JFreeChart demo collection:
+ * <br><br>
+ * <img src="../../../../../images/XYLineAndShapeRendererSample.png"
+ * alt="XYLineAndShapeRendererSample.png" />
+ *
  */
 public class XYLineAndShapeRenderer extends AbstractXYItemRenderer
         implements XYItemRenderer, Cloneable, PublicCloneable, Serializable {
@@ -806,6 +814,26 @@ public class XYLineAndShapeRenderer extends AbstractXYItemRenderer
         public void setLastPointGood(boolean good) {
             this.lastPointGood = good;
         }
+
+        /**
+         * This method is called by the {@link XYPlot} at the start of each
+         * series pass.  We reset the state for the current series.
+         *
+         * @param dataset  the dataset.
+         * @param series  the series index.
+         * @param firstItem  the first item index for this pass.
+         * @param lastItem  the last item index for this pass.
+         * @param pass  the current pass index.
+         * @param passCount  the number of passes.
+         */
+        public void startSeriesPass(XYDataset dataset, int series,
+                int firstItem, int lastItem, int pass, int passCount) {
+            this.seriesPath.reset();
+            this.lastPointGood = false;
+            super.startSeriesPass(dataset, series, firstItem, lastItem, pass,
+                    passCount);
+       }
+
     }
 
     /**
@@ -874,14 +902,6 @@ public class XYLineAndShapeRenderer extends AbstractXYItemRenderer
 
         // first pass draws the background (lines, for instance)
         if (isLinePass(pass)) {
-            if (item == 0) {
-                if (this.drawSeriesLineAsPath) {
-                    State s = (State) state;
-                    s.seriesPath.reset();
-                    s.lastPointGood = false;
-                }
-            }
-
             if (getItemLineVisible(series, item)) {
                 if (this.drawSeriesLineAsPath) {
                     drawPrimaryLineAsPath(state, g2, plot, dataset, pass,
@@ -1079,7 +1099,7 @@ public class XYLineAndShapeRenderer extends AbstractXYItemRenderer
             s.setLastPointGood(false);
         }
         // if this is the last item, draw the path ...
-        if (item == dataset.getItemCount(series) - 1) {
+        if (item == s.getLastItemIndex()) {
             // draw path
             drawFirstPassShape(g2, pass, series, item, s.seriesPath);
         }
@@ -1221,7 +1241,7 @@ public class XYLineAndShapeRenderer extends AbstractXYItemRenderer
                             dataset, series);
                 }
                 boolean shapeIsVisible = getItemShapeVisible(series, 0);
-                Shape shape = lookupSeriesShape(series);
+                Shape shape = lookupLegendShape(series);
                 boolean shapeIsFilled = getItemShapeFilled(series, 0);
                 Paint fillPaint = (this.useFillPaint
                     ? lookupSeriesFillPaint(series)
@@ -1239,6 +1259,11 @@ public class XYLineAndShapeRenderer extends AbstractXYItemRenderer
                         fillPaint, shapeOutlineVisible, outlinePaint,
                         outlineStroke, lineVisible, this.legendLine,
                         lineStroke, linePaint);
+                result.setLabelFont(lookupLegendTextFont(series));
+                Paint labelPaint = lookupLegendTextPaint(series);
+                if (labelPaint != null) {
+                    result.setLabelPaint(labelPaint);
+                }
                 result.setSeriesKey(dataset.getSeriesKey(series));
                 result.setSeriesIndex(series);
                 result.setDataset(dataset);
@@ -1279,7 +1304,6 @@ public class XYLineAndShapeRenderer extends AbstractXYItemRenderer
      * @return <code>true</code> or <code>false</code>.
      */
     public boolean equals(Object obj) {
-
         if (obj == this) {
             return true;
         }
@@ -1339,7 +1363,6 @@ public class XYLineAndShapeRenderer extends AbstractXYItemRenderer
             return false;
         }
         return true;
-
     }
 
     /**
