@@ -2,52 +2,54 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2006, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
- * This library is free software; you can redistribute it and/or modify it 
- * under the terms of the GNU Lesser General Public License as published by 
- * the Free Software Foundation; either version 2.1 of the License, or 
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
  * License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
- * USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+ * USA.
  *
- * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
+ * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
  * in the United States and other countries.]
  *
  * -----------------------
  * XYStepAreaRenderer.java
  * -----------------------
- * (C) Copyright 2003-2006, by Matthias Rose and Contributors.
+ * (C) Copyright 2003-2008, by Matthias Rose and Contributors.
  *
  * Original Author:  Matthias Rose (based on XYAreaRenderer.java);
  * Contributor(s):   David Gilbert (for Object Refinery Limited);
  *
- * $Id: XYStepAreaRenderer.java,v 1.7.2.4 2006/07/06 10:27:57 mungady Exp $
- *
  * Changes:
  * --------
  * 07-Oct-2003 : Version 1, contributed by Matthias Rose (DG);
  * 10-Feb-2004 : Added some getter and setter methods (DG);
- * 25-Feb-2004 : Replaced CrosshairInfo with CrosshairState.  Renamed 
+ * 25-Feb-2004 : Replaced CrosshairInfo with CrosshairState.  Renamed
  *               XYToolTipGenerator --> XYItemLabelGenerator (DG);
- * 15-Jul-2004 : Switched getX() with getXValue() and getY() with 
+ * 15-Jul-2004 : Switched getX() with getXValue() and getY() with
  *               getYValue() (DG);
  * 11-Nov-2004 : Now uses ShapeUtilities to translate shapes (DG);
  * 06-Jul-2005 : Renamed get/setPlotShapes() --> get/setShapesVisible() (DG);
- * ------------- JFREECHART 1.0.0 ---------------------------------------------
- * 06-Jul-2006 : Modified to call dataset methods that return double 
+ * ------------- JFREECHART 1.0.x ---------------------------------------------
+ * 06-Jul-2006 : Modified to call dataset methods that return double
  *               primitives only (DG);
- * 
+ * 06-Feb-2007 : Fixed bug 1086307, crosshairs with multiple axes (DG);
+ * 14-Feb-2007 : Added equals() method override (DG);
+ * 04-May-2007 : Set processVisibleItemsOnly flag to false (DG);
+ * 14-May-2008 : Call addEntity() from within drawItem() (DG);
+ *
  */
 
 package org.jfree.chart.renderer.xy;
@@ -62,7 +64,6 @@ import java.io.Serializable;
 
 import org.jfree.chart.axis.ValueAxis;
 import org.jfree.chart.entity.EntityCollection;
-import org.jfree.chart.entity.XYItemEntity;
 import org.jfree.chart.event.RendererChangeEvent;
 import org.jfree.chart.labels.XYToolTipGenerator;
 import org.jfree.chart.plot.CrosshairState;
@@ -76,24 +77,27 @@ import org.jfree.util.ShapeUtilities;
 
 /**
  * A step chart renderer that fills the area between the step and the x-axis.
+ * The example shown here is generated by the
+ * <code>XYStepAreaRendererDemo1.java</code> program included in the JFreeChart
+ * demo collection:
+ * <br><br>
+ * <img src="../../../../../images/XYStepAreaRendererSample.png"
+ * alt="XYStepAreaRendererSample.png" />
  */
-public class XYStepAreaRenderer extends AbstractXYItemRenderer 
-                                implements XYItemRenderer, 
-                                           Cloneable,
-                                           PublicCloneable,
-                                           Serializable {
+public class XYStepAreaRenderer extends AbstractXYItemRenderer
+        implements XYItemRenderer, Cloneable, PublicCloneable, Serializable {
 
     /** For serialization. */
     private static final long serialVersionUID = -7311560779702649635L;
-    
+
     /** Useful constant for specifying the type of rendering (shapes only). */
     public static final int SHAPES = 1;
 
     /** Useful constant for specifying the type of rendering (area only). */
     public static final int AREA = 2;
 
-    /** 
-     * Useful constant for specifying the type of rendering (area and shapes). 
+    /**
+     * Useful constant for specifying the type of rendering (area and shapes).
      */
     public static final int AREA_AND_SHAPES = 3;
 
@@ -112,9 +116,9 @@ public class XYStepAreaRenderer extends AbstractXYItemRenderer
     /** Area of the complete series */
     protected transient Polygon pArea = null;
 
-    /** 
-     * The value on the range axis which defines the 'lower' border of the 
-     * area. 
+    /**
+     * The value on the range axis which defines the 'lower' border of the
+     * area.
      */
     private double rangeBase;
 
@@ -141,12 +145,12 @@ public class XYStepAreaRenderer extends AbstractXYItemRenderer
      * AREA, SHAPES or AREA_AND_SHAPES.
      *
      * @param type  the type of renderer.
-     * @param toolTipGenerator  the tool tip generator to use 
+     * @param toolTipGenerator  the tool tip generator to use
      *                          (<code>null</code> permitted).
      * @param urlGenerator  the URL generator (<code>null</code> permitted).
      */
     public XYStepAreaRenderer(int type,
-                              XYToolTipGenerator toolTipGenerator, 
+                              XYToolTipGenerator toolTipGenerator,
                               XYURLGenerator urlGenerator) {
 
         super();
@@ -167,109 +171,132 @@ public class XYStepAreaRenderer extends AbstractXYItemRenderer
     }
 
     /**
-     * Returns a flag that controls whether or not outlines of the areas are 
+     * Returns a flag that controls whether or not outlines of the areas are
      * drawn.
      *
      * @return The flag.
+     *
+     * @see #setOutline(boolean)
      */
     public boolean isOutline() {
         return this.showOutline;
     }
 
     /**
-     * Sets a flag that controls whether or not outlines of the areas are 
-     * drawn, and sends a {@link RendererChangeEvent} to all registered 
+     * Sets a flag that controls whether or not outlines of the areas are
+     * drawn, and sends a {@link RendererChangeEvent} to all registered
      * listeners.
      *
      * @param show  the flag.
+     *
+     * @see #isOutline()
      */
     public void setOutline(boolean show) {
         this.showOutline = show;
-        notifyListeners(new RendererChangeEvent(this));
+        fireChangeEvent();
     }
 
     /**
      * Returns true if shapes are being plotted by the renderer.
      *
      * @return <code>true</code> if shapes are being plotted by the renderer.
+     *
+     * @see #setShapesVisible(boolean)
      */
     public boolean getShapesVisible() {
         return this.shapesVisible;
     }
-    
+
     /**
-     * Sets the flag that controls whether or not shapes are displayed for each 
+     * Sets the flag that controls whether or not shapes are displayed for each
      * data item, and sends a {@link RendererChangeEvent} to all registered
      * listeners.
-     * 
+     *
      * @param flag  the flag.
+     *
+     * @see #getShapesVisible()
      */
     public void setShapesVisible(boolean flag) {
         this.shapesVisible = flag;
-        notifyListeners(new RendererChangeEvent(this));
+        fireChangeEvent();
     }
 
     /**
      * Returns the flag that controls whether or not the shapes are filled.
-     * 
+     *
      * @return A boolean.
+     *
+     * @see #setShapesFilled(boolean)
      */
     public boolean isShapesFilled() {
         return this.shapesFilled;
     }
-    
+
     /**
-     * Sets the 'shapes filled' for ALL series.
+     * Sets the 'shapes filled' for ALL series and sends a
+     * {@link RendererChangeEvent} to all registered listeners.
      *
      * @param filled  the flag.
+     *
+     * @see #isShapesFilled()
      */
     public void setShapesFilled(boolean filled) {
         this.shapesFilled = filled;
-        notifyListeners(new RendererChangeEvent(this));
+        fireChangeEvent();
     }
 
     /**
      * Returns true if Area is being plotted by the renderer.
      *
      * @return <code>true</code> if Area is being plotted by the renderer.
+     *
+     * @see #setPlotArea(boolean)
      */
     public boolean getPlotArea() {
         return this.plotArea;
     }
 
     /**
-     * Sets a flag that controls whether or not areas are drawn for each data 
-     * item.
-     * 
+     * Sets a flag that controls whether or not areas are drawn for each data
+     * item and sends a {@link RendererChangeEvent} to all registered
+     * listeners.
+     *
      * @param flag  the flag.
+     *
+     * @see #getPlotArea()
      */
     public void setPlotArea(boolean flag) {
         this.plotArea = flag;
-        notifyListeners(new RendererChangeEvent(this));
+        fireChangeEvent();
     }
-    
+
     /**
      * Returns the value on the range axis which defines the 'lower' border of
      * the area.
      *
-     * @return <code>double</code> the value on the range axis which defines 
+     * @return <code>double</code> the value on the range axis which defines
      *         the 'lower' border of the area.
+     *
+     * @see #setRangeBase(double)
      */
     public double getRangeBase() {
         return this.rangeBase;
     }
 
     /**
-     * Sets the value on the range axis which defines the default border of the 
-     * area.  E.g. setRangeBase(Double.NEGATIVE_INFINITY) lets areas always 
-     * reach the lower border of the plotArea. 
-     * 
+     * Sets the value on the range axis which defines the default border of the
+     * area, and sends a {@link RendererChangeEvent} to all registered
+     * listeners.  E.g. setRangeBase(Double.NEGATIVE_INFINITY) lets areas always
+     * reach the lower border of the plotArea.
+     *
      * @param val  the value on the range axis which defines the default border
      *             of the area.
+     *
+     * @see #getRangeBase()
      */
     public void setRangeBase(double val) {
         this.rangeBase = val;
-        notifyListeners(new RendererChangeEvent(this));
+        fireChangeEvent();
     }
 
     /**
@@ -280,7 +307,7 @@ public class XYStepAreaRenderer extends AbstractXYItemRenderer
      * @param dataArea  the area inside the axes.
      * @param plot  the plot.
      * @param data  the data.
-     * @param info  an optional info collection object to return data back to 
+     * @param info  an optional info collection object to return data back to
      *              the caller.
      *
      * @return The number of passes required by the renderer.
@@ -291,7 +318,13 @@ public class XYStepAreaRenderer extends AbstractXYItemRenderer
                                           XYDataset data,
                                           PlotRenderingInfo info) {
 
-        return super.initialise(g2, dataArea, plot, data, info);
+
+        XYItemRendererState state = super.initialise(g2, dataArea, plot, data,
+                info);
+        // disable visible items optimisation - it doesn't work for this
+        // renderer...
+        state.setProcessVisibleItemsOnly(false);
+        return state;
 
     }
 
@@ -303,14 +336,14 @@ public class XYStepAreaRenderer extends AbstractXYItemRenderer
      * @param state  the renderer state.
      * @param dataArea  the area within which the data is being drawn.
      * @param info  collects information about the drawing.
-     * @param plot  the plot (can be used to obtain standard color information 
+     * @param plot  the plot (can be used to obtain standard color information
      *              etc).
      * @param domainAxis  the domain axis.
      * @param rangeAxis  the range axis.
      * @param dataset  the dataset.
      * @param series  the series index (zero-based).
      * @param item  the item index (zero-based).
-     * @param crosshairState  crosshair information for the plot 
+     * @param crosshairState  crosshair information for the plot
      *                        (<code>null</code> permitted).
      * @param pass  the pass index.
      */
@@ -326,10 +359,10 @@ public class XYStepAreaRenderer extends AbstractXYItemRenderer
                          int item,
                          CrosshairState crosshairState,
                          int pass) {
-                             
+
         PlotOrientation orientation = plot.getOrientation();
-        
-        // Get the item count for the series, so that we can know which is the 
+
+        // Get the item count for the series, so that we can know which is the
         // end of the series.
         int itemCount = dataset.getItemCount(series);
 
@@ -343,26 +376,26 @@ public class XYStepAreaRenderer extends AbstractXYItemRenderer
         double y1 = dataset.getYValue(series, item);
         double x = x1;
         double y = Double.isNaN(y1) ? getRangeBase() : y1;
-        double transX1 = domainAxis.valueToJava2D(x, dataArea, 
+        double transX1 = domainAxis.valueToJava2D(x, dataArea,
                 plot.getDomainAxisEdge());
-        double transY1 = rangeAxis.valueToJava2D(y, dataArea, 
+        double transY1 = rangeAxis.valueToJava2D(y, dataArea,
                 plot.getRangeAxisEdge());
-                                                          
+
         // avoid possible sun.dc.pr.PRException: endPath: bad path
-        transY1 = restrictValueToDataArea(transY1, plot, dataArea);         
+        transY1 = restrictValueToDataArea(transY1, plot, dataArea);
 
         if (this.pArea == null && !Double.isNaN(y1)) {
 
             // Create a new Area for the series
             this.pArea = new Polygon();
-        
+
             // start from Y = rangeBase
             double transY2 = rangeAxis.valueToJava2D(getRangeBase(), dataArea,
                     plot.getRangeAxisEdge());
-        
+
             // avoid possible sun.dc.pr.PRException: endPath: bad path
-            transY2 = restrictValueToDataArea(transY2, plot, dataArea);         
-        
+            transY2 = restrictValueToDataArea(transY2, plot, dataArea);
+
             // The first point is (x, this.baseYValue)
             if (orientation == PlotOrientation.VERTICAL) {
                 this.pArea.addPoint((int) transX1, (int) transY2);
@@ -373,10 +406,9 @@ public class XYStepAreaRenderer extends AbstractXYItemRenderer
         }
 
         double transX0 = 0;
-        double transY0 = restrictValueToDataArea(
-            getRangeBase(), plot, dataArea
-        );           
-        
+        double transY0 = restrictValueToDataArea(getRangeBase(), plot,
+                dataArea);
+
         double x0;
         double y0;
         if (item > 0) {
@@ -386,19 +418,19 @@ public class XYStepAreaRenderer extends AbstractXYItemRenderer
 
             x = x0;
             y = Double.isNaN(y0) ? getRangeBase() : y0;
-            transX0 = domainAxis.valueToJava2D(x, dataArea, 
+            transX0 = domainAxis.valueToJava2D(x, dataArea,
                     plot.getDomainAxisEdge());
-            transY0 = rangeAxis.valueToJava2D(y, dataArea, 
+            transY0 = rangeAxis.valueToJava2D(y, dataArea,
                     plot.getRangeAxisEdge());
 
             // avoid possible sun.dc.pr.PRException: endPath: bad path
             transY0 = restrictValueToDataArea(transY0, plot, dataArea);
-                        
+
             if (Double.isNaN(y1)) {
                 // NULL value -> insert point on base line
                 // instead of 'step point'
                 transX1 = transX0;
-                transY0 = transY1;          
+                transY0 = transY1;
             }
             if (transY0 != transY1) {
                 // not just a horizontal bar but need to perform a 'step'.
@@ -409,7 +441,7 @@ public class XYStepAreaRenderer extends AbstractXYItemRenderer
                     this.pArea.addPoint((int) transY0, (int) transX1);
                 }
             }
-        }           
+        }
 
         Shape shape = null;
         if (!Double.isNaN(y1)) {
@@ -424,43 +456,43 @@ public class XYStepAreaRenderer extends AbstractXYItemRenderer
             if (getShapesVisible()) {
                 shape = getItemShape(series, item);
                 if (orientation == PlotOrientation.VERTICAL) {
-                    shape = ShapeUtilities.createTranslatedShape(shape, 
+                    shape = ShapeUtilities.createTranslatedShape(shape,
                             transX1, transY1);
                 }
                 else if (orientation == PlotOrientation.HORIZONTAL) {
-                    shape = ShapeUtilities.createTranslatedShape(shape, 
+                    shape = ShapeUtilities.createTranslatedShape(shape,
                             transY1, transX1);
                 }
                 if (isShapesFilled()) {
                     g2.fill(shape);
-                }   
+                }
                 else {
                     g2.draw(shape);
-                }   
+                }
             }
             else {
                 if (orientation == PlotOrientation.VERTICAL) {
-                    shape = new Rectangle2D.Double(transX1 - 2, transY1 - 2, 
+                    shape = new Rectangle2D.Double(transX1 - 2, transY1 - 2,
                             4.0, 4.0);
                 }
                 else if (orientation == PlotOrientation.HORIZONTAL) {
-                    shape = new Rectangle2D.Double(transY1 - 2, transX1 - 2, 
+                    shape = new Rectangle2D.Double(transY1 - 2, transX1 - 2,
                             4.0, 4.0);
                 }
             }
         }
 
         // Check if the item is the last item for the series or if it
-        // is a NULL value and number of items > 0.  We can't draw an area for 
+        // is a NULL value and number of items > 0.  We can't draw an area for
         // a single point.
-        if (getPlotArea() && item > 0 && this.pArea != null 
+        if (getPlotArea() && item > 0 && this.pArea != null
                           && (item == (itemCount - 1) || Double.isNaN(y1))) {
 
-            double transY2 = rangeAxis.valueToJava2D(getRangeBase(), dataArea, 
+            double transY2 = rangeAxis.valueToJava2D(getRangeBase(), dataArea,
                     plot.getRangeAxisEdge());
 
             // avoid possible sun.dc.pr.PRException: endPath: bad path
-            transY2 = restrictValueToDataArea(transY2, plot, dataArea);         
+            transY2 = restrictValueToDataArea(transY2, plot, dataArea);
 
             if (orientation == PlotOrientation.VERTICAL) {
                 // Add the last point (x,0)
@@ -487,70 +519,91 @@ public class XYStepAreaRenderer extends AbstractXYItemRenderer
 
         // do we need to update the crosshair values?
         if (!Double.isNaN(y1)) {
-            updateCrosshairValues(crosshairState, x1, y1, transX1, transY1, 
-                    orientation);
+            int domainAxisIndex = plot.getDomainAxisIndex(domainAxis);
+            int rangeAxisIndex = plot.getRangeAxisIndex(rangeAxis);
+            updateCrosshairValues(crosshairState, x1, y1, domainAxisIndex,
+                    rangeAxisIndex, transX1, transY1, orientation);
         }
 
         // collect entity and tool tip information...
-        if (state.getInfo() != null) {
-            EntityCollection entities = state.getEntityCollection();
-            if (entities != null && shape != null) {
-                String tip = null;
-                XYToolTipGenerator generator 
-                    = getToolTipGenerator(series, item);
-                if (generator != null) {
-                    tip = generator.generateToolTip(dataset, series, item);
-                }
-                String url = null;
-                if (getURLGenerator() != null) {
-                    url = getURLGenerator().generateURL(dataset, series, item);
-                }
-                XYItemEntity entity = new XYItemEntity(shape, dataset, series, 
-                        item, tip, url);
-                entities.add(entity);
-            }
+        EntityCollection entities = state.getEntityCollection();
+        if (entities != null) {
+            addEntity(entities, shape, dataset, series, item, transX1, transY1);
         }
     }
 
+    /**
+     * Tests this renderer for equality with an arbitrary object.
+     *
+     * @param obj  the object (<code>null</code> permitted).
+     *
+     * @return A boolean.
+     */
+    public boolean equals(Object obj) {
+        if (obj == this) {
+            return true;
+        }
+        if (!(obj instanceof XYStepAreaRenderer)) {
+            return false;
+        }
+        XYStepAreaRenderer that = (XYStepAreaRenderer) obj;
+        if (this.showOutline != that.showOutline) {
+            return false;
+        }
+        if (this.shapesVisible != that.shapesVisible) {
+            return false;
+        }
+        if (this.shapesFilled != that.shapesFilled) {
+            return false;
+        }
+        if (this.plotArea != that.plotArea) {
+            return false;
+        }
+        if (this.rangeBase != that.rangeBase) {
+            return false;
+        }
+        return super.equals(obj);
+    }
+
     /**
      * Returns a clone of the renderer.
-     * 
+     *
      * @return A clone.
-     * 
+     *
      * @throws CloneNotSupportedException  if the renderer cannot be cloned.
      */
     public Object clone() throws CloneNotSupportedException {
         return super.clone();
     }
-    
+
     /**
      * Helper method which returns a value if it lies
      * inside the visible dataArea and otherwise the corresponding
      * coordinate on the border of the dataArea. The PlotOrientation
-     * is taken into account. 
+     * is taken into account.
      * Useful to avoid possible sun.dc.pr.PRException: endPath: bad path
      * which occurs when trying to draw lines/shapes which in large part
      * lie outside of the visible dataArea.
-     * 
-     * @param value the value which shall be 
+     *
+     * @param value the value which shall be
      * @param dataArea  the area within which the data is being drawn.
-     * @param plot  the plot (can be used to obtain standard color 
+     * @param plot  the plot (can be used to obtain standard color
      *              information etc).
      * @return <code>double</code> value inside the data area.
      */
-    protected static double restrictValueToDataArea(double value, 
-                                                    XYPlot plot, 
+    protected static double restrictValueToDataArea(double value,
+                                                    XYPlot plot,
                                                     Rectangle2D dataArea) {
         double min = 0;
         double max = 0;
         if (plot.getOrientation() == PlotOrientation.VERTICAL) {
             min = dataArea.getMinY();
             max = dataArea.getMaxY();
-        } 
+        }
         else if (plot.getOrientation() ==  PlotOrientation.HORIZONTAL) {
             min = dataArea.getMinX();
             max = dataArea.getMaxX();
-        }       
+        }
         if (value < min) {
             value = min;
         }
