@@ -2,43 +2,44 @@
  * JFreeChart : a free Java chart library
  * ======================================
  *
- * (C) Copyright 2000-2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
- * This library is free software; you can redistribute it and/or modify it 
- * under the terms of the GNU Lesser General Public License as published by 
- * the Free Software Foundation; either version 2.1 of the License, or 
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
  * License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
- * USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+ * USA.
  *
- * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
+ * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
  * in the United States and other countries.]
  *
  * --------------------------
  * CustomPieURLGenerator.java
  * --------------------------
- * (C) Copyright 2004-2007, by David Basten and Contributors.
+ * (C) Copyright 2004-2008, by David Basten and Contributors.
  *
  * Original Author:  David Basten;
  * Contributors:     -;
  *
  * Changes:
  * --------
- * 04-Feb-2004 : Version 1, contributed by David Basten based on 
+ * 04-Feb-2004 : Version 1, contributed by David Basten based on
  *               CustomXYURLGenerator by Richard Atkinson (added to main source
  *               tree on 25-May-2004);
  *
  */
+
 package org.jfree.chart.urls;
 
 import java.io.Serializable;
@@ -55,10 +56,8 @@ import org.jfree.util.PublicCloneable;
 /**
  * A custom URL generator for pie charts.
  */
-public class CustomPieURLGenerator implements PieURLGenerator, 
-                                              Cloneable, 
-                                              PublicCloneable, 
-                                              Serializable {
+public class CustomPieURLGenerator implements PieURLGenerator,
+        Cloneable, PublicCloneable, Serializable {
 
     /** For serialization. */
     private static final long serialVersionUID = 7100607670144900503L;
@@ -83,33 +82,33 @@ public class CustomPieURLGenerator implements PieURLGenerator,
      * @param pieIndex  the pie index.
      *
      * @return A string containing the generated URL.
-     * 
+     *
      * @see #getURL(Comparable, int)
      */
-    public String generateURL(PieDataset dataset, Comparable key, 
+    public String generateURL(PieDataset dataset, Comparable key,
                               int pieIndex) {
         return getURL(key, pieIndex);
     }
 
     /**
      * Returns the number of URL maps stored by the renderer.
-     * 
+     *
      * @return The list count.
-     * 
+     *
      * @see #addURLs(Map)
      */
     public int getListCount() {
         return this.urls.size();
     }
-    
+
     /**
-     * Returns the number of URLs in a given map (specified by its position 
+     * Returns the number of URLs in a given map (specified by its position
      * in the map list).
-     * 
+     *
      * @param list  the list index (zero based).
-     * 
+     *
      * @return The URL count.
-     * 
+     *
      * @see #getListCount()
      */
     public int getURLCount(int list) {
@@ -123,12 +122,12 @@ public class CustomPieURLGenerator implements PieURLGenerator,
 
     /**
      * Returns the URL for a section in the specified map.
-     * 
+     *
      * @param key  the key.
      * @param mapIndex  the map index.
-     * 
+     *
      * @return The URL.
-     */    
+     */
     public String getURL(Comparable key, int mapIndex) {
         String result = null;
         if (mapIndex < getListCount()) {
@@ -142,32 +141,32 @@ public class CustomPieURLGenerator implements PieURLGenerator,
 
     /**
      * Adds a map containing <code>(key, URL)</code> mappings where each
-     * <code>key</code> is an instance of <code>Comparable</code> 
-     * (corresponding to the key for an item in a pie dataset) and each 
+     * <code>key</code> is an instance of <code>Comparable</code>
+     * (corresponding to the key for an item in a pie dataset) and each
      * <code>URL</code> is a <code>String</code> representing a URL fragment.
      * <br><br>
      * The map is appended to an internal list...you can add multiple maps
      * if you are working with, say, a {@link MultiplePiePlot}.
-     * 
+     *
      * @param urlMap  the URLs (<code>null</code> permitted).
      */
     public void addURLs(Map urlMap) {
         this.urls.add(urlMap);
     }
-    
+
     /**
      * Tests if this object is equal to another.
-     * 
+     *
      * @param o  the other object.
-     * 
+     *
      * @return A boolean.
      */
     public boolean equals(Object o) {
-    
+
         if (o == this) {
             return true;
         }
-        
+
         if (o instanceof CustomPieURLGenerator) {
             CustomPieURLGenerator generator = (CustomPieURLGenerator) o;
             if (getListCount() != generator.getListCount()) {
@@ -195,9 +194,9 @@ public class CustomPieURLGenerator implements PieURLGenerator,
 
     /**
      * Returns a clone of the generator.
-     * 
+     *
      * @return A clone.
-     * 
+     *
      * @throws CloneNotSupportedException if cloning is not supported.
      */
     public Object clone() throws CloneNotSupportedException {
