@@ -2,32 +2,32 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
- * This library is free software; you can redistribute it and/or modify it 
- * under the terms of the GNU Lesser General Public License as published by 
- * the Free Software Foundation; either version 2.1 of the License, or 
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
  * License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
- * USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+ * USA.
  *
- * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
+ * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
  * in the United States and other countries.]
  *
  * -----------------------
  * DefaultKeyedValues.java
  * -----------------------
- * (C) Copyright 2002-2007, by Object Refinery Limited.
+ * (C) Copyright 2002-2008, by Object Refinery Limited.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   Thomas Morgner;
@@ -42,19 +42,19 @@
  * 18-Aug-2003 : Implemented Cloneable (DG);
  * 27-Aug-2003 : Moved SortOrder from org.jfree.data --> org.jfree.util (DG);
  * 09-Feb-2004 : Modified getIndex() method - see bug report 893256 (DG);
- * 15-Sep-2004 : Updated clone() method and added PublicCloneable 
+ * 15-Sep-2004 : Updated clone() method and added PublicCloneable
  *               interface (DG);
  * 25-Nov-2004 : Small update to the clone() implementation (DG);
- * 24-Feb-2005 : Added methods addValue(Comparable, double) and 
+ * 24-Feb-2005 : Added methods addValue(Comparable, double) and
  *               setValue(Comparable, double) for convenience (DG);
  * ------------- JFREECHART 1.0.x ---------------------------------------------
  * 31-Jul-2006 : Added a clear() method (DG);
  * 01-Aug-2006 : Added argument check to getIndex() method (DG);
  * 30-Apr-2007 : Added insertValue() methods (DG);
- * 31-Oct-2007 : Performance improvements by using separate lists for keys and 
+ * 31-Oct-2007 : Performance improvements by using separate lists for keys and
  *               values (TM);
  * 21-Nov-2007 : Fixed bug in removeValue() method from previous patch (DG);
- *               
+ *
  */
 
 package org.jfree.data;
@@ -70,27 +70,26 @@ import org.jfree.util.PublicCloneable;
 import org.jfree.util.SortOrder;
 
 /**
- * An ordered list of (key, value) items.  This class provides a default 
+ * An ordered list of (key, value) items.  This class provides a default
  * implementation of the {@link KeyedValues} interface.
  */
-public class DefaultKeyedValues implements KeyedValues, 
-                                           Cloneable, PublicCloneable, 
-                                           Serializable {
+public class DefaultKeyedValues implements KeyedValues, Cloneable,
+        PublicCloneable, Serializable {
 
     /** For serialization. */
     private static final long serialVersionUID = 8468154364608194797L;
-    
+
     /** Storage for the keys. */
     private ArrayList keys;
-    
+
     /** Storage for the values. */
     private ArrayList values;
-    
-    /** 
+
+    /**
      * Contains (key, Integer) mappings, where the Integer is the index for
-     * the key in the list. 
+     * the key in the list.
      */
-    private HashMap indexMap; 
+    private HashMap indexMap;
 
   /**
      * Creates a new collection (initially empty).
@@ -116,7 +115,7 @@ public class DefaultKeyedValues implements KeyedValues,
      * @param item  the item of interest (zero-based index).
      *
      * @return The value (possibly <code>null</code>).
-     * 
+     *
      * @throws IndexOutOfBoundsException if <code>item</code> is out of bounds.
      */
     public Number getValue(int item) {
@@ -129,7 +128,7 @@ public class DefaultKeyedValues implements KeyedValues,
      * @param index  the item index (zero-based).
      *
      * @return The row key.
-     * 
+     *
      * @throws IndexOutOfBoundsException if <code>item</code> is out of bounds.
      */
     public Comparable getKey(int index) {
@@ -142,8 +141,8 @@ public class DefaultKeyedValues implements KeyedValues,
      * @param key  the key (<code>null</code> not permitted).
      *
      * @return The index, or <code>-1</code> if the key is not recognised.
-     * 
-     * @throws IllegalArgumentException if <code>key</code> is 
+     *
+     * @throws IllegalArgumentException if <code>key</code> is
      *     <code>null</code>.
      */
     public int getIndex(Comparable key) {
@@ -172,9 +171,9 @@ public class DefaultKeyedValues implements KeyedValues,
      * @param key  the key (<code>null</code> not permitted).
      *
      * @return The value (possibly <code>null</code>).
-     * 
+     *
      * @throws UnknownKeyException if the key is not recognised.
-     * 
+     *
      * @see #getValue(int)
      */
     public Number getValue(Comparable key) {
@@ -190,16 +189,16 @@ public class DefaultKeyedValues implements KeyedValues,
      *
      * @param key  the key (<code>null</code> not permitted).
      * @param value  the value.
-     * 
+     *
      * @see #addValue(Comparable, Number)
      */
     public void addValue(Comparable key, double value) {
-        addValue(key, new Double(value)); 
+        addValue(key, new Double(value));
     }
-    
+
     /**
      * Adds a new value to the collection, or updates an existing value.
-     * This method passes control directly to the 
+     * This method passes control directly to the
      * {@link #setValue(Comparable, Number)} method.
      *
      * @param key  the key (<code>null</code> not permitted).
@@ -216,9 +215,9 @@ public class DefaultKeyedValues implements KeyedValues,
      * @param value  the value.
      */
     public void setValue(Comparable key, double value) {
-        setValue(key, new Double(value));   
+        setValue(key, new Double(value));
     }
-    
+
     /**
      * Updates an existing value, or adds a new value to the collection.
      *
@@ -240,16 +239,16 @@ public class DefaultKeyedValues implements KeyedValues,
             this.indexMap.put(key, new Integer(this.keys.size() - 1));
         }
     }
-    
+
     /**
      * Inserts a new value at the specified position in the dataset or, if
-     * there is an existing item with the specified key, updates the value 
+     * there is an existing item with the specified key, updates the value
      * for that item and moves it to the specified position.
-     * 
+     *
      * @param position  the position (in the range 0 to getItemCount()).
      * @param key  the key (<code>null</code> not permitted).
      * @param value  the value.
-     * 
+     *
      * @since 1.0.6
      */
     public void insertValue(int position, Comparable key, double value) {
@@ -258,13 +257,13 @@ public class DefaultKeyedValues implements KeyedValues,
 
     /**
      * Inserts a new value at the specified position in the dataset or, if
-     * there is an existing item with the specified key, updates the value 
+     * there is an existing item with the specified key, updates the value
      * for that item and moves it to the specified position.
-     * 
+     *
      * @param position  the position (in the range 0 to getItemCount()).
      * @param key  the key (<code>null</code> not permitted).
      * @param value  the value (<code>null</code> permitted).
-     * 
+     *
      * @since 1.0.6
      */
     public void insertValue(int position, Comparable key, Number value) {
@@ -284,7 +283,7 @@ public class DefaultKeyedValues implements KeyedValues,
                 this.keys.remove(pos);
                 this.values.remove(pos);
             }
-          
+
             this.keys.add(position, key);
             this.values.add(position, value);
             rebuildIndex();
@@ -306,9 +305,9 @@ public class DefaultKeyedValues implements KeyedValues,
     /**
      * Removes a value from the collection.
      *
-     * @param index  the index of the item to remove (in the range 
+     * @param index  the index of the item to remove (in the range
      *     <code>0</code> to <code>getItemCount() - 1</code>).
-     *     
+     *
      * @throws IndexOutOfBoundsException if <code>index</code> is not within
      *     the specified range.
      */
@@ -322,23 +321,23 @@ public class DefaultKeyedValues implements KeyedValues,
      * Removes a value from the collection.
      *
      * @param key  the item key (<code>null</code> not permitted).
-     * 
-     * @throws IllegalArgumentException if <code>key</code> is 
+     *
+     * @throws IllegalArgumentException if <code>key</code> is
      *     <code>null</code>.
      * @throws UnknownKeyException if <code>key</code> is not recognised.
      */
     public void removeValue(Comparable key) {
         int index = getIndex(key);
         if (index < 0) {
-            throw new UnknownKeyException("The key (" + key 
+            throw new UnknownKeyException("The key (" + key
                     + ") is not recognised.");
         }
         removeValue(index);
     }
-    
+
     /**
      * Clears all values from the collection.
-     * 
+     *
      * @since 1.0.2
      */
     public void clear() {
@@ -357,7 +356,7 @@ public class DefaultKeyedValues implements KeyedValues,
         final DefaultKeyedValue[] data = new DefaultKeyedValue[size];
 
         for (int i = 0; i < size; i++) {
-            data[i] = new DefaultKeyedValue((Comparable) this.keys.get(i), 
+            data[i] = new DefaultKeyedValue((Comparable) this.keys.get(i),
                     (Number) this.values.get(i));
         }
 
@@ -373,8 +372,8 @@ public class DefaultKeyedValues implements KeyedValues,
     }
 
     /**
-     * Sorts the items in the list by value.  If the list contains 
-     * <code>null</code> values, they will sort to the end of the list, 
+     * Sorts the items in the list by value.  If the list contains
+     * <code>null</code> values, they will sort to the end of the list,
      * irrespective of the sort order.
      *
      * @param order  the sort order (<code>null</code> not permitted).
@@ -383,7 +382,7 @@ public class DefaultKeyedValues implements KeyedValues,
         final int size = this.keys.size();
         final DefaultKeyedValue[] data = new DefaultKeyedValue[size];
         for (int i = 0; i < size; i++) {
-            data[i] = new DefaultKeyedValue((Comparable) this.keys.get(i), 
+            data[i] = new DefaultKeyedValue((Comparable) this.keys.get(i),
                     (Number) this.values.get(i));
         }
 
@@ -444,7 +443,7 @@ public class DefaultKeyedValues implements KeyedValues,
 
     /**
      * Returns a hash code.
-     * 
+     *
      * @return A hash code.
      */
     public int hashCode() {
@@ -453,10 +452,10 @@ public class DefaultKeyedValues implements KeyedValues,
 
     /**
      * Returns a clone.
-     * 
+     *
      * @return A clone.
-     * 
-     * @throws CloneNotSupportedException  this class will not throw this 
+     *
+     * @throws CloneNotSupportedException  this class will not throw this
      *         exception, but subclasses might.
      */
     public Object clone() throws CloneNotSupportedException {
@@ -466,5 +465,5 @@ public class DefaultKeyedValues implements KeyedValues,
         clone.indexMap = (HashMap) this.indexMap.clone();
         return clone;
     }
-    
+
 }
