@@ -6,22 +6,22 @@
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
- * This library is free software; you can redistribute it and/or modify it 
- * under the terms of the GNU Lesser General Public License as published by 
- * the Free Software Foundation; either version 2.1 of the License, or 
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
  * License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
- * USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+ * USA.
  *
- * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
+ * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
  * in the United States and other countries.]
  *
  * -----------------------------------
@@ -38,8 +38,10 @@
  * 24-Oct-2002 : Amendments for changes made to the dataset interface (DG);
  * ------------- JFREECHART 1.0.x ---------------------------------------------
  * 08-Mar-2007 : Added equals() and clone() overrides (DG);
- * 25-Feb-2008 : Fix for the special case where the dataset is empty, see bug 
+ * 25-Feb-2008 : Fix for the special case where the dataset is empty, see bug
  *               1897580 (DG)
+ * 18-Dec-2008 : Use ResourceBundleWrapper - see patch 1607918 by
+ *               Jess Thrysoee (DG);
  *
  */
 
@@ -51,6 +53,7 @@ import java.util.Collections;
 import java.util.List;
 import java.util.ResourceBundle;
 
+import org.jfree.chart.util.ResourceBundleWrapper;
 import org.jfree.data.DataUtilities;
 import org.jfree.data.UnknownKeyException;
 import org.jfree.data.general.AbstractSeriesDataset;
@@ -96,7 +99,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * <p>
      * The arrays are indexed as data[series][category].  Series and category
      * names are automatically generated - you can change them using the
-     * {@link #setSeriesKeys(Comparable[])} and 
+     * {@link #setSeriesKeys(Comparable[])} and
      * {@link #setCategoryKeys(Comparable[])} methods.
      *
      * @param starts  the start values data.
@@ -133,7 +136,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      *
      * @param seriesKeys  the series keys (if <code>null</code>, series keys
      *         will be generated automatically).
-     * @param categoryKeys  the category keys (if <code>null</code>, category 
+     * @param categoryKeys  the category keys (if <code>null</code>, category
      *         keys will be generated automatically).
      * @param starts  the start values data, indexed as data[series][category].
      * @param ends  the end values data, indexed as data[series][category].
@@ -149,7 +152,8 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
         if (starts != null && ends != null) {
 
             String baseName = "org.jfree.data.resources.DataPackageResources";
-            ResourceBundle resources = ResourceBundle.getBundle(baseName);
+            ResourceBundle resources = ResourceBundleWrapper.getBundle(
+                    baseName);
 
             int seriesCount = starts.length;
             if (seriesCount != ends.length) {
@@ -214,7 +218,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * Returns the number of series in the dataset (possibly zero).
      *
      * @return The number of series in the dataset.
-     * 
+     *
      * @see #getRowCount()
      * @see #getCategoryCount()
      */
@@ -232,7 +236,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * @param seriesKey  the series key.
      *
      * @return The series index.
-     * 
+     *
      * @see #getRowIndex(Comparable)
      * @see #getSeriesKey(int)
      */
@@ -253,7 +257,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * @param series  the index of the required series (zero-based).
      *
      * @return The name of the specified series.
-     * 
+     *
      * @see #getSeriesIndex(Comparable)
      */
     public Comparable getSeriesKey(int series) {
@@ -266,10 +270,10 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
     /**
      * Sets the names of the series in the dataset.
      *
-     * @param seriesKeys  the new keys (<code>null</code> not permitted, the 
-     *         length of the array must match the number of series in the 
+     * @param seriesKeys  the new keys (<code>null</code> not permitted, the
+     *         length of the array must match the number of series in the
      *         dataset).
-     *         
+     *
      * @see #setCategoryKeys(Comparable[])
      */
     public void setSeriesKeys(Comparable[] seriesKeys) {
@@ -288,7 +292,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * Returns the number of categories in the dataset.
      *
      * @return The number of categories in the dataset.
-     * 
+     *
      * @see #getColumnCount()
      */
     public int getCategoryCount() {
@@ -300,13 +304,13 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
         }
         return result;
     }
-    
+
     /**
-     * Returns a list of the categories in the dataset.  This method supports 
+     * Returns a list of the categories in the dataset.  This method supports
      * the {@link CategoryDataset} interface.
      *
      * @return A list of the categories in the dataset.
-     * 
+     *
      * @see #getRowKeys()
      */
     public List getColumnKeys() {
@@ -324,9 +328,9 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
     /**
      * Sets the categories for the dataset.
      *
-     * @param categoryKeys  an array of objects representing the categories in 
+     * @param categoryKeys  an array of objects representing the categories in
      *                      the dataset.
-     *                      
+     *
      * @see #getRowKeys()
      * @see #setSeriesKeys(Comparable[])
      */
@@ -354,12 +358,12 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * <P>
      * This method is part of the CategoryDataset interface.  Not particularly
      * meaningful for this class...returns the end value.
-     * 
+     *
      * @param series    The required series (zero based index).
      * @param category  The required category.
-     * 
+     *
      * @return The data value for one category in a series (null possible).
-     * 
+     *
      * @see #getEndValue(Comparable, Comparable)
      */
     public Number getValue(Comparable series, Comparable category) {
@@ -384,7 +388,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * @param category  the required category.
      *
      * @return The data value for one category in a series (null possible).
-     * 
+     *
      * @see #getEndValue(int, int)
      */
     public Number getValue(int series, int category) {
@@ -397,9 +401,9 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * @param series  the required series.
      * @param category  the required category.
      *
-     * @return The start data value for one category in a series 
+     * @return The start data value for one category in a series
      *         (possibly <code>null</code>).
-     *         
+     *
      * @see #getStartValue(int, int)
      */
     public Number getStartValue(Comparable series, Comparable category) {
@@ -420,9 +424,9 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * @param series  the required series (zero based index).
      * @param category  the required category.
      *
-     * @return The start data value for one category in a series 
+     * @return The start data value for one category in a series
      *         (possibly <code>null</code>).
-     *         
+     *
      * @see #getStartValue(Comparable, Comparable)
      */
     public Number getStartValue(int series, int category) {
@@ -452,7 +456,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * @param category  the required category.
      *
      * @return The end data value for one category in a series (null possible).
-     * 
+     *
      * @see #getEndValue(int, int)
      */
     public Number getEndValue(Comparable series, Comparable category) {
@@ -474,7 +478,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * @param category  the required category.
      *
      * @return The end data value for one category in a series (null possible).
-     * 
+     *
      * @see #getEndValue(Comparable, Comparable)
      */
     public Number getEndValue(int series, int category) {
@@ -495,12 +499,12 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
 
     /**
      * Sets the start data value for one category in a series.
-     * 
+     *
      * @param series  the series (zero-based index).
      * @param category  the category.
-     * 
+     *
      * @param value The value.
-     * 
+     *
      * @see #setEndValue(int, Comparable, Number)
      */
     public void setStartValue(int series, Comparable category, Number value) {
@@ -533,7 +537,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * @param category  the category.
      *
      * @param value the value.
-     * 
+     *
      * @see #setStartValue(int, Comparable, Number)
      */
     public void setEndValue(int series, Comparable category, Number value) {
@@ -565,7 +569,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * @param category  the category (<code>null</code> not permitted).
      *
      * @return The index.
-     * 
+     *
      * @see #getColumnIndex(Comparable)
      */
     public int getCategoryIndex(Comparable category) {
@@ -604,7 +608,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * @param column  the column index.
      *
      * @return The column key.
-     * 
+     *
      * @see #getRowKey(int)
      */
     public Comparable getColumnKey(int column) {
@@ -617,7 +621,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * @param columnKey  the column key (<code>null</code> not permitted).
      *
      * @return The column index.
-     * 
+     *
      * @see #getCategoryIndex(Comparable)
      */
     public int getColumnIndex(Comparable columnKey) {
@@ -633,7 +637,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * @param rowKey  the row key.
      *
      * @return The row index.
-     * 
+     *
      * @see #getSeriesIndex(Comparable)
      */
     public int getRowIndex(Comparable rowKey) {
@@ -641,11 +645,11 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
     }
 
     /**
-     * Returns a list of the series in the dataset.  This method supports the 
+     * Returns a list of the series in the dataset.  This method supports the
      * {@link CategoryDataset} interface.
      *
      * @return A list of the series in the dataset.
-     * 
+     *
      * @see #getColumnKeys()
      */
     public List getRowKeys() {
@@ -665,7 +669,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * @param row  the index of the required row/series (zero-based).
      *
      * @return The name of the specified series.
-     * 
+     *
      * @see #getColumnKey(int)
      */
     public Comparable getRowKey(int row) {
@@ -677,11 +681,11 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
     }
 
     /**
-     * Returns the number of categories in the dataset.  This method is part of 
+     * Returns the number of categories in the dataset.  This method is part of
      * the {@link CategoryDataset} interface.
      *
      * @return The number of categories in the dataset.
-     * 
+     *
      * @see #getCategoryCount()
      * @see #getRowCount()
      */
@@ -693,19 +697,19 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * Returns the number of series in the dataset (possibly zero).
      *
      * @return The number of series in the dataset.
-     * 
+     *
      * @see #getSeriesCount()
      * @see #getColumnCount()
      */
     public int getRowCount() {
         return this.seriesKeys.length;
     }
-    
+
     /**
      * Tests this dataset for equality with an arbitrary object.
-     * 
+     *
      * @param obj  the object (<code>null</code> permitted).
-     * 
+     *
      * @return A boolean.
      */
     public boolean equals(Object obj) {
@@ -715,7 +719,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
         if (!(obj instanceof DefaultIntervalCategoryDataset)) {
             return false;
         }
-        DefaultIntervalCategoryDataset that 
+        DefaultIntervalCategoryDataset that
                 = (DefaultIntervalCategoryDataset) obj;
         if (!Arrays.equals(this.seriesKeys, that.seriesKeys)) {
             return false;
@@ -735,14 +739,14 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
 
     /**
      * Returns a clone of this dataset.
-     * 
+     *
      * @return A clone.
-     * 
+     *
      * @throws CloneNotSupportedException if there is a problem cloning the
      *         dataset.
      */
     public Object clone() throws CloneNotSupportedException {
-        DefaultIntervalCategoryDataset clone 
+        DefaultIntervalCategoryDataset clone
                 = (DefaultIntervalCategoryDataset) super.clone();
         clone.categoryKeys = (Comparable[]) this.categoryKeys.clone();
         clone.seriesKeys = (Comparable[]) this.seriesKeys.clone();
@@ -750,13 +754,13 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
         clone.endData = clone(this.endData);
         return clone;
     }
-    
+
     /**
      * Tests two double[][] arrays for equality.
-     * 
+     *
      * @param array1  the first array (<code>null</code> permitted).
      * @param array2  the second arrray (<code>null</code> permitted).
-     * 
+     *
      * @return A boolean.
      */
     private static boolean equal(Number[][] array1, Number[][] array2) {
@@ -776,12 +780,12 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
         }
         return true;
     }
-    
+
     /**
      * Clones a two dimensional array of <code>Number</code> objects.
-     * 
+     *
      * @param array  the array (<code>null</code> not permitted).
-     * 
+     *
      * @return A clone of the array.
      */
     private static Number[][] clone(Number[][] array) {
@@ -802,7 +806,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * Returns a list of the series in the dataset.
      *
      * @return A list of the series in the dataset.
-     * 
+     *
      * @deprecated Use {@link #getRowKeys()} instead.
      */
     public List getSeries() {
@@ -818,7 +822,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * Returns a list of the categories in the dataset.
      *
      * @return A list of the categories in the dataset.
-     * 
+     *
      * @deprecated Use {@link #getColumnKeys()} instead.
      */
     public List getCategories() {
@@ -829,7 +833,7 @@ public class DefaultIntervalCategoryDataset extends AbstractSeriesDataset
      * Returns the item count.
      *
      * @return The item count.
-     * 
+     *
      * @deprecated Use {@link #getCategoryCount()} instead.
      */
     public int getItemCount() {
