@@ -2,32 +2,32 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
- * This library is free software; you can redistribute it and/or modify it 
- * under the terms of the GNU Lesser General Public License as published by 
- * the Free Software Foundation; either version 2.1 of the License, or 
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
  * License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
- * USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+ * USA.
  *
- * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
+ * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
  * in the United States and other countries.]
  *
  * ---------------------------------
  * NormalDistributionFunction2D.java
  * ---------------------------------
- * (C)opyright 2004-2007, by Object Refinery Limited.
+ * (C)opyright 2004-2009, by Object Refinery Limited.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   -;
@@ -36,13 +36,16 @@
  * -------
  * 25-May-2004 : Version 1 (DG);
  * 21-Nov-2005 : Added getters for the mean and standard deviation (DG);
- * 
+ * 12-Feb-2009 : Precompute some constants from the function - see bug
+ *               2572016 (DG);
+ *
  */
 
 package org.jfree.data.function;
 
 /**
- * A normal distribution function.
+ * A normal distribution function.  See
+ * http://en.wikipedia.org/wiki/Normal_distribution.
  */
 public class NormalDistributionFunction2D implements Function2D {
 
@@ -52,20 +55,32 @@ public class NormalDistributionFunction2D implements Function2D {
     /** The standard deviation. */
     private double std;
 
+    /** Precomputed factor for the function value. */
+    private double factor;
+
+    /** Precomputed denominator for the function value. */
+    private double denominator;
+
     /**
      * Constructs a new normal distribution function.
      *
      * @param mean  the mean.
-     * @param std  the standard deviation.
+     * @param std  the standard deviation (> 0).
      */
     public NormalDistributionFunction2D(double mean, double std) {
+        if (std <= 0) {
+            throw new IllegalArgumentException("Requires 'std' > 0.");
+        }
         this.mean = mean;
         this.std = std;
+        // calculate constant values
+        this.factor = 1 / (std * Math.sqrt(2.0 * Math.PI));
+        this.denominator = 2 * std * std;
     }
-    
+
     /**
      * Returns the mean for the function.
-     * 
+     *
      * @return The mean.
      */
     public double getMean() {
@@ -74,7 +89,7 @@ public class NormalDistributionFunction2D implements Function2D {
     
     /**
      * Returns the standard deviation for the function.
-     * 
+     *
      * @return The standard deviation.
      */
     public double getStandardDeviation() {
@@ -89,9 +104,8 @@ public class NormalDistributionFunction2D implements Function2D {
      * @return The value.
      */
     public double getValue(double x) {
-        return Math.exp(-1.0 * (x - this.mean) * (x - this.mean) 
-                / (2 * this.std * this.std)) / Math.sqrt(2 * Math.PI 
-                * this.std * this.std);
+        double z = x - this.mean;
+        return this.factor * Math.exp(-z * z / this.denominator);
     }
 
 }
