@@ -2,38 +2,36 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2006, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
- * This library is free software; you can redistribute it and/or modify it 
- * under the terms of the GNU Lesser General Public License as published by 
- * the Free Software Foundation; either version 2.1 of the License, or 
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
  * License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
- * USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+ * USA.
  *
- * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
+ * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
  * in the United States and other countries.]
  *
  * ---------
  * Week.java
  * ---------
- * (C) Copyright 2001-2004, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2001-2008, by Object Refinery Limited and Contributors.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   Aimin Han;
  *
- * $Id: Week.java,v 1.7.2.2 2006/04/06 13:23:57 mungady Exp $
- *
  * Changes
  * -------
  * 11-Oct-2001 : Version 1 (DG);
@@ -41,27 +39,34 @@
  * 19-Dec-2001 : Added a new constructor as suggested by Paul English (DG);
  * 29-Jan-2002 : Worked on the parseWeek() method (DG);
  * 13-Feb-2002 : Fixed bug in Week(Date) constructor (DG);
- * 26-Feb-2002 : Changed getStart(), getMiddle() and getEnd() methods to 
+ * 26-Feb-2002 : Changed getStart(), getMiddle() and getEnd() methods to
  *               evaluate with reference to a particular time zone (DG);
  * 05-Apr-2002 : Reinstated this class to the JCommon library (DG);
  * 24-Jun-2002 : Removed unnecessary main method (DG);
  * 10-Sep-2002 : Added getSerialIndex() method (DG);
  * 06-Oct-2002 : Fixed errors reported by Checkstyle (DG);
- * 18-Oct-2002 : Changed to observe 52 or 53 weeks per year, consistent with 
+ * 18-Oct-2002 : Changed to observe 52 or 53 weeks per year, consistent with
  *               GregorianCalendar. Thanks to Aimin Han for the code (DG);
  * 02-Jan-2003 : Removed debug code (DG);
- * 13-Mar-2003 : Moved to com.jrefinery.data.time package, and implemented 
+ * 13-Mar-2003 : Moved to com.jrefinery.data.time package, and implemented
  *               Serializable (DG);
  * 21-Oct-2003 : Added hashCode() method (DG);
- * 24-May-2004 : Modified getFirstMillisecond() and getLastMillisecond() to 
- *               take account of firstDayOfWeek setting in Java's Calendar 
+ * 24-May-2004 : Modified getFirstMillisecond() and getLastMillisecond() to
+ *               take account of firstDayOfWeek setting in Java's Calendar
  *               class (DG);
  * 30-Sep-2004 : Replaced getTime().getTime() with getTimeInMillis() (DG);
- * 04-Nov-2004 : Reverted change of 30-Sep-2004, because it won't work for 
+ * 04-Nov-2004 : Reverted change of 30-Sep-2004, because it won't work for
  *               JDK 1.3 (DG);
- * ------------- JFREECHART 1.0.0 ---------------------------------------------
+ * ------------- JFREECHART 1.0.x ---------------------------------------------
  * 06-Mar-2006 : Fix for bug 1448828, incorrect calculation of week and year
  *               for the first few days of some years (DG);
+ * 05-Oct-2006 : Updated API docs (DG);
+ * 06-Oct-2006 : Refactored to cache first and last millisecond values (DG);
+ * 09-Jan-2007 : Fixed bug in next() (DG);
+ * 28-Aug-2007 : Added new constructor to avoid problem in creating new
+ *               instances (DG);
+ * 19-Dec-2007 : Fixed bug in deprecated constructor (DG);
+ * 16-Sep-2008 : Deprecated DEFAULT_TIME_ZONE (DG);
  *
  */
 
@@ -70,23 +75,24 @@ package org.jfree.data.time;
 import java.io.Serializable;
 import java.util.Calendar;
 import java.util.Date;
+import java.util.Locale;
 import java.util.TimeZone;
 
 /**
- * A calendar week.  All years are considered to have 53 weeks, numbered from 1 
+ * A calendar week.  All years are considered to have 53 weeks, numbered from 1
  * to 53, although in many cases the 53rd week is empty.  Most of the time, the
- * 1st week of the year *begins* in the previous calendar year, but it always 
- * finishes in the current year (this behaviour matches the workings of the 
+ * 1st week of the year *begins* in the previous calendar year, but it always
+ * finishes in the current year (this behaviour matches the workings of the
  * <code>GregorianCalendar</code> class).
  * <P>
- * This class is immutable, which is a requirement for all 
+ * This class is immutable, which is a requirement for all
  * {@link RegularTimePeriod} subclasses.
  */
 public class Week extends RegularTimePeriod implements Serializable {
 
     /** For serialization. */
     private static final long serialVersionUID = 1856387786939865061L;
-    
+
     /** Constant for the first week in the year. */
     public static final int FIRST_WEEK_IN_YEAR = 1;
 
@@ -94,13 +100,19 @@ public class Week extends RegularTimePeriod implements Serializable {
     public static final int LAST_WEEK_IN_YEAR = 53;
 
     /** The year in which the week falls. */
-    private Year year;
+    private short year;
 
     /** The week (1-53). */
-    private int week;
+    private byte week;
+
+    /** The first millisecond. */
+    private long firstMillisecond;
+
+    /** The last millisecond. */
+    private long lastMillisecond;
 
     /**
-     * Creates a new time period for the week in which the current system 
+     * Creates a new time period for the week in which the current system
      * date/time falls.
      */
     public Week() {
@@ -114,7 +126,13 @@ public class Week extends RegularTimePeriod implements Serializable {
      * @param year  the year (1900 to 9999).
      */
     public Week(int week, int year) {
-        this(week, new Year(year));
+        if ((week < FIRST_WEEK_IN_YEAR) && (week > LAST_WEEK_IN_YEAR)) {
+            throw new IllegalArgumentException(
+                    "The 'week' argument must be in the range 1 - 53.");
+        }
+        this.week = (byte) week;
+        this.year = (short) year;
+        peg(Calendar.getInstance());
     }
 
     /**
@@ -126,62 +144,86 @@ public class Week extends RegularTimePeriod implements Serializable {
     public Week(int week, Year year) {
         if ((week < FIRST_WEEK_IN_YEAR) && (week > LAST_WEEK_IN_YEAR)) {
             throw new IllegalArgumentException(
-                "The 'week' argument must be in the range 1 - 53."
-            );
+                    "The 'week' argument must be in the range 1 - 53.");
         }
-        this.week = week;
-        this.year = year;
-    }
+        this.week = (byte) week;
+        this.year = (short) year.getYear();
+        peg(Calendar.getInstance());
+   }
 
     /**
-     * Creates a time period for the week in which the specified date/time 
-     * falls.
+     * Creates a time period for the week in which the specified date/time
+     * falls, using the default time zone and locale (the locale can affect the
+     * day-of-the-week that marks the beginning of the week, as well as the
+     * minimal number of days in the first week of the year).
      *
      * @param time  the time (<code>null</code> not permitted).
+     *
+     * @see #Week(Date, TimeZone, Locale)
      */
     public Week(Date time) {
         // defer argument checking...
-        this(time, RegularTimePeriod.DEFAULT_TIME_ZONE);
+        this(time, TimeZone.getDefault(), Locale.getDefault());
     }
 
     /**
-     * Creates a time period for the week in which the specified date/time 
+     * Creates a time period for the week in which the specified date/time
      * falls, calculated relative to the specified time zone.
      *
      * @param time  the date/time (<code>null</code> not permitted).
      * @param zone  the time zone (<code>null</code> not permitted).
+     *
+     * @deprecated As of 1.0.7, use {@link #Week(Date, TimeZone, Locale)}.
      */
     public Week(Date time, TimeZone zone) {
+        // defer argument checking...
+        this(time, zone, Locale.getDefault());
+    }
+
+    /**
+     * Creates a time period for the week in which the specified date/time
+     * falls, calculated relative to the specified time zone.
+     *
+     * @param time  the date/time (<code>null</code> not permitted).
+     * @param zone  the time zone (<code>null</code> not permitted).
+     * @param locale  the locale (<code>null</code> not permitted).
+     *
+     * @since 1.0.7
+     */
+    public Week(Date time, TimeZone zone, Locale locale) {
         if (time == null) {
-            throw new IllegalArgumentException("Null 'time' argument.");   
+            throw new IllegalArgumentException("Null 'time' argument.");
         }
         if (zone == null) {
-            throw new IllegalArgumentException("Null 'zone' argument.");   
+            throw new IllegalArgumentException("Null 'zone' argument.");
         }
-        Calendar calendar = Calendar.getInstance(zone);
+        if (locale == null) {
+            throw new IllegalArgumentException("Null 'locale' argument.");
+        }
+        Calendar calendar = Calendar.getInstance(zone, locale);
         calendar.setTime(time);
 
-        // sometimes the last few days of the year are considered to fall in 
-        // the *first* week of the following year.  Refer to the Javadocs for 
+        // sometimes the last few days of the year are considered to fall in
+        // the *first* week of the following year.  Refer to the Javadocs for
         // GregorianCalendar.
         int tempWeek = calendar.get(Calendar.WEEK_OF_YEAR);
-        if (tempWeek == 1 
+        if (tempWeek == 1
                 && calendar.get(Calendar.MONTH) == Calendar.DECEMBER) {
             this.week = 1;
-            this.year =  new Year(calendar.get(Calendar.YEAR) + 1);
+            this.year = (short) (calendar.get(Calendar.YEAR) + 1);
         }
         else {
-            this.week = Math.min(tempWeek, LAST_WEEK_IN_YEAR);
+            this.week = (byte) Math.min(tempWeek, LAST_WEEK_IN_YEAR);
             int yyyy = calendar.get(Calendar.YEAR);
             // alternatively, sometimes the first few days of the year are
             // considered to fall in the *last* week of the previous year...
-            if (calendar.get(Calendar.MONTH) == Calendar.JANUARY 
+            if (calendar.get(Calendar.MONTH) == Calendar.JANUARY
                     && this.week >= 52) {
-                yyyy--; 
+                yyyy--;
             }
-            this.year = new Year(yyyy);
+            this.year = (short) yyyy;
         }
-
+        peg(calendar);
     }
 
     /**
@@ -190,7 +232,7 @@ public class Week extends RegularTimePeriod implements Serializable {
      * @return The year (never <code>null</code>).
      */
     public Year getYear() {
-        return this.year;
+        return new Year(this.year);
     }
 
     /**
@@ -199,7 +241,7 @@ public class Week extends RegularTimePeriod implements Serializable {
      * @return The year.
      */
     public int getYearValue() {
-        return this.year.getYear();
+        return this.year;
     }
 
     /**
@@ -212,9 +254,50 @@ public class Week extends RegularTimePeriod implements Serializable {
     }
 
     /**
-     * Returns the week preceding this one.  This method will return 
-     * <code>null</code> for some lower limit on the range of weeks (currently 
-     * week 1, 1900).  For week 1 of any year, the previous week is always week 
+     * Returns the first millisecond of the week.  This will be determined
+     * relative to the time zone specified in the constructor, or in the
+     * calendar instance passed in the most recent call to the
+     * {@link #peg(Calendar)} method.
+     *
+     * @return The first millisecond of the week.
+     *
+     * @see #getLastMillisecond()
+     */
+    public long getFirstMillisecond() {
+        return this.firstMillisecond;
+    }
+
+    /**
+     * Returns the last millisecond of the week.  This will be
+     * determined relative to the time zone specified in the constructor, or
+     * in the calendar instance passed in the most recent call to the
+     * {@link #peg(Calendar)} method.
+     *
+     * @return The last millisecond of the week.
+     *
+     * @see #getFirstMillisecond()
+     */
+    public long getLastMillisecond() {
+        return this.lastMillisecond;
+    }
+
+    /**
+     * Recalculates the start date/time and end date/time for this time period
+     * relative to the supplied calendar (which incorporates a time zone).
+     *
+     * @param calendar  the calendar (<code>null</code> not permitted).
+     *
+     * @since 1.0.3
+     */
+    public void peg(Calendar calendar) {
+        this.firstMillisecond = getFirstMillisecond(calendar);
+        this.lastMillisecond = getLastMillisecond(calendar);
+    }
+
+    /**
+     * Returns the week preceding this one.  This method will return
+     * <code>null</code> for some lower limit on the range of weeks (currently
+     * week 1, 1900).  For week 1 of any year, the previous week is always week
      * 53, but week 53 may not contain any days (you should check for this).
      *
      * @return The preceding week (possibly <code>null</code>).
@@ -227,15 +310,12 @@ public class Week extends RegularTimePeriod implements Serializable {
         }
         else {
             // we need to work out if the previous year has 52 or 53 weeks...
-            Year prevYear = (Year) this.year.previous();
-            if (prevYear != null) {
-                int yy = prevYear.getYear();
+            if (this.year > 1900) {
+                int yy = this.year - 1;
                 Calendar prevYearCalendar = Calendar.getInstance();
                 prevYearCalendar.set(yy, Calendar.DECEMBER, 31);
-                result = new Week(
-                    prevYearCalendar.getActualMaximum(Calendar.WEEK_OF_YEAR), 
-                    prevYear
-                );
+                result = new Week(prevYearCalendar.getActualMaximum(
+                        Calendar.WEEK_OF_YEAR), yy);
             }
             else {
                 result = null;
@@ -246,10 +326,10 @@ public class Week extends RegularTimePeriod implements Serializable {
     }
 
     /**
-     * Returns the week following this one.  This method will return 
-     * <code>null</code> for some upper limit on the range of weeks (currently 
-     * week 53, 9999).  For week 52 of any year, the following week is always 
-     * week 53, but week 53 may not contain any days (you should check for 
+     * Returns the week following this one.  This method will return
+     * <code>null</code> for some upper limit on the range of weeks (currently
+     * week 53, 9999).  For week 52 of any year, the following week is always
+     * week 53, but week 53 may not contain any days (you should check for
      * this).
      *
      * @return The following week (possibly <code>null</code>).
@@ -262,16 +342,15 @@ public class Week extends RegularTimePeriod implements Serializable {
         }
         else {
             Calendar calendar = Calendar.getInstance();
-            calendar.set(this.year.getYear(), Calendar.DECEMBER, 31);
-            int actualMaxWeek 
+            calendar.set(this.year, Calendar.DECEMBER, 31);
+            int actualMaxWeek
                 = calendar.getActualMaximum(Calendar.WEEK_OF_YEAR);
-            if (this.week != actualMaxWeek) {
+            if (this.week < actualMaxWeek) {
                 result = new Week(this.week + 1, this.year);
             }
             else {
-                Year nextYear = (Year) this.year.next();
-                if (nextYear != null) {
-                    result = new Week(FIRST_WEEK_IN_YEAR, nextYear);
+                if (this.year < 9999) {
+                    result = new Week(FIRST_WEEK_IN_YEAR, this.year + 1);
                 }
                 else {
                     result = null;
@@ -288,21 +367,24 @@ public class Week extends RegularTimePeriod implements Serializable {
      * @return The serial index number.
      */
     public long getSerialIndex() {
-        return this.year.getYear() * 53L + this.week;
+        return this.year * 53L + this.week;
     }
 
     /**
      * Returns the first millisecond of the week, evaluated using the supplied
      * calendar (which determines the time zone).
      *
-     * @param calendar  the calendar.
+     * @param calendar  the calendar (<code>null</code> not permitted).
      *
      * @return The first millisecond of the week.
+     *
+     * @throws NullPointerException if <code>calendar</code> is
+     *     <code>null</code>.
      */
     public long getFirstMillisecond(Calendar calendar) {
         Calendar c = (Calendar) calendar.clone();
         c.clear();
-        c.set(Calendar.YEAR, this.year.getYear());
+        c.set(Calendar.YEAR, this.year);
         c.set(Calendar.WEEK_OF_YEAR, this.week);
         c.set(Calendar.DAY_OF_WEEK, c.getFirstDayOfWeek());
         c.set(Calendar.HOUR, 0);
@@ -317,13 +399,25 @@ public class Week extends RegularTimePeriod implements Serializable {
      * Returns the last millisecond of the week, evaluated using the supplied
      * calendar (which determines the time zone).
      *
-     * @param calendar  the calendar.
+     * @param calendar  the calendar (<code>null</code> not permitted).
      *
      * @return The last millisecond of the week.
+     *
+     * @throws NullPointerException if <code>calendar</code> is
+     *     <code>null</code>.
      */
     public long getLastMillisecond(Calendar calendar) {
-        RegularTimePeriod next = next();
-        return next.getFirstMillisecond(calendar) - 1;
+        Calendar c = (Calendar) calendar.clone();
+        c.clear();
+        c.set(Calendar.YEAR, this.year);
+        c.set(Calendar.WEEK_OF_YEAR, this.week + 1);
+        c.set(Calendar.DAY_OF_WEEK, c.getFirstDayOfWeek());
+        c.set(Calendar.HOUR, 0);
+        c.set(Calendar.MINUTE, 0);
+        c.set(Calendar.SECOND, 0);
+        c.set(Calendar.MILLISECOND, 0);
+        //return c.getTimeInMillis();  // this won't work for JDK 1.3
+        return c.getTime().getTime() - 1;
     }
 
     /**
@@ -341,9 +435,10 @@ public class Week extends RegularTimePeriod implements Serializable {
      * Tests the equality of this Week object to an arbitrary object.  Returns
      * true if the target is a Week instance representing the same week as this
      * object.  In all other cases, returns false.
-     * @param obj The object.
      *
-     * @return <code>true</code> if week and year of this and object are the 
+     * @param obj  the object (<code>null</code> permitted).
+     *
+     * @return <code>true</code> if week and year of this and object are the
      *         same.
      */
     public boolean equals(Object obj) {
@@ -358,7 +453,7 @@ public class Week extends RegularTimePeriod implements Serializable {
         if (this.week != that.week) {
             return false;
         }
-        if (!this.year.equals(that.year)) {
+        if (this.year != that.year) {
             return false;
         }
         return true;
@@ -371,13 +466,13 @@ public class Week extends RegularTimePeriod implements Serializable {
      * <p>
      * <code>http://developer.java.sun.com/developer/Books/effectivejava
      * /Chapter3.pdf</code>
-     * 
+     *
      * @return A hash code.
      */
     public int hashCode() {
         int result = 17;
         result = 37 * result + this.week;
-        result = 37 * result + this.year.hashCode();
+        result = 37 * result + this.year;
         return result;
     }
 
@@ -399,7 +494,7 @@ public class Week extends RegularTimePeriod implements Serializable {
         // --------------------------------------------
         if (o1 instanceof Week) {
             Week w = (Week) o1;
-            result = this.year.getYear() - w.getYear().getYear();
+            result = this.year - w.getYear().getYear();
             if (result == 0) {
                 result = this.week - w.getWeek();
             }
@@ -431,7 +526,7 @@ public class Week extends RegularTimePeriod implements Serializable {
      *
      * @param s  string to parse.
      *
-     * @return <code>null</code> if the string is not parseable, the week 
+     * @return <code>null</code> if the string is not parseable, the week
      *         otherwise.
      */
     public static Week parseWeek(String s) {
@@ -453,8 +548,7 @@ public class Week extends RegularTimePeriod implements Serializable {
                     w = Week.stringToWeek(s2);
                     if (w == -1) {
                         throw new TimePeriodFormatException(
-                            "Can't evaluate the week."
-                        );
+                                "Can't evaluate the week.");
                     }
                     result = new Week(w, y);
                 }
@@ -464,23 +558,20 @@ public class Week extends RegularTimePeriod implements Serializable {
                         w = Week.stringToWeek(s1);
                         if (w == -1) {
                             throw new TimePeriodFormatException(
-                                "Can't evaluate the week."
-                            );
+                                    "Can't evaluate the week.");
                         }
                         result = new Week(w, y);
                     }
                     else {
                         throw new TimePeriodFormatException(
-                            "Can't evaluate the year."
-                        );
+                                "Can't evaluate the year.");
                     }
                 }
 
             }
             else {
                 throw new TimePeriodFormatException(
-                    "Could not find separator."
-                );
+                        "Could not find separator.");
             }
 
         }
@@ -517,7 +608,7 @@ public class Week extends RegularTimePeriod implements Serializable {
      *
      * @param s  string to parse.
      *
-     * @return <code>null</code> if the string is not parseable, the year 
+     * @return <code>null</code> if the string is not parseable, the year
      *         otherwise.
      */
     private static Year evaluateAsYear(String s) {
@@ -557,5 +648,5 @@ public class Week extends RegularTimePeriod implements Serializable {
         return result;
 
     }
-    
+
 }
