@@ -2,32 +2,32 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
- * This library is free software; you can redistribute it and/or modify it 
- * under the terms of the GNU Lesser General Public License as published by 
- * the Free Software Foundation; either version 2.1 of the License, or 
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
  * License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
- * USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+ * USA.
  *
- * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
+ * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
  * in the United States and other countries.]
  *
  * -----------------------------
  * DefaultIntervalXYDataset.java
  * -----------------------------
- * (C) Copyright 2006, 2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2006-2008, by Object Refinery Limited and Contributors.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   -;
@@ -38,6 +38,7 @@
  * 02-Nov-2006 : Fixed a problem with adding a new series with the same key
  *               as an existing series (see bug 1589392) (DG);
  * 28-Nov-2006 : New override for clone() (DG);
+ * 22-Apr-2008 : Implemented PublicCloneable (DG);
  *
  */
 
@@ -48,6 +49,7 @@ import java.util.Arrays;
 import java.util.List;
 
 import org.jfree.data.general.DatasetChangeEvent;
+import org.jfree.util.PublicCloneable;
 
 /**
  * A dataset that defines a range (interval) for both the x-values and the
@@ -56,31 +58,32 @@ import org.jfree.data.general.DatasetChangeEvent;
  * <br><br>
  * An alternative implementation of the {@link IntervalXYDataset} interface
  * is provided by the {@link XYIntervalSeriesCollection} class.
- * 
+ *
  * @since 1.0.3
  */
-public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
+public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset
+        implements PublicCloneable {
 
     /**
      * Storage for the series keys.  This list must be kept in sync with the
      * seriesList.
      */
     private List seriesKeys;
-    
-    /** 
-     * Storage for the series in the dataset.  We use a list because the
-     * order of the series is significant.  This list must be kept in sync 
-     * with the seriesKeys list.
-     */ 
-    private List seriesList;
-    
+
     /**
-     * Creates a new <code>DefaultIntervalXYDataset</code> instance, initially 
+     * Storage for the series in the dataset.  We use a list because the
+     * order of the series is significant.  This list must be kept in sync
+     * with the seriesKeys list.
+     */
+    private List seriesList;
+
+    /**
+     * Creates a new <code>DefaultIntervalXYDataset</code> instance, initially
      * containing no data.
      */
     public DefaultIntervalXYDataset() {
         this.seriesKeys = new java.util.ArrayList();
-        this.seriesList = new java.util.ArrayList();    
+        this.seriesList = new java.util.ArrayList();
     }
 
     /**
@@ -93,14 +96,14 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
     }
 
     /**
-     * Returns the key for a series.  
+     * Returns the key for a series.
      *
-     * @param series  the series index (in the range <code>0</code> to 
+     * @param series  the series index (in the range <code>0</code> to
      *     <code>getSeriesCount() - 1</code>).
      *
      * @return The key for the series.
-     * 
-     * @throws IllegalArgumentException if <code>series</code> is not in the 
+     *
+     * @throws IllegalArgumentException if <code>series</code> is not in the
      *     specified range.
      */
     public Comparable getSeriesKey(int series) {
@@ -112,13 +115,13 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
 
     /**
      * Returns the number of items in the specified series.
-     * 
-     * @param series  the series index (in the range <code>0</code> to 
+     *
+     * @param series  the series index (in the range <code>0</code> to
      *     <code>getSeriesCount() - 1</code>).
-     * 
+     *
      * @return The item count.
-     * 
-     * @throws IllegalArgumentException if <code>series</code> is not in the 
+     *
+     * @throws IllegalArgumentException if <code>series</code> is not in the
      *     specified range.
      */
     public int getItemCount(int series) {
@@ -131,19 +134,19 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
 
     /**
      * Returns the x-value for an item within a series.
-     * 
-     * @param series  the series index (in the range <code>0</code> to 
+     *
+     * @param series  the series index (in the range <code>0</code> to
      *     <code>getSeriesCount() - 1</code>).
-     * @param item  the item index (in the range <code>0</code> to 
+     * @param item  the item index (in the range <code>0</code> to
      *     <code>getItemCount(series)</code>).
-     *     
+     *
      * @return The x-value.
-     * 
-     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not 
+     *
+     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not
      *     within the specified range.
-     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not 
+     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not
      *     within the specified range.
-     * 
+     *
      * @see #getX(int, int)
      */
     public double getXValue(int series, int item) {
@@ -153,19 +156,19 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
 
     /**
      * Returns the y-value for an item within a series.
-     * 
-     * @param series  the series index (in the range <code>0</code> to 
+     *
+     * @param series  the series index (in the range <code>0</code> to
      *     <code>getSeriesCount() - 1</code>).
-     * @param item  the item index (in the range <code>0</code> to 
+     * @param item  the item index (in the range <code>0</code> to
      *     <code>getItemCount(series)</code>).
-     *     
+     *
      * @return The y-value.
-     * 
-     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not 
+     *
+     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not
      *     within the specified range.
-     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not 
+     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not
      *     within the specified range.
-     * 
+     *
      * @see #getY(int, int)
      */
     public double getYValue(int series, int item) {
@@ -175,19 +178,19 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
 
     /**
      * Returns the starting x-value for an item within a series.
-     * 
-     * @param series  the series index (in the range <code>0</code> to 
+     *
+     * @param series  the series index (in the range <code>0</code> to
      *     <code>getSeriesCount() - 1</code>).
-     * @param item  the item index (in the range <code>0</code> to 
+     * @param item  the item index (in the range <code>0</code> to
      *     <code>getItemCount(series)</code>).
-     *     
+     *
      * @return The starting x-value.
-     * 
-     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not 
+     *
+     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not
      *     within the specified range.
-     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not 
+     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not
      *     within the specified range.
-     * 
+     *
      * @see #getStartX(int, int)
      */
     public double getStartXValue(int series, int item) {
@@ -197,19 +200,19 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
 
     /**
      * Returns the ending x-value for an item within a series.
-     * 
-     * @param series  the series index (in the range <code>0</code> to 
+     *
+     * @param series  the series index (in the range <code>0</code> to
      *     <code>getSeriesCount() - 1</code>).
-     * @param item  the item index (in the range <code>0</code> to 
+     * @param item  the item index (in the range <code>0</code> to
      *     <code>getItemCount(series)</code>).
-     *     
+     *
      * @return The ending x-value.
-     * 
-     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not 
+     *
+     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not
      *     within the specified range.
-     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not 
+     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not
      *     within the specified range.
-     * 
+     *
      * @see #getEndX(int, int)
      */
     public double getEndXValue(int series, int item) {
@@ -219,19 +222,19 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
 
     /**
      * Returns the starting y-value for an item within a series.
-     * 
-     * @param series  the series index (in the range <code>0</code> to 
+     *
+     * @param series  the series index (in the range <code>0</code> to
      *     <code>getSeriesCount() - 1</code>).
-     * @param item  the item index (in the range <code>0</code> to 
+     * @param item  the item index (in the range <code>0</code> to
      *     <code>getItemCount(series)</code>).
-     *     
+     *
      * @return The starting y-value.
-     * 
-     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not 
+     *
+     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not
      *     within the specified range.
-     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not 
+     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not
      *     within the specified range.
-     * 
+     *
      * @see #getStartY(int, int)
      */
     public double getStartYValue(int series, int item) {
@@ -241,19 +244,19 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
 
     /**
      * Returns the ending y-value for an item within a series.
-     * 
-     * @param series  the series index (in the range <code>0</code> to 
+     *
+     * @param series  the series index (in the range <code>0</code> to
      *     <code>getSeriesCount() - 1</code>).
-     * @param item  the item index (in the range <code>0</code> to 
+     * @param item  the item index (in the range <code>0</code> to
      *     <code>getItemCount(series)</code>).
-     *     
+     *
      * @return The ending y-value.
-     * 
-     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not 
+     *
+     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not
      *     within the specified range.
-     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not 
+     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not
      *     within the specified range.
-     * 
+     *
      * @see #getEndY(int, int)
      */
     public double getEndYValue(int series, int item) {
@@ -263,19 +266,19 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
 
     /**
      * Returns the ending x-value for an item within a series.
-     * 
-     * @param series  the series index (in the range <code>0</code> to 
+     *
+     * @param series  the series index (in the range <code>0</code> to
      *     <code>getSeriesCount() - 1</code>).
-     * @param item  the item index (in the range <code>0</code> to 
+     * @param item  the item index (in the range <code>0</code> to
      *     <code>getItemCount(series)</code>).
-     *     
+     *
      * @return The ending x-value.
-     * 
-     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not 
+     *
+     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not
      *     within the specified range.
-     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not 
+     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not
      *     within the specified range.
-     * 
+     *
      * @see #getEndXValue(int, int)
      */
     public Number getEndX(int series, int item) {
@@ -284,19 +287,19 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
 
     /**
      * Returns the ending y-value for an item within a series.
-     * 
-     * @param series  the series index (in the range <code>0</code> to 
+     *
+     * @param series  the series index (in the range <code>0</code> to
      *     <code>getSeriesCount() - 1</code>).
-     * @param item  the item index (in the range <code>0</code> to 
+     * @param item  the item index (in the range <code>0</code> to
      *     <code>getItemCount(series)</code>).
-     *     
+     *
      * @return The ending y-value.
-     * 
-     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not 
+     *
+     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not
      *     within the specified range.
-     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not 
+     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not
      *     within the specified range.
-     * 
+     *
      * @see #getEndYValue(int, int)
      */
     public Number getEndY(int series, int item) {
@@ -305,19 +308,19 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
 
     /**
      * Returns the starting x-value for an item within a series.
-     * 
-     * @param series  the series index (in the range <code>0</code> to 
+     *
+     * @param series  the series index (in the range <code>0</code> to
      *     <code>getSeriesCount() - 1</code>).
-     * @param item  the item index (in the range <code>0</code> to 
+     * @param item  the item index (in the range <code>0</code> to
      *     <code>getItemCount(series)</code>).
-     *     
+     *
      * @return The starting x-value.
-     * 
-     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not 
+     *
+     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not
      *     within the specified range.
-     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not 
+     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not
      *     within the specified range.
-     * 
+     *
      * @see #getStartXValue(int, int)
      */
     public Number getStartX(int series, int item) {
@@ -326,19 +329,19 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
 
     /**
      * Returns the starting y-value for an item within a series.
-     * 
-     * @param series  the series index (in the range <code>0</code> to 
+     *
+     * @param series  the series index (in the range <code>0</code> to
      *     <code>getSeriesCount() - 1</code>).
-     * @param item  the item index (in the range <code>0</code> to 
+     * @param item  the item index (in the range <code>0</code> to
      *     <code>getItemCount(series)</code>).
-     *     
+     *
      * @return The starting y-value.
-     * 
-     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not 
+     *
+     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not
      *     within the specified range.
-     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not 
+     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not
      *     within the specified range.
-     * 
+     *
      * @see #getStartYValue(int, int)
      */
     public Number getStartY(int series, int item) {
@@ -347,19 +350,19 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
 
     /**
      * Returns the x-value for an item within a series.
-     * 
-     * @param series  the series index (in the range <code>0</code> to 
+     *
+     * @param series  the series index (in the range <code>0</code> to
      *     <code>getSeriesCount() - 1</code>).
-     * @param item  the item index (in the range <code>0</code> to 
+     * @param item  the item index (in the range <code>0</code> to
      *     <code>getItemCount(series)</code>).
-     *     
+     *
      * @return The x-value.
-     * 
-     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not 
+     *
+     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not
      *     within the specified range.
-     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not 
+     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not
      *     within the specified range.
-     * 
+     *
      * @see #getXValue(int, int)
      */
     public Number getX(int series, int item) {
@@ -368,34 +371,34 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
 
     /**
      * Returns the y-value for an item within a series.
-     * 
-     * @param series  the series index (in the range <code>0</code> to 
+     *
+     * @param series  the series index (in the range <code>0</code> to
      *     <code>getSeriesCount() - 1</code>).
-     * @param item  the item index (in the range <code>0</code> to 
+     * @param item  the item index (in the range <code>0</code> to
      *     <code>getItemCount(series)</code>).
-     *     
+     *
      * @return The y-value.
-     * 
-     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not 
+     *
+     * @throws ArrayIndexOutOfBoundsException if <code>series</code> is not
      *     within the specified range.
-     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not 
+     * @throws ArrayIndexOutOfBoundsException if <code>item</code> is not
      *     within the specified range.
-     * 
+     *
      * @see #getYValue(int, int)
      */
     public Number getY(int series, int item) {
         return new Double(getYValue(series, item));
     }
-    
+
     /**
      * Adds a series or if a series with the same key already exists replaces
-     * the data for that series, then sends a {@link DatasetChangeEvent} to 
+     * the data for that series, then sends a {@link DatasetChangeEvent} to
      * all registered listeners.
-     * 
+     *
      * @param seriesKey  the series key (<code>null</code> not permitted).
-     * @param data  the data (must be an array with length 6, containing six 
+     * @param data  the data (must be an array with length 6, containing six
      *     arrays of equal length, the first containing the x-values and the
-     *     second containing the y-values). 
+     *     second containing the y-values).
      */
     public void addSeries(Comparable seriesKey, double[][] data) {
         if (seriesKey == null) {
@@ -410,8 +413,8 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
                     "The 'data' array must have length == 6.");
         }
         int length = data[0].length;
-        if (length != data[1].length || length != data[2].length 
-                || length != data[3].length || length != data[4].length 
+        if (length != data[1].length || length != data[2].length
+                || length != data[3].length || length != data[4].length
                 || length != data[5].length) {
             throw new IllegalArgumentException(
                 "The 'data' array must contain two arrays with equal length.");
@@ -427,21 +430,21 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
         }
         notifyListeners(new DatasetChangeEvent(this, this));
     }
-    
+
     /**
-     * Tests this <code>DefaultIntervalXYDataset</code> instance for equality 
-     * with an arbitrary object.  This method returns <code>true</code> if and 
+     * Tests this <code>DefaultIntervalXYDataset</code> instance for equality
+     * with an arbitrary object.  This method returns <code>true</code> if and
      * only if:
      * <ul>
      * <li><code>obj</code> is not <code>null</code>;</li>
-     * <li><code>obj</code> is an instance of 
+     * <li><code>obj</code> is an instance of
      *         <code>DefaultIntervalXYDataset</code>;</li>
-     * <li>both datasets have the same number of series, each containing 
+     * <li>both datasets have the same number of series, each containing
      *         exactly the same values.</li>
      * </ul>
-     * 
+     *
      * @param obj  the object (<code>null</code> permitted).
-     * 
+     *
      * @return A boolean.
      */
     public boolean equals(Object obj) {
@@ -474,27 +477,27 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
                 return false;
             }
             double[] d1y = d1[3];
-            double[] d2y = d2[3];            
+            double[] d2y = d2[3];
             if (!Arrays.equals(d1y, d2y)) {
                 return false;
             }
             double[] d1ys = d1[4];
-            double[] d2ys = d2[4];            
+            double[] d2ys = d2[4];
             if (!Arrays.equals(d1ys, d2ys)) {
                 return false;
             }
             double[] d1ye = d1[5];
-            double[] d2ye = d2[5];            
+            double[] d2ye = d2[5];
             if (!Arrays.equals(d1ye, d2ye)) {
                 return false;
             }
         }
         return true;
     }
-    
+
     /**
      * Returns a hash code for this instance.
-     * 
+     *
      * @return A hash code.
      */
     public int hashCode() {
@@ -503,17 +506,17 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
         result = 29 * result + this.seriesList.hashCode();
         return result;
     }
-    
+
     /**
      * Returns a clone of this dataset.
-     * 
+     *
      * @return A clone.
-     * 
+     *
      * @throws CloneNotSupportedException if the dataset contains a series with
      *         a key that cannot be cloned.
      */
     public Object clone() throws CloneNotSupportedException {
-        DefaultIntervalXYDataset clone 
+        DefaultIntervalXYDataset clone
                 = (DefaultIntervalXYDataset) super.clone();
         clone.seriesKeys = new java.util.ArrayList(this.seriesKeys);
         clone.seriesList = new ArrayList(this.seriesList.size());
@@ -537,7 +540,7 @@ public class DefaultIntervalXYDataset extends AbstractIntervalXYDataset {
             System.arraycopy(y, 0, yy, 0, y.length);
             System.arraycopy(yStart, 0, yyStart, 0, yStart.length);
             System.arraycopy(yEnd, 0, yyEnd, 0, yEnd.length);
-            clone.seriesList.add(i, new double[][] {xx, xxStart, xxEnd, yy, 
+            clone.seriesList.add(i, new double[][] {xx, xxStart, xxEnd, yy,
                     yyStart, yyEnd});
         }
         return clone;
