@@ -2,32 +2,32 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
- * This library is free software; you can redistribute it and/or modify it 
- * under the terms of the GNU Lesser General Public License as published by 
- * the Free Software Foundation; either version 2.1 of the License, or 
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
  * License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
- * USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+ * USA.
  *
- * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
+ * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
  * in the United States and other countries.]
  *
  * -----------------------
  * XYSeriesCollection.java
  * -----------------------
- * (C) Copyright 2001-2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2001-2009, by Object Refinery Limited and Contributors.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   Aaron Metzger;
@@ -51,6 +51,11 @@
  * 27-Nov-2006 : Added clone() override (DG);
  * 08-May-2007 : Added indexOf(XYSeries) method (DG);
  * 03-Dec-2007 : Added getSeries(Comparable) method (DG);
+ * 22-Apr-2008 : Implemented PublicCloneable (DG);
+ * 27-Feb-2009 : Overridden getDomainOrder() to detect when all series are
+ *               sorted in ascending order (DG);
+ * 06-Mar-2009 : Implemented RangeInfo (DG);
+ * 06-Mar-2009 : Fixed equals() implementation (DG);
  *
  */
 
@@ -61,30 +66,33 @@ import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
 
+import org.jfree.chart.HashUtilities;
 import org.jfree.data.DomainInfo;
+import org.jfree.data.DomainOrder;
 import org.jfree.data.Range;
+import org.jfree.data.RangeInfo;
 import org.jfree.data.UnknownKeyException;
 import org.jfree.data.general.DatasetChangeEvent;
-import org.jfree.data.general.DatasetUtilities;
 import org.jfree.util.ObjectUtilities;
+import org.jfree.util.PublicCloneable;
 
 /**
- * Represents a collection of {@link XYSeries} objects that can be used as a 
+ * Represents a collection of {@link XYSeries} objects that can be used as a
  * dataset.
  */
 public class XYSeriesCollection extends AbstractIntervalXYDataset
-                                implements IntervalXYDataset, DomainInfo, 
-                                           Serializable {
+        implements IntervalXYDataset, DomainInfo, RangeInfo, PublicCloneable,
+                   Serializable {
 
     /** For serialization. */
     private static final long serialVersionUID = -7590013825931496766L;
-    
+
     /** The series that are included in the collection. */
     private List data;
-    
+
     /** The interval delegate (used to calculate the start and end x-values). */
     private IntervalXYDelegate intervalDelegate;
-    
+
     /**
      * Constructs an empty dataset.
      */
@@ -106,32 +114,45 @@ public class XYSeriesCollection extends AbstractIntervalXYDataset
             series.addChangeListener(this);
         }
     }
-    
+
     /**
-     * Adds a series to the collection and sends a {@link DatasetChangeEvent} 
+     * Returns the order of the domain (X) values, if this is known.
+     *
+     * @return The domain order.
+     */
+    public DomainOrder getDomainOrder() {
+        int seriesCount = getSeriesCount();
+        for (int i = 0; i < seriesCount; i++) {
+            XYSeries s = getSeries(i);
+            if (!s.getAutoSort()) {
+                return DomainOrder.NONE;  // we can't be sure of the order
+            }
+        }
+        return DomainOrder.ASCENDING;
+    }
+
+    /**
+     * Adds a series to the collection and sends a {@link DatasetChangeEvent}
      * to all registered listeners.
      *
      * @param series  the series (<code>null</code> not permitted).
      */
     public void addSeries(XYSeries series) {
-
         if (series == null) {
             throw new IllegalArgumentException("Null 'series' argument.");
         }
         this.data.add(series);
         series.addChangeListener(this);
         fireDatasetChanged();
-
     }
 
     /**
-     * Removes a series from the collection and sends a 
+     * Removes a series from the collection and sends a
      * {@link DatasetChangeEvent} to all registered listeners.
      *
      * @param series  the series index (zero-based).
      */
     public void removeSeries(int series) {
-
         if ((series < 0) || (series >= getSeriesCount())) {
             throw new IllegalArgumentException("Series index out of bounds.");
         }
@@ -141,17 +162,15 @@ public class XYSeriesCollection extends AbstractIntervalXYDataset
         ts.removeChangeListener(this);
         this.data.remove(series);
         fireDatasetChanged();
-
     }
 
     /**
-     * Removes a series from the collection and sends a 
+     * Removes a series from the collection and sends a
      * {@link DatasetChangeEvent} to all registered listeners.
      *
      * @param series  the series (<code>null</code> not permitted).
      */
     public void removeSeries(XYSeries series) {
-
         if (series == null) {
             throw new IllegalArgumentException("Null 'series' argument.");
         }
@@ -160,15 +179,14 @@ public class XYSeriesCollection extends AbstractIntervalXYDataset
             this.data.remove(series);
             fireDatasetChanged();
         }
-
     }
-    
+
     /**
-     * Removes all the series from the collection and sends a 
+     * Removes all the series from the collection and sends a
      * {@link DatasetChangeEvent} to all registered listeners.
      */
     public void removeAllSeries() {
-        // Unregister the collection as a change listener to each series in 
+        // Unregister the collection as a change listener to each series in
         // the collection.
         for (int i = 0; i < this.data.size(); i++) {
           XYSeries series = (XYSeries) this.data.get(i);
@@ -190,22 +208,22 @@ public class XYSeriesCollection extends AbstractIntervalXYDataset
     }
 
     /**
-     * Returns a list of all the series in the collection.  
-     * 
+     * Returns a list of all the series in the collection.
+     *
      * @return The list (which is unmodifiable).
      */
     public List getSeries() {
         return Collections.unmodifiableList(this.data);
     }
-    
+
     /**
      * Returns the index of the specified series, or -1 if that series is not
      * present in the dataset.
-     * 
+     *
      * @param series  the series (<code>null</code> not permitted).
-     * 
+     *
      * @return The series index.
-     * 
+     *
      * @since 1.0.6
      */
     public int indexOf(XYSeries series) {
@@ -221,7 +239,7 @@ public class XYSeriesCollection extends AbstractIntervalXYDataset
      * @param series  the series index (zero-based).
      *
      * @return The series.
-     * 
+     *
      * @throws IllegalArgumentException if <code>series</code> is not in the
      *     range <code>0</code> to <code>getSeriesCount() - 1</code>.
      */
@@ -231,17 +249,17 @@ public class XYSeriesCollection extends AbstractIntervalXYDataset
         }
         return (XYSeries) this.data.get(series);
     }
-    
+
     /**
      * Returns a series from the collection.
-     * 
+     *
      * @param key  the key (<code>null</code> not permitted).
-     * 
+     *
      * @return The series with the specified key.
-     * 
+     *
      * @throws UnknownKeyException if <code>key</code> is not found in the
      *         collection.
-     * 
+     *
      * @since 1.0.9
      */
     public XYSeries getSeries(Comparable key) {
@@ -261,11 +279,11 @@ public class XYSeriesCollection extends AbstractIntervalXYDataset
     /**
      * Returns the key for a series.
      *
-     * @param series  the series index (in the range <code>0</code> to 
+     * @param series  the series index (in the range <code>0</code> to
      *     <code>getSeriesCount() - 1</code>).
      *
      * @return The key for a series.
-     * 
+     *
      * @throws IllegalArgumentException if <code>series</code> is not in the
      *     specified range.
      */
@@ -280,7 +298,7 @@ public class XYSeriesCollection extends AbstractIntervalXYDataset
      * @param series  the series (zero-based index).
      *
      * @return The item count.
-     * 
+     *
      * @throws IllegalArgumentException if <code>series</code> is not in the
      *     range <code>0</code> to <code>getSeriesCount() - 1</code>.
      */
@@ -336,11 +354,9 @@ public class XYSeriesCollection extends AbstractIntervalXYDataset
      * @return The value (possibly <code>null</code>).
      */
     public Number getY(int series, int index) {
-
         XYSeries ts = (XYSeries) this.data.get(series);
         XYDataItem xyItem = ts.getDataItem(index);
         return xyItem.getY();
-
     }
 
     /**
@@ -375,15 +391,6 @@ public class XYSeriesCollection extends AbstractIntervalXYDataset
      * @return A boolean.
      */
     public boolean equals(Object obj) {
-        /* 
-         * XXX
-         *  
-         * what about  the interval delegate...?
-         * The interval width etc wasn't considered
-         * before, hence i did not add it here (AS)
-         * 
-         */
-
         if (obj == this) {
             return true;
         }
@@ -391,44 +398,68 @@ public class XYSeriesCollection extends AbstractIntervalXYDataset
             return false;
         }
         XYSeriesCollection that = (XYSeriesCollection) obj;
+        if (!this.intervalDelegate.equals(that.intervalDelegate)) {
+            return false;
+        }
         return ObjectUtilities.equal(this.data, that.data);
     }
-    
+
     /**
      * Returns a clone of this instance.
-     * 
+     *
      * @return A clone.
-     * 
+     *
      * @throws CloneNotSupportedException if there is a problem.
      */
     public Object clone() throws CloneNotSupportedException {
         XYSeriesCollection clone = (XYSeriesCollection) super.clone();
         clone.data = (List) ObjectUtilities.deepClone(this.data);
-        clone.intervalDelegate 
+        clone.intervalDelegate
                 = (IntervalXYDelegate) this.intervalDelegate.clone();
         return clone;
     }
 
     /**
      * Returns a hash code.
-     * 
+     *
      * @return A hash code.
      */
     public int hashCode() {
-        // Same question as for equals (AS)
-        return (this.data != null ? this.data.hashCode() : 0);
+        int hash = 5;
+        hash = HashUtilities.hashCode(hash, this.intervalDelegate);
+        hash = HashUtilities.hashCode(hash, this.data);
+        return hash;
     }
-       
+
     /**
      * Returns the minimum x-value in the dataset.
      *
      * @param includeInterval  a flag that determines whether or not the
      *                         x-interval is taken into account.
-     * 
+     *
      * @return The minimum value.
      */
     public double getDomainLowerBound(boolean includeInterval) {
-        return this.intervalDelegate.getDomainLowerBound(includeInterval);
+        if (includeInterval) {
+            return this.intervalDelegate.getDomainLowerBound(includeInterval);
+        }
+        else {
+            double result = Double.NaN;
+            int seriesCount = getSeriesCount();
+            for (int s = 0; s < seriesCount; s++) {
+                XYSeries series = getSeries(s);
+                double lowX = series.getMinX();
+                if (Double.isNaN(result)) {
+                    result = lowX;
+                }
+                else {
+                    if (!Double.isNaN(lowX)) {
+                        result = Math.min(result, lowX);
+                    }
+                }
+            }
+            return result;
+        }
     }
 
     /**
@@ -436,11 +467,30 @@ public class XYSeriesCollection extends AbstractIntervalXYDataset
      *
      * @param includeInterval  a flag that determines whether or not the
      *                         x-interval is taken into account.
-     * 
+     *
      * @return The maximum value.
      */
     public double getDomainUpperBound(boolean includeInterval) {
-        return this.intervalDelegate.getDomainUpperBound(includeInterval);
+        if (includeInterval) {
+            return this.intervalDelegate.getDomainUpperBound(includeInterval);
+        }
+        else {
+            double result = Double.NaN;
+            int seriesCount = getSeriesCount();
+            for (int s = 0; s < seriesCount; s++) {
+                XYSeries series = getSeries(s);
+                double hiX = series.getMaxX();
+                if (Double.isNaN(result)) {
+                    result = hiX;
+                }
+                else {
+                    if (!Double.isNaN(hiX)) {
+                        result = Math.max(result, hiX);
+                    }
+                }
+            }
+            return result;
+        }
     }
 
     /**
@@ -448,33 +498,52 @@ public class XYSeriesCollection extends AbstractIntervalXYDataset
      *
      * @param includeInterval  a flag that determines whether or not the
      *                         x-interval is taken into account.
-     * 
-     * @return The range.
+     *
+     * @return The range (or <code>null</code> if the dataset contains no
+     *     values).
      */
     public Range getDomainBounds(boolean includeInterval) {
         if (includeInterval) {
             return this.intervalDelegate.getDomainBounds(includeInterval);
         }
         else {
-            return DatasetUtilities.iterateDomainBounds(this, includeInterval);
+            double lower = Double.POSITIVE_INFINITY;
+            double upper = Double.NEGATIVE_INFINITY;
+            int seriesCount = getSeriesCount();
+            for (int s = 0; s < seriesCount; s++) {
+                XYSeries series = getSeries(s);
+                double minX = series.getMinX();
+                if (!Double.isNaN(minX)) {
+                    lower = Math.min(lower, minX);
+                }
+                double maxX = series.getMaxX();
+                if (!Double.isNaN(maxX)) {
+                    upper = Math.max(upper, maxX);
+                }
+            }
+            if (lower > upper) {
+                return null;
+            }
+            else {
+                return new Range(lower, upper);
+            }
         }
-            
     }
-    
+
     /**
-     * Returns the interval width. This is used to calculate the start and end 
-     * x-values, if/when the dataset is used as an {@link IntervalXYDataset}.  
-     * 
+     * Returns the interval width. This is used to calculate the start and end
+     * x-values, if/when the dataset is used as an {@link IntervalXYDataset}.
+     *
      * @return The interval width.
      */
     public double getIntervalWidth() {
         return this.intervalDelegate.getIntervalWidth();
     }
-    
+
     /**
-     * Sets the interval width and sends a {@link DatasetChangeEvent} to all 
+     * Sets the interval width and sends a {@link DatasetChangeEvent} to all
      * registered listeners.
-     * 
+     *
      * @param width  the width (negative values not permitted).
      */
     public void setIntervalWidth(double width) {
@@ -486,29 +555,29 @@ public class XYSeriesCollection extends AbstractIntervalXYDataset
     }
 
     /**
-     * Returns the interval position factor.  
-     * 
+     * Returns the interval position factor.
+     *
      * @return The interval position factor.
      */
     public double getIntervalPositionFactor() {
         return this.intervalDelegate.getIntervalPositionFactor();
     }
-    
+
     /**
      * Sets the interval position factor. This controls where the x-value is in
-     * relation to the interval surrounding the x-value (0.0 means the x-value 
+     * relation to the interval surrounding the x-value (0.0 means the x-value
      * will be positioned at the start, 0.5 in the middle, and 1.0 at the end).
-     * 
+     *
      * @param factor  the factor.
      */
     public void setIntervalPositionFactor(double factor) {
         this.intervalDelegate.setIntervalPositionFactor(factor);
         fireDatasetChanged();
     }
-    
+
     /**
      * Returns whether the interval width is automatically calculated or not.
-     * 
+     *
      * @return Whether the width is automatically calculated or not.
      */
     public boolean isAutoWidth() {
@@ -517,13 +586,96 @@ public class XYSeriesCollection extends AbstractIntervalXYDataset
 
     /**
      * Sets the flag that indicates wether the interval width is automatically
-     * calculated or not. 
-     * 
+     * calculated or not.
+     *
      * @param b  a boolean.
      */
     public void setAutoWidth(boolean b) {
         this.intervalDelegate.setAutoWidth(b);
         fireDatasetChanged();
     }
-    
+
+    /**
+     * Returns the range of the values in this dataset's range.
+     *
+     * @param includeInterval  ignored.
+     *
+     * @return The range (or <code>null</code> if the dataset contains no
+     *     values).
+     */
+    public Range getRangeBounds(boolean includeInterval) {
+        double lower = Double.POSITIVE_INFINITY;
+        double upper = Double.NEGATIVE_INFINITY;
+        int seriesCount = getSeriesCount();
+        for (int s = 0; s < seriesCount; s++) {
+            XYSeries series = getSeries(s);
+            double minY = series.getMinY();
+            if (!Double.isNaN(minY)) {
+                lower = Math.min(lower, minY);
+            }
+            double maxY = series.getMaxY();
+            if (!Double.isNaN(maxY)) {
+                upper = Math.max(upper, maxY);
+            }
+        }
+        if (lower > upper) {
+            return null;
+        }
+        else {
+            return new Range(lower, upper);
+        }
+    }
+
+    /**
+     * Returns the minimum y-value in the dataset.
+     *
+     * @param includeInterval  a flag that determines whether or not the
+     *                         y-interval is taken into account.
+     *
+     * @return The minimum value.
+     */
+    public double getRangeLowerBound(boolean includeInterval) {
+        double result = Double.NaN;
+        int seriesCount = getSeriesCount();
+        for (int s = 0; s < seriesCount; s++) {
+            XYSeries series = getSeries(s);
+            double lowY = series.getMinY();
+            if (Double.isNaN(result)) {
+                result = lowY;
+            }
+            else {
+                if (!Double.isNaN(lowY)) {
+                    result = Math.min(result, lowY);
+                }
+            }
+        }
+        return result;
+    }
+
+    /**
+     * Returns the maximum y-value in the dataset.
+     *
+     * @param includeInterval  a flag that determines whether or not the
+     *                         y-interval is taken into account.
+     *
+     * @return The maximum value.
+     */
+    public double getRangeUpperBound(boolean includeInterval) {
+        double result = Double.NaN;
+        int seriesCount = getSeriesCount();
+        for (int s = 0; s < seriesCount; s++) {
+            XYSeries series = getSeries(s);
+            double hiY = series.getMaxY();
+            if (Double.isNaN(result)) {
+                result = hiY;
+            }
+            else {
+                if (!Double.isNaN(hiY)) {
+                    result = Math.max(result, hiY);
+                }
+            }
+        }
+        return result;
+    }
+
 }
