@@ -2,46 +2,44 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
- * This library is free software; you can redistribute it and/or modify it 
- * under the terms of the GNU Lesser General Public License as published by 
- * the Free Software Foundation; either version 2.1 of the License, or 
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
  * License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
- * USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+ * USA.
  *
- * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
+ * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
  * in the United States and other countries.]
  *
  * ---------------------
  * SWTBarChartDemo1.java
  * ---------------------
- * (C) Copyright 2006, 2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2006-2008, by Object Refinery Limited and Contributors.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
- * Contributor(s):
+ * Contributor(s):   Henry Proudhon (henry.proudhon AT ensmp.fr).
  *
  * Changes
  * -------
  * 23-Aug-2006 : New class (DG);
- * 
+ *
  */
 
 package org.jfree.experimental.chart.swt.demo;
 
-import java.awt.Color;
-
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.layout.FillLayout;
 import org.eclipse.swt.widgets.Display;
@@ -54,6 +52,7 @@ import org.jfree.chart.axis.NumberAxis;
 import org.jfree.chart.plot.CategoryPlot;
 import org.jfree.chart.plot.PlotOrientation;
 import org.jfree.chart.renderer.category.BarRenderer;
+import org.jfree.chart.renderer.category.StandardBarPainter;
 import org.jfree.data.category.CategoryDataset;
 import org.jfree.data.category.DefaultCategoryDataset;
 import org.jfree.experimental.chart.swt.ChartComposite;
@@ -62,14 +61,14 @@ import org.jfree.experimental.chart.swt.ChartComposite;
  * An SWT demo.
  */
 public class SWTBarChartDemo1 {
-    
+
     /**
      * Returns a sample dataset.
-     * 
+     *
      * @return The dataset.
      */
     private static CategoryDataset createDataset() {
-        
+
         // row keys...
         String series1 = "First";
         String series2 = "Second";
@@ -102,23 +101,23 @@ public class SWTBarChartDemo1 {
         dataset.addValue(2.0, series3, category3);
         dataset.addValue(3.0, series3, category4);
         dataset.addValue(6.0, series3, category5);
-        
+
         return dataset;
-        
+
     }
-    
+
     /**
      * Creates a sample chart.
-     * 
+     *
      * @param dataset  the dataset.
-     * 
+     *
      * @return The chart.
      */
     private static JFreeChart createChart(CategoryDataset dataset) {
-        
+
         // create the chart...
         JFreeChart chart = ChartFactory.createBarChart(
-            "Bar Chart Demo",         // chart title
+            "SWTBarChartDemo1",       // chart title
             "Category",               // domain axis label
             "Value",                  // range axis label
             dataset,                  // data
@@ -130,34 +129,32 @@ public class SWTBarChartDemo1 {
 
         // NOW DO SOME OPTIONAL CUSTOMISATION OF THE CHART...
 
-        // set the background color for the chart...
-        chart.setBackgroundPaint(Color.white);
-
         // get a reference to the plot for further customisation...
         CategoryPlot plot = (CategoryPlot) chart.getPlot();
-        plot.setBackgroundPaint(Color.lightGray);
-        plot.setDomainGridlinePaint(Color.white);
-        plot.setDomainGridlinesVisible(true);
-        plot.setRangeGridlinePaint(Color.white);
 
         // set the range axis to display integers only...
-        final NumberAxis rangeAxis = (NumberAxis) plot.getRangeAxis();
+        NumberAxis rangeAxis = (NumberAxis) plot.getRangeAxis();
         rangeAxis.setStandardTickUnits(NumberAxis.createIntegerTickUnits());
 
         // disable bar outlines...
         BarRenderer renderer = (BarRenderer) plot.getRenderer();
         renderer.setDrawBarOutline(false);
 
+        // the SWTGraphics2D class doesn't handle GradientPaint well, so
+        // replace the gradient painter from the default theme with a
+        // standard painter...
+        renderer.setBarPainter(new StandardBarPainter());
+
         CategoryAxis domainAxis = plot.getDomainAxis();
         domainAxis.setCategoryLabelPositions(
-            CategoryLabelPositions.createUpRotationLabelPositions(Math.PI / 6.0)
-        );
+                CategoryLabelPositions.createUpRotationLabelPositions(
+                        Math.PI / 6.0));
         // OPTIONAL CUSTOMISATION COMPLETED.
-        
+
         return chart;
-        
+
     }
-    
+
     /**
      * Starting point for the demonstration application.
      *
@@ -170,7 +167,7 @@ public class SWTBarChartDemo1 {
         shell.setSize(600, 300);
         shell.setLayout(new FillLayout());
         shell.setText("Test for jfreechart running with SWT");
-        final ChartComposite frame = new ChartComposite(shell, SWT.NONE, chart,
+        ChartComposite frame = new ChartComposite(shell, SWT.NONE, chart,
                 true);
         frame.pack();
         shell.open();
