@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,7 +27,7 @@
  * -------------------------
  * SWTMultipleAxisDemo1.java
  * -------------------------
- * (C) Copyright 2006, 2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2006-2009, by Object Refinery Limited and Contributors.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   Henry Proudhon;
@@ -169,7 +169,7 @@ public class SWTMultipleAxisDemo1
     private static XYDataset createDataset(String name, double base, 
                                            RegularTimePeriod start, int count) {
 
-        TimeSeries series = new TimeSeries(name, start.getClass());
+        TimeSeries series = new TimeSeries(name);
         RegularTimePeriod period = start;
         double value = base;
         for (int i = 0; i < count; i++) {
