@@ -41,6 +41,7 @@
  * 22-Sep-2005 : Renamed getMaxBarWidth() --> getMaximumBarWidth() (DG);
  * 11-May-2007 : Added testGetLegendItem() (DG);
  * 23-Apr-2008 : Added testPublicCloneable() (DG);
+ * 25-Nov-2008 : Added testFindRangeBounds (DG);
  *
  */
 
@@ -67,7 +68,9 @@ import org.jfree.chart.labels.ItemLabelPosition;
 import org.jfree.chart.labels.StandardCategoryItemLabelGenerator;
 import org.jfree.chart.plot.CategoryPlot;
 import org.jfree.chart.renderer.category.BarRenderer;
+import org.jfree.chart.renderer.category.GradientBarPainter;
 import org.jfree.chart.renderer.junit.RendererChangeDetector;
+import org.jfree.data.Range;
 import org.jfree.data.category.DefaultCategoryDataset;
 import org.jfree.ui.GradientPaintTransformType;
 import org.jfree.ui.StandardGradientPaintTransformer;
@@ -160,6 +163,35 @@ public class BarRendererTests extends TestCase {
                 ItemLabelAnchor.INSIDE1, TextAnchor.CENTER));
         assertTrue(r1.equals(r2));
 
+        // barPainter
+        r1.setBarPainter(new GradientBarPainter(0.1, 0.2, 0.3));
+        assertFalse(r1.equals(r2));
+        r2.setBarPainter(new GradientBarPainter(0.1, 0.2, 0.3));
+        assertTrue(r1.equals(r2));
+
+        // shadowsVisible
+        r1.setShadowVisible(false);
+        assertFalse(r1.equals(r2));
+        r2.setShadowVisible(false);
+        assertTrue(r1.equals(r2));
+
+        r1.setShadowPaint(Color.red);
+        assertFalse(r1.equals(r2));
+        r2.setShadowPaint(Color.red);
+        assertTrue(r1.equals(r2));
+
+        // shadowXOffset
+        r1.setShadowXOffset(3.3);
+        assertFalse(r1.equals(r2));
+        r2.setShadowXOffset(3.3);
+        assertTrue(r1.equals(r2));
+
+        // shadowYOffset
+        r1.setShadowYOffset(3.3);
+        assertFalse(r1.equals(r2));
+        r2.setShadowYOffset(3.3);
+        assertTrue(r1.equals(r2));
+
     }
 
     /**
@@ -180,6 +212,7 @@ public class BarRendererTests extends TestCase {
     public void testCloning() {
         BarRenderer r1 = new BarRenderer();
         r1.setBaseItemLabelGenerator(new StandardCategoryItemLabelGenerator());
+        r1.setBarPainter(new GradientBarPainter(0.11, 0.22, 0.33));
         BarRenderer r2 = null;
         try {
             r2 = (BarRenderer) r1.clone();
@@ -281,4 +314,28 @@ public class BarRendererTests extends TestCase {
         assertEquals(2, li.getSeriesIndex());
     }
 
+    /**
+     * Some checks for the findRangeBounds() method.
+     */
+    public void testFindRangeBounds() {
+        BarRenderer r = new BarRenderer();
+        assertNull(r.findRangeBounds(null));
+
+        // an empty dataset should return a null range
+        DefaultCategoryDataset dataset = new DefaultCategoryDataset();
+        assertNull(r.findRangeBounds(dataset));
+
+        dataset.addValue(1.0, "R1", "C1");
+        assertEquals(new Range(0.0, 1.0), r.findRangeBounds(dataset));
+        r.setIncludeBaseInRange(false);
+        assertEquals(new Range(1.0, 1.0), r.findRangeBounds(dataset));
+        r.setIncludeBaseInRange(true);
+
+        dataset.addValue(-2.0, "R1", "C2");
+        assertEquals(new Range(-2.0, 1.0), r.findRangeBounds(dataset));
+
+        dataset.addValue(null, "R1", "C3");
+        assertEquals(new Range(-2.0, 1.0), r.findRangeBounds(dataset));
+    }
+
 }
