@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,7 +27,7 @@
  * ------------------------------
  * WaterfallBarRendererTests.java
  * ------------------------------
- * (C) Copyright 2003-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2003-2009, by Object Refinery Limited and Contributors.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   -;
@@ -36,6 +36,7 @@
  * -------
  * 21-Oct-2003 : Version 1 (DG);
  * 23-Apr-2008 : Added testPublicCloneable() (DG);
+ * 04-Feb-2009 : Added testFindRangeBounds() (DG);
  *
  */
 
@@ -79,6 +80,14 @@ public class WaterfallBarRendererTests extends TestCase {
         super(name);
     }
 
+    /**
+     * Some tests for the findRangeBounds() method.
+     */
+    public void testFindRangeBounds() {
+        WaterfallBarRenderer r = new WaterfallBarRenderer();
+        assertNull(r.findRangeBounds(null));
+    }
+
     /**
      * Check that the equals() method distinguishes all fields.
      */
