@@ -193,8 +193,7 @@ public class XYAreaRendererTests extends TestCase {
             out.close();
 
             ObjectInput in = new ObjectInputStream(
-                new ByteArrayInputStream(buffer.toByteArray())
-            );
+                    new ByteArrayInputStream(buffer.toByteArray()));
             r2 = (XYAreaRenderer) in.readObject();
             in.close();
         }
