@@ -39,6 +39,7 @@
  * 09-Feb-2007 : Added to testCloning() (DG);
  * 17-May-2007 : Added testGetLegendItemSeriesIndex() (DG);
  * 22-Apr-2008 : Added testPublicCloneable (DG);
+ * 19-Jun-2008 : Added testFindRangeBounds() (DG);
  *
  */
 
@@ -63,8 +64,10 @@ import org.jfree.chart.axis.NumberAxis;
 import org.jfree.chart.labels.ItemLabelPosition;
 import org.jfree.chart.plot.PlotOrientation;
 import org.jfree.chart.plot.XYPlot;
+import org.jfree.chart.renderer.xy.GradientXYBarPainter;
 import org.jfree.chart.renderer.xy.XYBarRenderer;
 import org.jfree.data.Range;
+import org.jfree.data.xy.DefaultIntervalXYDataset;
 import org.jfree.data.xy.XYBarDataset;
 import org.jfree.data.xy.XYSeries;
 import org.jfree.data.xy.XYSeriesCollection;
@@ -155,6 +158,31 @@ public class XYBarRendererTests extends TestCase {
         assertFalse(r1.equals(r2));
         r2.setNegativeItemLabelPositionFallback(new ItemLabelPosition());
         assertTrue(r1.equals(r2));
+
+        // barPainter
+        r1.setBarPainter(new GradientXYBarPainter(0.11, 0.22, 0.33));
+        assertFalse(r1.equals(r2));
+        r2.setBarPainter(new GradientXYBarPainter(0.11, 0.22, 0.33));
+        assertTrue(r1.equals(r2));
+
+        // shadowsVisible
+        r1.setShadowVisible(false);
+        assertFalse(r1.equals(r2));
+        r2.setShadowVisible(false);
+        assertTrue(r1.equals(r2));
+
+        // shadowXOffset
+        r1.setShadowXOffset(3.3);
+        assertFalse(r1.equals(r2));
+        r2.setShadowXOffset(3.3);
+        assertTrue(r1.equals(r2));
+
+        // shadowYOffset
+        r1.setShadowYOffset(3.3);
+        assertFalse(r1.equals(r2));
+        r2.setShadowYOffset(3.3);
+        assertTrue(r1.equals(r2));
+
     }
 
     /**
@@ -217,13 +245,12 @@ public class XYBarRendererTests extends TestCase {
             out.close();
 
             ObjectInput in = new ObjectInputStream(
-                new ByteArrayInputStream(buffer.toByteArray())
-            );
+                    new ByteArrayInputStream(buffer.toByteArray()));
             r2 = (XYBarRenderer) in.readObject();
             in.close();
         }
         catch (Exception e) {
-            System.out.println(e.toString());
+            e.printStackTrace();
         }
         assertEquals(r1, r2);
 
@@ -275,6 +302,33 @@ public class XYBarRendererTests extends TestCase {
         assertFalse(bounds.contains(2.8));
     }
 
+    private static final double EPSILON = 0.0000000001;
+
+    /**
+     * A simple test for the findRangeBounds() method.
+     */
+    public void testFindRangeBounds() {
+        DefaultIntervalXYDataset dataset = new DefaultIntervalXYDataset();
+        double[] x = {1.0, 2.0, 3.0, 4.0};
+        double[] startx = {0.9, 1.8, 2.7, 3.6};
+        double[] endx = {1.1, 2.2, 3.3, 4.4};
+        double[] y = {1.0, 2.0, 3.0, 4.0};
+        double[] starty = {0.9, 1.8, 2.7, 3.6};
+        double[] endy = {1.1, 2.2, 3.3, 4.4};
+        double[][] data = new double[][] {x, startx, endx, y, starty, endy};
+        dataset.addSeries("Series 1", data);
+        XYBarRenderer renderer = new XYBarRenderer();
+        renderer.setUseYInterval(true);
+        Range r = renderer.findRangeBounds(dataset);
+        assertEquals(0.9, r.getLowerBound(), EPSILON);
+        assertEquals(4.4, r.getUpperBound(), EPSILON);
+
+        renderer.setUseYInterval(false);
+        r = renderer.findRangeBounds(dataset);
+        assertEquals(1.0, r.getLowerBound(), EPSILON);
+        assertEquals(4.0, r.getUpperBound(), EPSILON);
+    }
+
     /**
      * A check for the datasetIndex and seriesIndex fields in the LegendItem
      * returned by the getLegendItem() method.
