@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,7 +27,7 @@
  * -------------------------
  * XYErrorRendererTests.java
  * -------------------------
- * (C) Copyright 2006-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2006-2009, by Object Refinery Limited and Contributors.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   -;
@@ -36,11 +36,13 @@
  * -------
  * 25-Oct-2006 : Version 1 (DG);
  * 22-Apr-2008 : Added testPublicCloneable (DG);
+ * 28-Jan-2009 : Updated tests for new errorStroke field (DG);
  *
  */
 
 package org.jfree.chart.renderer.xy.junit;
 
+import java.awt.BasicStroke;
 import java.awt.Color;
 import java.awt.GradientPaint;
 import java.io.ByteArrayInputStream;
@@ -113,6 +115,13 @@ public class XYErrorRendererTests extends TestCase {
         r2.setErrorPaint(new GradientPaint(1.0f, 2.0f, Color.red, 3.0f, 4.0f,
                 Color.green));
         assertTrue(r1.equals(r2));
+
+        // errorStroke
+        r1.setErrorStroke(new BasicStroke(1.5f));
+        assertFalse(r1.equals(r2));
+        r2.setErrorStroke(new BasicStroke(1.5f));
+        assertTrue(r1.equals(r2));
+
     }
 
     /**
@@ -146,6 +155,24 @@ public class XYErrorRendererTests extends TestCase {
         assertTrue(r1.equals(r2));
     }
 
+    /**
+     * A test for cloning.
+     */
+    public void testCloning2() {
+        XYErrorRenderer r1 = new XYErrorRenderer();
+        r1.setErrorStroke(new BasicStroke(1.5f));
+        XYErrorRenderer r2 = null;
+        try {
+            r2 = (XYErrorRenderer) r1.clone();
+        }
+        catch (CloneNotSupportedException e) {
+            e.printStackTrace();
+        }
+        assertTrue(r1 != r2);
+        assertTrue(r1.getClass() == r2.getClass());
+        assertTrue(r1.equals(r2));
+    }
+
     /**
      * Verify that this class implements {@link PublicCloneable}.
      */
@@ -158,7 +185,6 @@ public class XYErrorRendererTests extends TestCase {
      * Serialize an instance, restore it, and check for equality.
      */
     public void testSerialization() {
-
         XYErrorRenderer r1 = new XYErrorRenderer();
         r1.setErrorPaint(new GradientPaint(1.0f, 2.0f, Color.red, 3.0f, 4.0f,
                 Color.white));
@@ -179,7 +205,31 @@ public class XYErrorRendererTests extends TestCase {
             e.printStackTrace();
         }
         assertEquals(r1, r2);
+    }
 
+    /**
+     * Serialize an instance, restore it, and check for equality.
+     */
+    public void testSerialization2() {
+        XYErrorRenderer r1 = new XYErrorRenderer();
+        r1.setErrorStroke(new BasicStroke(1.5f));
+        XYErrorRenderer r2 = null;
+
+        try {
+            ByteArrayOutputStream buffer = new ByteArrayOutputStream();
+            ObjectOutput out = new ObjectOutputStream(buffer);
+            out.writeObject(r1);
+            out.close();
+
+            ObjectInput in = new ObjectInputStream(
+                    new ByteArrayInputStream(buffer.toByteArray()));
+            r2 = (XYErrorRenderer) in.readObject();
+            in.close();
+        }
+        catch (Exception e) {
+            e.printStackTrace();
+        }
+        assertEquals(r1, r2);
     }
 
 }
