@@ -2,32 +2,32 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2009, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
- * This library is free software; you can redistribute it and/or modify it 
- * under the terms of the GNU Lesser General Public License as published by 
- * the Free Software Foundation; either version 2.1 of the License, or 
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
  * License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
- * USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+ * USA.
  *
- * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
+ * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
  * in the United States and other countries.]
  *
  * ----------------------------------------
  * DefaultIntervalCategoryDatasetTests.java
  * ----------------------------------------
- * (C) Copyright 2007, 2008, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2007-2009, by Object Refinery Limited and Contributors.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   -;
@@ -36,7 +36,8 @@
  * -------
  * 08-Mar-2007 : Version 1 (DG);
  * 25-Feb-2008 : Added new tests to check behaviour of an empty dataset (DG);
- * 
+ * 11-Feb-2009 : Fixed locale-sensitive failures (DG);
+ *
  */
 
 package org.jfree.data.category.junit;
@@ -53,6 +54,7 @@ import junit.framework.Test;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
+import org.jfree.data.DataUtilities;
 import org.jfree.data.UnknownKeyException;
 import org.jfree.data.category.DefaultIntervalCategoryDataset;
 
@@ -60,7 +62,7 @@ import org.jfree.data.category.DefaultIntervalCategoryDataset;
  * Tests for the {@link DefaultIntervalCategoryDataset} class.
  */
 public class DefaultIntervalCategoryDatasetTests extends TestCase {
-    
+
     /**
      * Returns the tests as a test suite.
      *
@@ -78,44 +80,47 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
     public DefaultIntervalCategoryDatasetTests(String name) {
         super(name);
     }
-    
+
     /**
      * Some checks for the getValue() method.
      */
-    public void testGetValue() {        
+    public void testGetValue() {
         double[] starts_S1 = new double[] {0.1, 0.2, 0.3};
         double[] starts_S2 = new double[] {0.3, 0.4, 0.5};
         double[] ends_S1 = new double[] {0.5, 0.6, 0.7};
         double[] ends_S2 = new double[] {0.7, 0.8, 0.9};
         double[][] starts = new double[][] {starts_S1, starts_S2};
         double[][] ends = new double[][] {ends_S1, ends_S2};
-        DefaultIntervalCategoryDataset d 
-                = new DefaultIntervalCategoryDataset(starts, ends);        
+        DefaultIntervalCategoryDataset d = new DefaultIntervalCategoryDataset(
+                new Comparable[] {"Series 1", "Series 2"},
+                new Comparable[] {"Category 1", "Category 2", "Category 3"},
+                DataUtilities.createNumberArray2D(starts),
+                DataUtilities.createNumberArray2D(ends));
 
-        assertEquals(new Double(0.1), d.getStartValue("Series 1", 
+        assertEquals(new Double(0.1), d.getStartValue("Series 1",
                 "Category 1"));
-        assertEquals(new Double(0.2), d.getStartValue("Series 1", 
+        assertEquals(new Double(0.2), d.getStartValue("Series 1",
                 "Category 2"));
-        assertEquals(new Double(0.3), d.getStartValue("Series 1", 
+        assertEquals(new Double(0.3), d.getStartValue("Series 1",
                 "Category 3"));
-        assertEquals(new Double(0.3), d.getStartValue("Series 2", 
+        assertEquals(new Double(0.3), d.getStartValue("Series 2",
                 "Category 1"));
-        assertEquals(new Double(0.4), d.getStartValue("Series 2", 
+        assertEquals(new Double(0.4), d.getStartValue("Series 2",
                 "Category 2"));
-        assertEquals(new Double(0.5), d.getStartValue("Series 2", 
+        assertEquals(new Double(0.5), d.getStartValue("Series 2",
                 "Category 3"));
-        
-        assertEquals(new Double(0.5), d.getEndValue("Series 1", 
+
+        assertEquals(new Double(0.5), d.getEndValue("Series 1",
                 "Category 1"));
-        assertEquals(new Double(0.6), d.getEndValue("Series 1", 
+        assertEquals(new Double(0.6), d.getEndValue("Series 1",
                 "Category 2"));
-        assertEquals(new Double(0.7), d.getEndValue("Series 1", 
+        assertEquals(new Double(0.7), d.getEndValue("Series 1",
                 "Category 3"));
-        assertEquals(new Double(0.7), d.getEndValue("Series 2", 
+        assertEquals(new Double(0.7), d.getEndValue("Series 2",
                 "Category 1"));
-        assertEquals(new Double(0.8), d.getEndValue("Series 2", 
+        assertEquals(new Double(0.8), d.getEndValue("Series 2",
                 "Category 2"));
-        assertEquals(new Double(0.9), d.getEndValue("Series 2", 
+        assertEquals(new Double(0.9), d.getEndValue("Series 2",
                 "Category 3"));
 
         boolean pass = false;
@@ -123,21 +128,21 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
             d.getValue("XX", "Category 1");
         }
         catch (UnknownKeyException e) {
-            pass = true;   
+            pass = true;
         }
         assertTrue(pass);
-        
+
         pass = false;
         try {
             d.getValue("Series 1", "XX");
         }
         catch (UnknownKeyException e) {
-            pass = true;   
+            pass = true;
         }
         assertTrue(pass);
     }
-    
-   
+
+
     /**
      * Some tests for the getRowCount() method.
      */
@@ -148,8 +153,8 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
         double[] ends_S2 = new double[] {0.7, 0.8, 0.9};
         double[][] starts = new double[][] {starts_S1, starts_S2};
         double[][] ends = new double[][] {ends_S1, ends_S2};
-        DefaultIntervalCategoryDataset d 
-                = new DefaultIntervalCategoryDataset(starts, ends);        
+        DefaultIntervalCategoryDataset d
+                = new DefaultIntervalCategoryDataset(starts, ends);
 
         assertEquals(2, d.getRowCount());
         assertEquals(3, d.getColumnCount());
@@ -165,8 +170,8 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
         double[] ends_S2A = new double[] {0.7, 0.8, 0.9};
         double[][] startsA = new double[][] {starts_S1A, starts_S2A};
         double[][] endsA = new double[][] {ends_S1A, ends_S2A};
-        DefaultIntervalCategoryDataset dA 
-                = new DefaultIntervalCategoryDataset(startsA, endsA);        
+        DefaultIntervalCategoryDataset dA
+                = new DefaultIntervalCategoryDataset(startsA, endsA);
 
         double[] starts_S1B = new double[] {0.1, 0.2, 0.3};
         double[] starts_S2B = new double[] {0.3, 0.4, 0.5};
@@ -174,18 +179,18 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
         double[] ends_S2B = new double[] {0.7, 0.8, 0.9};
         double[][] startsB = new double[][] {starts_S1B, starts_S2B};
         double[][] endsB = new double[][] {ends_S1B, ends_S2B};
-        DefaultIntervalCategoryDataset dB 
-                = new DefaultIntervalCategoryDataset(startsB, endsB);        
-            
+        DefaultIntervalCategoryDataset dB
+                = new DefaultIntervalCategoryDataset(startsB, endsB);
+
         assertTrue(dA.equals(dB));
         assertTrue(dB.equals(dA));
-        
+
         // check that two empty datasets are equal
-        DefaultIntervalCategoryDataset empty1 
-                = new DefaultIntervalCategoryDataset(new double[0][0], 
+        DefaultIntervalCategoryDataset empty1
+                = new DefaultIntervalCategoryDataset(new double[0][0],
                         new double[0][0]);
-        DefaultIntervalCategoryDataset empty2 
-                = new DefaultIntervalCategoryDataset(new double[0][0], 
+        DefaultIntervalCategoryDataset empty2
+                = new DefaultIntervalCategoryDataset(new double[0][0],
                         new double[0][0]);
         assertTrue(empty1.equals(empty2));
     }
@@ -202,7 +207,7 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
         double[][] starts = new double[][] {starts_S1, starts_S2};
         double[][] ends = new double[][] {ends_S1, ends_S2};
         DefaultIntervalCategoryDataset d1
-                = new DefaultIntervalCategoryDataset(starts, ends);        
+                = new DefaultIntervalCategoryDataset(starts, ends);
         DefaultIntervalCategoryDataset d2 = null;
 
         try {
@@ -222,7 +227,7 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
         assertEquals(d1, d2);
 
     }
-    
+
     /**
      * Confirm that cloning works.
      */
@@ -234,7 +239,10 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
         double[][] starts = new double[][] {starts_S1, starts_S2};
         double[][] ends = new double[][] {ends_S1, ends_S2};
         DefaultIntervalCategoryDataset d1 = new DefaultIntervalCategoryDataset(
-                starts, ends);
+                new Comparable[] {"Series 1", "Series 2"},
+                new Comparable[] {"Category 1", "Category 2", "Category 3"},
+                DataUtilities.createNumberArray2D(starts),
+                DataUtilities.createNumberArray2D(ends));
         DefaultIntervalCategoryDataset d2 = null;
         try {
             d2 = (DefaultIntervalCategoryDataset) d1.clone();
@@ -245,20 +253,20 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
         assertTrue(d1 != d2);
         assertTrue(d1.getClass() == d2.getClass());
         assertTrue(d1.equals(d2));
-        
+
         // check that the clone doesn't share the same underlying arrays.
         d1.setStartValue(0, "Category 1", new Double(0.99));
         assertFalse(d1.equals(d2));
         d2.setStartValue(0, "Category 1", new Double(0.99));
         assertTrue(d1.equals(d2));
     }
-    
+
     /**
      * A check to ensure that an empty dataset can be cloned.
      */
     public void testCloning2() {
-        DefaultIntervalCategoryDataset d1 
-                = new DefaultIntervalCategoryDataset(new double[0][0], 
+        DefaultIntervalCategoryDataset d1
+                = new DefaultIntervalCategoryDataset(new double[0][0],
                     new double[0][0]);
         DefaultIntervalCategoryDataset d2 = null;
         try {
@@ -269,7 +277,7 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
         }
         assertTrue(d1 != d2);
         assertTrue(d1.getClass() == d2.getClass());
-        assertTrue(d1.equals(d2));  
+        assertTrue(d1.equals(d2));
     }
 
     /**
@@ -283,11 +291,14 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
         double[][] starts = new double[][] {starts_S1, starts_S2};
         double[][] ends = new double[][] {ends_S1, ends_S2};
         DefaultIntervalCategoryDataset d1 = new DefaultIntervalCategoryDataset(
-                starts, ends);
+                new Comparable[] {"Series 1", "Series 2"},
+                new Comparable[] {"Category 1", "Category 2", "Category 3"},
+                DataUtilities.createNumberArray2D(starts),
+                DataUtilities.createNumberArray2D(ends));
         d1.setStartValue(0, "Category 2", new Double(99.9));
-        assertEquals(new Double(99.9), d1.getStartValue("Series 1", 
+        assertEquals(new Double(99.9), d1.getStartValue("Series 1",
                 "Category 2"));
-        
+
         boolean pass = false;
         try {
             d1.setStartValue(-1, "Category 2", new Double(99.9));
@@ -296,7 +307,7 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
             pass = true;
         }
         assertTrue(pass);
-        
+
         pass = false;
         try {
             d1.setStartValue(2, "Category 2", new Double(99.9));
@@ -306,7 +317,7 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
         }
         assertTrue(pass);
     }
-   
+
     /**
      * Some basic checks for the setEndValue() method.
      */
@@ -318,11 +329,14 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
         double[][] starts = new double[][] {starts_S1, starts_S2};
         double[][] ends = new double[][] {ends_S1, ends_S2};
         DefaultIntervalCategoryDataset d1 = new DefaultIntervalCategoryDataset(
-                starts, ends);
+                new Comparable[] {"Series 1", "Series 2"},
+                new Comparable[] {"Category 1", "Category 2", "Category 3"},
+                DataUtilities.createNumberArray2D(starts),
+                DataUtilities.createNumberArray2D(ends));
         d1.setEndValue(0, "Category 2", new Double(99.9));
-        assertEquals(new Double(99.9), d1.getEndValue("Series 1", 
+        assertEquals(new Double(99.9), d1.getEndValue("Series 1",
                 "Category 2"));
-        
+
         boolean pass = false;
         try {
             d1.setEndValue(-1, "Category 2", new Double(99.9));
@@ -331,7 +345,7 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
             pass = true;
         }
         assertTrue(pass);
-        
+
         pass = false;
         try {
             d1.setEndValue(2, "Category 2", new Double(99.9));
@@ -341,14 +355,14 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
         }
         assertTrue(pass);
     }
-    
+
     /**
      * Some checks for the getSeriesCount() method.
      */
     public void testGetSeriesCount() {
         // check an empty dataset
-        DefaultIntervalCategoryDataset empty 
-                = new DefaultIntervalCategoryDataset(new double[0][0], 
+        DefaultIntervalCategoryDataset empty
+                = new DefaultIntervalCategoryDataset(new double[0][0],
                         new double[0][0]);
         assertEquals(0, empty.getSeriesCount());
     }
@@ -358,30 +372,30 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
      */
     public void testGetCategoryCount() {
         // check an empty dataset
-        DefaultIntervalCategoryDataset empty 
-                = new DefaultIntervalCategoryDataset(new double[0][0], 
+        DefaultIntervalCategoryDataset empty
+                = new DefaultIntervalCategoryDataset(new double[0][0],
                         new double[0][0]);
         assertEquals(0, empty.getCategoryCount());
     }
-    
+
     /**
      * Some checks for the getSeriesIndex() method.
      */
     public void testGetSeriesIndex() {
         // check an empty dataset
-        DefaultIntervalCategoryDataset empty 
-                = new DefaultIntervalCategoryDataset(new double[0][0], 
+        DefaultIntervalCategoryDataset empty
+                = new DefaultIntervalCategoryDataset(new double[0][0],
                         new double[0][0]);
         assertEquals(-1, empty.getSeriesIndex("ABC"));
     }
-    
+
     /**
      * Some checks for the getRowIndex() method.
      */
     public void testGetRowIndex() {
         // check an empty dataset
-        DefaultIntervalCategoryDataset empty 
-                = new DefaultIntervalCategoryDataset(new double[0][0], 
+        DefaultIntervalCategoryDataset empty
+                = new DefaultIntervalCategoryDataset(new double[0][0],
                         new double[0][0]);
         assertEquals(-1, empty.getRowIndex("ABC"));
     }
@@ -391,8 +405,8 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
      */
     public void testSetSeriesKeys() {
         // check an empty dataset
-        DefaultIntervalCategoryDataset empty 
-                = new DefaultIntervalCategoryDataset(new double[0][0], 
+        DefaultIntervalCategoryDataset empty
+                = new DefaultIntervalCategoryDataset(new double[0][0],
                         new double[0][0]);
         boolean pass = true;
         try {
@@ -403,25 +417,25 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
         }
         assertTrue(pass);
     }
-    
+
     /**
      * Some checks for the getCategoryIndex() method.
      */
     public void testGetCategoryIndex() {
         // check an empty dataset
-        DefaultIntervalCategoryDataset empty 
-                = new DefaultIntervalCategoryDataset(new double[0][0], 
+        DefaultIntervalCategoryDataset empty
+                = new DefaultIntervalCategoryDataset(new double[0][0],
                         new double[0][0]);
         assertEquals(-1, empty.getCategoryIndex("ABC"));
     }
-    
+
     /**
      * Some checks for the getColumnIndex() method.
      */
     public void testGetColumnIndex() {
         // check an empty dataset
-        DefaultIntervalCategoryDataset empty 
-                = new DefaultIntervalCategoryDataset(new double[0][0], 
+        DefaultIntervalCategoryDataset empty
+                = new DefaultIntervalCategoryDataset(new double[0][0],
                         new double[0][0]);
         assertEquals(-1, empty.getColumnIndex("ABC"));
     }
@@ -431,8 +445,8 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
      */
     public void testSetCategoryKeys() {
         // check an empty dataset
-        DefaultIntervalCategoryDataset empty 
-                = new DefaultIntervalCategoryDataset(new double[0][0], 
+        DefaultIntervalCategoryDataset empty
+                = new DefaultIntervalCategoryDataset(new double[0][0],
                         new double[0][0]);
         boolean pass = true;
         try {
@@ -449,45 +463,45 @@ public class DefaultIntervalCategoryDatasetTests extends TestCase {
      */
     public void testGetColumnKeys() {
         // check an empty dataset
-        DefaultIntervalCategoryDataset empty 
-                = new DefaultIntervalCategoryDataset(new double[0][0], 
+        DefaultIntervalCategoryDataset empty
+                = new DefaultIntervalCategoryDataset(new double[0][0],
                         new double[0][0]);
         List keys = empty.getColumnKeys();
         assertEquals(0, keys.size());
     }
-    
+
     /**
      * Some checks for the getRowKeys() method.
      */
     public void testGetRowKeys() {
         // check an empty dataset
-        DefaultIntervalCategoryDataset empty 
-                = new DefaultIntervalCategoryDataset(new double[0][0], 
+        DefaultIntervalCategoryDataset empty
+                = new DefaultIntervalCategoryDataset(new double[0][0],
                         new double[0][0]);
         List keys = empty.getRowKeys();
         assertEquals(0, keys.size());
     }
-    
+
     /**
      * Some checks for the getColumnCount() method.
      */
     public void testGetColumnCount() {
         // check an empty dataset
-        DefaultIntervalCategoryDataset empty 
-                = new DefaultIntervalCategoryDataset(new double[0][0], 
+        DefaultIntervalCategoryDataset empty
+                = new DefaultIntervalCategoryDataset(new double[0][0],
                         new double[0][0]);
         assertEquals(0, empty.getColumnCount());
     }
-    
+
     /**
      * Some checks for the getRowCount() method.
      */
     public void testGetRowCount() {
         // check an empty dataset
-        DefaultIntervalCategoryDataset empty 
-                = new DefaultIntervalCategoryDataset(new double[0][0], 
+        DefaultIntervalCategoryDataset empty
+                = new DefaultIntervalCategoryDataset(new double[0][0],
                         new double[0][0]);
         assertEquals(0, empty.getColumnCount());
     }
-    
+
 }
