@@ -2,32 +2,32 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2008, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
- * This library is free software; you can redistribute it and/or modify it 
- * under the terms of the GNU Lesser General Public License as published by 
- * the Free Software Foundation; either version 2.1 of the License, or 
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
  * License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
- * USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+ * USA.
  *
- * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
+ * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
  * in the United States and other countries.]
  *
  * ------------------------------
  * TaskSeriesCollectionTests.java
  * ------------------------------
- * (C) Copyright 2004-2007, by Object Refinery Limited.
+ * (C) Copyright 2004-2008, by Object Refinery Limited.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   -;
@@ -84,7 +84,7 @@ public class TaskSeriesCollectionTests extends TestCase {
 
     /**
      * Creates a sample collection for testing purposes.
-     * 
+     *
      * @return A sample collection.
      */
     private TaskSeriesCollection createCollection1() {
@@ -98,10 +98,10 @@ public class TaskSeriesCollectionTests extends TestCase {
         result.add(s2);
         return result;
     }
-    
+
     /**
      * Creates a sample collection for testing purposes.
-     * 
+     *
      * @return A sample collection.
      */
     private TaskSeriesCollection createCollection2() {
@@ -127,14 +127,14 @@ public class TaskSeriesCollectionTests extends TestCase {
         result.add(s2);
         return result;
     }
-    
+
     /**
      * Creates a sample collection for testing purposes.
-     * 
+     *
      * @return A sample collection.
      */
     private TaskSeriesCollection createCollection3() {
-        
+
         // define subtasks
         Task sub1 = new Task("Sub1", new Date(11), new Date(111));
         Task sub2 = new Task("Sub2", new Date(22), new Date(222));
@@ -148,23 +148,23 @@ public class TaskSeriesCollectionTests extends TestCase {
         sub4.setPercentComplete(0.444);
         sub5.setPercentComplete(0.555);
         sub6.setPercentComplete(0.666);
-        
+
         TaskSeries seriesA = new TaskSeries("Series A");
-        Task taskA1 = new Task("Task 1", new SimpleTimePeriod(new Date(100), 
+        Task taskA1 = new Task("Task 1", new SimpleTimePeriod(new Date(100),
                 new Date(200)));
         taskA1.setPercentComplete(0.1);
         taskA1.addSubtask(sub1);
-        Task taskA2 = new Task("Task 2", new SimpleTimePeriod(new Date(220), 
+        Task taskA2 = new Task("Task 2", new SimpleTimePeriod(new Date(220),
                 new Date(350)));
         taskA2.setPercentComplete(0.2);
         taskA2.addSubtask(sub2);
         taskA2.addSubtask(sub3);
         seriesA.add(taskA1);
         seriesA.add(taskA2);
-         
+
         TaskSeries seriesB = new TaskSeries("Series B");
         // note that we don't define taskB1
-        Task taskB2 = new Task("Task 2", new SimpleTimePeriod(new Date(2220), 
+        Task taskB2 = new Task("Task 2", new SimpleTimePeriod(new Date(2220),
                 new Date(3350)));
         taskB2.setPercentComplete(0.3);
         taskB2.addSubtask(sub4);
@@ -174,11 +174,11 @@ public class TaskSeriesCollectionTests extends TestCase {
 
         TaskSeriesCollection tsc = new TaskSeriesCollection();
         tsc.add(seriesA);
-        tsc.add(seriesB);        
-        
+        tsc.add(seriesB);
+
         return tsc;
     }
-    
+
     /**
      * A test for the getSeriesCount() method.
      */
@@ -186,7 +186,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         TaskSeriesCollection c = createCollection1();
         assertEquals(2, c.getSeriesCount());
     }
-    
+
     /**
      * Some tests for the getSeriesKey() method.
      */
@@ -195,7 +195,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertEquals("S1", c.getSeriesKey(0));
         assertEquals("S2", c.getSeriesKey(1));
     }
-    
+
     /**
      * A test for the getRowCount() method.
      */
@@ -203,7 +203,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         TaskSeriesCollection c = createCollection1();
         assertEquals(2, c.getRowCount());
     }
-    
+
     /**
      * Some tests for the getRowKey() method.
      */
@@ -212,7 +212,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertEquals("S1", c.getRowKey(0));
         assertEquals("S2", c.getRowKey(1));
     }
-    
+
     /**
      * Some tests for the getRowIndex() method.
      */
@@ -221,7 +221,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertEquals(0, c.getRowIndex("S1"));
         assertEquals(1, c.getRowIndex("S2"));
     }
-    
+
     /**
      * Some tests for the getValue() method.
      */
@@ -230,7 +230,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertEquals(new Long(1L), c.getValue("S1", "Task 1"));
         assertEquals(new Long(3L), c.getValue("S1", "Task 2"));
         assertEquals(new Long(5L), c.getValue("S2", "Task 3"));
-        
+
         assertEquals(new Long(1L), c.getValue(0, 0));
         assertEquals(new Long(3L), c.getValue(0, 1));
         assertEquals(null, c.getValue(0, 2));
@@ -238,7 +238,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertEquals(null, c.getValue(1, 1));
         assertEquals(new Long(5L), c.getValue(1, 2));
     }
-    
+
     /**
      * Some tests for the getStartValue() method.
      */
@@ -247,14 +247,14 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertEquals(new Long(1L), c.getStartValue("S1", "Task 1"));
         assertEquals(new Long(3L), c.getStartValue("S1", "Task 2"));
         assertEquals(new Long(5L), c.getStartValue("S2", "Task 3"));
-        
+
         assertEquals(new Long(1L), c.getStartValue(0, 0));
         assertEquals(new Long(3L), c.getStartValue(0, 1));
         assertEquals(null, c.getStartValue(0, 2));
         assertEquals(null, c.getStartValue(1, 0));
         assertEquals(null, c.getStartValue(1, 1));
         assertEquals(new Long(5L), c.getStartValue(1, 2));
-        
+
         // test collection 3, which doesn't define all tasks in all series
         TaskSeriesCollection c3 = createCollection3();
         assertEquals(new Long(100), c3.getStartValue(0, 0));
@@ -262,7 +262,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertTrue(c3.getStartValue(1, 0) == null);
         assertEquals(new Long(2220), c3.getStartValue(1, 1));
     }
-    
+
     /**
      * Some tests for the getStartValue() method for sub-intervals.
      */
@@ -274,7 +274,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertEquals(new Long(36L), c.getStartValue("S1", "Task 2", 1));
         assertEquals(new Long(50L), c.getStartValue("S2", "Task 3", 0));
         assertEquals(new Long(56L), c.getStartValue("S2", "Task 3", 1));
-        
+
         assertEquals(new Long(10L), c.getStartValue(0, 0, 0));
         assertEquals(new Long(16L), c.getStartValue(0, 0, 1));
         assertEquals(new Long(30L), c.getStartValue(0, 1, 0));
@@ -291,7 +291,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertEquals(new Long(55), c3.getStartValue(1, 1, 1));
         assertEquals(new Long(66), c3.getStartValue(1, 1, 2));
     }
-    
+
     /**
      * A check for a null task duration.
      */
@@ -303,7 +303,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         Number millis = c.getStartValue("Series 1", "Task with null duration");
         assertTrue(millis == null);
     }
-    
+
     /**
      * Some tests for the getEndValue() method.
      */
@@ -312,14 +312,14 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertEquals(new Long(2L), c.getEndValue("S1", "Task 1"));
         assertEquals(new Long(4L), c.getEndValue("S1", "Task 2"));
         assertEquals(new Long(6L), c.getEndValue("S2", "Task 3"));
-        
+
         assertEquals(new Long(2L), c.getEndValue(0, 0));
         assertEquals(new Long(4L), c.getEndValue(0, 1));
         assertEquals(null, c.getEndValue(0, 2));
         assertEquals(null, c.getEndValue(1, 0));
         assertEquals(null, c.getEndValue(1, 1));
         assertEquals(new Long(6L), c.getEndValue(1, 2));
-        
+
         // test collection 3, which doesn't define all tasks in all series
         TaskSeriesCollection c3 = createCollection3();
         assertEquals(new Long(200), c3.getEndValue(0, 0));
@@ -327,7 +327,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertTrue(c3.getEndValue(1, 0) == null);
         assertEquals(new Long(3350), c3.getEndValue(1, 1));
     }
-    
+
     /**
      * Some tests for the getEndValue() method for sub-intervals.
      */
@@ -339,14 +339,14 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertEquals(new Long(40L), c.getEndValue("S1", "Task 2", 1));
         assertEquals(new Long(55L), c.getEndValue("S2", "Task 3", 0));
         assertEquals(new Long(60L), c.getEndValue("S2", "Task 3", 1));
-        
+
         assertEquals(new Long(15L), c.getEndValue(0, 0, 0));
         assertEquals(new Long(20L), c.getEndValue(0, 0, 1));
         assertEquals(new Long(35L), c.getEndValue(0, 1, 0));
         assertEquals(new Long(40L), c.getEndValue(0, 1, 1));
         assertEquals(new Long(55L), c.getEndValue(1, 2, 0));
         assertEquals(new Long(60L), c.getEndValue(1, 2, 1));
-        
+
         TaskSeriesCollection c3 = createCollection3();
         assertEquals(new Long(111), c3.getEndValue(0, 0, 0));
         assertEquals(new Long(222), c3.getEndValue(0, 1, 0));
@@ -356,7 +356,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertEquals(new Long(555), c3.getEndValue(1, 1, 1));
         assertEquals(new Long(666), c3.getEndValue(1, 1, 2));
     }
-    
+
     /**
      * A check for a null task duration.
      */
@@ -377,23 +377,23 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertEquals(new Double(0.10), c.getPercentComplete("S1", "Task 1"));
         assertEquals(new Double(0.20), c.getPercentComplete("S1", "Task 2"));
         assertEquals(new Double(0.30), c.getPercentComplete("S2", "Task 3"));
-        
+
         assertEquals(new Double(0.10), c.getPercentComplete(0, 0));
         assertEquals(new Double(0.20), c.getPercentComplete(0, 1));
         assertEquals(null, c.getPercentComplete(0, 2));
         assertEquals(null, c.getPercentComplete(1, 0));
         assertEquals(null, c.getPercentComplete(1, 1));
         assertEquals(new Double(0.30), c.getPercentComplete(1, 2));
-        
+
         // test collection 3, which doesn't define all tasks in all series
         TaskSeriesCollection c3 = createCollection3();
         assertEquals(new Double(0.1), c3.getPercentComplete(0, 0));
         assertEquals(new Double(0.2), c3.getPercentComplete(0, 1));
         assertTrue(c3.getPercentComplete(1, 0) == null);
         assertEquals(new Double(0.3), c3.getPercentComplete(1, 1));
-        
+
         assertEquals(new Double(0.111), c3.getPercentComplete(0, 0, 0));
- 
+
         assertEquals(new Double(0.222), c3.getPercentComplete(0, 1, 0));
         assertEquals(new Double(0.333), c3.getPercentComplete(0, 1, 1));
 
@@ -408,7 +408,7 @@ public class TaskSeriesCollectionTests extends TestCase {
     public void testGetColumnCount() {
         TaskSeriesCollection c = createCollection1();
         assertEquals(3, c.getColumnCount());
-    }  
+    }
 
     /**
      * Some tests for the getColumnKey() method.
@@ -419,7 +419,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertEquals("Task 2", c.getColumnKey(1));
         assertEquals("Task 3", c.getColumnKey(2));
     }
-    
+
     /**
      * Some tests for the getColumnIndex() method.
      */
@@ -429,12 +429,12 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertEquals(1, c.getColumnIndex("Task 2"));
         assertEquals(2, c.getColumnIndex("Task 3"));
     }
-    
+
     /**
      * Confirm that the equals method can distinguish all the required fields.
      */
     public void testEquals() {
-        
+
         TaskSeries s1 = new TaskSeries("S");
         s1.add(new Task("T1", new Date(1), new Date(2)));
         s1.add(new Task("T2", new Date(11), new Date(22)));
@@ -444,7 +444,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         TaskSeriesCollection c1 = new TaskSeriesCollection();
         c1.add(s1);
         c1.add(s2);
-        
+
         TaskSeries s1b = new TaskSeries("S");
         s1b.add(new Task("T1", new Date(1), new Date(2)));
         s1b.add(new Task("T2", new Date(11), new Date(22)));
@@ -454,7 +454,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         TaskSeriesCollection c2 = new TaskSeriesCollection();
         c2.add(s1b);
         c2.add(s2b);
-        
+
         assertTrue(c1.equals(c2));
         assertTrue(c2.equals(c1));
 
@@ -464,12 +464,12 @@ public class TaskSeriesCollectionTests extends TestCase {
      * Confirm that cloning works.
      */
     public void testCloning() {
-        TaskSeries s1 = new TaskSeries("S");
+        TaskSeries s1 = new TaskSeries("S1");
         s1.add(new Task("T1", new Date(1), new Date(2)));
         s1.add(new Task("T2", new Date(11), new Date(22)));
-        TaskSeries s2 = new TaskSeries("S");
-        s2.add(new Task("T1", new Date(1), new Date(2)));
-        s2.add(new Task("T2", new Date(11), new Date(22)));
+        TaskSeries s2 = new TaskSeries("S2");
+        s2.add(new Task("T1", new Date(33), new Date(44)));
+        s2.add(new Task("T2", new Date(55), new Date(66)));
         TaskSeriesCollection c1 = new TaskSeriesCollection();
         c1.add(s1);
         c1.add(s2);
@@ -479,11 +479,19 @@ public class TaskSeriesCollectionTests extends TestCase {
             c2 = (TaskSeriesCollection) c1.clone();
         }
         catch (CloneNotSupportedException e) {
-            System.err.println("Failed to clone.");
+            e.printStackTrace();
         }
         assertTrue(c1 != c2);
         assertTrue(c1.getClass() == c2.getClass());
         assertTrue(c1.equals(c2));
+
+        // basic check for independence
+        s1.add(new Task("T3", new Date(21), new Date(33)));
+        assertFalse(c1.equals(c2));
+        TaskSeries series = c2.getSeries("S1");
+        series.add(new Task("T3", new Date(21), new Date(33)));
+        assertTrue(c1.equals(c2));
+
     }
 
     /**
@@ -526,19 +534,19 @@ public class TaskSeriesCollectionTests extends TestCase {
     public void test697153() {
 
         TaskSeries s1 = new TaskSeries("S1");
-        s1.add(new Task("Task 1", new SimpleTimePeriod(new Date(), 
+        s1.add(new Task("Task 1", new SimpleTimePeriod(new Date(),
                 new Date())));
-        s1.add(new Task("Task 2", new SimpleTimePeriod(new Date(), 
+        s1.add(new Task("Task 2", new SimpleTimePeriod(new Date(),
                 new Date())));
-        s1.add(new Task("Task 3", new SimpleTimePeriod(new Date(), 
+        s1.add(new Task("Task 3", new SimpleTimePeriod(new Date(),
                 new Date())));
 
         TaskSeries s2 = new TaskSeries("S2");
-        s2.add(new Task("Task 2", new SimpleTimePeriod(new Date(), 
+        s2.add(new Task("Task 2", new SimpleTimePeriod(new Date(),
                 new Date())));
-        s2.add(new Task("Task 3", new SimpleTimePeriod(new Date(), 
+        s2.add(new Task("Task 3", new SimpleTimePeriod(new Date(),
                 new Date())));
-        s2.add(new Task("Task 4", new SimpleTimePeriod(new Date(), 
+        s2.add(new Task("Task 4", new SimpleTimePeriod(new Date(),
                 new Date())));
 
         TaskSeriesCollection tsc = new TaskSeriesCollection();
@@ -558,46 +566,46 @@ public class TaskSeriesCollectionTests extends TestCase {
      */
     public void test800324() {
         TaskSeries s1 = new TaskSeries("S1");
-        s1.add(new Task("Task 1", new SimpleTimePeriod(new Date(), 
+        s1.add(new Task("Task 1", new SimpleTimePeriod(new Date(),
                 new Date())));
-        s1.add(new Task("Task 2", new SimpleTimePeriod(new Date(), 
+        s1.add(new Task("Task 2", new SimpleTimePeriod(new Date(),
                 new Date())));
-        s1.add(new Task("Task 3", new SimpleTimePeriod(new Date(), 
+        s1.add(new Task("Task 3", new SimpleTimePeriod(new Date(),
                 new Date())));
-                
+
         TaskSeriesCollection tsc = new TaskSeriesCollection();
         tsc.add(s1);
 
-        // these methods should throw an IndexOutOfBoundsException since the 
+        // these methods should throw an IndexOutOfBoundsException since the
         // column is too high...
         try {
             /* Number start = */ tsc.getStartValue(0, 3);
             assertTrue(false);
         }
         catch (IndexOutOfBoundsException e) {
-            // expected 
+            // expected
         }
         try {
             /* Number end = */ tsc.getEndValue(0, 3);
             assertTrue(false);
         }
         catch (IndexOutOfBoundsException e) {
-            // expected 
+            // expected
         }
         try {
             /* int count = */ tsc.getSubIntervalCount(0, 3);
             assertTrue(false);
         }
         catch (IndexOutOfBoundsException e) {
-            // expected 
+            // expected
         }
     }
-    
+
     /**
-     * Some tests for the bug report 1099331.  We create a TaskSeriesCollection 
-     * with two series - the first series has two tasks, but the second has 
-     * only one.  The key is to ensure that the methods in TaskSeriesCollection 
-     * translate the index values to key values *before* accessing the tasks 
+     * Some tests for the bug report 1099331.  We create a TaskSeriesCollection
+     * with two series - the first series has two tasks, but the second has
+     * only one.  The key is to ensure that the methods in TaskSeriesCollection
+     * translate the index values to key values *before* accessing the tasks
      * in the series.
      */
     public void testGetSubIntervalCount() {
@@ -607,7 +615,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         assertEquals(0, tsc.getSubIntervalCount(1, 0));
         assertEquals(3, tsc.getSubIntervalCount(1, 1));
     }
-    
+
     /**
      * Some basic tests for the getSeries() methods.
      */
@@ -616,15 +624,15 @@ public class TaskSeriesCollectionTests extends TestCase {
         TaskSeries s2 = new TaskSeries("S2");
         TaskSeriesCollection c = new TaskSeriesCollection();
         c.add(s1);
-        
+
         assertEquals(c.getSeries(0), s1);
         assertEquals(c.getSeries("S1"), s1);
         assertEquals(c.getSeries("XX"), null);
-        
+
         c.add(s2);
         assertEquals(c.getSeries(1), s2);
         assertEquals(c.getSeries("S2"), s2);
-        
+
         boolean pass = false;
         try {
             c.getSeries(null);
@@ -634,7 +642,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         }
         assertTrue(pass);
     }
-    
+
     /**
      * Some basic checks for the remove() method.
      */
@@ -646,7 +654,7 @@ public class TaskSeriesCollectionTests extends TestCase {
         c.remove(0);
         assertEquals(0, c.getSeriesCount());
         c.add(s1);
-        
+
         boolean pass = false;
         try {
             c.remove(-1);
@@ -655,7 +663,7 @@ public class TaskSeriesCollectionTests extends TestCase {
             pass = true;
         }
         assertTrue(pass);
-        
+
         pass = false;
         try {
             c.remove(1);
@@ -665,5 +673,5 @@ public class TaskSeriesCollectionTests extends TestCase {
         }
         assertTrue(pass);
     }
-    
+
 }
